/*
	description:

		"C declarations for the Gobo Eiffel runtime."

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2005-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_EIFFEL_H
#define GE_EIFFEL_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

/* Class name mapping as defined in the FreeELKS library. */
#ifndef EIF_INTEGER
#define EIF_INTEGER EIF_INTEGER_32
#endif
#ifndef EIF_CHARACTER
#define EIF_CHARACTER EIF_CHARACTER_8
#endif
#ifndef EIF_REAL
#define EIF_REAL EIF_REAL_32
#endif
#ifndef EIF_DOUBLE
#define EIF_DOUBLE EIF_REAL_64
#endif
#ifndef GE_ms
#define GE_ms(s,c) GE_ms8((s),(c))
#endif

#if defined(__USE_POSIX) || defined(__unix__) || defined(_POSIX_C_SOURCE)
#include <unistd.h>
#endif
#if !defined(WIN32) && \
	(defined(WINVER) || defined(_WIN32_WINNT) || defined(_WIN32) || \
	defined(__WIN32__) || defined(__TOS_WIN__) || defined(_MSC_VER) || \
	defined(__MINGW32__))
#define WIN32 1
#endif
#ifdef WIN32
#define EIF_WINDOWS 1
#include <windows.h>
#endif

#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <stddef.h>

/* Platform definition */
/* Unix definition */
#define EIF_IS_UNIX EIF_TRUE
/* Windows definition */
#ifdef EIF_WINDOWS
#define EIF_IS_WINDOWS EIF_TRUE
#undef EIF_IS_UNIX
#define EIF_IS_UNIX EIF_FALSE
#else
#define EIF_IS_WINDOWS EIF_FALSE
#endif
/* VMS definition */
#ifdef EIF_VMS
#define EIF_IS_VMS EIF_TRUE
#undef EIF_IS_UNIX
#define EIF_IS_UNIX EIF_FALSE
#else
#define EIF_IS_VMS EIF_FALSE
#endif
/* MAC definition */
#ifdef EIF_MAC
#define EIF_IS_MAC EIF_TRUE
#undef EIF_IS_UNIX
#define EIF_IS_UNIX EIF_FALSE
#else
#define EIF_IS_MAC EIF_FALSE
#endif
/* VxWorks definition */
#ifdef EIF_VXWORKS
#define EIF_IS_VXWORKS EIF_TRUE
#undef EIF_IS_UNIX
#define EIF_IS_UNIX EIF_FALSE
#else
#define EIF_IS_VXWORKS EIF_FALSE
#endif

#ifdef __cplusplus
extern "C" {
#endif

#ifdef _MSC_VER /* MSVC */
typedef signed char int8_t;
typedef signed short int16_t;
typedef signed int int32_t;
typedef signed __int64 int64_t;
typedef unsigned char uint8_t;
typedef unsigned short uint16_t;
typedef unsigned int uint32_t;
typedef unsigned __int64 uint64_t;
#else
#if defined (__BORLANDC__) && (__BORLANDC__ < 0x600) /* Borland before 6.0 */
typedef signed char int8_t;
typedef signed short int16_t;
typedef signed long int int32_t;
typedef signed __int64 int64_t;
typedef unsigned char uint8_t;
typedef unsigned short uint16_t;
typedef unsigned long int uint32_t;
typedef unsigned __int64 uint64_t;
#else
#include <inttypes.h>
#endif
#endif

/* Portable integer pointers */
#ifdef EIF_WINDOWS
#ifndef _INTPTR_T_DEFINED
#define _INTPTR_T_DEFINED
#ifdef _WIN64
typedef __int64 intptr_t;
#else
typedef int intptr_t;
#endif
#endif
#ifndef _UINTPTR_T_DEFINED
#define _UINTPTR_T_DEFINED
#ifdef _WIN64
  typedef unsigned __int64 uintptr_t;
#else
  typedef unsigned int uintptr_t;
#endif
#endif
#endif

/* C type for underlying integer type identifying object's dynamic type. */
typedef uint16_t EIF_TYPE_INDEX;

/*
 * Abstraction representing an Eiffel type.
 * It is made of a compiler type-id,
 * and of some annotations (attached/detachable/separate/variant/frozen).
 */
typedef struct eif_type {
	EIF_TYPE_INDEX id;
	EIF_TYPE_INDEX annotations;
} EIF_TYPE;

/*
 * Since EIF_TYPE and EIF_ENCODED_TYPE have the same size, the encoded version
 * is basically a memcpy version of the EIF_TYPE representation.
 * It is used to provide backward compatibility to most Eiffel and
 * C APIs manipulating types as an INTEGER.
 */
typedef int32_t EIF_ENCODED_TYPE;
typedef EIF_ENCODED_TYPE EIF_TYPE_ID;
#define EIF_NO_TYPE (EIF_TYPE_ID)(-1)

/* Basic Eiffel types */
typedef char EIF_BOOLEAN;
typedef unsigned char EIF_CHARACTER_8;
typedef uint32_t EIF_CHARACTER_32;
typedef int8_t EIF_INTEGER_8;
typedef int16_t EIF_INTEGER_16;
typedef int32_t EIF_INTEGER_32;
typedef int64_t EIF_INTEGER_64;
typedef uint8_t EIF_NATURAL_8;
typedef uint16_t EIF_NATURAL_16;
typedef uint32_t EIF_NATURAL_32;
typedef uint64_t EIF_NATURAL_64;
typedef void* EIF_POINTER;
typedef float EIF_REAL_32;
typedef double EIF_REAL_64;
typedef struct {EIF_TYPE_INDEX id; uint16_t flags;} EIF_ANY;
typedef EIF_ANY* EIF_REFERENCE;
typedef struct {EIF_TYPE_INDEX id; uint16_t flags; EIF_REFERENCE area; EIF_INTEGER count;} EIF_STRING;
typedef struct {EIF_TYPE_INDEX id; uint16_t flags; uint32_t offset; EIF_INTEGER count; EIF_INTEGER capacity;} EIF_SPECIAL;

#ifdef EIF_WINDOWS
typedef wchar_t EIF_NATIVE_CHAR;
#else
typedef char EIF_NATIVE_CHAR;
#endif
typedef EIF_NATIVE_CHAR* EIF_FILENAME;

#define EIF_VOID ((EIF_REFERENCE)0)
#define EIF_FALSE ((EIF_BOOLEAN)'\0')
#define EIF_TRUE ((EIF_BOOLEAN)'\1')
#define EIF_TEST(x) ((x) ? EIF_TRUE : EIF_FALSE)

#define EIF_IS_WORKBENCH EIF_FALSE
#define EIF_POINTER_DISPLAY "lX"

/* For INTEGER and NATURAL manifest constants */
#define GE_int8(x) x
#define GE_nat8(x) x
#define GE_int16(x) x
#define GE_nat16(x) x
#define GE_int32(x) x##L
#define GE_nat32(x) x##U
#if defined (_MSC_VER) && (_MSC_VER < 1400) /* MSC older than v8 */
#define GE_int64(x) x##i64
#define GE_nat64(x) x##ui64
#else
#if defined (__BORLANDC__) && (__BORLANDC__ < 0x600) /* Borland before 6.0 */
#define GE_int64(x) x##i64
#define GE_nat64(x) x##ui64
#else /* ISO C 99 */
#define GE_int64(x) x##LL
#define GE_nat64(x) x##ULL
#endif
#endif

#ifdef _WIN64
#define GE_IS_64_BITS EIF_TRUE
#else
#define GE_IS_64_BITS EIF_TEST(sizeof(void*)==64)
#endif

#ifdef _MSC_VER /* MSVC */
/* MSVC does not support ISO C 99's 'snprintf' from stdio.h */
#define snprintf(a,b,c,d) sprintf(a,c,d)
#endif

/*
 * Gobo compiler version.
 * Starts with 6080 (looks like GOBO) followed by 5 digits.
 */
#define GE_compiler_version() 608000001

/*
	Interoperability with ISE.
*/
#define RTI64C(x) GE_int64(x)
#define EIF_OBJECT EIF_REFERENCE
#define EIF_OBJ EIF_OBJECT
/* Function pointer call to make sure all arguments are correctly pushed onto stack. */
/* FUNCTION_CAST is for standard C calls. */
/* FUNCTION_CAST_TYPE is for non-standard C calls. */
#define FUNCTION_CAST(r_type,arg_types) (r_type (*) arg_types)
#define FUNCTION_CAST_TYPE(r_type,call_type,arg_types) (r_type (call_type *) arg_types)
#define SIGBLOCK
#define SIGRESUME
#define rt_public				/* default C scope */
#define rt_private static		/* static outside a block means private */
#define rt_shared				/* data shared between modules, but not public */
typedef intptr_t rt_int_ptr;
typedef uintptr_t rt_uint_ptr;
#define RTMS(s) GE_str8(s)
#define RTMS_EX(s,c) GE_ms8((s),(c))

#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to implement once features"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_ONCE_H
#define GE_ONCE_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Struct to keep track of the call status
 * and results of once features.
 */
typedef struct {
	EIF_BOOLEAN* boolean_value;
	EIF_REFERENCE* boolean_exception;
	unsigned char* boolean_status;
	unsigned int boolean_count;
	EIF_CHARACTER_8* character_8_value;
	EIF_REFERENCE* character_8_exception;
	unsigned char* character_8_status;
	unsigned int character_8_count;
	EIF_CHARACTER_32* character_32_value;
	EIF_REFERENCE* character_32_exception;
	unsigned char* character_32_status;
	unsigned int character_32_count;
	EIF_INTEGER_8* integer_8_value;
	EIF_REFERENCE* integer_8_exception;
	unsigned char* integer_8_status;
	unsigned int integer_8_count;
	EIF_INTEGER_16* integer_16_value;
	EIF_REFERENCE* integer_16_exception;
	unsigned char* integer_16_status;
	unsigned int integer_16_count;
	EIF_INTEGER_32* integer_32_value;
	EIF_REFERENCE* integer_32_exception;
	unsigned char* integer_32_status;
	unsigned int integer_32_count;
	EIF_INTEGER_64* integer_64_value;
	EIF_REFERENCE* integer_64_exception;
	unsigned char* integer_64_status;
	unsigned int integer_64_count;
	EIF_NATURAL_8* natural_8_value;
	EIF_REFERENCE* natural_8_exception;
	unsigned char* natural_8_status;
	unsigned int natural_8_count;
	EIF_NATURAL_16* natural_16_value;
	EIF_REFERENCE* natural_16_exception;
	unsigned char* natural_16_status;
	unsigned int natural_16_count;
	EIF_NATURAL_32* natural_32_value;
	EIF_REFERENCE* natural_32_exception;
	unsigned char* natural_32_status;
	unsigned int natural_32_count;
	EIF_NATURAL_64* natural_64_value;
	EIF_REFERENCE* natural_64_exception;
	unsigned char* natural_64_status;
	unsigned int natural_64_count;
	EIF_POINTER* pointer_value;
	EIF_REFERENCE* pointer_exception;
	unsigned char* pointer_status;
	unsigned int pointer_count;
	EIF_REAL_32* real_32_value;
	EIF_REFERENCE* real_32_exception;
	unsigned char* real_32_status;
	unsigned int real_32_count;
	EIF_REAL_64* real_64_value;
	EIF_REFERENCE* real_64_exception;
	unsigned char* real_64_status;
	unsigned int real_64_count;
	EIF_REFERENCE* reference_value;
	EIF_REFERENCE* reference_exception;
	unsigned char* reference_status;
	unsigned int reference_count;
	EIF_REFERENCE* procedure_exception;
	unsigned char* procedure_status;
	unsigned int procedure_count;
} GE_onces;

/*
 * Variable to keep track of the call status
 * and results of once-per-process features.
 */
extern GE_onces* GE_process_onces;

/*
 * Initialize `GE_process_onces'.
 */
extern void GE_init_onces(
	unsigned int a_boolean_count,
	unsigned int a_character_8_count,
	unsigned int a_character_32_count,
	unsigned int a_integer_8_count,
	unsigned int a_integer_16_count,
	unsigned int a_integer_32_count,
	unsigned int a_integer_64_count,
	unsigned int a_natural_8_count,
	unsigned int a_natural_16_count,
	unsigned int a_natural_32_count,
	unsigned int a_natural_64_count,
	unsigned int a_pointer_count,
	unsigned int a_real_32_count,
	unsigned int a_real_64_count,
	unsigned int a_reference_count,
	unsigned int a_procedure_count);

/*
 * Create a new 'GE_onces' struct which can deal with the
 * numbers of once features passed as argument.
 */
extern GE_onces* GE_new_onces(
	unsigned int a_boolean_count,
	unsigned int a_character_8_count,
	unsigned int a_character_32_count,
	unsigned int a_integer_8_count,
	unsigned int a_integer_16_count,
	unsigned int a_integer_32_count,
	unsigned int a_integer_64_count,
	unsigned int a_natural_8_count,
	unsigned int a_natural_16_count,
	unsigned int a_natural_32_count,
	unsigned int a_natural_64_count,
	unsigned int a_pointer_count,
	unsigned int a_real_32_count,
	unsigned int a_real_64_count,
	unsigned int a_reference_count,
	unsigned int a_procedure_count);

/*
 * Free memory allocated by `a_onces'.
 */
extern void GE_free_onces(GE_onces* a_onces);

#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to implement class EXCEPTION"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2007-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_EXCEPTION_H
#define GE_EXCEPTION_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif
#ifndef GE_ONCE_H
#include "ge_once.h"
#endif
#ifdef GE_USE_THREADS
#ifndef GE_THREAD_TYPES_H
#include "ge_thread_types.h"
#endif
#endif

#include <setjmp.h>

/*
 * On Linux glibc systems, we need to use sig* versions of jmp_buf,
 * setjmp and longjmp to preserve the signal handling context.
 * One way to detect this is if _SIGSET_H_types has
 * been defined in /usr/include/setjmp.h.
 * NOTE: ANSI only recognizes the non-sig versions.
 */
#if (defined(_SIGSET_H_types) && !defined(__STRICT_ANSI__))
#define GE_jmp_buf sigjmp_buf
#define GE_setjmp(x) sigsetjmp((x),1)
#define GE_longjmp(x,y) siglongjmp((x),(y))
#else
#define GE_jmp_buf jmp_buf
#define GE_setjmp(x) setjmp((x))
#define GE_longjmp(x,y) longjmp((x),(y))
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Predefined exception codes.
 */
#define GE_EX_VOID		1			/* Feature applied to void reference */
#define GE_EX_MEM		2			/* No more memory */
#define GE_EX_PRE		3			/* Pre-condition violated */
#define GE_EX_POST		4			/* Post-condition violated */
#define GE_EX_FLOAT		5			/* Floating point exception (signal SIGFPE) */
#define GE_EX_CINV		6			/* Class invariant violated */
#define GE_EX_CHECK		7			/* Check instruction violated */
#define GE_EX_FAIL		8			/* Routine failure */
#define GE_EX_WHEN		9			/* Unmatched inspect value */
#define GE_EX_VAR		10			/* Non-decreasing loop variant */
#define GE_EX_LINV		11			/* Loop invariant violated */
#define GE_EX_SIG		12			/* Operating system signal */
#define GE_EX_BYE		13			/* Eiffel run-time panic */
#define GE_EX_RESC		14			/* Exception in rescue clause */
#define GE_EX_OMEM		15			/* Out of memory (cannot be ignored) */
#define GE_EX_RES		16			/* Resumption failed (retry did not succeed) */
#define GE_EX_CDEF		17			/* Create on deferred */
#define GE_EX_EXT		18			/* External event */
#define GE_EX_VEXP		19			/* Void assigned to expanded */
#define GE_EX_HDLR		20			/* Exception in signal handler */
#define GE_EX_IO		21			/* I/O error */
#define GE_EX_SYS		22			/* Operating system error */
#define GE_EX_RETR		23			/* Retrieval error */
#define GE_EX_PROG		24			/* Developer exception */
#define GE_EX_FATAL		25			/* Eiffel run-time fatal error */
#define GE_EX_DOL		26			/* $ applied to melted feature */
#define GE_EX_ISE_IO	27			/* I/O error raised by the ISE Eiffel runtime */
#define GE_EX_COM		28			/* COM error raised by EiffelCOM runtime */
#define GE_EX_RT_CHECK	29			/* Runtime check error such as out-of-bound array access */
#define GE_EX_OLD		30			/* Old violation */
#define GE_EX_SEL		31			/* Serialization failure */
#define GE_EX_DIRTY		32			/* SCOOP processor dirty exception. */
#define GE_EX_NEX		32			/* Number of internal exceptions */

/*
 * String buffer used to build the exception trace.
 */
typedef struct GE_exception_trace_buffer_struct GE_exception_trace_buffer;
struct GE_exception_trace_buffer_struct {
	char* area;
	uint32_t count;
	uint32_t capacity;
};

/*
 * Information about the feature being executed.
 */
typedef struct GE_call_struct GE_call;
struct GE_call_struct {
#ifdef GE_USE_CURRENT_IN_EXCEPTION_TRACE
	void* object; /* Current object */
#endif
	const char* class_name;
	const char* feature_name;
	GE_call* caller; /* previous feature in the call chain */
};

/*
 * Context of features containing a rescue clause.
 */
typedef struct GE_rescue_struct GE_rescue;
struct GE_rescue_struct {
	GE_jmp_buf jb;
	GE_rescue* previous; /* previous context in the call chain */
};

/*
 * Information about the execution context.
 * One such struct per thread.
 */
typedef struct GE_context_struct GE_context;
struct GE_context_struct {
	GE_call* call; /* Call stack */
	uint32_t in_assertion; /* Is an assertion evaluated? */
	GE_rescue* last_rescue; /* Context of last feature entered containing a rescue clause */
	uint32_t in_rescue; /* Number of rescue clauses currently being executed */
	EIF_REFERENCE exception_manager; /* Exception manager */
	char raising_exception; /* Is an exception currently being raised? */
	char exception_trace_enabled; /* Should exception trace be displayed? */
	long exception_code; /* Code of the exception currently being raised, 0 otherwise */
	const char* exception_tag; /* Tag of the exception currently being raised, NULL otherwise */
	GE_exception_trace_buffer exception_trace_buffer; /* String buffer used to build the exception trace */
	GE_exception_trace_buffer last_exception_trace; /* Last non-routine-failure exception trace */
	int pre_ecma_mapping_status; /* Do we map old names to new name? (i.e. STRING to STRING_8, INTEGER to INTEGER_32, ...). */
#ifdef GE_USE_THREADS
	GE_thread_context* thread; /* Thread context */
	GE_onces* process_onces; /* Cache for status and results of onces-per-process */
	GE_onces* thread_onces; /* Status and results of onces-per-thread */
	void* wel_per_thread_data; /* WEL private data */
#endif
};

/*
 * Default initialization for `GE_context'.
 */
extern GE_context GE_default_context;

/*
 * Execution context of main thread.
 */
extern GE_context* GE_main_context;

/*
 * Execution context of current thread.
 */
extern GE_context* GE_current_context();

/*
 * Initialization of exception handling.
 */
extern void GE_init_exception(GE_context* context);

/*
 * Free memory allocated in `a_context' for exception handling.
 */
extern void GE_free_exception(GE_context* a_context);

/*
 * Pointer to function to create a new exception manager object
 * (of type ISE_EXCEPTION_MANAGER).
 */
extern EIF_REFERENCE (*GE_new_exception_manager)(EIF_BOOLEAN);

/*
 * Pointer to Eiffel routine ISE_EXCEPTION_MANAGER.init_exception_manager.
 */
extern void (*GE_init_exception_manager)(GE_context*, EIF_REFERENCE);

/*
 * Pointer to Eiffel routine ISE_EXCEPTION_MANAGER.last_exception.
 */
extern EIF_REFERENCE (*GE_last_exception)(GE_context*, EIF_REFERENCE);

/*
 * Pointer to Eiffel routine ISE_EXCEPTION_MANAGER.once_raise.
 */
extern void (*GE_once_raise)(GE_context*, EIF_REFERENCE, EIF_REFERENCE);

/*
 * Pointer to Eiffel routine ISE_EXCEPTION_MANAGER.set_exception_data.
 */
extern void (*GE_set_exception_data)(GE_context*, EIF_REFERENCE, EIF_INTEGER_32, EIF_BOOLEAN, EIF_INTEGER_32, EIF_INTEGER_32, EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32, EIF_BOOLEAN);

/*
 * Exception tag associated with `a_code'.
 */
extern char* GE_exception_tag(long a_code);

/*
 * Raise an exception with code `a_code'.
 */
extern void GE_raise(long a_code);

/*
 * Raise an exception with code `a_code' and message `msg'.
 */
extern void GE_raise_with_message(long a_code, const char* msg);

/*
 * Raise an exception from EXCEPTION_MANAGER.
 */
extern void GE_developer_raise(long a_code, char* a_meaning, char* a_message);

/*
 * Raise exception which was raised the first time a once routine
 * was executed when executing it again.
 */
extern void GE_raise_once_exception(GE_context* a_context, EIF_REFERENCE a_exception);

/*
 * Exception, if any, which was last raised in `a_context'.
 */
extern EIF_REFERENCE GE_last_exception_raised(GE_context* a_context);

/*
 * Jump to execute the rescue of the last routine with a rescue
 * in the call stack.
 */
extern void GE_jump_to_last_rescue(GE_context* a_context);

/*
 * Set `in_assertion' to 'not b'.
 * Return the opposite of previous value.
 */
extern EIF_BOOLEAN GE_check_assert(EIF_BOOLEAN b);

/*
 * Check whether the type id of `obj' is not in `type_ids'.
 * If it is, then raise a CAT-call exception. Don't do anything if `obj' is Void.
 * `nb' is the number of ids in `type_ids' and is expected to be >0.
 * `type_ids' is sorted in increasing order.
 * Return `obj'.
 */
#define GE_catcall(obj,type_ids,nb) GE_check_catcall((obj),(type_ids),(nb))
extern EIF_REFERENCE GE_check_catcall(EIF_REFERENCE obj, EIF_TYPE_INDEX type_ids[], int nb);

/*
 * Check whether `obj' is Void.
 * If it is, then raise a call-on-void-target exception.
 * Return `obj'.
 */
#define GE_void(obj) (!(obj)?GE_check_void(obj):(obj))
extern EIF_REFERENCE GE_check_void(EIF_REFERENCE obj);

/*
 * Check whether `ptr' is a null pointer.
 * If it is, then raise a no-more-memory exception.
 * Return `ptr'.
 */
#define GE_null(ptr) GE_check_null(ptr)
extern void* GE_check_null(void* ptr);

#ifdef EIF_WINDOWS
/*
 * Set default exception handler.
 */
extern void GE_set_windows_exception_filter();
#endif

#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to manipulate native strings"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2013-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_NATIVE_STRING_H
#define GE_NATIVE_STRING_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#include <string.h>
#ifndef EIF_WINDOWS
#include <sys/types.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#ifdef EIF_WINDOWS

/* Macro used to manipulate native strings, i.e: (wchar_t*) */
#define GE_nstrlen wcslen /* size of string */
#define GE_nstrncpy wcsncpy /* Copy n characters of one string to another */
#define GE_nstrcpy wcscpy /* Copy one string to another */
#define GE_nstrncat wcsncat /* Append characters of a string */
#define GE_nstrcat wcscat /* Append a string */
#define GE_nstrstr wcsstr /* Return a pointer to the first occurrence of a search string in a string. */
#define GE_nmakestr(quote) L##quote /* Manifest Native string declaration */
#define GE_nstr_fopen _wfopen /* Open file using native string name */
#define GE_nstrcmp wcscmp /* Compare two strings. */
#define GE_nstrdup _wcsdup /* Duplicate string. */
#define GE_nstr_cat_ascii(dest, src) {							\
		int i;													\
		size_t dest_len, src_len;								\
		dest_len = rt_nstrlen (dest);							\
		src_len = strlen (src);									\
		for (i = 0; i < src_len; i++) {							\
			dest[dest_len + i] = (EIF_NATIVE_CHAR)src[i];		\
		}														\
		dest[dest_len + src_len] = (EIF_NATIVE_CHAR)0;			\
	}

#else /* not EIF_WINDOWS */

/* Macro used to manipulate native strings, i.e: (char*) */
#define GE_nstrlen strlen /* size of string */
#define GE_nstrncpy strncpy /* Copy n characters of one string to another */
#define GE_nstrcpy strcpy /* Copy one string to another */
#define GE_nstrncat strncat /* Append characters of a string */
#define GE_nstrcat strcat /* Append a string */
#define GE_nstrstr strstr /* Return a pointer to the first occurrence of a search string in a string. */
#define GE_nmakestr(quote) quote /* Manifest Native string declaration */
#define GE_nstr_fopen fopen /* Open file using native string name */
#define GE_nstrcmp strcmp /* Compare two strings. */
#define GE_nstrdup strdup /* Duplicate string. */
#define GE_nstr_cat_ascii strcat

#endif


#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to implement class ARGUMENTS"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2007-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_ARGUMENTS_H
#define GE_ARGUMENTS_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

extern int GE_argc;
extern EIF_NATIVE_CHAR** GE_argv;

#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to implement type information"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2016-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_TYPES_H
#define GE_TYPES_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif
#ifndef GE_EXCEPTION_H
#include "ge_exception.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Type annotations.
 * When a type has no annotation, it means a detachable, non-separate, variant type.
 * In all other cases, there will be an annotation.
 */
#define ANNOTATION_MASK			0x007F	/* All possible annotations. */
#define ATTACHED_FLAG			0x0001
#define DETACHABLE_FLAG			0x0002	/* Only present when overriding an attached type. */
#define SEPARATE_FLAG			0x0004
#define VARIANT_FLAG			0x0008	/* Only present when overriding a frozen/poly type. */
#define UNUSABLE_FLAG			0x0010	/* Reserved for backward compatibility for storables. */
#define FROZEN_FLAG				0x0020
#define POLY_FLAG				0x0040

/*
 * Type flags.
 */
#define GE_TYPE_FLAG_SPECIAL		0x0010
#define GE_TYPE_FLAG_TUPLE			0x0020
#define GE_TYPE_FLAG_EXPANDED		0x0040
#define GE_TYPE_FLAG_DEFERRED		0x0080
#define GE_TYPE_FLAG_NONE			0x0100
#define GE_TYPE_FLAG_BASIC_MASK		0x000F /* One of "BOOLEAN", "CHARACTER_8", "CHARACTER_32", "INTEGER_8", "INTEGER_16", "INTEGER_32", "INTEGER_64", "NATURAL_8", "NATURAL_16", "NATURAL_32", "NATURAL_64", "POINTER", "REAL_32", "REAL_64" */
#define GE_TYPE_FLAG_BOOLEAN		0x0001
#define GE_TYPE_FLAG_CHARACTER_8	0x0002
#define GE_TYPE_FLAG_CHARACTER_32	0x0003
#define GE_TYPE_FLAG_INTEGER_8		0x0004
#define GE_TYPE_FLAG_INTEGER_16		0x0005
#define GE_TYPE_FLAG_INTEGER_32		0x0006
#define GE_TYPE_FLAG_INTEGER_64		0x0007
#define GE_TYPE_FLAG_NATURAL_8		0x0008
#define GE_TYPE_FLAG_NATURAL_16		0x0009
#define GE_TYPE_FLAG_NATURAL_32		0x000A
#define GE_TYPE_FLAG_NATURAL_64		0x000B
#define GE_TYPE_FLAG_POINTER		0x000C
#define GE_TYPE_FLAG_REAL_32		0x000D
#define GE_TYPE_FLAG_REAL_64		0x000E

/*
 * Convention for attribute types.
 * The values are in sync with REFLECTOR_CONSTANTS.
 */
#define GE_TYPE_KIND_INVALID		-1
#define GE_TYPE_KIND_POINTER		0
#define GE_TYPE_KIND_REFERENCE		1
#define GE_TYPE_KIND_CHARACTER_8	2
#define GE_TYPE_KIND_BOOLEAN		3
#define GE_TYPE_KIND_INTEGER_32		4
#define GE_TYPE_KIND_REAL_32		5
#define GE_TYPE_KIND_REAL_64		6
#define GE_TYPE_KIND_EXPANDED		7
#define GE_TYPE_KIND_INTEGER_8		9
#define GE_TYPE_KIND_INTEGER_16		10
#define GE_TYPE_KIND_INTEGER_64 	11
#define GE_TYPE_KIND_CHARACTER_32	12
#define GE_TYPE_KIND_NATURAL_8		13
#define GE_TYPE_KIND_NATURAL_16		14
#define GE_TYPE_KIND_NATURAL_32 	15
#define GE_TYPE_KIND_NATURAL_64 	16

/*
 * Object flags.
 */
#define GE_OBJECT_FLAG_MARKED		0x0001

/*
 * Ancestor relationship between two types X and Y.
 */
#ifdef GE_USE_ANCESTORS
typedef struct {
	EIF_TYPE_INDEX type_id; /* Type id of Y */
	EIF_BOOLEAN conforms; /* Does X conform to Y? */
	void (**qualified_calls)(); /* Function pointers, indexed by call id, when the static type of the target is Y and the dynamic type is X */
} GE_ancestor;
#endif

/*
 * Attribute.
 */
#ifdef GE_USE_ATTRIBUTES
typedef struct {
#ifdef GE_USE_ATTRIBUTE_NAME
	const char* name; /* Attribute name */
#endif
#ifdef GE_USE_ATTRIBUTE_TYPE_ID
	EIF_ENCODED_TYPE type_id; /* Static type id */
#endif
#ifdef GE_USE_ATTRIBUTE_OFFSET
	uint32_t offset; /* Address offset in object */
#endif
} GE_attribute;
#endif

/*
 * Type information.
 */
typedef struct {
	EIF_TYPE_INDEX type_id;
	uint16_t flags;
#ifdef GE_USE_TYPE_GENERATOR
	const char* generator; /* Generator class name */
#endif
#ifdef GE_USE_TYPE_NAME
	const char* name; /* Full type name */
#endif
#ifdef GE_USE_TYPE_GENERIC_PARAMETERS
	EIF_ENCODED_TYPE* generic_parameters;
	uint32_t generic_parameter_count;
#endif
#ifdef GE_USE_ANCESTORS
	GE_ancestor** ancestors;
	uint32_t ancestor_count;
#endif
#ifdef GE_USE_ATTRIBUTES
	GE_attribute** attributes;
	uint32_t attribute_count;
#endif
#ifdef GE_USE_TYPE_OBJECT_SIZE
	uint64_t object_size;
#endif
	EIF_REFERENCE (*new_instance)();
	void (*dispose)(GE_context*, EIF_REFERENCE);
} GE_type_info;

typedef struct {
	EIF_TYPE_INDEX id; /* Type id of the "TYPE [X]" object */
	EIF_INTEGER type_id; /* Type id of the type "X" */
	EIF_BOOLEAN is_special;
	void (*dispose)(GE_context*, EIF_REFERENCE);
	EIF_REFERENCE a1; /* internal_name */
	EIF_REFERENCE a2; /* internal_name_32 */
} EIF_TYPE_OBJ;

/*
 * Types indexed by type id.
 * Generated by the compiler.
 */
extern EIF_TYPE_OBJ GE_types[];
extern GE_type_info GE_type_infos[];

/*
 * Number of type infos in `GE_type_infos'.
 * Do not take into account the fake item at index 0.
 */
extern int GE_type_info_count;

/*
 * Encode a EIF_TYPE into a EIF_ENCODED_TYPE.
 * The lower part of EIF_ENCODED_TYPE contains the .id field,
 * and the upper part the .annotations.
 */
extern EIF_ENCODED_TYPE GE_encoded_type(EIF_TYPE a_type);

/*
 * Decode a EIF_ENCODED_TYPE into a EIF_TYPE.
 * The lower part of EIF_ENCODED_TYPE contains the .id field,
 * and the upper part the .annotations.
 */
extern EIF_TYPE GE_decoded_type(EIF_ENCODED_TYPE a_type);

/*
 * Type with `a_id' and `a_annotations'.
 */
extern EIF_TYPE GE_new_type(EIF_TYPE_INDEX a_id, EIF_TYPE_INDEX a_annotations);

/*
 * Type of object `obj'.
 */
#define GE_object_type(obj)	GE_new_type(((EIF_REFERENCE)(obj))->id, 0x0)
#define GE_object_encoded_type(obj) GE_encoded_type(GE_object_type(obj))

/*
 * Attachment status of `a_type'.
 */
#define GE_is_attached_type(a_type) EIF_TEST(((a_type).annotations & ATTACHED_FLAG) || GE_is_expanded_type_index((a_type).id))
#define GE_is_attached_encoded_type(a_type) GE_is_attached_type(GE_decoded_type(a_type))

/*
 * Associated detachable type of `a_type' if any,
 * otherwise `a_type'.
 */
extern EIF_TYPE GE_non_attached_type(EIF_TYPE a_type);
#define GE_non_attached_encoded_type(a_type) GE_encoded_type(GE_non_attached_type(GE_decoded_type(a_type)))

/*
 * Associated attached type of `a_type' if any,
 * otherwise `a_type'.
 */
extern EIF_TYPE GE_attached_type(EIF_TYPE a_type);
#define GE_attached_encoded_type(t) GE_encoded_type(GE_attached_type(GE_decoded_type(t)))

/*
 * Is `a_type' a SPECIAL type?
 */
#define GE_is_special_type_index(a_type) EIF_TEST(GE_type_infos[a_type].flags & GE_TYPE_FLAG_SPECIAL)
#define GE_is_special_encoded_type(a_type) GE_is_special_type_index(GE_decoded_type(a_type).id)
#define GE_is_special_object(obj) GE_is_special_type_index(((EIF_REFERENCE)(obj))->id)

/*
 * Is `a_type' a SPECIAL type of user-defined expanded type?
 */
extern EIF_BOOLEAN GE_is_special_of_expanded_type_index(EIF_TYPE_INDEX a_type);
#define GE_is_special_of_expanded_encoded_type(a_type) GE_is_special_of_expanded_type_index(GE_decoded_type(a_type).id)
#define GE_is_special_of_expanded_object(obj) GE_is_special_of_expanded_type_index(((EIF_REFERENCE)(obj))->id)

/*
 * Is `a_type' a SPECIAL type of reference type?
 */
extern EIF_BOOLEAN GE_is_special_of_reference_type_index(EIF_TYPE_INDEX a_type);
#define GE_is_special_of_reference_encoded_type(a_type) GE_is_special_of_reference_type_index(GE_decoded_type(a_type).id)
#define GE_is_special_of_reference_object(obj) GE_is_special_of_reference_type_index(((EIF_REFERENCE)(obj))->id)

/*
 * Is `a_type' a SPECIAL type of reference type or basic expanded type?
 * (Note that user-defined expanded types are excluded.)
 */
extern EIF_BOOLEAN GE_is_special_of_reference_or_basic_expanded_type_index(EIF_TYPE_INDEX a_type);
#define GE_is_special_of_reference_or_basic_expanded_encoded_type(a_type) GE_is_special_of_reference_or_basic_expanded_type_index(GE_decoded_type(a_type).id)
#define GE_is_special_of_reference_or_basic_expanded_object(obj) GE_is_special_of_reference_or_basic_expanded_type_index(((EIF_REFERENCE)(obj))->id)

/*
 * Is `a_type' a TUPLE type?
 */
#define GE_is_tuple_type_index(a_type) EIF_TEST(GE_type_infos[a_type].flags & GE_TYPE_FLAG_TUPLE)
#define GE_is_tuple_encoded_type(a_type) GE_is_tuple_type_index(GE_decoded_type(a_type).id)
#define GE_is_tuple_object(obj) GE_is_tuple_type_index(((EIF_REFERENCE)(obj))->id)

/*
 * Is `a_type' an expanded type?
 */
#define GE_is_expanded_type_index(a_type) EIF_TEST(GE_type_infos[a_type].flags & GE_TYPE_FLAG_EXPANDED)
#define GE_is_expanded_encoded_type(a_type) GE_is_expanded_type_index(GE_decoded_type(a_type).id)
#define GE_is_expanded_object(obj) GE_is_expanded_type_index(((EIF_REFERENCE)(obj))->id)

/*
 * Is `a_type' a type whose base class is deferred?
 */
#define GE_is_deferred_type_index(a_type) EIF_TEST(GE_type_infos[a_type].flags & GE_TYPE_FLAG_DEFERRED)
#define GE_is_deferred_encoded_type(a_type) GE_is_deferred_type_index(GE_decoded_type(a_type).id)

/*
 * Does `i'-th field of `a_object + a_physical_offset' (which is expected to be reference)
 * denote a reference with copy semantics?
 */
extern EIF_BOOLEAN GE_is_copy_semantics_field(EIF_INTEGER i, EIF_POINTER a_object, EIF_INTEGER a_physical_offset);

/*
 * Does `i'-th item of special `a_object' (which is expected to be reference)
 * denote a reference with copy semantics?
 */
extern EIF_BOOLEAN GE_is_special_copy_semantics_item(EIF_INTEGER i, EIF_POINTER a_object);

/*
 * Generator class name of `a_type'.
 */
extern EIF_REFERENCE GE_generator_of_type_index(EIF_TYPE_INDEX a_type);
#define GE_generator_of_encoded_type(a_type) GE_generator_of_type_index(GE_decoded_type(a_type).id)

/*
 * Full name of `a_type'.
 */
extern EIF_REFERENCE GE_generating_type_of_encoded_type(EIF_ENCODED_TYPE a_type);

/*
 * Encoded type whose name is `a_name'.
 * -1 if no such type.
 */
extern EIF_ENCODED_TYPE GE_encoded_type_from_name(EIF_POINTER a_name);

/*
 * Does `a_type_1' conform to `a_type_2'?
 */
extern EIF_BOOLEAN GE_encoded_type_conforms_to(EIF_ENCODED_TYPE a_type_1, EIF_ENCODED_TYPE a_type_2);

/*
 * Number of generic parameters.
 */
extern EIF_INTEGER GE_generic_parameter_count_of_type_index(EIF_TYPE_INDEX a_type);
#define GE_generic_parameter_count_of_encoded_type(a_type) GE_generic_parameter_count_of_type_index(GE_decoded_type(a_type).id)

/*
 * Type of `i'-th generic parameter of `a_type'.
 */
extern EIF_INTEGER GE_generic_parameter_of_type_index(EIF_TYPE_INDEX a_type, EIF_INTEGER i);
#define GE_generic_parameter_of_encoded_type(a_type,i) GE_generic_parameter_of_type_index(GE_decoded_type(a_type).id, (i))

/*
 * Number of fields of an object of dynamic type `a_type'.
 */
extern EIF_INTEGER GE_field_count_of_type_index(EIF_TYPE_INDEX a_type);
#define GE_field_count_of_encoded_type(a_type) GE_field_count_of_type_index(GE_decoded_type(a_type).id)

/*
 * Physical offset of the `i'-th field for an object of dynamic type `a_type'.
 */
extern EIF_INTEGER GE_field_offset_of_type_index(EIF_INTEGER i, EIF_TYPE_INDEX a_type);
#define GE_field_offset_of_encoded_type(i, a_type) GE_field_offset_of_type_index((i), GE_decoded_type(a_type).id)

/*
 * Name of the `i'-th field for an object of dynamic type `a_type'.
 */
extern EIF_POINTER GE_field_name_of_type_index(EIF_INTEGER i, EIF_TYPE_INDEX a_type);
#define GE_field_name_of_encoded_type(i, a_type) GE_field_name_of_type_index((i), GE_decoded_type(a_type).id)

/*
 * Static type of the `i'-th field for an object of dynamic type `a_type'.
 */
extern EIF_INTEGER GE_field_static_type_of_type_index(EIF_INTEGER i, EIF_TYPE_INDEX a_type);
#define GE_field_static_type_of_encoded_type(i, a_type) GE_field_static_type_of_type_index((i), GE_decoded_type(a_type).id)

/*
 * Kind of type of the `i'-th field for an object of dynamic type `a_type'.
 */
extern EIF_INTEGER GE_field_type_kind_of_type_index(EIF_INTEGER i, EIF_TYPE_INDEX a_type);
#define GE_field_type_kind_of_encoded_type(i, a_type) GE_field_type_kind_of_type_index((i), GE_decoded_type(a_type).id)

/*
 * Physical size of `a_object'.
 */
extern EIF_NATURAL_64 GE_object_size(EIF_POINTER a_object);

/*
 * Is `i'-th field of objects of type `a_type' a user-defined expanded attribute?
 */
extern EIF_BOOLEAN GE_is_field_expanded_of_type_index(EIF_INTEGER i, EIF_TYPE_INDEX a_type);
#define GE_is_field_expanded_of_encoded_type(i, a_type) GE_is_field_expanded_of_type_index((i), GE_decoded_type(a_type).id)

#define GE_field_address_at(a_field_offset, a_object, a_physical_offset) ((char*)(a_object) + (a_physical_offset) + (a_field_offset))
#define GE_object_at_offset(a_enclosing, a_physical_offset) (EIF_REFERENCE)(GE_field_address_at(0, (a_enclosing), (a_physical_offset)))
#define GE_raw_object_at_offset(a_enclosing, a_physical_offset) (EIF_POINTER)(GE_field_address_at(0, (a_enclosing), (a_physical_offset)))
#define GE_object_encoded_type_at_offset(a_enclosing, a_physical_offset) GE_object_encoded_type(GE_raw_object_at_offset((a_enclosing), (a_physical_offset)))
#define GE_boolean_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_BOOLEAN*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_character_8_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_CHARACTER_8*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_character_32_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_CHARACTER_32*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_integer_8_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_INTEGER_8*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_integer_16_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_INTEGER_16*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_integer_32_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_INTEGER_32*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_integer_64_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_INTEGER_64*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_natural_8_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_NATURAL_8*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_natural_16_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_NATURAL_16*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_natural_32_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_NATURAL_32*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_natural_64_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_NATURAL_64*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_pointer_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_POINTER*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_real_32_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_REAL_32*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_real_64_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_REAL_64*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_raw_reference_field_at(a_field_offset, a_object, a_physical_offset) (EIF_POINTER)*(EIF_REFERENCE*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_reference_field_at(a_field_offset, a_object, a_physical_offset) *(EIF_REFERENCE*)(GE_field_address_at((a_field_offset), (a_object), (a_physical_offset)))
#define GE_set_boolean_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_boolean_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_character_8_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_character_8_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_character_32_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_character_32_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_integer_8_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_integer_8_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_integer_16_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_integer_16_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_integer_32_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_integer_32_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_integer_64_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_integer_64_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_natural_8_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_natural_8_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_natural_16_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_natural_16_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_natural_32_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_natural_32_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_natural_64_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_natural_64_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_pointer_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_pointer_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_real_32_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_real_32_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_real_64_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_real_64_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value
#define GE_set_reference_field_at(a_field_offset, a_object, a_physical_offset, a_value) GE_reference_field_at((a_field_offset), (a_object), (a_physical_offset)) = a_value

#if defined(GE_USE_ATTRIBUTES) && defined(GE_USE_ATTRIBUTE_OFFSET)
#define GE_field_address(i, a_object, a_physical_offset) GE_field_address_at(GE_type_infos[((EIF_REFERENCE)(a_object))->id].attributes[(i) - 1]->offset, (a_object), (a_physical_offset))
#define GE_boolean_field(i, a_object, a_physical_offset) *(EIF_BOOLEAN*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_character_8_field(i, a_object, a_physical_offset) *(EIF_CHARACTER_8*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_character_32_field(i, a_object, a_physical_offset) *(EIF_CHARACTER_32*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_integer_8_field(i, a_object, a_physical_offset) *(EIF_INTEGER_8*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_integer_16_field(i, a_object, a_physical_offset) *(EIF_INTEGER_16*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_integer_32_field(i, a_object, a_physical_offset) *(EIF_INTEGER_32*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_integer_64_field(i, a_object, a_physical_offset) *(EIF_INTEGER_64*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_natural_8_field(i, a_object, a_physical_offset) *(EIF_NATURAL_8*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_natural_16_field(i, a_object, a_physical_offset) *(EIF_NATURAL_16*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_natural_32_field(i, a_object, a_physical_offset) *(EIF_NATURAL_32*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_natural_64_field(i, a_object, a_physical_offset) *(EIF_NATURAL_64*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_pointer_field(i, a_object, a_physical_offset) *(EIF_POINTER*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_real_32_field(i, a_object, a_physical_offset) *(EIF_REAL_32*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_real_64_field(i, a_object, a_physical_offset) *(EIF_REAL_64*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_reference_field(i, a_object, a_physical_offset) *(EIF_REFERENCE*)(GE_field_address((i), (a_object), (a_physical_offset)))
#define GE_set_boolean_field(i, a_object, a_physical_offset, a_value) GE_boolean_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_character_8_field(i, a_object, a_physical_offset, a_value) GE_character_8_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_character_32_field(i, a_object, a_physical_offset, a_value) GE_character_32_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_integer_8_field(i, a_object, a_physical_offset, a_value) GE_integer_8_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_integer_16_field(i, a_object, a_physical_offset, a_value) GE_integer_16_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_integer_32_field(i, a_object, a_physical_offset, a_value) GE_integer_32_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_integer_64_field(i, a_object, a_physical_offset, a_value) GE_integer_64_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_natural_8_field(i, a_object, a_physical_offset, a_value) GE_natural_8_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_natural_16_field(i, a_object, a_physical_offset, a_value) GE_natural_16_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_natural_32_field(i, a_object, a_physical_offset, a_value) GE_natural_32_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_natural_64_field(i, a_object, a_physical_offset, a_value) GE_natural_64_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_pointer_field(i, a_object, a_physical_offset, a_value) GE_pointer_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_real_32_field(i, a_object, a_physical_offset, a_value) GE_real_32_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_real_64_field(i, a_object, a_physical_offset, a_value) GE_real_64_field((i), (a_object), (a_physical_offset)) = (a_value)
#define GE_set_reference_field(i, a_object, a_physical_offset, a_value) GE_reference_field((i), (a_object), (a_physical_offset)) = (a_value)
#else
#define GE_boolean_field(i, a_object, a_physical_offset) (EIF_BOOLEAN)0
#define GE_character_8_field(i, a_object, a_physical_offset) (EIF_CHARACTER_8)0
#define GE_character_32_field(i, a_object, a_physical_offset) (EIF_CHARACTER_32)0
#define GE_integer_8_field(i, a_object, a_physical_offset) (EIF_INTEGER_8)0
#define GE_integer_16_field(i, a_object, a_physical_offset) (EIF_INTEGER_16)0
#define GE_integer_32_field(i, a_object, a_physical_offset) (EIF_INTEGER_32)0
#define GE_integer_64_field(i, a_object, a_physical_offset) (EIF_INTEGER_64)0
#define GE_natural_8_field(i, a_object, a_physical_offset) (EIF_NATURAL_8)0
#define GE_natural_16_field(i, a_object, a_physical_offset) (EIF_NATURAL_16)0
#define GE_natural_32_field(i, a_object, a_physical_offset) (EIF_NATURAL_32)0
#define GE_natural_64_field(i, a_object, a_physical_offset) (EIF_NATURAL_64)0
#define GE_pointer_field(i, a_object, a_physical_offset) (EIF_POINTER)0
#define GE_real_32_field(i, a_object, a_physical_offset) (EIF_REAL_32)0
#define GE_real_64_field(i, a_object, a_physical_offset) (EIF_REAL_64)0
#define GE_reference_field(i, a_object, a_physical_offset) (EIF_REFERENCE)0
#define GE_set_boolean_field(i, a_object, a_physical_offset, a_value)
#define GE_set_character_8_field(i, a_object, a_physical_offset, a_value)
#define GE_set_character_32_field(i, a_object, a_physical_offset, a_value)
#define GE_set_integer_8_field(i, a_object, a_physical_offset, a_value)
#define GE_set_integer_16_field(i, a_object, a_physical_offset, a_value)
#define GE_set_integer_32_field(i, a_object, a_physical_offset, a_value)
#define GE_set_integer_64_field(i, a_object, a_physical_offset, a_value)
#define GE_set_natural_8_field(i, a_object, a_physical_offset, a_value)
#define GE_set_natural_16_field(i, a_object, a_physical_offset, a_value)
#define GE_set_natural_32_field(i, a_object, a_physical_offset, a_value)
#define GE_set_natural_64_field(i, a_object, a_physical_offset, a_value)
#define GE_set_pointer_field(i, a_object, a_physical_offset, a_value)
#define GE_set_real_32_field(i, a_object, a_physical_offset, a_value)
#define GE_set_real_64_field(i, a_object, a_physical_offset, a_value)
#define GE_set_reference_field(i, a_object, a_physical_offset, a_value)
#endif

/*
 * Number of non-transient fields of an object of dynamic type `a_type'.
 * TODO: storable not implemented yet.
 */
#define GE_persistent_field_count_of_type_index(a_type) GE_field_count_of_type_index(a_type)
#define GE_persistent_field_count_of_encoded_type(a_type) GE_persistent_field_count_of_type_index(GE_decoded_type(a_type).id)

/*
 * Is `i'-th field of objects of type `a_type' a transient field?
 * TODO: storable not implemented yet.
 */
#define GE_is_field_transient_of_type_index(i, a_type) EIF_FALSE
#define GE_is_field_transient_of_encoded_type(i, a_type) GE_is_field_transient_of_type_index((i), GE_decoded_type(a_type).id)

/*
 * Storable version of objects of type `a_type'.
 * TODO: storable not implemented yet.
 */
#define GE_storable_version_of_type_index(a_type) EIF_VOID
#define GE_storable_version_of_encoded_type(a_type) GE_storable_version_of_type_index(GE_decoded_type(a_type).id)

/*
 * Get a lock on `GE_mark_object' and `GE_unmark_object' routines so that
 * 2 threads cannot `GE_mark_object' and `GE_unmark_object' at the same time.
 */
extern void GE_lock_marking();

/*
 * Release a lock on `GE_mark_object' and `GE_unmark_object', so that another
 * thread can use `GE_mark_object' and `GE_unmark_object'.
 */
extern void GE_unlock_marking();

/*
 * Is `obj' marked?
 */
extern EIF_BOOLEAN GE_is_object_marked(EIF_POINTER obj);

/*
 * Mark `obj'.
 */
extern void GE_mark_object(EIF_POINTER obj);

/*
 * Unmark `obj'.
 */
extern void GE_unmark_object(EIF_POINTER obj);

/*
 * New instance of dynamic `a_type'.
 * Note: returned object is not initialized and may
 * hence violate its invariant.
 * `a_type' cannot represent a SPECIAL type, use
 * `GE_new_special_instance_of_special_type_index' instead.
 */
extern EIF_REFERENCE GE_new_instance_of_type_index(EIF_TYPE_INDEX a_type);
#define GE_new_instance_of_encoded_type(a_type) GE_new_instance_of_type_index(GE_decoded_type(a_type).id)

/*
 * New instance of dynamic `a_type' that represents
 * a SPECIAL with can contain `a_capacity' element. To create a SPECIAL of
 * basic type, use `SPECIAL'.
 */
extern EIF_REFERENCE GE_new_special_any_instance_of_type_index(EIF_TYPE_INDEX a_type, EIF_INTEGER a_capacity);
#define GE_new_special_any_instance_of_encoded_type(a_type, a_capacity) GE_new_special_instance_of_type_index(GE_decoded_type(a_type).id, (a_capacity))

/*
 * New instance of tuple of type `a_type'.
 * Note: returned object is not initialized and may
 * hence violate its invariant.
 */
#define GE_new_tuple_instance_of_type_index(a_type) GE_new_instance_of_type_index(a_type)
#define GE_new_tuple_instance_of_encoded_type(a_type) GE_new_tuple_instance_of_type_index(GE_decoded_type(a_type).id)

/*
 * New instance of TYPE for object of type `a_type'.
 */
extern EIF_REFERENCE GE_new_type_instance_of_encoded_type(EIF_ENCODED_TYPE a_type);

#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to manipulate strings"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2016, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_STRING_H
#define GE_STRING_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*
 * New Eiffel empty string of type "STRING_8" with can
 * contain `c' characters.
 * Note: The implementation of this function is generated
 * by the Eiffel compiler.
 */
extern EIF_REFERENCE GE_new_str8(EIF_INTEGER c);

/*
 * New Eiffel empty string of type "STRING_32" with can
 * contain `c' characters.
 * Note: The implementation of this function is generated
 * by the Eiffel compiler.
 */
extern EIF_REFERENCE GE_new_str32(EIF_INTEGER c);

/*
 * New Eiffel empty string of type "IMMUTABLE_STRING_32" with can
 * contain `c' characters.
 * Note: The implementation of this function is generated
 * by the Eiffel compiler.
 */
extern EIF_REFERENCE GE_new_istr32(EIF_INTEGER c);

/*
 * New Eiffel string of type "STRING_8" containing the
 * first `c' characters found in ASCII string `s'.
 */
extern EIF_REFERENCE GE_ms8(const char* s, EIF_INTEGER c);

/*
 * New Eiffel string of type "STRING_8" containing all
 * characters found in the null-terminated ASCII string `s'.
 */
extern EIF_REFERENCE GE_str8(const char* s);

/*
 * New Eiffel string of type "STRING_32" containing the
 * first `c' characters found in ASCII string `s'.
 */
extern EIF_REFERENCE GE_ms32(const char* s, EIF_INTEGER c);

/*
 * New Eiffel string of type "STRING_32" containing all
 * characters found in the null-terminated ASCII string `s'.
 */
extern EIF_REFERENCE GE_str32(const char* s);

/*
 * New Eiffel string of type "IMMUTABLE_STRING_32" containing
 * the first `c' characters found in ASCII string `s'.
 */
extern EIF_REFERENCE GE_ims32(const char* s, EIF_INTEGER c);

/*
 * New Eiffel string of type "IMMUTABLE_STRING_32" containing all
 * characters found in the null-terminated ASCII string `s'.
 */
extern EIF_REFERENCE GE_istr32(const char* s);

/*
 * New Eiffel string of type "IMMUTABLE_STRING_32" containing the
 * first `n' native characters found in native string `s'.
 * Invalid native characters are escaped.
 */
extern EIF_REFERENCE GE_ims32_from_nstr(EIF_NATIVE_CHAR* s, EIF_INTEGER n);

/*
 * New Eiffel string of type "IMMUTABLE_STRING_32" containing all
 * characters found in the null-terminated native string `s'.
 * Invalid native characters are escaped.
 */
extern EIF_REFERENCE GE_istr32_from_nstr(EIF_NATIVE_CHAR* s);

/*
 * New Eiffel string of type "STRING" containing all
 * characters found in the null-terminated ASCII string `s'
 */
extern EIF_REFERENCE GE_str(const char* s);

#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to implement class CONSOLE"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2007-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_CONSOLE_H
#define GE_CONSOLE_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Initialize mutex to determine whether a new
 * console needs to be created.
 */
#ifdef EIF_WINDOWS
extern void GE_init_console(void);
#else
#define GE_init_console()
#endif

/*
 * Create a new DOS console if needed (i.e. in case of a Windows application).
 */
#ifdef EIF_WINDOWS
extern void GE_show_console(void);
#else
#define GE_show_console()
#endif

#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to implement the program initialization"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2007-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_MAIN_H
#define GE_MAIN_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

extern int GE_main(int argc, EIF_NATIVE_CHAR** argv);

/*
 * System name.
 */
extern char* GE_system_name;

/*
 * Root class name.
 */
extern char* GE_root_class_name;

#ifdef EIF_WINDOWS

#include <windows.h>

/*
 * Used in WEL.
 */
extern HINSTANCE eif_hInstance;
extern HINSTANCE eif_hPrevInstance;
extern LPWSTR eif_lpCmdLine;
extern int eif_nCmdShow;

/*
 * Main entry point when compiling a Windows application.
 * See:
 *    http://en.wikipedia.org/wiki/WinMain
 *    http://msdn2.microsoft.com/en-us/library/ms633559.aspx
 */
extern int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow);

#endif

#ifdef __cplusplus
}
#endif

#endif

/*
	description:

		"C functions used to access garbage collector facilities"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2007-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_GC_H
#define GE_GC_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EXCEPTION_H
#include "ge_exception.h"
#endif

#ifdef GE_USE_BOEHM_GC
/*
 *	Use the Boehm garbage collector.
 *	See:
 *		http://en.wikipedia.org/wiki/Boehm_GC
 *		http://www.hpl.hp.com/personal/Hans_Boehm/gc/
 */
#define GC_IGNORE_WARN
#ifdef GE_USE_THREADS
#define GC_THREADS
#undef GC_NO_THREAD_REDIRECTS
#endif
#include "gc.h"
#endif

/*
 * GC initialization.
 */

#ifdef GE_USE_BOEHM_GC
#ifdef GE_USE_THREADS
#define GE_init_gc() \
	GC_INIT(); \
	GC_allow_register_threads(); \
	GC_enable_incremental()
#else
#define GE_init_gc() \
	GC_INIT(); \
	GC_enable_incremental()
#endif
#else /* No GC */
#define GE_init_gc() /* do nothing */
#endif

/*
 * Memory allocation.
 */

/*
 * Allocate memory that can contain pointers to collectable objects.
 * The allocated memory is not necessarily zeroed (unless `GE_malloc_cleared' is_defined).
 * The allocated object is itself collectable.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_malloc(size) GE_null(GC_MALLOC(size))
#else /* No GC */
#define GE_malloc(size) GE_null(malloc(size))
#endif

/*
 * Allocate memory that can contain pointers to collectable objects.
 * The allocated memory is not necessarily zeroed (unless `GE_malloc_cleared' is_defined).
 * The allocated object is itself collectable.
 * Do not raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_unprotected_malloc(size) GC_MALLOC(size)
#else /* No GC */
#define GE_unprotected_malloc(size) malloc(size)
#endif

/*
 * Allocate memory that does not contain pointers to collectable objects.
 * The allocated memory is not necessarily zeroed (unless `GE_malloc_atomic_cleared' is_defined).
 * The allocated object is itself collectable.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_malloc_atomic(size) GE_null(GC_MALLOC_ATOMIC(size))
#else /* No GC */
#define GE_malloc_atomic(size) GE_null(malloc(size))
#endif

/*
 * Allocate memory that does not contain pointers to collectable objects.
 * The allocated memory is not necessarily zeroed (unless `GE_malloc_atomic_cleared' is_defined).
 * The allocated object is itself collectable.
 * Do not raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_unprotected_malloc_atomic(size) GC_MALLOC_ATOMIC(size)
#else /* No GC */
#define GE_unprotected_malloc_atomic(size) malloc(size)
#endif

/*
 * Allocate memory that can contain pointers to collectable objects.
 * The allocated memory is zeroed.
 * The allocated object is itself collectable.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_calloc(nelem, elsize) GE_null(GC_MALLOC((nelem) * (elsize)))
#else /* No GC */
#define GE_calloc(nelem, elsize) GE_null(calloc((nelem), (elsize)))
#endif

/*
 * Allocate memory that can contain pointers to collectable objects.
 * The allocated memory is zeroed.
 * The allocated object is itself collectable.
 * Do not raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_unprotected_calloc(nelem, elsize) GC_MALLOC((nelem) * (elsize))
#else /* No GC */
#define GE_unprotected_calloc(nelem, elsize) calloc((nelem), (elsize))
#endif

/*
 * Allocate memory that does not contain pointers to collectable objects.
 * The allocated memory is zeroed.
 * The allocated object is itself collectable.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_calloc_atomic(nelem, elsize) memset(GE_null(GC_MALLOC_ATOMIC((nelem) * (elsize))), 0, (nelem) * (elsize))
#else /* No GC */
#define GE_calloc(nelem, elsize) GE_null(calloc((nelem), (elsize)))
#endif

/*
 * Allocate memory that can contain pointers to collectable objects.
 * The allocated memory is not necessarily zeroed (unless `GE_malloc_cleared' is_defined).
 * The allocated object is itself not collectable.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_malloc_uncollectable(size) GE_null(GC_MALLOC_UNCOLLECTABLE(size))
#else /* No GC */
#define GE_malloc_uncollectable(size) GE_null(malloc(size))
#endif

/*
 * Allocate memory that can contain pointers to collectable objects.
 * The allocated memory is not necessarily zeroed (unless `GE_malloc_cleared' is_defined).
 * The allocated object is itself not collectable.
 * Do not raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_unprotected_malloc_uncollectable(size) GC_MALLOC_UNCOLLECTABLE(size)
#else /* No GC */
#define GE_unprotected_malloc_uncollectable(size) malloc(size)
#endif

/*
 * Allocate memory that does not contain pointers to collectable objects.
 * The allocated memory is not necessarily zeroed (unless `GE_malloc_atomic_cleared' is_defined).
 * The allocated object is itself not collectable.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_malloc_atomic_uncollectable(size) GE_null(GC_malloc_atomic_uncollectable(size))
#else /* No GC */
#define GE_malloc_atomic_uncollectable(size) GE_null(malloc(size))
#endif

/*
 * Allocate memory that does not contain pointers to collectable objects.
 * The allocated memory is not necessarily zeroed (unless `GE_malloc_atomic_cleared' is_defined).
 * The allocated object is itself not collectable.
 * Do not raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_unprotected_malloc_atomic_uncollectable(size) GC_malloc_atomic_uncollectable(size)
#else /* No GC */
#define GE_unprotected_malloc_atomic_uncollectable(size) malloc(size)
#endif

/*
 * Allocate memory that can contain pointers to collectable objects.
 * The allocated memory is zeroed.
 * The allocated object is itself not collectable.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_calloc_uncollectable(nelem, elsize) GE_null(GC_MALLOC_UNCOLLECTABLE((nelem) * (elsize)))
#else /* No GC */
#define GE_calloc_uncollectable(nelem, elsize) GE_null(calloc((nelem), (elsize)))
#endif

/*
 * Allocate memory that can contain pointers to collectable objects.
 * The allocated memory is zeroed.
 * The allocated object is itself not collectable.
 * Do not raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_unprotected_calloc_uncollectable(nelem, elsize) GC_MALLOC_UNCOLLECTABLE((nelem) * (elsize))
#else /* No GC */
#define GE_unprotected_calloc_uncollectable(nelem, elsize) calloc((nelem), (elsize))
#endif

/*
 * Allocate memory that does not contain pointers to collectable objects.
 * The allocated memory is zeroed.
 * The allocated object is itself not collectable.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_calloc_atomic_uncollectable(nelem, elsize) memset(GE_null(GC_malloc_atomic_uncollectable((nelem) * (elsize))), 0, (nelem) * (elsize))
#else /* No GC */
#define GE_calloc_atomic_uncollectable(nelem, elsize) GE_null(calloc((nelem), (elsize)))
#endif

/*
 * Allocate memory that does not contain pointers to collectable objects.
 * The allocated memory is zeroed.
 * The allocated object is itself not collectable.
 * Do not raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
extern void* GE_unprotected_calloc_atomic_uncollectable(size_t nelem, size_t elsize);
#else /* No GC */
#define GE_unprotected_calloc_atomic_uncollectable(nelem, elsize) calloc((nelem), (elsize))
#endif

/*
 * Allocate more memory for the given pointer.
 * The reallocated pointer keeps the same properties (e.g. atomic or not, collectable or not).
 * The extra allocated memory is not necessarily zeroed.
 * Raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_realloc(p, size) GE_null(GC_REALLOC((p), (size)))
#else /* No GC */
#define GE_realloc(p, size) GE_null(realloc((p), (size)))
#endif

/*
 * Allocate more memory for the given pointer.
 * The reallocated pointer keeps the same properties (e.g. atomic or not, collectable or not).
 * The extra allocated memory is not necessarily zeroed.
 * Do not raise an exception when no-more-memory.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_unprotected_realloc(p, size) GC_REALLOC((p), (size))
#else /* No GC */
#define GE_unprotected_realloc(p, size) realloc((p), (size))
#endif

/*
 * Allocate more memory for the given pointer.
 * The reallocated pointer keeps the same properties (e.g. atomic or not, collectable or not).
 * The extra allocated memory is zeroed.
 * Raise an exception when no-more-memory.
 */
extern void* GE_recalloc(void* p, size_t old_nelem, size_t new_nelem, size_t elsize);

/*
 * Allocate more memory for the given pointer.
 * The reallocated pointer keeps the same properties (e.g. atomic or not, collectable or not).
 * The extra allocated memory is zeroed.
 * Do not raise an exception when no-more-memory.
 */
extern void* GE_unprotected_recalloc(void* p, size_t old_nelem, size_t new_nelem, size_t elsize);

/*
 * Explicitly deallocate an object.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_free(p) GC_FREE(p)
#else /* No GC */
#define GE_free(p) free(p)
#endif

/*
 * When defined, `GE_malloc_cleared' means that `GE_malloc' and
 * `GE_malloc_uncollectable' make sure that the allocated memory
 * is zeroed.
 */
#ifdef GE_USE_BOEHM_GC
#define GE_malloc_cleared
#else /* No GC */
#endif

/*
 * When defined, `GE_malloc_atomic_cleared' means that `GE_malloc_atomic'
 * and `GE_malloc_atomic_uncollectable' make sure that the allocated memory
 * is zeroed.
 */
#ifdef GE_USE_BOEHM_GC
/* #define GE_malloc_atomic_cleared */
#else /* No GC */
#endif

/*
 * Dispose
 */

/*
 * Register dispose routine `disp' to be called on object `obj' when it will be collected.
 */
#ifdef GE_USE_BOEHM_GC
extern void GE_boehm_dispose(void* C, void* disp); /* Call dispose routine `disp' on object `C'. */
#define GE_register_dispose(obj, disp) GC_REGISTER_FINALIZER_NO_ORDER((void*)(obj), (void (*) (void*, void*)) &GE_boehm_dispose, NULL, NULL, NULL)
#else /* No GC */
#define GE_register_dispose(obj, disp) /* do nothing */
#endif

/*
 * Access to objects, useful with GCs which move objects in memory.
 * This is not the case here, since the Boehm GC is not a moving GC.
 */

/* Access object through hector. */
#define eif_access(obj) (obj)
/* Freeze memory address. */
#define eif_freeze(obj) (obj)
/* The C side adopts an object. */
#define eif_adopt(obj) (obj)
/* The C side protects an object. */
#define eif_protect(obj) (obj)
/* The C side weans adopted object. */
#define eif_wean(obj) (obj)
/* Forget a frozen memory address. */
#define eif_unfreeze(obj)
/* Always frozen since they do not move. */
#define eif_frozen(obj) 1
/* Always frozen since they do not move. */
#define spfrozen(obj) 1

#endif

/*
	description:

		"C functions used to implement class IDENTIFIED"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2007-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_IDENTIFIED_H
#define GE_IDENTIFIED_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Initialize data to keep track of object ids.
 */
extern void GE_init_identified(void);

/*
 * Get a new id for `object', assuming it is NOT in the stack.
 */
extern EIF_INTEGER_32 GE_object_id(EIF_OBJECT object);

/*
 * Return the object associated with `id'.
 */
extern EIF_REFERENCE GE_id_object(EIF_INTEGER_32 id);

/*
 * Remove the object associated with `id' from the stack.
 */
extern void GE_object_id_free(EIF_INTEGER_32 id);

#ifdef __cplusplus
}
#endif

#endif

#ifdef __cplusplus
extern "C" {
#endif

#define T0 EIF_ANY

/* CHARACTER */
#define EIF_CHARACTER EIF_CHARACTER_8

/* WIDE_CHARACTER */
#define EIF_WIDE_CHAR EIF_CHARACTER_32

/* INTEGER */
#define EIF_INTEGER EIF_INTEGER_32

/* NATURAL */
#define EIF_NATURAL EIF_NATURAL_32

/* REAL */
#define EIF_REAL EIF_REAL_32

/* DOUBLE */
#define EIF_DOUBLE EIF_REAL_64

/* BOOLEAN */
#define T1 EIF_BOOLEAN
extern T0* GE_boxed1(T1 a1);
typedef struct Sb1 Tb1;

/* CHARACTER_8 */
#define T2 EIF_CHARACTER_8
extern T0* GE_boxed2(T2 a1);
typedef struct Sb2 Tb2;

/* CHARACTER_32 */
#define T3 EIF_CHARACTER_32
extern T0* GE_boxed3(T3 a1);
typedef struct Sb3 Tb3;

/* INTEGER_8 */
#define T4 EIF_INTEGER_8
extern T0* GE_boxed4(T4 a1);
typedef struct Sb4 Tb4;

/* INTEGER_16 */
#define T5 EIF_INTEGER_16
extern T0* GE_boxed5(T5 a1);
typedef struct Sb5 Tb5;

/* INTEGER_32 */
#define T6 EIF_INTEGER_32
extern T0* GE_boxed6(T6 a1);
typedef struct Sb6 Tb6;

/* INTEGER_64 */
#define T7 EIF_INTEGER_64
extern T0* GE_boxed7(T7 a1);
typedef struct Sb7 Tb7;

/* NATURAL_8 */
#define T8 EIF_NATURAL_8
extern T0* GE_boxed8(T8 a1);
typedef struct Sb8 Tb8;

/* NATURAL_16 */
#define T9 EIF_NATURAL_16
extern T0* GE_boxed9(T9 a1);
typedef struct Sb9 Tb9;

/* NATURAL_32 */
#define T10 EIF_NATURAL_32
extern T0* GE_boxed10(T10 a1);
typedef struct Sb10 Tb10;

/* NATURAL_64 */
#define T11 EIF_NATURAL_64
extern T0* GE_boxed11(T11 a1);
typedef struct Sb11 Tb11;

/* REAL_32 */
#define T12 EIF_REAL_32
extern T0* GE_boxed12(T12 a1);
typedef struct Sb12 Tb12;

/* REAL_64 */
#define T13 EIF_REAL_64
extern T0* GE_boxed13(T13 a1);
typedef struct Sb13 Tb13;

/* POINTER */
#define T14 EIF_POINTER
extern T0* GE_boxed14(T14 a1);
typedef struct Sb14 Tb14;

/* SPECIAL [CHARACTER_8] */
typedef struct S15 T15;

/* SPECIAL [CHARACTER_32] */
typedef struct S16 T16;

/* STRING_8 */
typedef struct S17 T17;

/* IMMUTABLE_STRING_32 */
typedef struct S19 T19;

/* ISE_EXCEPTION_MANAGER */
typedef struct S20 T20;

/* XPLAIN2SQL */
typedef struct S24 T24;

/* CELL [detachable EXCEPTION] */
typedef struct S25 T25;

/* HASH_TABLE [INTEGER_32, INTEGER_32] */
typedef struct S26 T26;

/* CELL [detachable TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN]] */
typedef struct S27 T27;

/* CELL [NO_MORE_MEMORY] */
typedef struct S28 T28;

/* C_STRING */
typedef struct S29 T29;

/* [attached] TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN] */
typedef struct S30 T30;

/* KL_TEXT_INPUT_FILE */
typedef struct S31 T31;

/* KL_ARGUMENTS */
typedef struct S34 T34;

/* [attached] ARRAY [[attached] STRING_8] */
typedef struct S35 T35;

/* SPECIAL [[attached] STRING_8] */
typedef struct S36 T36;

/* ARRAY [ANY] */
typedef struct S37 T37;

/* SPECIAL [ANY] */
typedef struct S38 T38;

/* KL_STANDARD_FILES */
typedef struct S39 T39;

/* KL_STDERR_FILE */
typedef struct S40 T40;

/* SQL_GENERATOR_ANSI */
typedef struct S41 T41;

/* SQL_GENERATOR_BASIC */
typedef struct S42 T42;

/* SQL_GENERATOR_DB2_6 */
typedef struct S43 T43;

/* SQL_GENERATOR_DB2_71 */
typedef struct S44 T44;

/* SQL_GENERATOR_FOXPRO */
typedef struct S45 T45;

/* SQL_GENERATOR_INTERBASE6 */
typedef struct S46 T46;

/* SQL_GENERATOR_FIREBIRD_21 */
typedef struct S47 T47;

/* SQL_GENERATOR_MSACCESS97 */
typedef struct S48 T48;

/* SQL_GENERATOR_MSACCESS2000 */
typedef struct S49 T49;

/* SQL_GENERATOR_MSQL */
typedef struct S50 T50;

/* SQL_GENERATOR_MYSQL5 */
typedef struct S51 T51;

/* SQL_GENERATOR_MYSQL4 */
typedef struct S52 T52;

/* SQL_GENERATOR_MYSQL322 */
typedef struct S53 T53;

/* SQL_GENERATOR_ORACLE */
typedef struct S54 T54;

/* SQL_GENERATOR_PGSQL_95 */
typedef struct S55 T55;

/* SQL_GENERATOR_PGSQL_82 */
typedef struct S56 T56;

/* SQL_GENERATOR_PGSQL_81 */
typedef struct S57 T57;

/* SQL_GENERATOR_PGSQL_73 */
typedef struct S58 T58;

/* SQL_GENERATOR_PGSQL_72 */
typedef struct S59 T59;

/* SQL_GENERATOR_SQLITE_3 */
typedef struct S60 T60;

/* SQL_GENERATOR_TSQL2016 */
typedef struct S61 T61;

/* SQL_GENERATOR_TSQL2000 */
typedef struct S62 T62;

/* SQL_GENERATOR_TSQL70 */
typedef struct S63 T63;

/* SQL_GENERATOR_TSQL65 */
typedef struct S64 T64;

/* XPLAIN_PARSER */
typedef struct S65 T65;

/* XML_GENERATOR */
typedef struct S67 T67;

/* XPLAIN_STATEMENTS */
typedef struct S69 T69;

/* VOID_TARGET */
typedef struct S72 T72;

/* [attached] TYPE [VOID_TARGET] */
#define T73 EIF_TYPE_OBJ

/* ROUTINE_FAILURE */
typedef struct S74 T74;

/* [attached] TYPE [ROUTINE_FAILURE] */
#define T75 EIF_TYPE_OBJ

/* OLD_VIOLATION */
typedef struct S76 T76;

/* [attached] TYPE [OLD_VIOLATION] */
#define T77 EIF_TYPE_OBJ

/* NO_MORE_MEMORY */
typedef struct S78 T78;

/* INVARIANT_VIOLATION */
typedef struct S79 T79;

/* OPERATING_SYSTEM_SIGNAL_FAILURE */
typedef struct S80 T80;

/* IO_FAILURE */
typedef struct S81 T81;

/* OPERATING_SYSTEM_FAILURE */
typedef struct S82 T82;

/* COM_FAILURE */
typedef struct S83 T83;

/* EIFFEL_RUNTIME_PANIC */
typedef struct S84 T84;

/* PRECONDITION_VIOLATION */
typedef struct S86 T86;

/* POSTCONDITION_VIOLATION */
typedef struct S87 T87;

/* FLOATING_POINT_FAILURE */
typedef struct S88 T88;

/* CHECK_VIOLATION */
typedef struct S89 T89;

/* BAD_INSPECT_VALUE */
typedef struct S90 T90;

/* VARIANT_VIOLATION */
typedef struct S91 T91;

/* LOOP_INVARIANT_VIOLATION */
typedef struct S92 T92;

/* RESCUE_FAILURE */
typedef struct S93 T93;

/* RESUMPTION_FAILURE */
typedef struct S94 T94;

/* CREATE_ON_DEFERRED */
typedef struct S95 T95;

/* EXTERNAL_FAILURE */
typedef struct S96 T96;

/* VOID_ASSIGNED_TO_EXPANDED */
typedef struct S97 T97;

/* EXCEPTION_IN_SIGNAL_HANDLER_FAILURE */
typedef struct S98 T98;

/* MISMATCH_FAILURE */
typedef struct S99 T99;

/* DEVELOPER_EXCEPTION */
typedef struct S100 T100;

/* ADDRESS_APPLIED_TO_MELTED_FEATURE */
typedef struct S101 T101;

/* SERIALIZATION_FAILURE */
typedef struct S102 T102;

/* ST_SCIENTIFIC_FORMATTER */
typedef struct S103 T103;

/* PRIMES */
typedef struct S104 T104;

/* SPECIAL [INTEGER_32] */
typedef struct S105 T105;

/* SPECIAL [BOOLEAN] */
typedef struct S106 T106;

/* KL_STRING_ROUTINES */
typedef struct S108 T108;

/* MANAGED_POINTER */
typedef struct S111 T111;

/* FILE_INFO */
typedef struct S112 T112;

/* ARGUMENTS_32 */
typedef struct S113 T113;

/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8] */
typedef struct S114 T114;

/* KL_STDOUT_FILE */
typedef struct S115 T115;

/* KL_SPECIAL_ROUTINES [INTEGER_32] */
typedef struct S117 T117;

/* XPLAIN_SCANNER_STATE */
typedef struct S118 T118;

/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE] */
typedef struct S120 T120;

/* XPLAIN_REQUIRED */
typedef struct S122 T122;

/* KL_SPECIAL_ROUTINES [detachable ANY] */
typedef struct S124 T124;

/* KL_SPECIAL_ROUTINES [STRING_8] */
typedef struct S125 T125;

/* XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT */
typedef struct S127 T127;

/* XPLAIN_BASE */
typedef struct S128 T128;

/* XPLAIN_TYPE */
typedef struct S129 T129;

/* XPLAIN_CONSTANT_STATEMENT */
typedef struct S130 T130;

/* XPLAIN_A_NODE */
typedef struct S131 T131;

/* XPLAIN_I_NODE */
typedef struct S132 T132;

/* XPLAIN_LOGICAL_EXPRESSION */
typedef struct S133 T133;

/* XPLAIN_LOGICAL_VALUE_EXPRESSION */
typedef struct S135 T135;

/* XPLAIN_ATTRIBUTE_NAME_NODE */
typedef struct S137 T137;

/* XPLAIN_ATTRIBUTE_NAME */
typedef struct S138 T138;

/* XPLAIN_ATTRIBUTE_NODE */
typedef struct S141 T141;

/* XPLAIN_ATTRIBUTE */
typedef struct S142 T142;

/* XPLAIN_ASSERTION */
typedef struct S143 T143;

/* XPLAIN_ASSIGNMENT_NODE */
typedef struct S144 T144;

/* XPLAIN_ASSIGNMENT */
typedef struct S145 T145;

/* XPLAIN_CASCADE_STATEMENT */
typedef struct S146 T146;

/* XPLAIN_CASCADE_FUNCTION_EXPRESSION */
typedef struct S147 T147;

/* XPLAIN_DELETE_STATEMENT */
typedef struct S148 T148;

/* XPLAIN_SUBJECT */
typedef struct S149 T149;

/* XPLAIN_UPDATE_STATEMENT */
typedef struct S150 T150;

/* XPLAIN_VALUE_STATEMENT */
typedef struct S151 T151;

/* XPLAIN_VALUE_SELECTION_STATEMENT */
typedef struct S152 T152;

/* XPLAIN_SELECTION_FUNCTION */
typedef struct S154 T154;

/* XPLAIN_GET_STATEMENT */
typedef struct S155 T155;

/* XPLAIN_EXTEND_STATEMENT */
typedef struct S156 T156;

/* XPLAIN_EXTENSION */
typedef struct S157 T157;

/* XPLAIN_EXTEND_ATTRIBUTE */
typedef struct S158 T158;

/* XPLAIN_EXTENSION_EXPRESSION */
typedef struct S159 T159;

/* XPLAIN_SELECTION_LIST */
typedef struct S161 T161;

/* XPLAIN_SORT_NODE */
typedef struct S162 T162;

/* XPLAIN_EXPRESSION_NODE */
typedef struct S164 T164;

/* XPLAIN_PROCEDURE_STATEMENT */
typedef struct S165 T165;

/* XPLAIN_SQL_STATEMENT */
typedef struct S166 T166;

/* XPLAIN_STATEMENT_NODE */
typedef struct S167 T167;

/* SPECIAL [detachable XPLAIN_STATEMENT] */
typedef struct S168 T168;

/* SPECIAL [XPLAIN_SQL_STATEMENT] */
typedef struct S169 T169;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT] */
typedef struct S170 T170;

/* SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT] */
typedef struct S171 T171;

/* SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT] */
typedef struct S172 T172;

/* SPECIAL [detachable XPLAIN_TYPE] */
typedef struct S173 T173;

/* XPLAIN_TYPE_STATEMENT */
typedef struct S174 T174;

/* XPLAIN_UNIVERSE */
typedef struct S175 T175;

/* SPECIAL [XPLAIN_BASE] */
typedef struct S176 T176;

/* XPLAIN_BASE_STATEMENT */
typedef struct S177 T177;

/* SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT] */
typedef struct S178 T178;

/* XPLAIN_VARIABLE */
typedef struct S179 T179;

/* SPECIAL [XPLAIN_EXPRESSION] */
typedef struct S180 T180;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT] */
typedef struct S181 T181;

/* SPECIAL [XPLAIN_REPRESENTATION] */
typedef struct S182 T182;

/* KL_SPECIAL_ROUTINES [XPLAIN_BASE] */
typedef struct S183 T183;

/* SPECIAL [XPLAIN_DOMAIN_RESTRICTION] */
typedef struct S184 T184;

/* SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE] */
typedef struct S185 T185;

/* SPECIAL [XPLAIN_PK_REPRESENTATION] */
typedef struct S186 T186;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_TYPE] */
typedef struct S187 T187;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_STATEMENT] */
typedef struct S188 T188;

/* SPECIAL [XPLAIN_ATTRIBUTE_NAME] */
typedef struct S190 T190;

/* KL_SPECIAL_ROUTINES [XPLAIN_DOMAIN_RESTRICTION] */
typedef struct S191 T191;

/* XPLAIN_A_PATTERN */
typedef struct S192 T192;

/* SPECIAL [XPLAIN_A_NODE] */
typedef struct S193 T193;

/* XPLAIN_A_ENUMERATION */
typedef struct S194 T194;

/* SPECIAL [XPLAIN_I_NODE] */
typedef struct S195 T195;

/* XPLAIN_I_ENUMERATION */
typedef struct S196 T196;

/* KL_SPECIAL_ROUTINES [XPLAIN_A_NODE] */
typedef struct S197 T197;

/* KL_SPECIAL_ROUTINES [XPLAIN_I_NODE] */
typedef struct S199 T199;

/* XPLAIN_TRAJECTORY */
typedef struct S200 T200;

/* SPECIAL [XPLAIN_LOGICAL_EXPRESSION] */
typedef struct S201 T201;

/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_EXPRESSION] */
typedef struct S202 T202;

/* XPLAIN_LOGICAL_INFIX_EXPRESSION */
typedef struct S203 T203;

/* KL_SPECIAL_ROUTINES [XPLAIN_EXPRESSION] */
typedef struct S204 T204;

/* SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE] */
typedef struct S205 T205;

/* XPLAIN_NOTNOT_EXPRESSION */
typedef struct S206 T206;

/* XPLAIN_NOT_EXPRESSION */
typedef struct S207 T207;

/* XPLAIN_PARAMETER_EXPRESSION */
typedef struct S208 T208;

/* XPLAIN_EQ_NULL_EXPRESSION */
typedef struct S209 T209;

/* XPLAIN_NE_NULL_EXPRESSION */
typedef struct S210 T210;

/* XPLAIN_INFIX_EXPRESSION */
typedef struct S211 T211;

/* XPLAIN_PARENTHESIS_EXPRESSION */
typedef struct S212 T212;

/* SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION] */
typedef struct S213 T213;

/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_VALUE_EXPRESSION] */
typedef struct S214 T214;

/* XPLAIN_SYSTEMDATE_EXPRESSION */
typedef struct S215 T215;

/* SPECIAL [XPLAIN_SYSTEM_EXPRESSION] */
typedef struct S216 T216;

/* KL_SPECIAL_ROUTINES [XPLAIN_SYSTEM_EXPRESSION] */
typedef struct S217 T217;

/* XPLAIN_LOGINNAME_EXPRESSION */
typedef struct S218 T218;

/* XPLAIN_IF_EXPRESSION */
typedef struct S219 T219;

/* XPLAIN_PREFIX_EXPRESSION */
typedef struct S220 T220;

/* SPECIAL [detachable XPLAIN_EXPRESSION_NODE] */
typedef struct S221 T221;

/* XPLAIN_COMBINE_FUNCTION */
typedef struct S222 T222;

/* XPLAIN_DATEF_FUNCTION */
typedef struct S223 T223;

/* XPLAIN_INTEGER_FUNCTION */
typedef struct S224 T224;

/* XPLAIN_REAL_FUNCTION */
typedef struct S225 T225;

/* XPLAIN_STRING_FUNCTION */
typedef struct S226 T226;

/* XPLAIN_STRING_EXPRESSION */
typedef struct S227 T227;

/* XPLAIN_NEWDATE_FUNCTION */
typedef struct S228 T228;

/* XPLAIN_ID_FUNCTION */
typedef struct S229 T229;

/* XPLAIN_NUMBER_EXPRESSION */
typedef struct S230 T230;

/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION */
typedef struct S231 T231;

/* XPLAIN_USER_FUNCTION */
typedef struct S232 T232;

/* XPLAIN_SQL_EXPRESSION */
typedef struct S233 T233;

/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME_NODE] */
typedef struct S234 T234;

/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME] */
typedef struct S235 T235;

/* XPLAIN_A_REPRESENTATION */
typedef struct S236 T236;

/* KL_SPECIAL_ROUTINES [XPLAIN_REPRESENTATION] */
typedef struct S237 T237;

/* XPLAIN_B_REPRESENTATION */
typedef struct S238 T238;

/* XPLAIN_C_REPRESENTATION */
typedef struct S239 T239;

/* XPLAIN_D_REPRESENTATION */
typedef struct S240 T240;

/* XPLAIN_I_REPRESENTATION */
typedef struct S241 T241;

/* XPLAIN_M_REPRESENTATION */
typedef struct S242 T242;

/* XPLAIN_P_REPRESENTATION */
typedef struct S243 T243;

/* XPLAIN_R_REPRESENTATION */
typedef struct S244 T244;

/* XPLAIN_T_REPRESENTATION */
typedef struct S245 T245;

/* XPLAIN_PK_A_REPRESENTATION */
typedef struct S246 T246;

/* XPLAIN_A_REFERENCES */
typedef struct S247 T247;

/* KL_SPECIAL_ROUTINES [XPLAIN_PK_REPRESENTATION] */
typedef struct S248 T248;

/* XPLAIN_PK_I_REPRESENTATION */
typedef struct S249 T249;

/* XPLAIN_I_REFERENCES */
typedef struct S250 T250;

/* SPECIAL [XPLAIN_ATTRIBUTE] */
typedef struct S251 T251;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ATTRIBUTE_NODE] */
typedef struct S252 T252;

/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE] */
typedef struct S254 T254;

/* XPLAIN_VARIABLE_EXPRESSION */
typedef struct S255 T255;

/* XPLAIN_VALUE */
typedef struct S256 T256;

/* XPLAIN_VALUE_EXPRESSION */
typedef struct S257 T257;

/* SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION] */
typedef struct S258 T258;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSERTION] */
typedef struct S259 T259;

/* SPECIAL [detachable XPLAIN_ASSERTION] */
typedef struct S260 T260;

/* XPLAIN_INDEX */
typedef struct S261 T261;

/* SPECIAL [detachable XPLAIN_UPDATE_STATEMENT] */
typedef struct S262 T262;

/* SPECIAL [detachable XPLAIN_DELETE_STATEMENT] */
typedef struct S263 T263;

/* SPECIAL [detachable XPLAIN_CASCADE_STATEMENT] */
typedef struct S264 T264;

/* SPECIAL [detachable XPLAIN_SUBJECT] */
typedef struct S265 T265;

/* SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE] */
typedef struct S266 T266;

/* XPLAIN_INSERT_STATEMENT */
typedef struct S267 T267;

/* SPECIAL [detachable XPLAIN_SELECTION_LIST] */
typedef struct S268 T268;

/* XPLAIN_GET_INSERT_STATEMENT */
typedef struct S269 T269;

/* SPECIAL [XPLAIN_ASSIGNMENT] */
typedef struct S271 T271;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSIGNMENT_NODE] */
typedef struct S272 T272;

/* KL_SPECIAL_ROUTINES [XPLAIN_ASSIGNMENT] */
typedef struct S273 T273;

/* SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION] */
typedef struct S274 T274;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_STATEMENT] */
typedef struct S275 T275;

/* SPECIAL [detachable XPLAIN_SELECTION_FUNCTION] */
typedef struct S276 T276;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION] */
typedef struct S277 T277;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_DELETE_STATEMENT] */
typedef struct S278 T278;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SUBJECT] */
typedef struct S279 T279;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_UPDATE_STATEMENT] */
typedef struct S280 T280;

/* SPECIAL [XPLAIN_VALUE_STATEMENT] */
typedef struct S281 T281;

/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE_STATEMENT] */
typedef struct S282 T282;

/* XPLAIN_SELECTION_EXPRESSION */
typedef struct S283 T283;

/* XPLAIN_LAST_AUTO_PK_EXPRESSION */
typedef struct S285 T285;

/* SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT] */
typedef struct S286 T286;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_VALUE_SELECTION_STATEMENT] */
typedef struct S287 T287;

/* SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION] */
typedef struct S288 T288;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION] */
typedef struct S289 T289;

/* SPECIAL [XPLAIN_FUNCTION] */
typedef struct S290 T290;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_FUNCTION] */
typedef struct S291 T291;

/* SPECIAL [detachable XPLAIN_SELECTION] */
typedef struct S292 T292;

/* SPECIAL [detachable XPLAIN_GET_STATEMENT] */
typedef struct S293 T293;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_GET_STATEMENT] */
typedef struct S294 T294;

/* SPECIAL [detachable XPLAIN_EXTENSION] */
typedef struct S295 T295;

/* SPECIAL [detachable XPLAIN_EXTEND_STATEMENT] */
typedef struct S296 T296;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTEND_STATEMENT] */
typedef struct S297 T297;

/* SPECIAL [XPLAIN_EXTEND_ATTRIBUTE] */
typedef struct S298 T298;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION] */
typedef struct S299 T299;

/* KL_SPECIAL_ROUTINES [XPLAIN_EXTEND_ATTRIBUTE] */
typedef struct S300 T300;

/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION */
typedef struct S301 T301;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION_EXPRESSION] */
typedef struct S302 T302;

/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION */
typedef struct S303 T303;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION] */
typedef struct S304 T304;

/* SPECIAL [detachable XPLAIN_SORT_NODE] */
typedef struct S305 T305;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_LIST] */
typedef struct S306 T306;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SORT_NODE] */
typedef struct S307 T307;

/* XPLAIN_MAX_FUNCTION */
typedef struct S308 T308;

/* KL_SPECIAL_ROUTINES [XPLAIN_FUNCTION] */
typedef struct S309 T309;

/* XPLAIN_MIN_FUNCTION */
typedef struct S310 T310;

/* XPLAIN_TOTAL_FUNCTION */
typedef struct S311 T311;

/* XPLAIN_COUNT_FUNCTION */
typedef struct S312 T312;

/* XPLAIN_ANY_FUNCTION */
typedef struct S313 T313;

/* XPLAIN_NIL_FUNCTION */
typedef struct S314 T314;

/* XPLAIN_SOME_FUNCTION */
typedef struct S315 T315;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXPRESSION_NODE] */
typedef struct S316 T316;

/* SPECIAL [detachable XPLAIN_STATEMENT_NODE] */
typedef struct S317 T317;

/* XPLAIN_PROCEDURE */
typedef struct S318 T318;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_PROCEDURE_STATEMENT] */
typedef struct S319 T319;

/* KL_SPECIAL_ROUTINES [XPLAIN_SQL_STATEMENT] */
typedef struct S320 T320;

/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT_NODE] */
typedef struct S321 T321;

/* YY_FILE_BUFFER */
typedef struct S322 T322;

/* KL_STDIN_FILE */
typedef struct S323 T323;

/* XML_WRITER */
typedef struct S325 T325;

/* KL_TEXT_OUTPUT_FILE */
typedef struct S326 T326;

/* DS_LINKED_LIST [XPLAIN_STATEMENT] */
typedef struct S327 T327;

/* STD_FILES */
typedef struct S328 T328;

/* JOIN_LIST */
typedef struct S329 T329;

/* JOIN_NODE */
typedef struct S330 T330;

/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME] */
typedef struct S335 T335;

/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME] */
typedef struct S336 T336;

/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE] */
typedef struct S337 T337;

/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE] */
typedef struct S338 T338;

/* DS_BILINKED_LIST [XPLAIN_STATEMENT] */
typedef struct S339 T339;

/* XPLAIN_B_RESTRICTION */
typedef struct S342 T342;

/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE] */
typedef struct S344 T344;

/* XPLAIN_LIKE_EXPRESSION */
typedef struct S345 T345;

/* XPLAIN_NOT_LIKE_EXPRESSION */
typedef struct S346 T346;

/* ARRAY [INTEGER_32] */
typedef struct S347 T347;

/* KL_ARRAY_ROUTINES [INTEGER_32] */
typedef struct S348 T348;

/* UTF_CONVERTER */
typedef struct S349 T349;
extern T0* GE_boxed349(T349 a1);
typedef struct Sb349 Tb349;

/* CELL [INTEGER_32] */
typedef struct S350 T350;

/* KL_ARRAY_ROUTINES [detachable ANY] */
typedef struct S351 T351;

/* KL_NULL_TEXT_OUTPUT_STREAM */
typedef struct S352 T352;

/* KL_STRING_OUTPUT_STREAM */
typedef struct S354 T354;

/* DS_CELL [INTEGER_32] */
typedef struct S356 T356;

/* ST_BOOLEAN_FORMATTER */
typedef struct S358 T358;

/* ST_CHARACTER_FORMATTER */
typedef struct S359 T359;

/* ST_FLOATING_POINT_FORMATTER */
typedef struct S360 T360;

/* ST_FIXED_POINT_FORMATTER */
typedef struct S361 T361;

/* ST_FIXED_OR_FLOATING_POINT_FORMATTER */
typedef struct S362 T362;

/* ST_DECIMAL_FORMATTER */
typedef struct S363 T363;

/* ST_UNSIGNED_OCTAL_FORMATTER */
typedef struct S364 T364;

/* ST_UNSIGNED_HEXADECIMAL_FORMATTER */
typedef struct S365 T365;

/* ST_UNSIGNED_DECIMAL_FORMATTER */
typedef struct S366 T366;

/* ST_POINTER_FORMATTER */
typedef struct S367 T367;

/* ST_STRING_FORMATTER */
typedef struct S368 T368;

/* KL_ANY_ROUTINES */
typedef struct S369 T369;

/* UC_STRING */
typedef struct S370 T370;

/* READABLE_STRING_32 */
typedef struct S372 T372;

/* SPECIAL [NATURAL_8] */
typedef struct S373 T373;

/* TYPED_POINTER [SPECIAL [NATURAL_8]] */
typedef struct S374 T374;
extern T0* GE_boxed374(T374 a1);
typedef struct Sb374 Tb374;

/* ARRAY [IMMUTABLE_STRING_32] */
typedef struct S375 T375;

/* SPECIAL [IMMUTABLE_STRING_32] */
typedef struct S376 T376;

/* detachable KL_EQUALITY_TESTER [XPLAIN_VALUE] */
typedef struct S377 T377;

/* detachable KL_EQUALITY_TESTER [STRING_8] */
typedef struct S378 T378;

/* [attached] TYPE [XPLAIN_VALUE] */
#define T379 EIF_TYPE_OBJ

/* [attached] TYPE [STRING_8] */
#define T380 EIF_TYPE_OBJ

/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE] */
typedef struct S381 T381;

/* SPECIAL [XPLAIN_VALUE] */
typedef struct S382 T382;

/* DS_HASH_TABLE_CURSOR [XPLAIN_VALUE, STRING_8] */
typedef struct S383 T383;

/* detachable DS_LINKABLE [XPLAIN_SCANNER_STATE] */
typedef struct S385 T385;

/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE] */
typedef struct S386 T386;

/* XPLAIN_DATA_ATTRIBUTES_CURSOR */
typedef struct S387 T387;

/* XPLAIN_ATTRIBUTE_EXPRESSION */
typedef struct S389 T389;

/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8] */
typedef struct S391 T391;

/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT] */
typedef struct S393 T393;

/* DS_LINKED_STACK [STRING_8] */
typedef struct S394 T394;

/* TYPED_POINTER [ANY] */
typedef struct S395 T395;
extern T0* GE_boxed395(T395 a1);
typedef struct Sb395 Tb395;

/* DS_LINKED_LIST_CURSOR [XPLAIN_STATEMENT] */
typedef struct S396 T396;

/* detachable DS_LINKABLE [XPLAIN_STATEMENT] */
typedef struct S397 T397;

/* STRING_TO_INTEGER_CONVERTOR */
typedef struct S398 T398;

/* JOIN */
typedef struct S401 T401;

/* DS_HASH_SET [STRING_8] */
typedef struct S402 T402;

/* XPLAIN_F_REPRESENTATION */
typedef struct S403 T403;

/* EXCEPTIONS */
typedef struct S405 T405;

/* TYPED_POINTER [NATURAL_8] */
typedef struct S406 T406;
extern T0* GE_boxed406(T406 a1);
typedef struct Sb406 Tb406;

/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE] */
typedef struct S408 T408;

/* KL_INTEGER_ROUTINES */
typedef struct S410 T410;

/* [attached] ARRAY [DS_CELL [INTEGER_32]] */
typedef struct S411 T411;

/* SPECIAL [DS_CELL [INTEGER_32]] */
typedef struct S412 T412;

/* DS_CELL [REAL_64] */
typedef struct S413 T413;

/* KL_CHARACTER_BUFFER */
typedef struct S414 T414;

/* CONSOLE */
typedef struct S415 T415;

/* JOIN_TREE_NODE */
typedef struct S416 T416;

/* DS_LINKED_LIST [JOIN_TREE_NODE] */
typedef struct S417 T417;

/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME] */
typedef struct S418 T418;

/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE] */
typedef struct S419 T419;

/* detachable DS_BILINKABLE [XPLAIN_STATEMENT] */
typedef struct S420 T420;

/* DS_CELL [BOOLEAN] */
typedef struct S421 T421;

/* DS_CELL [CHARACTER_8] */
typedef struct S422 T422;

/* DS_ARRAYED_LIST [INTEGER_32] */
typedef struct S423 T423;

/* KL_DOUBLE_ROUTINES */
typedef struct S424 T424;

/* KL_PLATFORM */
typedef struct S425 T425;

/* DS_CELL [POINTER] */
typedef struct S427 T427;

/* SPECIAL [XPLAIN_ABSTRACT_OBJECT] */
typedef struct S428 T428;

/* detachable KL_EQUALITY_TESTER [XPLAIN_ABSTRACT_OBJECT] */
typedef struct S429 T429;

/* KL_SPECIAL_ROUTINES [XPLAIN_ABSTRACT_OBJECT] */
typedef struct S430 T430;

/* [attached] TYPE [XPLAIN_ABSTRACT_OBJECT] */
#define T431 EIF_TYPE_OBJ

/* DS_HASH_TABLE_CURSOR [XPLAIN_ABSTRACT_OBJECT, STRING_8] */
typedef struct S432 T432;

/* detachable DS_LINKABLE [STRING_8] */
typedef struct S434 T434;

/* TYPED_POINTER [NATURAL_16] */
typedef struct S435 T435;
extern T0* GE_boxed435(T435 a1);
typedef struct Sb435 Tb435;

/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER */
typedef struct S436 T436;

/* INTEGER_OVERFLOW_CHECKER */
typedef struct S437 T437;

/* DS_HASH_SET_CURSOR [STRING_8] */
typedef struct S438 T438;

/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE] */
typedef struct S439 T439;

/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE] */
typedef struct S440 T440;

/* detachable DS_LINKABLE [JOIN_TREE_NODE] */
typedef struct S441 T441;

/* DS_LINKED_LIST_CURSOR [JOIN_TREE_NODE] */
typedef struct S442 T442;

/* DS_ARRAYED_LIST_CURSOR [INTEGER_32] */
typedef struct S443 T443;

/* XPLAIN_VIRTUAL_ATTRIBUTE */
typedef struct S445 T445;

/* XPLAIN_EXTENSION_ATTRIBUTE */
typedef struct S446 T446;

/* XPLAIN_ASSERTION_EXPRESSION */
typedef struct S448 T448;

/* UC_UTF8_ROUTINES */
typedef struct S450 T450;

/* SPECIAL [NATURAL_64] */
typedef struct S452 T452;

/* detachable KL_EQUALITY_TESTER [XPLAIN_TYPE] */
typedef struct S453 T453;

/* detachable DS_HASH_TABLE_CURSOR [INTEGER_32, XPLAIN_TYPE] */
typedef struct S455 T455;

/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME_NODE] */
typedef struct S456 T456;

/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME_NODE] */
typedef struct S457 T457;

/* TYPE [DEVELOPER_EXCEPTION] */
#define T459 EIF_TYPE_OBJ

/* Struct for boxed version of type BOOLEAN */
struct Sb1 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 z1; /* item */
};

/* Struct for boxed version of type CHARACTER_8 */
struct Sb2 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T2 z1; /* item */
};

/* Struct for boxed version of type CHARACTER_32 */
struct Sb3 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T3 z1; /* item */
};

/* Struct for boxed version of type INTEGER_8 */
struct Sb4 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T4 z1; /* item */
};

/* Struct for boxed version of type INTEGER_16 */
struct Sb5 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T5 z1; /* item */
};

/* Struct for boxed version of type INTEGER_32 */
struct Sb6 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 z1; /* item */
};

/* Struct for boxed version of type INTEGER_64 */
struct Sb7 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T7 z1; /* item */
};

/* Struct for boxed version of type NATURAL_8 */
struct Sb8 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T8 z1; /* item */
};

/* Struct for boxed version of type NATURAL_16 */
struct Sb9 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T9 z1; /* item */
};

/* Struct for boxed version of type NATURAL_32 */
struct Sb10 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T10 z1; /* item */
};

/* Struct for boxed version of type NATURAL_64 */
struct Sb11 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T11 z1; /* item */
};

/* Struct for boxed version of type REAL_32 */
struct Sb12 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T12 z1; /* item */
};

/* Struct for boxed version of type REAL_64 */
struct Sb13 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T13 z1; /* item */
};

/* Struct for boxed version of type POINTER */
struct Sb14 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T14 z1; /* item */
};

/* Struct for type UTF_CONVERTER */
struct S349 {
	char dummy;
};

/* Struct for boxed version of type UTF_CONVERTER */
struct Sb349 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T349 z1; /* item */
};

/* Struct for type TYPED_POINTER [NATURAL_16] */
struct S435 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T14 a1; /* to_pointer */
};

/* Struct for boxed version of type TYPED_POINTER [NATURAL_16] */
struct Sb435 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T435 z1; /* item */
};

/* Struct for type TYPED_POINTER [NATURAL_8] */
struct S406 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T14 a1; /* to_pointer */
};

/* Struct for boxed version of type TYPED_POINTER [NATURAL_8] */
struct Sb406 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T406 z1; /* item */
};

/* Struct for type TYPED_POINTER [ANY] */
struct S395 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T14 a1; /* to_pointer */
};

/* Struct for boxed version of type TYPED_POINTER [ANY] */
struct Sb395 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T395 z1; /* item */
};

/* Struct for type TYPED_POINTER [SPECIAL [NATURAL_8]] */
struct S374 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T14 a1; /* to_pointer */
};

/* Struct for boxed version of type TYPED_POINTER [SPECIAL [NATURAL_8]] */
struct Sb374 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T374 z1; /* item */
};

/* Struct for type SPECIAL [CHARACTER_8] */
struct S15 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T2 z2[1]; /* item */
};

/* Struct for type SPECIAL [CHARACTER_32] */
struct S16 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T3 z2[1]; /* item */
};

/* Struct for type STRING_8 */
struct S17 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* area */
	T6 a2; /* count */
	T6 a3; /* internal_hash_code */
	T6 a4; /* internal_case_insensitive_hash_code */
};

/* Struct for type IMMUTABLE_STRING_32 */
struct S19 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* area */
	T6 a2; /* count */
	T6 a3; /* internal_hash_code */
	T6 a4; /* area_lower */
};

/* Struct for type ISE_EXCEPTION_MANAGER */
struct S20 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN2SQL */
struct S24 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* parser */
};

/* Struct for type CELL [detachable EXCEPTION] */
struct S25 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
};

/* Struct for type HASH_TABLE [INTEGER_32, INTEGER_32] */
struct S26 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* capacity */
	T0* a2; /* content */
	T0* a3; /* keys */
	T0* a4; /* deleted_marks */
	T0* a5; /* indexes_map */
	T6 a6; /* iteration_position */
	T6 a7; /* count */
	T6 a8; /* deleted_item_position */
	T6 a9; /* control */
	T6 a10; /* found_item */
	T1 a11; /* has_default */
	T6 a12; /* item_position */
	T6 a13; /* ht_lowest_deleted_position */
	T6 a14; /* ht_deleted_item */
	T6 a15; /* ht_deleted_key */
	T1 a16; /* object_comparison */
};

/* Struct for type CELL [detachable TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN]] */
struct S27 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
};

/* Struct for type CELL [NO_MORE_MEMORY] */
struct S28 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
};

/* Struct for type C_STRING */
struct S29 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* managed_data */
	T6 a2; /* count */
};

/* Struct for type [attached] TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN] */
struct S30 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 z1;
	T6 z2;
	T6 z3;
	T0* z4;
	T0* z5;
	T0* z6;
	T0* z7;
	T0* z8;
	T0* z9;
	T6 z10;
	T1 z11;
};

/* Struct for type KL_TEXT_INPUT_FILE */
struct S31 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* mode */
	T0* a2; /* last_string */
	T0* a3; /* name */
	T0* a4; /* character_buffer */
	T1 a5; /* end_of_file */
	T14 a6; /* file_pointer */
	T1 a7; /* descriptor_available */
	T0* a8; /* internal_name */
	T0* a9; /* internal_detachable_name_pointer */
	T2 a10; /* last_character */
};

/* Struct for type KL_ARGUMENTS */
struct S34 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* program_name */
};

/* Struct for type [attached] ARRAY [[attached] STRING_8] */
struct S35 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* area */
	T6 a2; /* lower */
	T6 a3; /* upper */
};

/* Struct for type SPECIAL [[attached] STRING_8] */
struct S36 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type ARRAY [ANY] */
struct S37 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* area */
	T6 a2; /* lower */
	T6 a3; /* upper */
};

/* Struct for type SPECIAL [ANY] */
struct S38 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_STANDARD_FILES */
struct S39 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_STDERR_FILE */
struct S40 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SQL_GENERATOR_ANSI */
struct S41 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_BASIC */
struct S42 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_DB2_6 */
struct S43 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_DB2_71 */
struct S44 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* is_stored_procedure */
	T1 a21; /* ValueTableCreated */
	T1 a22; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_FOXPRO */
struct S45 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_INTERBASE6 */
struct S46 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* init_error */
	T1 a2; /* DomainsEnabled */
	T1 a3; /* AttributeRequiredEnabled */
	T1 a4; /* AutoPrimaryKeyEnabled */
	T1 a5; /* SetDatabaseEnabled */
	T1 a6; /* StoredProcedureEnabled */
	T1 a7; /* IdentifierWithSpacesEnabled */
	T1 a8; /* TimestampEnabled */
	T1 a9; /* ViewsEnabled */
	T1 a10; /* ExtendIndex */
	T1 a11; /* ExtendView */
	T0* a12; /* declared_values */
	T1 a13; /* AssertEnabled */
	T1 a14; /* OldConstraintNames */
	T1 a15; /* TimeZoneEnabled */
	T1 a16; /* sequence_name_format_one_parameter */
	T1 a17; /* ConstantTableCreated */
	T0* a18; /* update_type */
	T0* a19; /* updated_extension */
	T1 a20; /* InUpdateStatement */
	T1 a21; /* is_stored_procedure */
	T1 a22; /* ValueTableCreated */
	T1 a23; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_FIREBIRD_21 */
struct S47 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* init_error */
	T1 a2; /* DomainsEnabled */
	T1 a3; /* AttributeRequiredEnabled */
	T1 a4; /* AutoPrimaryKeyEnabled */
	T1 a5; /* SetDatabaseEnabled */
	T1 a6; /* StoredProcedureEnabled */
	T1 a7; /* IdentifierWithSpacesEnabled */
	T1 a8; /* TimestampEnabled */
	T1 a9; /* ViewsEnabled */
	T1 a10; /* ExtendIndex */
	T1 a11; /* ExtendView */
	T0* a12; /* declared_values */
	T1 a13; /* AssertEnabled */
	T1 a14; /* OldConstraintNames */
	T1 a15; /* TimeZoneEnabled */
	T1 a16; /* sequence_name_format_one_parameter */
	T1 a17; /* ConstantTableCreated */
	T0* a18; /* update_type */
	T0* a19; /* updated_extension */
	T1 a20; /* InUpdateStatement */
	T1 a21; /* is_stored_procedure */
	T1 a22; /* ValueTableCreated */
	T1 a23; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_MSACCESS97 */
struct S48 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_MSACCESS2000 */
struct S49 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_MSQL */
struct S50 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_MYSQL5 */
struct S51 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* is_stored_procedure */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_MYSQL4 */
struct S52 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_MYSQL322 */
struct S53 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_ORACLE */
struct S54 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* is_stored_procedure */
	T1 a21; /* ValueTableCreated */
	T1 a22; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_PGSQL_95 */
struct S55 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* is_stored_procedure */
	T1 a21; /* in_user_declaration */
	T1 a22; /* ValueTableCreated */
	T1 a23; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_PGSQL_82 */
struct S56 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* is_stored_procedure */
	T1 a21; /* in_user_declaration */
	T1 a22; /* ValueTableCreated */
	T1 a23; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_PGSQL_81 */
struct S57 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* is_stored_procedure */
	T1 a21; /* in_user_declaration */
	T1 a22; /* ValueTableCreated */
	T1 a23; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_PGSQL_73 */
struct S58 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* is_stored_procedure */
	T1 a21; /* in_user_declaration */
	T1 a22; /* ValueTableCreated */
	T1 a23; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_PGSQL_72 */
struct S59 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* is_stored_procedure */
	T1 a21; /* in_user_declaration */
	T1 a22; /* ValueTableCreated */
	T1 a23; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_SQLITE_3 */
struct S60 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T0* a17; /* update_type */
	T0* a18; /* updated_extension */
	T1 a19; /* InUpdateStatement */
	T1 a20; /* ValueTableCreated */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_TSQL2016 */
struct S61 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T1 a17; /* is_stored_procedure */
	T0* a18; /* update_type */
	T0* a19; /* updated_extension */
	T1 a20; /* InUpdateStatement */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_TSQL2000 */
struct S62 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T1 a17; /* is_stored_procedure */
	T0* a18; /* update_type */
	T0* a19; /* updated_extension */
	T1 a20; /* InUpdateStatement */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_TSQL70 */
struct S63 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T1 a17; /* is_stored_procedure */
	T0* a18; /* update_type */
	T0* a19; /* updated_extension */
	T1 a20; /* InUpdateStatement */
	T1 a21; /* WhereWritten */
};

/* Struct for type SQL_GENERATOR_TSQL65 */
struct S64 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* DomainsEnabled */
	T1 a2; /* AttributeRequiredEnabled */
	T1 a3; /* AutoPrimaryKeyEnabled */
	T1 a4; /* SetDatabaseEnabled */
	T1 a5; /* StoredProcedureEnabled */
	T1 a6; /* IdentifierWithSpacesEnabled */
	T1 a7; /* TimestampEnabled */
	T1 a8; /* ViewsEnabled */
	T1 a9; /* ExtendIndex */
	T1 a10; /* ExtendView */
	T0* a11; /* declared_values */
	T1 a12; /* AssertEnabled */
	T1 a13; /* OldConstraintNames */
	T1 a14; /* TimeZoneEnabled */
	T1 a15; /* sequence_name_format_one_parameter */
	T1 a16; /* ConstantTableCreated */
	T1 a17; /* is_stored_procedure */
	T0* a18; /* update_type */
	T0* a19; /* updated_extension */
	T1 a20; /* InUpdateStatement */
	T1 a21; /* WhereWritten */
};

/* Struct for type XPLAIN_PARSER */
struct S65 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* statements */
	T6 a2; /* yy_parsing_status */
	T0* a3; /* mwgenerator */
	T6 a4; /* yy_suspended_yystacksize */
	T6 a5; /* yy_suspended_yystate */
	T6 a6; /* yy_suspended_yyn */
	T6 a7; /* yy_suspended_yychar1 */
	T6 a8; /* yy_suspended_index */
	T6 a9; /* yy_suspended_yyss_top */
	T6 a10; /* yy_suspended_yy_goto */
	T0* a11; /* yyr1 */
	T0* a12; /* yyss */
	T6 a13; /* yyssp */
	T0* a14; /* yypgoto */
	T0* a15; /* yycheck */
	T0* a16; /* yytable */
	T0* a17; /* yydefgoto */
	T6 a18; /* error_count */
	T1 a19; /* yy_lookahead_needed */
	T6 a20; /* yyerrstatus */
	T0* a21; /* yypact */
	T6 a22; /* last_token */
	T0* a23; /* yytranslate */
	T0* a24; /* yydefact */
	T0* a25; /* input_buffer */
	T0* a26; /* saved_state */
	T0* a27; /* dummyrestriction */
	T6 a28; /* yyvsp1 */
	T6 a29; /* yyvsp2 */
	T6 a30; /* yyvsp3 */
	T6 a31; /* yyvsp4 */
	T6 a32; /* yyvsp5 */
	T6 a33; /* yyvsp6 */
	T6 a34; /* yyvsp7 */
	T6 a35; /* yyvsp8 */
	T6 a36; /* yyvsp9 */
	T6 a37; /* yyvsp10 */
	T6 a38; /* yyvsp11 */
	T6 a39; /* yyvsp12 */
	T6 a40; /* yyvsp13 */
	T6 a41; /* yyvsp14 */
	T6 a42; /* yyvsp15 */
	T6 a43; /* yyvsp16 */
	T6 a44; /* yyvsp17 */
	T6 a45; /* yyvsp18 */
	T6 a46; /* yyvsp19 */
	T6 a47; /* yyvsp20 */
	T6 a48; /* yyvsp21 */
	T6 a49; /* yyvsp22 */
	T6 a50; /* yyvsp23 */
	T6 a51; /* yyvsp24 */
	T6 a52; /* yyvsp25 */
	T6 a53; /* yyvsp26 */
	T6 a54; /* yyvsp27 */
	T6 a55; /* yyvsp28 */
	T6 a56; /* yyvsp29 */
	T6 a57; /* yyvsp30 */
	T6 a58; /* yyvsp31 */
	T6 a59; /* yyvsp32 */
	T6 a60; /* yyvsp33 */
	T6 a61; /* yyvsp34 */
	T6 a62; /* yyvsp35 */
	T6 a63; /* yyvsp36 */
	T6 a64; /* yyvsp37 */
	T6 a65; /* yyvsp38 */
	T6 a66; /* yyvsp39 */
	T6 a67; /* yyvsp40 */
	T6 a68; /* yyvsp41 */
	T6 a69; /* yyvsp42 */
	T6 a70; /* yyvsp43 */
	T6 a71; /* yyvsp44 */
	T6 a72; /* yyvsp45 */
	T6 a73; /* yyvsp46 */
	T6 a74; /* yyvsp47 */
	T6 a75; /* yyvsp48 */
	T6 a76; /* yyvsp49 */
	T6 a77; /* yyvsp50 */
	T1 a78; /* yy_more_flag */
	T6 a79; /* yy_more_len */
	T6 a80; /* yy_end */
	T6 a81; /* yy_start */
	T6 a82; /* line */
	T6 a83; /* yy_line */
	T6 a84; /* column */
	T6 a85; /* yy_column */
	T6 a86; /* position */
	T6 a87; /* yy_position */
	T6 a88; /* yy_start_state */
	T0* a89; /* yy_state_stack */
	T6 a90; /* yy_state_count */
	T0* a91; /* yy_content_area */
	T0* a92; /* yy_ec */
	T0* a93; /* yy_content */
	T0* a94; /* yy_accept */
	T6 a95; /* yy_last_accepting_state */
	T6 a96; /* yy_last_accepting_cpos */
	T0* a97; /* yy_chk */
	T0* a98; /* yy_base */
	T0* a99; /* yy_def */
	T0* a100; /* yy_meta */
	T0* a101; /* yy_nxt */
	T6 a102; /* yy_lp */
	T0* a103; /* yy_acclist */
	T6 a104; /* yy_looking_for_trail_begin */
	T6 a105; /* yy_full_match */
	T6 a106; /* yy_full_state */
	T6 a107; /* yy_full_lp */
	T1 a108; /* yy_rejected */
	T0* a109; /* yytypes2 */
	T6 a110; /* yyvsc1 */
	T0* a111; /* yyvs1 */
	T0* a112; /* yyspecial_routines1 */
	T0* a113; /* last_detachable_any_value */
	T6 a114; /* yyvsc2 */
	T0* a115; /* yyvs2 */
	T0* a116; /* yyspecial_routines2 */
	T0* a117; /* last_string_value */
	T6 a118; /* yyvsc3 */
	T0* a119; /* yyvs3 */
	T0* a120; /* yyspecial_routines3 */
	T6 a121; /* last_integer_value */
	T0* a122; /* sqlgenerator */
	T0* a123; /* yyvs38 */
	T0* a124; /* yyvs47 */
	T0* a125; /* yyspecial_routines38 */
	T0* a126; /* yyvs46 */
	T6 a127; /* yyvsc38 */
	T0* a128; /* yyvs40 */
	T0* a129; /* yyvs15 */
	T0* a130; /* yyvs4 */
	T0* a131; /* yyvs39 */
	T0* a132; /* yyvs10 */
	T1 a133; /* constant_mode */
	T0* a134; /* yyspecial_routines40 */
	T6 a135; /* yyvsc40 */
	T0* a136; /* yyvs17 */
	T6 a137; /* yyvsc4 */
	T0* a138; /* yyspecial_routines4 */
	T0* a139; /* yyvs6 */
	T0* a140; /* yyvs19 */
	T0* a141; /* yyvs18 */
	T0* a142; /* pending_type */
	T6 a143; /* yyvsc15 */
	T0* a144; /* yyspecial_routines15 */
	T0* a145; /* pending_init */
	T1 a146; /* is_init_default */
	T0* a147; /* myvariable */
	T6 a148; /* yyvsc39 */
	T0* a149; /* yyspecial_routines39 */
	T0* a150; /* subject_type */
	T0* a151; /* yyvs14 */
	T0* a152; /* yyspecial_routines6 */
	T6 a153; /* yyvsc6 */
	T0* a154; /* yyvs7 */
	T0* a155; /* yyvs8 */
	T6 a156; /* yyvsc7 */
	T0* a157; /* yyspecial_routines7 */
	T6 a158; /* yyvsc8 */
	T0* a159; /* yyspecial_routines8 */
	T6 a160; /* last_width */
	T0* a161; /* yyvs9 */
	T0* a162; /* yyspecial_routines9 */
	T6 a163; /* yyvsc9 */
	T0* a164; /* yyspecial_routines10 */
	T0* a165; /* yyvs13 */
	T0* a166; /* last_object_in_tree */
	T6 a167; /* yyvsc10 */
	T0* a168; /* yyvs11 */
	T6 a169; /* yyvsc11 */
	T0* a170; /* yyspecial_routines11 */
	T6 a171; /* yyvsc12 */
	T0* a172; /* yyvs12 */
	T0* a173; /* yyspecial_routines12 */
	T0* a174; /* yyvs35 */
	T6 a175; /* yyvsc13 */
	T0* a176; /* yyspecial_routines13 */
	T6 a177; /* yyvsc14 */
	T0* a178; /* yyspecial_routines14 */
	T0* a179; /* yyvs16 */
	T6 a180; /* yyvsc16 */
	T0* a181; /* yyspecial_routines16 */
	T6 a182; /* yyvsc17 */
	T0* a183; /* yyspecial_routines17 */
	T0* a184; /* dummya */
	T6 a185; /* yyvsc18 */
	T0* a186; /* yyspecial_routines18 */
	T0* a187; /* dummyi */
	T0* a188; /* current_type_name */
	T0* a189; /* yyvs20 */
	T6 a190; /* yyvsc19 */
	T0* a191; /* yyspecial_routines19 */
	T6 a192; /* yyvsc20 */
	T0* a193; /* yyspecial_routines20 */
	T0* a194; /* dummye */
	T6 a195; /* yyvsc5 */
	T0* a196; /* yyvs5 */
	T0* a197; /* yyspecial_routines5 */
	T0* a198; /* extend_type */
	T0* a199; /* yyvs30 */
	T0* a200; /* yyspecial_routines21 */
	T0* a201; /* yyvs21 */
	T6 a202; /* yyvsc21 */
	T0* a203; /* yyvs22 */
	T0* a204; /* myindex */
	T6 a205; /* yyvsc22 */
	T0* a206; /* yyspecial_routines22 */
	T0* a207; /* yyvs48 */
	T0* a208; /* yyvs43 */
	T0* a209; /* yyvs41 */
	T0* a210; /* yyvs25 */
	T0* a211; /* yyvs23 */
	T0* a212; /* yyvs32 */
	T0* a213; /* yyvs24 */
	T6 a214; /* yyvsc23 */
	T0* a215; /* yyspecial_routines23 */
	T6 a216; /* yyvsc24 */
	T0* a217; /* yyspecial_routines24 */
	T0* a218; /* yyvs42 */
	T0* a219; /* yyspecial_routines41 */
	T6 a220; /* yyvsc41 */
	T0* a221; /* yyvs27 */
	T6 a222; /* yyvsc42 */
	T0* a223; /* yyspecial_routines42 */
	T6 a224; /* yyvsc43 */
	T0* a225; /* yyspecial_routines43 */
	T6 a226; /* yyvsc25 */
	T0* a227; /* yyspecial_routines25 */
	T6 a228; /* yyvsc48 */
	T0* a229; /* yyspecial_routines48 */
	T6 a230; /* yyvsc49 */
	T0* a231; /* yyvs49 */
	T0* a232; /* yyspecial_routines49 */
	T6 a233; /* yyvsc50 */
	T0* a234; /* yyvs50 */
	T0* a235; /* yyspecial_routines50 */
	T6 a236; /* yyvsc26 */
	T0* a237; /* yyvs26 */
	T0* a238; /* yyspecial_routines26 */
	T0* a239; /* yyvs34 */
	T6 a240; /* yyvsc27 */
	T0* a241; /* yyspecial_routines27 */
	T0* a242; /* yyvs31 */
	T6 a243; /* yyvsc45 */
	T0* a244; /* yyvs45 */
	T0* a245; /* yyspecial_routines45 */
	T0* a246; /* yyvs28 */
	T6 a247; /* yyvsc44 */
	T0* a248; /* yyvs44 */
	T0* a249; /* yyspecial_routines44 */
	T0* a250; /* yyvs29 */
	T0* a251; /* yyspecial_routines28 */
	T6 a252; /* yyvsc28 */
	T6 a253; /* yyvsc29 */
	T0* a254; /* yyspecial_routines29 */
	T6 a255; /* yyvsc30 */
	T0* a256; /* yyspecial_routines30 */
	T6 a257; /* yyvsc31 */
	T0* a258; /* yyspecial_routines31 */
	T0* a259; /* yyvs33 */
	T6 a260; /* yyvsc32 */
	T0* a261; /* yyspecial_routines32 */
	T6 a262; /* yyvsc33 */
	T0* a263; /* yyspecial_routines33 */
	T6 a264; /* yyvsc34 */
	T0* a265; /* yyspecial_routines34 */
	T6 a266; /* yyvsc35 */
	T0* a267; /* yyspecial_routines35 */
	T0* a268; /* yyvs36 */
	T6 a269; /* yyvsc36 */
	T0* a270; /* yyspecial_routines36 */
	T1 a271; /* procedure_mode */
	T0* a272; /* yyvs37 */
	T0* a273; /* yyspecial_routines46 */
	T6 a274; /* yyvsc46 */
	T0* a275; /* my_parameters */
	T6 a276; /* yyvsc47 */
	T0* a277; /* yyspecial_routines47 */
	T6 a278; /* yyvsc37 */
	T0* a279; /* yyspecial_routines37 */
	T0* a280; /* yytypes1 */
	T0* a281; /* my_sql */
	T1 a282; /* expect_domain */
	T0* a283; /* yy_pushed_start_conditions */
	T2 a284; /* last_character */
};

/* Struct for type XML_GENERATOR */
struct S67 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* sqlgenerator */
	T0* a2; /* xml */
};

/* Struct for type XPLAIN_STATEMENTS */
struct S69 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* statements */
};

/* Struct for type VOID_TARGET */
struct S72 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type ROUTINE_FAILURE */
struct S74 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* routine_name */
	T0* a2; /* class_name */
	T0* a3; /* throwing_exception */
	T0* a4; /* internal_trace */
	T0* a5; /* c_description */
	T0* a6; /* recipient_name */
	T0* a7; /* type_name */
};

/* Struct for type OLD_VIOLATION */
struct S76 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type NO_MORE_MEMORY */
struct S78 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* internal_trace */
	T6 a2; /* internal_code */
	T0* a3; /* throwing_exception */
	T0* a4; /* c_description */
	T0* a5; /* recipient_name */
	T0* a6; /* type_name */
};

/* Struct for type INVARIANT_VIOLATION */
struct S79 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T1 a2; /* is_entry */
	T0* a3; /* internal_trace */
	T0* a4; /* c_description */
	T0* a5; /* recipient_name */
	T0* a6; /* type_name */
};

/* Struct for type OPERATING_SYSTEM_SIGNAL_FAILURE */
struct S80 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T6 a2; /* signal_code */
	T0* a3; /* internal_trace */
	T0* a4; /* c_description */
	T0* a5; /* recipient_name */
	T0* a6; /* type_name */
};

/* Struct for type IO_FAILURE */
struct S81 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* internal_code */
	T0* a2; /* throwing_exception */
	T6 a3; /* error_code */
	T0* a4; /* internal_trace */
	T0* a5; /* c_description */
	T0* a6; /* recipient_name */
	T0* a7; /* type_name */
};

/* Struct for type OPERATING_SYSTEM_FAILURE */
struct S82 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T6 a2; /* error_code */
	T0* a3; /* internal_trace */
	T0* a4; /* c_description */
	T0* a5; /* recipient_name */
	T0* a6; /* type_name */
};

/* Struct for type COM_FAILURE */
struct S83 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T6 a2; /* hresult_code */
	T0* a3; /* exception_information */
	T6 a4; /* hresult */
	T0* a5; /* internal_trace */
	T0* a6; /* c_description */
	T0* a7; /* recipient_name */
	T0* a8; /* type_name */
};

/* Struct for type EIFFEL_RUNTIME_PANIC */
struct S84 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* internal_code */
	T0* a2; /* throwing_exception */
	T0* a3; /* internal_trace */
	T0* a4; /* c_description */
	T0* a5; /* recipient_name */
	T0* a6; /* type_name */
};

/* Struct for type PRECONDITION_VIOLATION */
struct S86 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type POSTCONDITION_VIOLATION */
struct S87 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type FLOATING_POINT_FAILURE */
struct S88 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type CHECK_VIOLATION */
struct S89 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type BAD_INSPECT_VALUE */
struct S90 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type VARIANT_VIOLATION */
struct S91 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type LOOP_INVARIANT_VIOLATION */
struct S92 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type RESCUE_FAILURE */
struct S93 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type RESUMPTION_FAILURE */
struct S94 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type CREATE_ON_DEFERRED */
struct S95 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type EXTERNAL_FAILURE */
struct S96 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type VOID_ASSIGNED_TO_EXPANDED */
struct S97 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type EXCEPTION_IN_SIGNAL_HANDLER_FAILURE */
struct S98 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type MISMATCH_FAILURE */
struct S99 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type DEVELOPER_EXCEPTION */
struct S100 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type ADDRESS_APPLIED_TO_MELTED_FEATURE */
struct S101 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type SERIALIZATION_FAILURE */
struct S102 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* throwing_exception */
	T0* a2; /* internal_trace */
	T0* a3; /* c_description */
	T0* a4; /* recipient_name */
	T0* a5; /* type_name */
};

/* Struct for type ST_SCIENTIFIC_FORMATTER */
struct S103 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* string_output_stream */
	T0* a2; /* error */
	T2 a3; /* escape_character */
	T0* a4; /* boolean_formatter */
	T0* a5; /* character_formatter */
	T0* a6; /* floating_point_formatter */
	T0* a7; /* fixed_point_formatter */
	T0* a8; /* fixed_or_floating_point_formatter */
	T0* a9; /* decimal_formatter */
	T0* a10; /* octal_formatter */
	T0* a11; /* hexadecimal_formatter */
	T0* a12; /* unsigned_decimal_formatter */
	T0* a13; /* pointer_formatter */
	T0* a14; /* string_formatter */
	T0* a15; /* single_parameter */
};

/* Struct for type PRIMES */
struct S104 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [INTEGER_32] */
struct S105 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T6 z2[1]; /* item */
};

/* Struct for type SPECIAL [BOOLEAN] */
struct S106 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T1 z2[1]; /* item */
};

/* Struct for type KL_STRING_ROUTINES */
struct S108 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type MANAGED_POINTER */
struct S111 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T14 a1; /* item */
	T6 a2; /* count */
	T1 a3; /* is_shared */
};

/* Struct for type FILE_INFO */
struct S112 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* buffered_file_info */
	T1 a2; /* is_following_symlinks */
	T1 a3; /* exists */
	T0* a4; /* internal_file_name */
	T0* a5; /* internal_name_pointer */
};

/* Struct for type ARGUMENTS_32 */
struct S113 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type DS_HASH_TABLE [XPLAIN_VALUE, STRING_8] */
struct S114 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* equality_tester */
	T0* a2; /* key_equality_tester */
	T6 a3; /* position */
	T6 a4; /* count */
	T6 a5; /* capacity */
	T6 a6; /* slots_position */
	T6 a7; /* free_slot */
	T6 a8; /* last_position */
	T6 a9; /* found_position */
	T6 a10; /* modulus */
	T6 a11; /* clashes_previous_position */
	T0* a12; /* special_item_routines */
	T0* a13; /* item_storage */
	T0* a14; /* clashes */
	T0* a15; /* slots */
	T0* a16; /* special_key_routines */
	T0* a17; /* key_storage */
	T0* a18; /* internal_keys */
	T0* a19; /* internal_cursor */
	T0* a20; /* hash_function */
};

/* Struct for type KL_STDOUT_FILE */
struct S115 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [INTEGER_32] */
struct S117 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_SCANNER_STATE */
struct S118 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* filename */
	T0* a2; /* directory */
	T1 a3; /* use_mode */
	T0* a4; /* input_buffer */
};

/* Struct for type DS_LINKED_LIST [XPLAIN_SCANNER_STATE] */
struct S120 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* count */
	T0* a2; /* last_cell */
	T0* a3; /* first_cell */
	T0* a4; /* internal_cursor */
};

/* Struct for type XPLAIN_REQUIRED */
struct S122 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* required */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable ANY] */
struct S124 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [STRING_8] */
struct S125 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT */
struct S127 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* constant */
	T0* a2; /* expression */
};

/* Struct for type XPLAIN_BASE */
struct S128 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* name */
	T0* a2; /* representation */
};

/* Struct for type XPLAIN_TYPE */
struct S129 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* representation */
	T0* a2; /* attributes */
	T6 a3; /* constraint_number */
	T0* a4; /* name */
	T0* a5; /* abstract_representation */
};

/* Struct for type XPLAIN_CONSTANT_STATEMENT */
struct S130 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* constant */
};

/* Struct for type XPLAIN_A_NODE */
struct S131 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* next */
};

/* Struct for type XPLAIN_I_NODE */
struct S132 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* next */
};

/* Struct for type XPLAIN_LOGICAL_EXPRESSION */
struct S133 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* expression */
};

/* Struct for type XPLAIN_LOGICAL_VALUE_EXPRESSION */
struct S135 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* value */
};

/* Struct for type XPLAIN_ATTRIBUTE_NAME_NODE */
struct S137 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* next */
	T0* a3; /* prefix_table */
};

/* Struct for type XPLAIN_ATTRIBUTE_NAME */
struct S138 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* role */
	T0* a2; /* name */
	T0* a3; /* object */
	T0* a4; /* type_attribute */
};

/* Struct for type XPLAIN_ATTRIBUTE_NODE */
struct S141 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* next */
};

/* Struct for type XPLAIN_ATTRIBUTE */
struct S142 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* role */
	T0* a2; /* internal_abstracttype */
	T1 a3; /* overrule_required */
	T1 a4; /* is_required */
	T1 a5; /* is_specialization */
	T1 a6; /* is_unique */
	T0* a7; /* init */
	T1 a8; /* is_init_default */
};

/* Struct for type XPLAIN_ASSERTION */
struct S143 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* type */
	T0* a2; /* name */
	T0* a3; /* expression */
	T0* a4; /* range */
	T0* a5; /* attributes */
	T0* a6; /* representation */
	T0* a7; /* abstract_extension_representation */
	T1 a8; /* no_update_optimization */
	T0* a9; /* abstract_representation */
	T1 a10; /* explicit_domain */
	T6 a11; /* constraint_number */
};

/* Struct for type XPLAIN_ASSIGNMENT_NODE */
struct S144 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* next */
};

/* Struct for type XPLAIN_ASSIGNMENT */
struct S145 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* attribute_name */
	T0* a2; /* expression */
};

/* Struct for type XPLAIN_CASCADE_STATEMENT */
struct S146 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* subtype */
	T0* a2; /* cascade_attribute */
	T0* a3; /* definition */
	T0* a4; /* counter_statement */
	T0* a5; /* increment_value_statement */
	T0* a6; /* finished_statement */
};

/* Struct for type XPLAIN_CASCADE_FUNCTION_EXPRESSION */
struct S147 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* selection */
	T0* a2; /* grouping_attributes */
};

/* Struct for type XPLAIN_DELETE_STATEMENT */
struct S148 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* subject */
	T0* a2; /* predicate */
};

/* Struct for type XPLAIN_SUBJECT */
struct S149 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* type */
	T0* a2; /* identification */
};

/* Struct for type XPLAIN_UPDATE_STATEMENT */
struct S150 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* subject */
	T0* a2; /* assignment_list */
	T0* a3; /* predicate */
};

/* Struct for type XPLAIN_VALUE_STATEMENT */
struct S151 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* value */
};

/* Struct for type XPLAIN_VALUE_SELECTION_STATEMENT */
struct S152 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* value */
};

/* Struct for type XPLAIN_SELECTION_FUNCTION */
struct S154 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* function */
	T0* a2; /* subject */
	T0* a3; /* property */
	T0* a4; /* predicate */
};

/* Struct for type XPLAIN_GET_STATEMENT */
struct S155 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* selection */
};

/* Struct for type XPLAIN_EXTEND_STATEMENT */
struct S156 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* extension */
};

/* Struct for type XPLAIN_EXTENSION */
struct S157 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* type */
	T0* a2; /* expression */
	T0* a3; /* attributes */
	T1 a4; /* explicit_domain */
	T0* a5; /* representation */
	T0* a6; /* abstract_extension_representation */
	T0* a7; /* name */
	T0* a8; /* abstract_representation */
	T1 a9; /* no_update_optimization */
	T6 a10; /* constraint_number */
};

/* Struct for type XPLAIN_EXTEND_ATTRIBUTE */
struct S158 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* name */
	T0* a2; /* domain */
};

/* Struct for type XPLAIN_EXTENSION_EXPRESSION */
struct S159 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* extension */
	T0* a2; /* anode */
};

/* Struct for type XPLAIN_SELECTION_LIST */
struct S161 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* subject */
	T0* a2; /* expression_list */
	T0* a3; /* predicate */
	T0* a4; /* sort_order */
	T0* a5; /* identification_text */
};

/* Struct for type XPLAIN_SORT_NODE */
struct S162 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* ascending */
	T0* a2; /* item */
	T0* a3; /* next */
};

/* Struct for type XPLAIN_EXPRESSION_NODE */
struct S164 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* new_name */
	T0* a2; /* item */
	T0* a3; /* next */
};

/* Struct for type XPLAIN_PROCEDURE_STATEMENT */
struct S165 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* procedure */
};

/* Struct for type XPLAIN_SQL_STATEMENT */
struct S166 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* sql */
};

/* Struct for type XPLAIN_STATEMENT_NODE */
struct S167 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* next */
};

/* Struct for type SPECIAL [detachable XPLAIN_STATEMENT] */
struct S168 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [XPLAIN_SQL_STATEMENT] */
struct S169 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT] */
struct S170 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT] */
struct S171 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT] */
struct S172 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_TYPE] */
struct S173 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_TYPE_STATEMENT */
struct S174 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* type */
};

/* Struct for type XPLAIN_UNIVERSE */
struct S175 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* objects */
};

/* Struct for type SPECIAL [XPLAIN_BASE] */
struct S176 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_BASE_STATEMENT */
struct S177 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* base */
};

/* Struct for type SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT] */
struct S178 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_VARIABLE */
struct S179 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* representation */
	T0* a2; /* name */
	T0* a3; /* value */
};

/* Struct for type SPECIAL [XPLAIN_EXPRESSION] */
struct S180 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT] */
struct S181 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_REPRESENTATION] */
struct S182 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_BASE] */
struct S183 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_DOMAIN_RESTRICTION] */
struct S184 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE] */
struct S185 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [XPLAIN_PK_REPRESENTATION] */
struct S186 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_TYPE] */
struct S187 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_STATEMENT] */
struct S188 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_ATTRIBUTE_NAME] */
struct S190 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_DOMAIN_RESTRICTION] */
struct S191 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_A_PATTERN */
struct S192 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* pattern */
	T1 a2; /* required */
};

/* Struct for type SPECIAL [XPLAIN_A_NODE] */
struct S193 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_A_ENUMERATION */
struct S194 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* first */
	T1 a2; /* required */
};

/* Struct for type SPECIAL [XPLAIN_I_NODE] */
struct S195 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_I_ENUMERATION */
struct S196 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* first */
	T1 a2; /* required */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_A_NODE] */
struct S197 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_I_NODE] */
struct S199 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_TRAJECTORY */
struct S200 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* min */
	T0* a2; /* max */
	T1 a3; /* required */
};

/* Struct for type SPECIAL [XPLAIN_LOGICAL_EXPRESSION] */
struct S201 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_EXPRESSION] */
struct S202 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_LOGICAL_INFIX_EXPRESSION */
struct S203 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* operator */
	T0* a2; /* left */
	T0* a3; /* right */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_EXPRESSION] */
struct S204 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE] */
struct S205 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_NOTNOT_EXPRESSION */
struct S206 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* expression */
};

/* Struct for type XPLAIN_NOT_EXPRESSION */
struct S207 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* operand */
	T0* a2; /* operator */
};

/* Struct for type XPLAIN_PARAMETER_EXPRESSION */
struct S208 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* name */
};

/* Struct for type XPLAIN_EQ_NULL_EXPRESSION */
struct S209 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* expression */
};

/* Struct for type XPLAIN_NE_NULL_EXPRESSION */
struct S210 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* expression */
};

/* Struct for type XPLAIN_INFIX_EXPRESSION */
struct S211 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* left */
	T0* a2; /* right */
	T0* a3; /* operator */
};

/* Struct for type XPLAIN_PARENTHESIS_EXPRESSION */
struct S212 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* expression */
};

/* Struct for type SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION] */
struct S213 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_VALUE_EXPRESSION] */
struct S214 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_SYSTEMDATE_EXPRESSION */
struct S215 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_SYSTEM_EXPRESSION] */
struct S216 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_SYSTEM_EXPRESSION] */
struct S217 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_LOGINNAME_EXPRESSION */
struct S218 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_IF_EXPRESSION */
struct S219 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* condition */
	T0* a2; /* then_specification */
	T0* a3; /* else_specification */
};

/* Struct for type XPLAIN_PREFIX_EXPRESSION */
struct S220 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* operand */
	T0* a2; /* operator */
};

/* Struct for type SPECIAL [detachable XPLAIN_EXPRESSION_NODE] */
struct S221 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_COMBINE_FUNCTION */
struct S222 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* operands */
};

/* Struct for type XPLAIN_DATEF_FUNCTION */
struct S223 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* operand */
};

/* Struct for type XPLAIN_INTEGER_FUNCTION */
struct S224 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* operand */
};

/* Struct for type XPLAIN_REAL_FUNCTION */
struct S225 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* operand */
};

/* Struct for type XPLAIN_STRING_FUNCTION */
struct S226 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* operand */
};

/* Struct for type XPLAIN_STRING_EXPRESSION */
struct S227 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* value */
};

/* Struct for type XPLAIN_NEWDATE_FUNCTION */
struct S228 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* date */
	T0* a2; /* number */
	T0* a3; /* part */
};

/* Struct for type XPLAIN_ID_FUNCTION */
struct S229 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* type */
};

/* Struct for type XPLAIN_NUMBER_EXPRESSION */
struct S230 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* value */
};

/* Struct for type XPLAIN_UNMANAGED_PARAMETER_EXPRESSION */
struct S231 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* name */
};

/* Struct for type XPLAIN_USER_FUNCTION */
struct S232 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* parameters */
	T0* a2; /* name */
};

/* Struct for type XPLAIN_SQL_EXPRESSION */
struct S233 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* value */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME_NODE] */
struct S234 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME] */
struct S235 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_A_REPRESENTATION */
struct S236 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* length */
	T0* a2; /* domain_restriction */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_REPRESENTATION] */
struct S237 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_B_REPRESENTATION */
struct S238 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
};

/* Struct for type XPLAIN_C_REPRESENTATION */
struct S239 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
	T6 a2; /* length */
};

/* Struct for type XPLAIN_D_REPRESENTATION */
struct S240 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
};

/* Struct for type XPLAIN_I_REPRESENTATION */
struct S241 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
	T6 a2; /* length */
};

/* Struct for type XPLAIN_M_REPRESENTATION */
struct S242 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
};

/* Struct for type XPLAIN_P_REPRESENTATION */
struct S243 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
};

/* Struct for type XPLAIN_R_REPRESENTATION */
struct S244 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
	T6 a2; /* before */
	T6 a3; /* after */
};

/* Struct for type XPLAIN_T_REPRESENTATION */
struct S245 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
};

/* Struct for type XPLAIN_PK_A_REPRESENTATION */
struct S246 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* length */
	T0* a2; /* domain_restriction */
};

/* Struct for type XPLAIN_A_REFERENCES */
struct S247 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* required */
	T0* a2; /* owner */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_PK_REPRESENTATION] */
struct S248 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_PK_I_REPRESENTATION */
struct S249 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* length */
	T0* a2; /* domain_restriction */
};

/* Struct for type XPLAIN_I_REFERENCES */
struct S250 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* owner */
	T1 a2; /* required */
};

/* Struct for type SPECIAL [XPLAIN_ATTRIBUTE] */
struct S251 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_ATTRIBUTE_NODE] */
struct S252 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE] */
struct S254 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_VARIABLE_EXPRESSION */
struct S255 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* variable */
};

/* Struct for type XPLAIN_VALUE */
struct S256 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* name */
	T0* a2; /* representation */
	T0* a3; /* expression */
};

/* Struct for type XPLAIN_VALUE_EXPRESSION */
struct S257 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* value */
};

/* Struct for type SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION] */
struct S258 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSERTION] */
struct S259 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_ASSERTION] */
struct S260 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_INDEX */
struct S261 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* is_unique */
	T1 a2; /* is_clustered */
	T0* a3; /* type */
	T0* a4; /* first_attribute */
	T0* a5; /* name */
};

/* Struct for type SPECIAL [detachable XPLAIN_UPDATE_STATEMENT] */
struct S262 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_DELETE_STATEMENT] */
struct S263 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_CASCADE_STATEMENT] */
struct S264 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_SUBJECT] */
struct S265 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE] */
struct S266 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_INSERT_STATEMENT */
struct S267 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* type */
	T0* a2; /* id */
	T0* a3; /* assignment_list */
};

/* Struct for type SPECIAL [detachable XPLAIN_SELECTION_LIST] */
struct S268 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_GET_INSERT_STATEMENT */
struct S269 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* selection */
	T0* a2; /* insert_type */
	T1 a3; /* auto_primary_key */
	T0* a4; /* assignment_list */
};

/* Struct for type SPECIAL [XPLAIN_ASSIGNMENT] */
struct S271 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSIGNMENT_NODE] */
struct S272 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_ASSIGNMENT] */
struct S273 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION] */
struct S274 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_STATEMENT] */
struct S275 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_SELECTION_FUNCTION] */
struct S276 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION] */
struct S277 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_DELETE_STATEMENT] */
struct S278 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_SUBJECT] */
struct S279 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_UPDATE_STATEMENT] */
struct S280 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_VALUE_STATEMENT] */
struct S281 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_VALUE_STATEMENT] */
struct S282 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_SELECTION_EXPRESSION */
struct S283 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* select_value */
};

/* Struct for type XPLAIN_LAST_AUTO_PK_EXPRESSION */
struct S285 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* type */
};

/* Struct for type SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT] */
struct S286 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_VALUE_SELECTION_STATEMENT] */
struct S287 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION] */
struct S288 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION] */
struct S289 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_FUNCTION] */
struct S290 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_FUNCTION] */
struct S291 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_SELECTION] */
struct S292 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_GET_STATEMENT] */
struct S293 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_GET_STATEMENT] */
struct S294 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_EXTENSION] */
struct S295 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type SPECIAL [detachable XPLAIN_EXTEND_STATEMENT] */
struct S296 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTEND_STATEMENT] */
struct S297 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_EXTEND_ATTRIBUTE] */
struct S298 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION] */
struct S299 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_EXTEND_ATTRIBUTE] */
struct S300 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_EXTENSION_EXPRESSION_EXPRESSION */
struct S301 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* expression */
	T0* a2; /* extension */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION_EXPRESSION] */
struct S302 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_EXTENSION_FUNCTION_EXPRESSION */
struct S303 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* selection */
	T0* a2; /* sqlfromaliasname */
	T0* a3; /* per_property */
	T0* a4; /* extension */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION] */
struct S304 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_SORT_NODE] */
struct S305 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_LIST] */
struct S306 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_SORT_NODE] */
struct S307 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_MAX_FUNCTION */
struct S308 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_FUNCTION] */
struct S309 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_MIN_FUNCTION */
struct S310 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_TOTAL_FUNCTION */
struct S311 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_COUNT_FUNCTION */
struct S312 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_ANY_FUNCTION */
struct S313 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_NIL_FUNCTION */
struct S314 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_SOME_FUNCTION */
struct S315 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_EXPRESSION_NODE] */
struct S316 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [detachable XPLAIN_STATEMENT_NODE] */
struct S317 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type XPLAIN_PROCEDURE */
struct S318 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* sql_declare */
	T0* a2; /* name */
	T0* a3; /* parameters */
	T0* a4; /* statements */
	T1 a5; /* is_path_procedure */
	T1 a6; /* is_postgresql_trigger */
	T1 a7; /* recompile */
	T0* a8; /* representation */
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_PROCEDURE_STATEMENT] */
struct S319 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_SQL_STATEMENT] */
struct S320 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT_NODE] */
struct S321 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type YY_FILE_BUFFER */
struct S322 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* beginning_of_line */
	T6 a2; /* count */
	T1 a3; /* filled */
	T0* a4; /* content */
	T6 a5; /* index */
	T6 a6; /* line */
	T6 a7; /* column */
	T6 a8; /* position */
	T1 a9; /* end_of_file */
	T6 a10; /* capacity */
	T1 a11; /* interactive */
	T0* a12; /* file */
};

/* Struct for type KL_STDIN_FILE */
struct S323 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* end_of_file */
	T2 a2; /* last_character */
	T0* a3; /* last_string */
	T0* a4; /* character_buffer */
};

/* Struct for type XML_WRITER */
struct S325 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* my_xml */
	T0* a2; /* tags */
	T0* a3; /* attributes */
	T0* a4; /* values */
	T1 a5; /* tag_written */
	T1 a6; /* may_close_tag */
	T1 a7; /* tag_closed */
	T1 a8; /* header_written */
	T6 a9; /* attribute_count */
	T6 a10; /* current_attribute */
};

/* Struct for type KL_TEXT_OUTPUT_FILE */
struct S326 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* mode */
	T0* a2; /* name */
	T14 a3; /* file_pointer */
	T1 a4; /* descriptor_available */
	T0* a5; /* last_string */
	T0* a6; /* internal_name */
	T0* a7; /* internal_detachable_name_pointer */
};

/* Struct for type DS_LINKED_LIST [XPLAIN_STATEMENT] */
struct S327 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* internal_cursor */
	T0* a2; /* first_cell */
	T6 a3; /* count */
	T0* a4; /* last_cell */
};

/* Struct for type STD_FILES */
struct S328 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* default_output */
};

/* Struct for type JOIN_LIST */
struct S329 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* my_first */
	T0* a2; /* base_aggregate */
	T0* a3; /* root */
	T1 a4; /* is_finalized */
	T1 a5; /* is_upward_join */
	T1 a6; /* force_left_outer_join */
	T6 a7; /* existential_join_optimisation_count */
};

/* Struct for type JOIN_NODE */
struct S330 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* next */
};

/* Struct for type DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME] */
struct S335 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* count */
	T0* a2; /* internal_cursor */
	T0* a3; /* last_cell */
	T0* a4; /* first_cell */
};

/* Struct for type DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME] */
struct S336 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* after */
	T0* a2; /* current_cell */
	T0* a3; /* next_cursor */
	T0* a4; /* container */
	T1 a5; /* before */
};

/* Struct for type DS_LINKED_LIST [XPLAIN_ATTRIBUTE] */
struct S337 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* count */
	T0* a2; /* internal_cursor */
	T0* a3; /* first_cell */
	T0* a4; /* last_cell */
	T0* a5; /* equality_tester */
};

/* Struct for type DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE] */
struct S338 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* after */
	T0* a2; /* current_cell */
	T0* a3; /* next_cursor */
	T0* a4; /* container */
	T1 a5; /* before */
};

/* Struct for type DS_BILINKED_LIST [XPLAIN_STATEMENT] */
struct S339 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* internal_cursor */
	T0* a2; /* last_cell */
	T6 a3; /* count */
	T0* a4; /* first_cell */
};

/* Struct for type XPLAIN_B_RESTRICTION */
struct S342 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* required */
};

/* Struct for type DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE] */
struct S344 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* before */
	T0* a2; /* current_cell */
	T0* a3; /* next_cursor */
	T0* a4; /* container */
	T1 a5; /* after */
};

/* Struct for type XPLAIN_LIKE_EXPRESSION */
struct S345 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* left */
	T0* a2; /* right */
	T0* a3; /* operator */
};

/* Struct for type XPLAIN_NOT_LIKE_EXPRESSION */
struct S346 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* left */
	T0* a2; /* right */
	T0* a3; /* operator */
};

/* Struct for type ARRAY [INTEGER_32] */
struct S347 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* area */
	T6 a2; /* lower */
	T6 a3; /* upper */
};

/* Struct for type KL_ARRAY_ROUTINES [INTEGER_32] */
struct S348 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type CELL [INTEGER_32] */
struct S350 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* item */
};

/* Struct for type KL_ARRAY_ROUTINES [detachable ANY] */
struct S351 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_NULL_TEXT_OUTPUT_STREAM */
struct S352 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* name */
};

/* Struct for type KL_STRING_OUTPUT_STREAM */
struct S354 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* string */
};

/* Struct for type DS_CELL [INTEGER_32] */
struct S356 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* item */
};

/* Struct for type ST_BOOLEAN_FORMATTER */
struct S358 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* alignment */
	T2 a2; /* padding_character */
	T1 a3; /* space_sign_enabled */
	T1 a4; /* plus_sign_enabled */
	T6 a5; /* width */
	T6 a6; /* precision */
	T1 a7; /* is_lowercase */
};

/* Struct for type ST_CHARACTER_FORMATTER */
struct S359 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* alignment */
	T2 a2; /* padding_character */
	T1 a3; /* space_sign_enabled */
	T1 a4; /* plus_sign_enabled */
	T6 a5; /* width */
	T6 a6; /* precision */
	T1 a7; /* is_lowercase */
};

/* Struct for type ST_FLOATING_POINT_FORMATTER */
struct S360 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* double_buffer */
	T0* a2; /* string_output_stream */
	T0* a3; /* unsigned_decimal_formatter */
	T0* a4; /* decimal_formatter */
	T0* a5; /* fractional_part */
	T0* a6; /* fractional_list */
	T6 a7; /* alignment */
	T2 a8; /* padding_character */
	T1 a9; /* space_sign_enabled */
	T1 a10; /* plus_sign_enabled */
	T6 a11; /* width */
	T6 a12; /* precision */
	T1 a13; /* is_lowercase */
	T6 a14; /* fsign */
	T6 a15; /* integer_part */
};

/* Struct for type ST_FIXED_POINT_FORMATTER */
struct S361 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* double_buffer */
	T0* a2; /* string_output_stream */
	T0* a3; /* unsigned_decimal_formatter */
	T0* a4; /* decimal_formatter */
	T0* a5; /* fractional_part */
	T0* a6; /* fractional_list */
	T6 a7; /* alignment */
	T2 a8; /* padding_character */
	T1 a9; /* space_sign_enabled */
	T1 a10; /* plus_sign_enabled */
	T6 a11; /* width */
	T6 a12; /* precision */
	T1 a13; /* is_lowercase */
	T6 a14; /* fsign */
	T6 a15; /* integer_part */
};

/* Struct for type ST_FIXED_OR_FLOATING_POINT_FORMATTER */
struct S362 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* double_buffer */
	T0* a2; /* string_output_stream */
	T0* a3; /* unsigned_decimal_formatter */
	T0* a4; /* decimal_formatter */
	T0* a5; /* fractional_part */
	T0* a6; /* fractional_list */
	T6 a7; /* alignment */
	T2 a8; /* padding_character */
	T1 a9; /* space_sign_enabled */
	T1 a10; /* plus_sign_enabled */
	T6 a11; /* width */
	T6 a12; /* precision */
	T1 a13; /* is_lowercase */
	T6 a14; /* fsign */
	T6 a15; /* integer_part */
};

/* Struct for type ST_DECIMAL_FORMATTER */
struct S363 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* integer_buffer */
	T6 a2; /* alignment */
	T2 a3; /* padding_character */
	T1 a4; /* space_sign_enabled */
	T1 a5; /* plus_sign_enabled */
	T6 a6; /* width */
	T6 a7; /* precision */
	T1 a8; /* is_lowercase */
};

/* Struct for type ST_UNSIGNED_OCTAL_FORMATTER */
struct S364 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* integer_buffer */
	T6 a2; /* alignment */
	T2 a3; /* padding_character */
	T1 a4; /* space_sign_enabled */
	T1 a5; /* plus_sign_enabled */
	T6 a6; /* width */
	T6 a7; /* precision */
	T1 a8; /* is_lowercase */
};

/* Struct for type ST_UNSIGNED_HEXADECIMAL_FORMATTER */
struct S365 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* integer_buffer */
	T6 a2; /* alignment */
	T2 a3; /* padding_character */
	T1 a4; /* space_sign_enabled */
	T1 a5; /* plus_sign_enabled */
	T6 a6; /* width */
	T6 a7; /* precision */
	T1 a8; /* is_lowercase */
};

/* Struct for type ST_UNSIGNED_DECIMAL_FORMATTER */
struct S366 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* integer_buffer */
	T6 a2; /* alignment */
	T2 a3; /* padding_character */
	T1 a4; /* space_sign_enabled */
	T1 a5; /* plus_sign_enabled */
	T6 a6; /* width */
	T6 a7; /* precision */
	T1 a8; /* is_lowercase */
};

/* Struct for type ST_POINTER_FORMATTER */
struct S367 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* alignment */
	T2 a2; /* padding_character */
	T1 a3; /* space_sign_enabled */
	T1 a4; /* plus_sign_enabled */
	T6 a5; /* width */
	T6 a6; /* precision */
	T1 a7; /* is_lowercase */
};

/* Struct for type ST_STRING_FORMATTER */
struct S368 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* alignment */
	T2 a2; /* padding_character */
	T1 a3; /* space_sign_enabled */
	T1 a4; /* plus_sign_enabled */
	T6 a5; /* width */
	T6 a6; /* precision */
	T1 a7; /* is_lowercase */
};

/* Struct for type KL_ANY_ROUTINES */
struct S369 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type UC_STRING */
struct S370 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* count */
	T6 a2; /* byte_count */
	T6 a3; /* last_byte_index_input */
	T6 a4; /* last_byte_index_result */
	T0* a5; /* area */
	T6 a6; /* internal_hash_code */
	T6 a7; /* internal_case_insensitive_hash_code */
};

/* Struct for type READABLE_STRING_32 */
struct S372 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [NATURAL_8] */
struct S373 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T8 z2[1]; /* item */
};

/* Struct for type ARRAY [IMMUTABLE_STRING_32] */
struct S375 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* area */
	T6 a2; /* lower */
	T6 a3; /* upper */
	T1 a4; /* object_comparison */
};

/* Struct for type SPECIAL [IMMUTABLE_STRING_32] */
struct S376 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type detachable KL_EQUALITY_TESTER [XPLAIN_VALUE] */
struct S377 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type detachable KL_EQUALITY_TESTER [STRING_8] */
struct S378 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_VALUE] */
struct S381 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_VALUE] */
struct S382 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type DS_HASH_TABLE_CURSOR [XPLAIN_VALUE, STRING_8] */
struct S383 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* position */
	T0* a2; /* next_cursor */
	T0* a3; /* container */
};

/* Struct for type detachable DS_LINKABLE [XPLAIN_SCANNER_STATE] */
struct S385 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* right */
};

/* Struct for type XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE] */
struct S386 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* after */
	T0* a2; /* current_cell */
	T1 a3; /* generate_assert */
	T1 a4; /* is_first */
	T0* a5; /* container */
	T0* a6; /* next_cursor */
	T1 a7; /* before */
};

/* Struct for type XPLAIN_DATA_ATTRIBUTES_CURSOR */
struct S387 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* after */
	T1 a2; /* is_first */
	T0* a3; /* current_cell */
	T0* a4; /* container */
	T0* a5; /* next_cursor */
	T1 a6; /* before */
};

/* Struct for type XPLAIN_ATTRIBUTE_EXPRESSION */
struct S389 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* first */
};

/* Struct for type DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8] */
struct S391 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* position */
	T6 a2; /* found_position */
	T0* a3; /* item_storage */
	T0* a4; /* equality_tester */
	T0* a5; /* key_equality_tester */
	T6 a6; /* count */
	T6 a7; /* capacity */
	T6 a8; /* slots_position */
	T6 a9; /* free_slot */
	T6 a10; /* last_position */
	T6 a11; /* modulus */
	T6 a12; /* clashes_previous_position */
	T0* a13; /* special_item_routines */
	T0* a14; /* clashes */
	T0* a15; /* slots */
	T0* a16; /* special_key_routines */
	T0* a17; /* key_storage */
	T0* a18; /* internal_keys */
	T0* a19; /* internal_cursor */
	T0* a20; /* hash_function */
};

/* Struct for type DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT] */
struct S393 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* before */
	T1 a2; /* after */
	T0* a3; /* current_cell */
	T0* a4; /* next_cursor */
	T0* a5; /* container */
};

/* Struct for type DS_LINKED_STACK [STRING_8] */
struct S394 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* count */
	T0* a2; /* first_cell */
};

/* Struct for type DS_LINKED_LIST_CURSOR [XPLAIN_STATEMENT] */
struct S396 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* after */
	T0* a2; /* current_cell */
	T0* a3; /* next_cursor */
	T0* a4; /* container */
	T1 a5; /* before */
};

/* Struct for type detachable DS_LINKABLE [XPLAIN_STATEMENT] */
struct S397 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* right */
};

/* Struct for type STRING_TO_INTEGER_CONVERTOR */
struct S398 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* sign */
	T11 a2; /* part1 */
	T11 a3; /* part2 */
	T6 a4; /* last_state */
	T1 a5; /* internal_overflowed */
	T0* a6; /* leading_separators */
	T0* a7; /* trailing_separators */
	T1 a8; /* leading_separators_acceptable */
	T1 a9; /* trailing_separators_acceptable */
	T6 a10; /* conversion_type */
};

/* Struct for type JOIN */
struct S401 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* aggregate_attribute */
	T0* a2; /* attribute_alias_name */
	T1 a3; /* is_upward_join */
	T0* a4; /* aggregate_fk */
	T0* a5; /* aggregate_alias_name */
	T0* a6; /* aggregate */
	T1 a7; /* is_forced_inner_join */
	T1 a8; /* is_forced_left_outer_join */
	T0* a9; /* actual_attribute */
};

/* Struct for type DS_HASH_SET [STRING_8] */
struct S402 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* position */
	T0* a2; /* equality_tester */
	T6 a3; /* count */
	T6 a4; /* capacity */
	T6 a5; /* slots_position */
	T6 a6; /* free_slot */
	T6 a7; /* last_position */
	T6 a8; /* modulus */
	T6 a9; /* clashes_previous_position */
	T6 a10; /* found_position */
	T0* a11; /* special_item_routines */
	T0* a12; /* item_storage */
	T0* a13; /* clashes */
	T0* a14; /* slots */
	T0* a15; /* internal_cursor */
	T0* a16; /* hash_function */
};

/* Struct for type XPLAIN_F_REPRESENTATION */
struct S403 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* domain_restriction */
};

/* Struct for type EXCEPTIONS */
struct S405 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE] */
struct S408 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* after */
	T0* a2; /* current_cell */
	T1 a3; /* is_first */
	T0* a4; /* container */
	T0* a5; /* next_cursor */
	T1 a6; /* before */
};

/* Struct for type KL_INTEGER_ROUTINES */
struct S410 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type [attached] ARRAY [DS_CELL [INTEGER_32]] */
struct S411 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* area */
	T6 a2; /* lower */
	T6 a3; /* upper */
};

/* Struct for type SPECIAL [DS_CELL [INTEGER_32]] */
struct S412 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type DS_CELL [REAL_64] */
struct S413 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T13 a1; /* item */
};

/* Struct for type KL_CHARACTER_BUFFER */
struct S414 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* as_special */
	T0* a2; /* area */
};

/* Struct for type CONSOLE */
struct S415 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T2 a1; /* last_character */
	T14 a2; /* file_pointer */
	T6 a3; /* mode */
	T0* a4; /* last_string */
	T0* a5; /* internal_name */
	T0* a6; /* internal_detachable_name_pointer */
};

/* Struct for type JOIN_TREE_NODE */
struct S416 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* found_immediate_child */
	T0* a2; /* next */
	T0* a3; /* item */
	T1 a4; /* is_upward_join */
	T1 a5; /* is_forced_left_outer_join */
	T1 a6; /* is_forced_inner_join */
	T0* a7; /* other_items */
};

/* Struct for type DS_LINKED_LIST [JOIN_TREE_NODE] */
struct S417 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* last_cell */
	T0* a2; /* internal_cursor */
	T6 a3; /* count */
	T0* a4; /* first_cell */
};

/* Struct for type detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME] */
struct S418 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* right */
};

/* Struct for type detachable DS_LINKABLE [XPLAIN_ATTRIBUTE] */
struct S419 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* right */
};

/* Struct for type detachable DS_BILINKABLE [XPLAIN_STATEMENT] */
struct S420 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* right */
	T0* a3; /* left */
};

/* Struct for type DS_CELL [BOOLEAN] */
struct S421 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type DS_CELL [CHARACTER_8] */
struct S422 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type DS_ARRAYED_LIST [INTEGER_32] */
struct S423 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* count */
	T0* a2; /* storage */
	T0* a3; /* special_routines */
	T6 a4; /* capacity */
	T0* a5; /* internal_cursor */
};

/* Struct for type KL_DOUBLE_ROUTINES */
struct S424 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_PLATFORM */
struct S425 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type DS_CELL [POINTER] */
struct S427 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [XPLAIN_ABSTRACT_OBJECT] */
struct S428 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T0* z2[1]; /* item */
};

/* Struct for type detachable KL_EQUALITY_TESTER [XPLAIN_ABSTRACT_OBJECT] */
struct S429 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type KL_SPECIAL_ROUTINES [XPLAIN_ABSTRACT_OBJECT] */
struct S430 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type DS_HASH_TABLE_CURSOR [XPLAIN_ABSTRACT_OBJECT, STRING_8] */
struct S432 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* position */
	T0* a2; /* next_cursor */
	T0* a3; /* container */
};

/* Struct for type detachable DS_LINKABLE [STRING_8] */
struct S434 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* right */
};

/* Struct for type HEXADECIMAL_STRING_TO_INTEGER_CONVERTER */
struct S436 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* last_state */
	T1 a2; /* internal_overflowed */
	T11 a3; /* part1 */
	T11 a4; /* part2 */
	T0* a5; /* leading_separators */
	T0* a6; /* trailing_separators */
	T6 a7; /* sign */
	T6 a8; /* conversion_type */
	T2 a9; /* internal_lookahead */
	T1 a10; /* leading_separators_acceptable */
	T1 a11; /* trailing_separators_acceptable */
};

/* Struct for type INTEGER_OVERFLOW_CHECKER */
struct S437 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* integer_overflow_state1 */
	T0* a2; /* integer_overflow_state2 */
	T0* a3; /* natural_overflow_state1 */
	T0* a4; /* natural_overflow_state2 */
};

/* Struct for type DS_HASH_SET_CURSOR [STRING_8] */
struct S438 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* container */
	T6 a2; /* position */
};

/* Struct for type DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE] */
struct S439 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T6 a1; /* found_position */
	T0* a2; /* item_storage */
	T0* a3; /* key_equality_tester */
	T6 a4; /* count */
	T6 a5; /* last_position */
	T6 a6; /* free_slot */
	T6 a7; /* position */
	T6 a8; /* slots_position */
	T0* a9; /* equality_tester */
	T0* a10; /* internal_cursor */
	T0* a11; /* key_storage */
	T0* a12; /* clashes */
	T6 a13; /* modulus */
	T0* a14; /* slots */
	T6 a15; /* clashes_previous_position */
	T0* a16; /* special_item_routines */
	T0* a17; /* special_key_routines */
	T6 a18; /* capacity */
	T0* a19; /* hash_function */
};

/* Struct for type detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE] */
struct S440 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* internal_cursor */
	T0* a2; /* last_cell */
	T6 a3; /* count */
	T0* a4; /* first_cell */
};

/* Struct for type detachable DS_LINKABLE [JOIN_TREE_NODE] */
struct S441 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* right */
};

/* Struct for type DS_LINKED_LIST_CURSOR [JOIN_TREE_NODE] */
struct S442 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* after */
	T0* a2; /* current_cell */
	T0* a3; /* next_cursor */
	T0* a4; /* container */
	T1 a5; /* before */
};

/* Struct for type DS_ARRAYED_LIST_CURSOR [INTEGER_32] */
struct S443 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* next_cursor */
	T0* a2; /* container */
	T6 a3; /* position */
};

/* Struct for type XPLAIN_VIRTUAL_ATTRIBUTE */
struct S445 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* role */
	T0* a2; /* init */
	T1 a3; /* is_init_default */
	T1 a4; /* is_specialization */
	T1 a5; /* is_unique */
	T1 a6; /* is_required */
	T1 a7; /* overrule_required */
	T0* a8; /* internal_abstracttype */
};

/* Struct for type XPLAIN_EXTENSION_ATTRIBUTE */
struct S446 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* role */
	T0* a2; /* init */
	T1 a3; /* is_init_default */
	T1 a4; /* is_specialization */
	T1 a5; /* is_unique */
	T1 a6; /* is_required */
	T1 a7; /* overrule_required */
	T0* a8; /* internal_extension */
};

/* Struct for type XPLAIN_ASSERTION_EXPRESSION */
struct S448 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* anode */
	T0* a2; /* assertion */
};

/* Struct for type UC_UTF8_ROUTINES */
struct S450 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type SPECIAL [NATURAL_64] */
struct S452 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	uint32_t offset;
	T6 a1; /* count */
	T6 a2; /* capacity */
	T11 z2[1]; /* item */
};

/* Struct for type detachable KL_EQUALITY_TESTER [XPLAIN_TYPE] */
struct S453 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
};

/* Struct for type detachable DS_HASH_TABLE_CURSOR [INTEGER_32, XPLAIN_TYPE] */
struct S455 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* next_cursor */
	T0* a2; /* container */
	T6 a3; /* position */
};

/* Struct for type DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME_NODE] */
struct S456 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T1 a1; /* after */
	T0* a2; /* current_cell */
	T0* a3; /* next_cursor */
	T0* a4; /* container */
	T1 a5; /* before */
};

/* Struct for type detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME_NODE] */
struct S457 {
	EIF_TYPE_INDEX id;
	uint16_t flags;
	T0* a1; /* item */
	T0* a2; /* right */
};


extern T1 GE_default1;
extern T2 GE_default2;
extern T3 GE_default3;
extern T4 GE_default4;
extern T5 GE_default5;
extern T6 GE_default6;
extern T7 GE_default7;
extern T8 GE_default8;
extern T9 GE_default9;
extern T10 GE_default10;
extern T11 GE_default11;
extern T12 GE_default12;
extern T13 GE_default13;
extern T14 GE_default14;
extern T15 GE_default15;
extern T16 GE_default16;
extern T17 GE_default17;
extern T19 GE_default19;
extern T20 GE_default20;
extern T24 GE_default24;
extern T25 GE_default25;
extern T26 GE_default26;
extern T27 GE_default27;
extern T28 GE_default28;
extern T29 GE_default29;
extern T30 GE_default30;
extern T31 GE_default31;
extern T34 GE_default34;
extern T35 GE_default35;
extern T36 GE_default36;
extern T37 GE_default37;
extern T38 GE_default38;
extern T39 GE_default39;
extern T40 GE_default40;
extern T41 GE_default41;
extern T42 GE_default42;
extern T43 GE_default43;
extern T44 GE_default44;
extern T45 GE_default45;
extern T46 GE_default46;
extern T47 GE_default47;
extern T48 GE_default48;
extern T49 GE_default49;
extern T50 GE_default50;
extern T51 GE_default51;
extern T52 GE_default52;
extern T53 GE_default53;
extern T54 GE_default54;
extern T55 GE_default55;
extern T56 GE_default56;
extern T57 GE_default57;
extern T58 GE_default58;
extern T59 GE_default59;
extern T60 GE_default60;
extern T61 GE_default61;
extern T62 GE_default62;
extern T63 GE_default63;
extern T64 GE_default64;
extern T65 GE_default65;
extern T67 GE_default67;
extern T69 GE_default69;
extern T72 GE_default72;
extern T74 GE_default74;
extern T76 GE_default76;
extern T78 GE_default78;
extern T79 GE_default79;
extern T80 GE_default80;
extern T81 GE_default81;
extern T82 GE_default82;
extern T83 GE_default83;
extern T84 GE_default84;
extern T86 GE_default86;
extern T87 GE_default87;
extern T88 GE_default88;
extern T89 GE_default89;
extern T90 GE_default90;
extern T91 GE_default91;
extern T92 GE_default92;
extern T93 GE_default93;
extern T94 GE_default94;
extern T95 GE_default95;
extern T96 GE_default96;
extern T97 GE_default97;
extern T98 GE_default98;
extern T99 GE_default99;
extern T100 GE_default100;
extern T101 GE_default101;
extern T102 GE_default102;
extern T103 GE_default103;
extern T104 GE_default104;
extern T105 GE_default105;
extern T106 GE_default106;
extern T108 GE_default108;
extern T111 GE_default111;
extern T112 GE_default112;
extern T113 GE_default113;
extern T114 GE_default114;
extern T115 GE_default115;
extern T117 GE_default117;
extern T118 GE_default118;
extern T120 GE_default120;
extern T122 GE_default122;
extern T124 GE_default124;
extern T125 GE_default125;
extern T127 GE_default127;
extern T128 GE_default128;
extern T129 GE_default129;
extern T130 GE_default130;
extern T131 GE_default131;
extern T132 GE_default132;
extern T133 GE_default133;
extern T135 GE_default135;
extern T137 GE_default137;
extern T138 GE_default138;
extern T141 GE_default141;
extern T142 GE_default142;
extern T143 GE_default143;
extern T144 GE_default144;
extern T145 GE_default145;
extern T146 GE_default146;
extern T147 GE_default147;
extern T148 GE_default148;
extern T149 GE_default149;
extern T150 GE_default150;
extern T151 GE_default151;
extern T152 GE_default152;
extern T154 GE_default154;
extern T155 GE_default155;
extern T156 GE_default156;
extern T157 GE_default157;
extern T158 GE_default158;
extern T159 GE_default159;
extern T161 GE_default161;
extern T162 GE_default162;
extern T164 GE_default164;
extern T165 GE_default165;
extern T166 GE_default166;
extern T167 GE_default167;
extern T168 GE_default168;
extern T169 GE_default169;
extern T170 GE_default170;
extern T171 GE_default171;
extern T172 GE_default172;
extern T173 GE_default173;
extern T174 GE_default174;
extern T175 GE_default175;
extern T176 GE_default176;
extern T177 GE_default177;
extern T178 GE_default178;
extern T179 GE_default179;
extern T180 GE_default180;
extern T181 GE_default181;
extern T182 GE_default182;
extern T183 GE_default183;
extern T184 GE_default184;
extern T185 GE_default185;
extern T186 GE_default186;
extern T187 GE_default187;
extern T188 GE_default188;
extern T190 GE_default190;
extern T191 GE_default191;
extern T192 GE_default192;
extern T193 GE_default193;
extern T194 GE_default194;
extern T195 GE_default195;
extern T196 GE_default196;
extern T197 GE_default197;
extern T199 GE_default199;
extern T200 GE_default200;
extern T201 GE_default201;
extern T202 GE_default202;
extern T203 GE_default203;
extern T204 GE_default204;
extern T205 GE_default205;
extern T206 GE_default206;
extern T207 GE_default207;
extern T208 GE_default208;
extern T209 GE_default209;
extern T210 GE_default210;
extern T211 GE_default211;
extern T212 GE_default212;
extern T213 GE_default213;
extern T214 GE_default214;
extern T215 GE_default215;
extern T216 GE_default216;
extern T217 GE_default217;
extern T218 GE_default218;
extern T219 GE_default219;
extern T220 GE_default220;
extern T221 GE_default221;
extern T222 GE_default222;
extern T223 GE_default223;
extern T224 GE_default224;
extern T225 GE_default225;
extern T226 GE_default226;
extern T227 GE_default227;
extern T228 GE_default228;
extern T229 GE_default229;
extern T230 GE_default230;
extern T231 GE_default231;
extern T232 GE_default232;
extern T233 GE_default233;
extern T234 GE_default234;
extern T235 GE_default235;
extern T236 GE_default236;
extern T237 GE_default237;
extern T238 GE_default238;
extern T239 GE_default239;
extern T240 GE_default240;
extern T241 GE_default241;
extern T242 GE_default242;
extern T243 GE_default243;
extern T244 GE_default244;
extern T245 GE_default245;
extern T246 GE_default246;
extern T247 GE_default247;
extern T248 GE_default248;
extern T249 GE_default249;
extern T250 GE_default250;
extern T251 GE_default251;
extern T252 GE_default252;
extern T254 GE_default254;
extern T255 GE_default255;
extern T256 GE_default256;
extern T257 GE_default257;
extern T258 GE_default258;
extern T259 GE_default259;
extern T260 GE_default260;
extern T261 GE_default261;
extern T262 GE_default262;
extern T263 GE_default263;
extern T264 GE_default264;
extern T265 GE_default265;
extern T266 GE_default266;
extern T267 GE_default267;
extern T268 GE_default268;
extern T269 GE_default269;
extern T271 GE_default271;
extern T272 GE_default272;
extern T273 GE_default273;
extern T274 GE_default274;
extern T275 GE_default275;
extern T276 GE_default276;
extern T277 GE_default277;
extern T278 GE_default278;
extern T279 GE_default279;
extern T280 GE_default280;
extern T281 GE_default281;
extern T282 GE_default282;
extern T283 GE_default283;
extern T285 GE_default285;
extern T286 GE_default286;
extern T287 GE_default287;
extern T288 GE_default288;
extern T289 GE_default289;
extern T290 GE_default290;
extern T291 GE_default291;
extern T292 GE_default292;
extern T293 GE_default293;
extern T294 GE_default294;
extern T295 GE_default295;
extern T296 GE_default296;
extern T297 GE_default297;
extern T298 GE_default298;
extern T299 GE_default299;
extern T300 GE_default300;
extern T301 GE_default301;
extern T302 GE_default302;
extern T303 GE_default303;
extern T304 GE_default304;
extern T305 GE_default305;
extern T306 GE_default306;
extern T307 GE_default307;
extern T308 GE_default308;
extern T309 GE_default309;
extern T310 GE_default310;
extern T311 GE_default311;
extern T312 GE_default312;
extern T313 GE_default313;
extern T314 GE_default314;
extern T315 GE_default315;
extern T316 GE_default316;
extern T317 GE_default317;
extern T318 GE_default318;
extern T319 GE_default319;
extern T320 GE_default320;
extern T321 GE_default321;
extern T322 GE_default322;
extern T323 GE_default323;
extern T325 GE_default325;
extern T326 GE_default326;
extern T327 GE_default327;
extern T328 GE_default328;
extern T329 GE_default329;
extern T330 GE_default330;
extern T335 GE_default335;
extern T336 GE_default336;
extern T337 GE_default337;
extern T338 GE_default338;
extern T339 GE_default339;
extern T342 GE_default342;
extern T344 GE_default344;
extern T345 GE_default345;
extern T346 GE_default346;
extern T347 GE_default347;
extern T348 GE_default348;
extern T349 GE_default349;
extern T350 GE_default350;
extern T351 GE_default351;
extern T352 GE_default352;
extern T354 GE_default354;
extern T356 GE_default356;
extern T358 GE_default358;
extern T359 GE_default359;
extern T360 GE_default360;
extern T361 GE_default361;
extern T362 GE_default362;
extern T363 GE_default363;
extern T364 GE_default364;
extern T365 GE_default365;
extern T366 GE_default366;
extern T367 GE_default367;
extern T368 GE_default368;
extern T369 GE_default369;
extern T370 GE_default370;
extern T372 GE_default372;
extern T373 GE_default373;
extern T374 GE_default374;
extern T375 GE_default375;
extern T376 GE_default376;
extern T377 GE_default377;
extern T378 GE_default378;
extern T381 GE_default381;
extern T382 GE_default382;
extern T383 GE_default383;
extern T385 GE_default385;
extern T386 GE_default386;
extern T387 GE_default387;
extern T389 GE_default389;
extern T391 GE_default391;
extern T393 GE_default393;
extern T394 GE_default394;
extern T395 GE_default395;
extern T396 GE_default396;
extern T397 GE_default397;
extern T398 GE_default398;
extern T401 GE_default401;
extern T402 GE_default402;
extern T403 GE_default403;
extern T405 GE_default405;
extern T406 GE_default406;
extern T408 GE_default408;
extern T410 GE_default410;
extern T411 GE_default411;
extern T412 GE_default412;
extern T413 GE_default413;
extern T414 GE_default414;
extern T415 GE_default415;
extern T416 GE_default416;
extern T417 GE_default417;
extern T418 GE_default418;
extern T419 GE_default419;
extern T420 GE_default420;
extern T421 GE_default421;
extern T422 GE_default422;
extern T423 GE_default423;
extern T424 GE_default424;
extern T425 GE_default425;
extern T427 GE_default427;
extern T428 GE_default428;
extern T429 GE_default429;
extern T430 GE_default430;
extern T432 GE_default432;
extern T434 GE_default434;
extern T435 GE_default435;
extern T436 GE_default436;
extern T437 GE_default437;
extern T438 GE_default438;
extern T439 GE_default439;
extern T440 GE_default440;
extern T441 GE_default441;
extern T442 GE_default442;
extern T443 GE_default443;
extern T445 GE_default445;
extern T446 GE_default446;
extern T448 GE_default448;
extern T450 GE_default450;
extern T452 GE_default452;
extern T453 GE_default453;
extern T455 GE_default455;
extern T456 GE_default456;
extern T457 GE_default457;

extern T0* GE_new_str8(T6 c);
extern T0* GE_new_str32(T6 c);
extern T0* GE_new_istr32(T6 c);
/* Call to ANY.out */
extern T0* T22x45(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.quote_identifier */
extern T0* T32x4928T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.calculatedcolumnssupported */
extern T1 T32x4985(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlcoalesce */
extern T0* T32x4770(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.table_has_auto_pk */
extern T1 T32x4938T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlfalse */
extern T0* T32x5003(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.create_table_name */
extern T0* T32x4935T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlcolumnconstraint_base */
extern T0* T32x4942T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.sqlcolumnconstraint_type */
extern T0* T32x4943T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.sql_subselect_for_extension */
extern T0* T32x4917T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.inupdatestatement */
extern T1 T32x4775(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlcolumndefault_type */
extern T0* T32x4880T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlcolumnrequired_type */
extern T0* T32x4882T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlcolumnidentifier_type */
extern T0* T32x4875T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.sqlcolumnrequired_base */
extern T0* T32x4881T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlcolumndefault_base */
extern T0* T32x4879T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlcolumnidentifier_base */
extern T0* T32x4874T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.make_valid_identifier */
extern T0* T32x4926T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlminint */
extern T0* T32x4767(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlmaxint */
extern T0* T32x4768(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sql_infix_expression_as_wildcard */
extern T0* T32x4897T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to SQL_GENERATOR.value_representation_integer */
extern T0* T32x4955T6(GE_context* ac, T0* C, T6 a1);
/* Call to SQL_GENERATOR.value_representation_char */
extern T0* T32x4951T6(GE_context* ac, T0* C, T6 a1);
/* Call to SQL_GENERATOR.value_representation_text */
extern T0* T32x4958(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.value_representation_float */
extern T0* T32x4954(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.value_representation_money */
extern T0* T32x4956(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.value_representation_date */
extern T0* T32x4953(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.as_string */
extern T0* T32x5004T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.minimum_date_value */
extern T0* T32x4762(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.value_representation_boolean */
extern T0* T32x4950(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sql_combine_expression_as_wildcard */
extern T0* T32x4899T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.constant_identifier */
extern T0* T32x4945T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sp_define_param_name */
extern T0* T32x4919T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.storedproceduresupported */
extern T1 T32x4747(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.quote_valid_identifier */
extern T0* T32x4929T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.supportsdomainsinstoredprocedures */
extern T1 T32x4746(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sp_define_in_param */
extern T0* T32x4918T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.namedparameterssupported */
extern T1 T32x4745(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sp_update_name */
extern T0* T32x4924T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sp_insert_name */
extern T0* T32x4921T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sp_delete_name */
extern T0* T32x4920T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.createstoredprocedure */
extern T1 T32x4744(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sql_subselect_for_attribute */
extern T0* T32x4916T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.updated_extension */
extern T0* T32x4970(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sql_like_operator */
extern T0* T32x4766(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlcheck_boolean */
extern T0* T32x4867T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.sqlfunction_some */
extern T0* T32x4890(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlfunction_nil */
extern T0* T32x4889(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.existentialfromneeded */
extern T1 T32x4752(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlfunction_any */
extern T0* T32x4885(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlfunction_count */
extern T0* T32x4886(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlfunction_total */
extern T0* T32x4891(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlfunction_min */
extern T0* T32x4888(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlfunction_max */
extern T0* T32x4887(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sql_select_for_extension_expression */
extern T0* T32x4904T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.value_representation_system_user */
extern T0* T32x4957(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.value_representation_current_timestamp */
extern T0* T32x4952(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sqlsysfunction_current_timestamp */
extern T0* T32x4892(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sql_infix_expression */
extern T0* T32x4896T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to SQL_GENERATOR.sqlcheck_between */
extern T0* T32x4866T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.sqlcheck_in */
extern T0* T32x4868T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.sqlcheck_like */
extern T0* T32x4869T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.temporarytableprefix */
extern T0* T32x4729(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.extension_name */
extern T0* T32x4969T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_select_function_as_subselect */
extern T0* T32x4908T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.assert_implemented_as_view */
extern T1 T32x4975T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqltrue */
extern T0* T32x5002(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sql_expression_as_boolean_value */
extern T0* T32x4894T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sp_name */
extern T0* T32x4922T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_select_for_extension_function */
extern T0* T32x4905T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.sql_extension_function */
extern T0* T32x4895T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_last_auto_generated_primary_key */
extern T0* T32x4903T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlgetvalue */
extern T0* T32x4871T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.quoted_value_identifier */
extern T0* T32x4949T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.value_identifier */
extern T0* T32x4948T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlgetconstant */
extern T0* T32x5005T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sp_use_param */
extern T0* T32x4925T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_newdate */
extern T0* T32x4967T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to SQL_GENERATOR.sql_cast_to_string */
extern T0* T32x4962T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_cast_to_real */
extern T0* T32x4961T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_cast_to_integer */
extern T0* T32x4960T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_cast_to_date */
extern T0* T32x4959T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_combine_expression */
extern T0* T32x4898T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sqlsysfunction_system_user */
extern T0* T32x4893(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.sql_not_expression */
extern T0* T32x4900T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.sql_notnot_expression */
extern T0* T32x4901T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.assertion_name */
extern T0* T32x4976T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.table_name */
extern T0* T32x4936T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.table_pk_name */
extern T0* T32x4937T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.createautoprimarykey */
extern T1 T32x4703(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR.check_if_required */
extern T1 T32x4933T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.target_name */
extern T0* T32x4679(GE_context* ac, T0* C);
/* Call to ARRAY [ANY].item */
extern T0* T37x902T6(GE_context* ac, T0* C, T6 a1);
/* Call to ARRAY [ANY].upper */
extern T6 T37x863(GE_context* ac, T0* C);
/* Call to ARRAY [ANY].lower */
extern T6 T37x862(GE_context* ac, T0* C);
/* Call to XPLAIN_DOMAIN_RESTRICTION.required */
extern T1 T121x5298(GE_context* ac, T0* C);
/* Call to XPLAIN_DOMAIN_RESTRICTION.sqldomainconstraint */
extern T0* T121x5299T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_DOMAIN_RESTRICTION.sqlcolumnconstraint */
extern T0* T121x5300T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_STATEMENT.updates_attribute */
extern T1 T126x7446T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_STATEMENT.uses_parameter */
extern T1 T126x7445T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.quoted_name */
extern T0* T129x5448T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.hash_code */
extern T6 T129x22(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.sqlpkname */
extern T0* T129x5129T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.name */
extern T0* T129x5443(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.new_data_attributes_cursor */
extern T0* T129x5145T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.representation */
extern T0* T129x5119(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.q_sqlpkname */
extern T0* T129x5130T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.sqlname */
extern T0* T129x5447T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.find_attribute */
extern T0* T129x5139T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.sqlcolumnidentifier */
extern T0* T129x5400T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_TYPE.attributes */
extern T0* T129x5120(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.sqltablename */
extern T0* T129x5131T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.q_sql_select_name */
extern T0* T129x5404T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_TYPE.constraint_number */
extern T6 T129x5121(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.has_non_literal_init */
extern T1 T129x5137(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.has_non_constant_init */
extern T1 T129x5136(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.columndatatype */
extern T0* T129x5399T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.has_updatable_attributes */
extern T1 T129x5138(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.new_all_attributes_cursor */
extern T0* T129x5144T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.has_auto_pk */
extern T1 T129x5135T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.new_init_attributes_cursor */
extern T0* T129x5146T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.has_attribute */
extern T1 T129x5140T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_EXPRESSION.column_name */
extern T0* T134x5184(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.path_name */
extern T0* T134x5185(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.is_literal */
extern T1 T134x5173(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.is_constant */
extern T1 T134x5172(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.uses_parameter */
extern T1 T134x5181T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.sqlinitvalue */
extern T0* T134x5187T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.sqlvalue */
extern T0* T134x5191T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.exact_representation */
extern T0* T134x5183T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.representation */
extern T0* T134x5186T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.is_specialization */
extern T1 T134x5176(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.sqlname */
extern T0* T134x5190T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T134x5192T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.is_logical_constant */
extern T1 T134x5174(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.uses_its */
extern T1 T134x5180(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.is_using_other_attributes */
extern T1 T134x5178T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.has_wild_card_characters */
extern T1 T134x5171(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.sqlminvalue */
extern T0* T134x5189T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.selects_max_one_row */
extern T1 T134x5179(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.is_logical_expression */
extern T1 T134x5175(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.outer_sqlvalue */
extern T0* T134x5193T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.sql_alias */
extern T0* T134x5194T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_EXPRESSION.can_be_null */
extern T1 T134x5170(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.is_string_expression */
extern T1 T134x5177(GE_context* ac, T0* C);
/* Call to XPLAIN_EXPRESSION.sqlmaxvalue */
extern T0* T134x5188T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_REPRESENTATION.max_value */
extern T0* T139x5820T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_REPRESENTATION.min_value */
extern T0* T139x5821T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_REPRESENTATION.domain_restriction */
extern T0* T139x5814(GE_context* ac, T0* C);
/* Call to XPLAIN_REPRESENTATION.datatype */
extern T0* T139x5818T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_REPRESENTATION.xml_schema_data_type */
extern T0* T139x5816(GE_context* ac, T0* C);
/* Call to XPLAIN_REPRESENTATION.domain */
extern T0* T139x5813(GE_context* ac, T0* C);
/* Call to XPLAIN_REPRESENTATION.value_representation */
extern T0* T139x5815T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_REPRESENTATION.default_value */
extern T0* T139x5819(GE_context* ac, T0* C);
/* Call to XPLAIN_REPRESENTATION.is_blob */
extern T1 T139x5811T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_ATTRIBUTE.abstracttype */
extern T0* T142x5311(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.is_extension */
extern T1 T142x5305(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.init */
extern T0* T142x5313(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.is_init_default */
extern T1 T142x5310(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.is_required */
extern T1 T142x5307(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.overrule_required */
extern T1 T142x5316(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.q_sql_select_name */
extern T0* T142x5321T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_ATTRIBUTE.full_name */
extern T0* T142x5312(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.is_assertion */
extern T1 T142x5304(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.is_specialization */
extern T1 T142x5308(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.role */
extern T0* T142x5315(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.name */
extern T0* T142x5314(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.is_unique */
extern T1 T142x5309(GE_context* ac, T0* C);
/* Call to XPLAIN_ATTRIBUTE.sql_select_name */
extern T0* T142x5322T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_ATTRIBUTE.is_logical_extension */
extern T1 T142x5306(GE_context* ac, T0* C);
/* Call to XPLAIN_FUNCTION.is_nil */
extern T1 T163x7430(GE_context* ac, T0* C);
/* Call to XPLAIN_FUNCTION.sqlextenddefault */
extern T0* T163x7438T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_FUNCTION.name */
extern T0* T163x7433(GE_context* ac, T0* C);
/* Call to XPLAIN_FUNCTION.sp_function_type */
extern T0* T163x7439T0T0T1(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* Call to XPLAIN_FUNCTION.representation */
extern T0* T163x7437T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to XPLAIN_FUNCTION.is_some */
extern T1 T163x7431(GE_context* ac, T0* C);
/* Call to XPLAIN_FUNCTION.needs_limit */
extern T1 T163x7436T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_FUNCTION.is_existential */
extern T1 T163x7441(GE_context* ac, T0* C);
/* Call to XPLAIN_FUNCTION.needs_distinct */
extern T1 T163x7435(GE_context* ac, T0* C);
/* Call to XPLAIN_FUNCTION.sqlfunction */
extern T0* T163x7440T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_FUNCTION.needs_coalesce */
extern T1 T163x7434(GE_context* ac, T0* C);
/* Call to XPLAIN_FUNCTION.property_required */
extern T6 T163x7432(GE_context* ac, T0* C);
/* Call to XPLAIN_ABSTRACT_OBJECT.representation */
extern T0* T189x5444(GE_context* ac, T0* C);
/* Call to XPLAIN_ABSTRACT_OBJECT.name */
extern T0* T189x5443(GE_context* ac, T0* C);
/* Call to XPLAIN_ABSTRACT_OBJECT.may_be_redefined */
extern T1 T189x5445(GE_context* ac, T0* C);
/* Call to XPLAIN_ABSTRACT_OBJECT.create_expression */
extern T0* T189x5446T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_ABSTRACT_TYPE.representation */
extern T0* T253x5444(GE_context* ac, T0* C);
/* Call to XPLAIN_ABSTRACT_TYPE.q_sql_select_name */
extern T0* T253x5404T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_ABSTRACT_TYPE.sql_select_name */
extern T0* T253x5406T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_ABSTRACT_TYPE.name */
extern T0* T253x5443(GE_context* ac, T0* C);
/* Call to XPLAIN_ABSTRACT_TYPE.sqlcolumnidentifier */
extern T0* T253x5400T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_ABSTRACT_TYPE.columndatatype */
extern T0* T253x5399T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_ABSTRACT_TYPE.sqlcolumnrequired */
extern T0* T253x5402T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_ABSTRACT_TYPE.sqlcolumndefault */
extern T0* T253x5401T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to ABSTRACT_GENERATOR.columndatatype_assertion */
extern T0* T270x5001T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.columndatatype_type */
extern T0* T270x5000T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.columndatatype_base */
extern T0* T270x4999T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_float */
extern T0* T270x4989T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_varchar */
extern T0* T270x4998T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_pk_char */
extern T0* T270x4994T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_ref_int */
extern T0* T270x4996T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_pk_int */
extern T0* T270x4995T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_text */
extern T0* T270x4997T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_numeric */
extern T0* T270x4992T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_picture */
extern T0* T270x4993T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_money */
extern T0* T270x4991T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_int */
extern T0* T270x4990T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_datetime */
extern T0* T270x4988T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_char */
extern T0* T270x4987T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.datatype_boolean */
extern T0* T270x4986T0(GE_context* ac, T0* C, T0* a1);
/* Call to DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].next_cursor */
extern T0* T338x8388(GE_context* ac, T0* C);
/* Call to DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].current_cell */
extern T0* T338x8631(GE_context* ac, T0* C);
/* Call to DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].off */
extern T1 T338x8382(GE_context* ac, T0* C);
/* Call to ST_PARAMETER_FORMATTER.valid_parameter */
extern T1 T355x7920T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR_WITH_SP.sp_function_type_for_selection_value */
extern T0* T390x5752T0T0T1(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* Call to SQL_GENERATOR_WITH_SP.value_representation_boolean */
extern T0* T390x4950(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR_WITH_SP.sp_function_type_for_selection_list */
extern T0* T390x5751T0T1(GE_context* ac, T0* C, T0* a1, T1 a2);
/* Call to SQL_GENERATOR_WITH_SP.storedproceduresupportstruefunction */
extern T1 T390x5734(GE_context* ac, T0* C);
/* Call to SQL_GENERATOR_WITH_SP.sp_function_type_for_selection */
extern T0* T390x5750T0T1(GE_context* ac, T0* C, T0* a1, T1 a2);
/* Call to SQL_GENERATOR_WITH_TRIGGERS.sqlinitvalue_attribute */
extern T0* T447x5800T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR_WITH_TRIGGERS.sql_init_infix_expression */
extern T0* T447x5799T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to SQL_GENERATOR_WITH_TRIGGERS.sql_init_cast_to_string */
extern T0* T447x5807T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR_WITH_TRIGGERS.sql_init_cast_to_real */
extern T0* T447x5806T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR_WITH_TRIGGERS.sql_init_cast_to_integer */
extern T0* T447x5805T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR_WITH_TRIGGERS.sql_init_cast_to_date */
extern T0* T447x5804T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR_WITH_TRIGGERS.sql_init_combine_expression */
extern T0* T447x5802T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR_WITH_TRIGGERS.sqlinitvalue_if */
extern T0* T447x5801T0(GE_context* ac, T0* C, T0* a1);
/* Call to EXCEPTION.set_type_name */
extern void T21x2811T0(GE_context* ac, T0* C, T0* a1);
/* Call to EXCEPTION.set_recipient_name */
extern void T21x2807T0(GE_context* ac, T0* C, T0* a1);
/* Call to EXCEPTION.set_description */
extern void T21x2799T0(GE_context* ac, T0* C, T0* a1);
/* Call to EXCEPTION.set_exception_trace */
extern void T21x2813T0(GE_context* ac, T0* C, T0* a1);
/* Call to EXCEPTION.set_throwing_exception */
extern void T21x2806T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_drop_extension */
extern void T32x4791T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_drop_assertion */
extern void T32x4789T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.drop_procedure */
extern void T32x4854T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.drop_value */
extern void T32x4858T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.drop_constant */
extern void T32x4851T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_drop_column */
extern void T32x4790T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.drop_table */
extern void T32x4855T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.drop_domain */
extern void T32x4852T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_type */
extern void T32x5018T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_init */
extern void T32x4797T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_one_line_comment */
extern void T32x4782T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_sql */
extern void T32x5017T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_procedure */
extern void T32x5012T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_echo */
extern void T32x4792T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.echo */
extern void T32x4781T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_extend */
extern void T32x5009T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_select */
extern void T32x5013T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_select_value */
extern void T32x5016T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_value */
extern void T32x5020T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_update */
extern void T32x5019T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to SQL_GENERATOR.write_delete */
extern void T32x5008T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.write_insert */
extern void T32x5011T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to SQL_GENERATOR.write_index */
extern void T32x4796T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_assertion */
extern void T32x4783T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_drop */
extern void T32x4788T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_constant */
extern void T32x5006T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_constant_assignment */
extern void T32x5007T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to SQL_GENERATOR.write_base */
extern void T32x4784T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_use_database */
extern void T32x4808T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.write_end */
extern void T32x4793T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.set_sequence_name_format */
extern void T32x4981T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.set_primary_key_format */
extern void T32x4980T0(GE_context* ac, T0* C, T0* a1);
/* Call to SQL_GENERATOR.set_options */
extern void T32x4979T1T1T1T1T1T1T1T1T1T1T1T1T1(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* Call to XPLAIN_DOMAIN_RESTRICTION.check_attachment */
extern void T121x5301T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_STATEMENT.cleanup */
extern void T126x7442(GE_context* ac, T0* C);
/* Call to XPLAIN_STATEMENT.optimize_for_procedure */
extern void T126x7443T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_STATEMENT.write */
extern void T126x7444T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.remove_extension */
extern void T129x5142T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.next_constraint_number */
extern void T129x5122(GE_context* ac, T0* C);
/* Call to XPLAIN_TYPE.add_extension */
extern void T129x5141T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.add_assertion */
extern void T129x5143T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_TYPE.write_drop_attribute */
extern void T129x5124T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_EXPRESSION.add_to_join */
extern void T134x5182T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_REPRESENTATION.set_domain_restriction */
extern void T139x5817T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_ATTRIBUTE.write_drop */
extern void T142x5323T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to XPLAIN_ATTRIBUTE.set_required */
extern void T142x5318T1(GE_context* ac, T0* C, T1 a1);
/* Call to XPLAIN_ATTRIBUTE.set_init */
extern void T142x5320T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_ATTRIBUTE.set_init_default */
extern void T142x5319T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_ABSTRACT_OBJECT.write_drop */
extern void T189x5449T0(GE_context* ac, T0* C, T0* a1);
/* Call to XPLAIN_ABSTRACT_TYPE.hack_anode */
extern void T253x5398T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_sql */
extern void T270x5017T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_procedure */
extern void T270x5012T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_select_list */
extern void T270x5015T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_extend */
extern void T270x5009T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_select */
extern void T270x5013T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_select_function */
extern void T270x5014T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_select_value */
extern void T270x5016T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_update */
extern void T270x5019T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to ABSTRACT_GENERATOR.write_delete */
extern void T270x5008T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to ABSTRACT_GENERATOR.write_constant */
extern void T270x5006T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_constant_assignment */
extern void T270x5007T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to ABSTRACT_GENERATOR.write_get_insert */
extern void T270x5010T0T0T1T0(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* Call to ABSTRACT_GENERATOR.write_insert */
extern void T270x5011T0T0T0(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* Call to ABSTRACT_GENERATOR.write_type */
extern void T270x5018T0(GE_context* ac, T0* C, T0* a1);
/* Call to ABSTRACT_GENERATOR.write_value */
extern void T270x5020T0(GE_context* ac, T0* C, T0* a1);
/* Call to DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].set_next_cursor */
extern void T338x8389T0(GE_context* ac, T0* C, T0* a1);
/* Call to DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].set_after */
extern void T338x8633(GE_context* ac, T0* C);
/* Call to DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].set_current_cell */
extern void T338x8632T0(GE_context* ac, T0* C, T0* a1);
/* Call to DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].set */
extern void T338x8635T0T1T1(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* Call to ST_PARAMETER_FORMATTER.set_lowercase */
extern void T355x7919T1(GE_context* ac, T0* C, T1 a1);
/* Call to ST_PARAMETER_FORMATTER.reset_options */
extern void T355x7901(GE_context* ac, T0* C);
/* Call to ST_PARAMETER_FORMATTER.format_to */
extern void T355x7921T0T0(GE_context* ac, T0* C, T0* a1, T0* a2);
/* Call to ST_PARAMETER_FORMATTER.set_precision */
extern void T355x7911T6(GE_context* ac, T0* C, T6 a1);
/* Call to ST_PARAMETER_FORMATTER.set_width */
extern void T355x7912T6(GE_context* ac, T0* C, T6 a1);
/* Call to ST_PARAMETER_FORMATTER.set_plus_sign_enabled */
extern void T355x7917T1(GE_context* ac, T0* C, T1 a1);
/* Call to ST_PARAMETER_FORMATTER.set_space_sign_enabled */
extern void T355x7918T1(GE_context* ac, T0* C, T1 a1);
/* Call to ST_PARAMETER_FORMATTER.set_padding_character */
extern void T355x7916T2(GE_context* ac, T0* C, T2 a1);
/* Call to ST_PARAMETER_FORMATTER.set_align_center */
extern void T355x7915(GE_context* ac, T0* C);
/* Call to ST_PARAMETER_FORMATTER.set_align_left */
extern void T355x7913(GE_context* ac, T0* C);
/* New instance of type SPECIAL [CHARACTER_8] */
extern T0* GE_new15(T6 a1, T1 initialize);
/* New instance of type SPECIAL [CHARACTER_32] */
extern T0* GE_new16(T6 a1, T1 initialize);
/* New instance of type STRING_8 */
extern T0* GE_new17(T1 initialize);
/* New instance of type IMMUTABLE_STRING_32 */
extern T0* GE_new19(T1 initialize);
/* New instance of type ISE_EXCEPTION_MANAGER */
extern T0* GE_new20(T1 initialize);
/* New instance of type XPLAIN2SQL */
extern T0* GE_new24(T1 initialize);
/* New instance of type CELL [detachable EXCEPTION] */
extern T0* GE_new25(T1 initialize);
/* New instance of type HASH_TABLE [INTEGER_32, INTEGER_32] */
extern T0* GE_new26(T1 initialize);
/* New instance of type CELL [detachable TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN]] */
extern T0* GE_new27(T1 initialize);
/* New instance of type CELL [NO_MORE_MEMORY] */
extern T0* GE_new28(T1 initialize);
/* New instance of type C_STRING */
extern T0* GE_new29(T1 initialize);
/* New instance of type [attached] TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN] */
extern T0* GE_new30(T1 initialize);
/* New instance of type KL_TEXT_INPUT_FILE */
extern T0* GE_new31(T1 initialize);
/* New instance of type KL_ARGUMENTS */
extern T0* GE_new34(T1 initialize);
/* New instance of type [attached] ARRAY [[attached] STRING_8] */
extern T0* GE_new35(T1 initialize);
/* New instance of type SPECIAL [[attached] STRING_8] */
extern T0* GE_new36(T6 a1, T1 initialize);
/* New instance of type ARRAY [ANY] */
extern T0* GE_new37(T1 initialize);
/* New instance of type SPECIAL [ANY] */
extern T0* GE_new38(T6 a1, T1 initialize);
/* New instance of type KL_STANDARD_FILES */
extern T0* GE_new39(T1 initialize);
/* New instance of type KL_STDERR_FILE */
extern T0* GE_new40(T1 initialize);
/* New instance of type SQL_GENERATOR_ANSI */
extern T0* GE_new41(T1 initialize);
/* New instance of type SQL_GENERATOR_BASIC */
extern T0* GE_new42(T1 initialize);
/* New instance of type SQL_GENERATOR_DB2_6 */
extern T0* GE_new43(T1 initialize);
/* New instance of type SQL_GENERATOR_DB2_71 */
extern T0* GE_new44(T1 initialize);
/* New instance of type SQL_GENERATOR_FOXPRO */
extern T0* GE_new45(T1 initialize);
/* New instance of type SQL_GENERATOR_INTERBASE6 */
extern T0* GE_new46(T1 initialize);
/* New instance of type SQL_GENERATOR_FIREBIRD_21 */
extern T0* GE_new47(T1 initialize);
/* New instance of type SQL_GENERATOR_MSACCESS97 */
extern T0* GE_new48(T1 initialize);
/* New instance of type SQL_GENERATOR_MSACCESS2000 */
extern T0* GE_new49(T1 initialize);
/* New instance of type SQL_GENERATOR_MSQL */
extern T0* GE_new50(T1 initialize);
/* New instance of type SQL_GENERATOR_MYSQL5 */
extern T0* GE_new51(T1 initialize);
/* New instance of type SQL_GENERATOR_MYSQL4 */
extern T0* GE_new52(T1 initialize);
/* New instance of type SQL_GENERATOR_MYSQL322 */
extern T0* GE_new53(T1 initialize);
/* New instance of type SQL_GENERATOR_ORACLE */
extern T0* GE_new54(T1 initialize);
/* New instance of type SQL_GENERATOR_PGSQL_95 */
extern T0* GE_new55(T1 initialize);
/* New instance of type SQL_GENERATOR_PGSQL_82 */
extern T0* GE_new56(T1 initialize);
/* New instance of type SQL_GENERATOR_PGSQL_81 */
extern T0* GE_new57(T1 initialize);
/* New instance of type SQL_GENERATOR_PGSQL_73 */
extern T0* GE_new58(T1 initialize);
/* New instance of type SQL_GENERATOR_PGSQL_72 */
extern T0* GE_new59(T1 initialize);
/* New instance of type SQL_GENERATOR_SQLITE_3 */
extern T0* GE_new60(T1 initialize);
/* New instance of type SQL_GENERATOR_TSQL2016 */
extern T0* GE_new61(T1 initialize);
/* New instance of type SQL_GENERATOR_TSQL2000 */
extern T0* GE_new62(T1 initialize);
/* New instance of type SQL_GENERATOR_TSQL70 */
extern T0* GE_new63(T1 initialize);
/* New instance of type SQL_GENERATOR_TSQL65 */
extern T0* GE_new64(T1 initialize);
/* New instance of type XPLAIN_PARSER */
extern T0* GE_new65(T1 initialize);
/* New instance of type XML_GENERATOR */
extern T0* GE_new67(T1 initialize);
/* New instance of type XPLAIN_STATEMENTS */
extern T0* GE_new69(T1 initialize);
/* New instance of type VOID_TARGET */
extern T0* GE_new72(T1 initialize);
/* New instance of type ROUTINE_FAILURE */
extern T0* GE_new74(T1 initialize);
/* New instance of type OLD_VIOLATION */
extern T0* GE_new76(T1 initialize);
/* New instance of type NO_MORE_MEMORY */
extern T0* GE_new78(T1 initialize);
/* New instance of type INVARIANT_VIOLATION */
extern T0* GE_new79(T1 initialize);
/* New instance of type OPERATING_SYSTEM_SIGNAL_FAILURE */
extern T0* GE_new80(T1 initialize);
/* New instance of type IO_FAILURE */
extern T0* GE_new81(T1 initialize);
/* New instance of type OPERATING_SYSTEM_FAILURE */
extern T0* GE_new82(T1 initialize);
/* New instance of type COM_FAILURE */
extern T0* GE_new83(T1 initialize);
/* New instance of type EIFFEL_RUNTIME_PANIC */
extern T0* GE_new84(T1 initialize);
/* New instance of type PRECONDITION_VIOLATION */
extern T0* GE_new86(T1 initialize);
/* New instance of type POSTCONDITION_VIOLATION */
extern T0* GE_new87(T1 initialize);
/* New instance of type FLOATING_POINT_FAILURE */
extern T0* GE_new88(T1 initialize);
/* New instance of type CHECK_VIOLATION */
extern T0* GE_new89(T1 initialize);
/* New instance of type BAD_INSPECT_VALUE */
extern T0* GE_new90(T1 initialize);
/* New instance of type VARIANT_VIOLATION */
extern T0* GE_new91(T1 initialize);
/* New instance of type LOOP_INVARIANT_VIOLATION */
extern T0* GE_new92(T1 initialize);
/* New instance of type RESCUE_FAILURE */
extern T0* GE_new93(T1 initialize);
/* New instance of type RESUMPTION_FAILURE */
extern T0* GE_new94(T1 initialize);
/* New instance of type CREATE_ON_DEFERRED */
extern T0* GE_new95(T1 initialize);
/* New instance of type EXTERNAL_FAILURE */
extern T0* GE_new96(T1 initialize);
/* New instance of type VOID_ASSIGNED_TO_EXPANDED */
extern T0* GE_new97(T1 initialize);
/* New instance of type EXCEPTION_IN_SIGNAL_HANDLER_FAILURE */
extern T0* GE_new98(T1 initialize);
/* New instance of type MISMATCH_FAILURE */
extern T0* GE_new99(T1 initialize);
/* New instance of type DEVELOPER_EXCEPTION */
extern T0* GE_new100(T1 initialize);
/* New instance of type ADDRESS_APPLIED_TO_MELTED_FEATURE */
extern T0* GE_new101(T1 initialize);
/* New instance of type SERIALIZATION_FAILURE */
extern T0* GE_new102(T1 initialize);
/* New instance of type ST_SCIENTIFIC_FORMATTER */
extern T0* GE_new103(T1 initialize);
/* New instance of type PRIMES */
extern T0* GE_new104(T1 initialize);
/* New instance of type SPECIAL [INTEGER_32] */
extern T0* GE_new105(T6 a1, T1 initialize);
/* New instance of type SPECIAL [BOOLEAN] */
extern T0* GE_new106(T6 a1, T1 initialize);
/* New instance of type KL_STRING_ROUTINES */
extern T0* GE_new108(T1 initialize);
/* New instance of type MANAGED_POINTER */
extern T0* GE_new111(T1 initialize);
/* New instance of type FILE_INFO */
extern T0* GE_new112(T1 initialize);
/* New instance of type ARGUMENTS_32 */
extern T0* GE_new113(T1 initialize);
/* New instance of type DS_HASH_TABLE [XPLAIN_VALUE, STRING_8] */
extern T0* GE_new114(T1 initialize);
/* New instance of type KL_STDOUT_FILE */
extern T0* GE_new115(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [INTEGER_32] */
extern T0* GE_new117(T1 initialize);
/* New instance of type XPLAIN_SCANNER_STATE */
extern T0* GE_new118(T1 initialize);
/* New instance of type DS_LINKED_LIST [XPLAIN_SCANNER_STATE] */
extern T0* GE_new120(T1 initialize);
/* New instance of type XPLAIN_REQUIRED */
extern T0* GE_new122(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable ANY] */
extern T0* GE_new124(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [STRING_8] */
extern T0* GE_new125(T1 initialize);
/* New instance of type XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT */
extern T0* GE_new127(T1 initialize);
/* New instance of type XPLAIN_BASE */
extern T0* GE_new128(T1 initialize);
/* New instance of type XPLAIN_TYPE */
extern T0* GE_new129(T1 initialize);
/* New instance of type XPLAIN_CONSTANT_STATEMENT */
extern T0* GE_new130(T1 initialize);
/* New instance of type XPLAIN_A_NODE */
extern T0* GE_new131(T1 initialize);
/* New instance of type XPLAIN_I_NODE */
extern T0* GE_new132(T1 initialize);
/* New instance of type XPLAIN_LOGICAL_EXPRESSION */
extern T0* GE_new133(T1 initialize);
/* New instance of type XPLAIN_LOGICAL_VALUE_EXPRESSION */
extern T0* GE_new135(T1 initialize);
/* New instance of type XPLAIN_ATTRIBUTE_NAME_NODE */
extern T0* GE_new137(T1 initialize);
/* New instance of type XPLAIN_ATTRIBUTE_NAME */
extern T0* GE_new138(T1 initialize);
/* New instance of type XPLAIN_ATTRIBUTE_NODE */
extern T0* GE_new141(T1 initialize);
/* New instance of type XPLAIN_ATTRIBUTE */
extern T0* GE_new142(T1 initialize);
/* New instance of type XPLAIN_ASSERTION */
extern T0* GE_new143(T1 initialize);
/* New instance of type XPLAIN_ASSIGNMENT_NODE */
extern T0* GE_new144(T1 initialize);
/* New instance of type XPLAIN_ASSIGNMENT */
extern T0* GE_new145(T1 initialize);
/* New instance of type XPLAIN_CASCADE_STATEMENT */
extern T0* GE_new146(T1 initialize);
/* New instance of type XPLAIN_CASCADE_FUNCTION_EXPRESSION */
extern T0* GE_new147(T1 initialize);
/* New instance of type XPLAIN_DELETE_STATEMENT */
extern T0* GE_new148(T1 initialize);
/* New instance of type XPLAIN_SUBJECT */
extern T0* GE_new149(T1 initialize);
/* New instance of type XPLAIN_UPDATE_STATEMENT */
extern T0* GE_new150(T1 initialize);
/* New instance of type XPLAIN_VALUE_STATEMENT */
extern T0* GE_new151(T1 initialize);
/* New instance of type XPLAIN_VALUE_SELECTION_STATEMENT */
extern T0* GE_new152(T1 initialize);
/* New instance of type XPLAIN_SELECTION_FUNCTION */
extern T0* GE_new154(T1 initialize);
/* New instance of type XPLAIN_GET_STATEMENT */
extern T0* GE_new155(T1 initialize);
/* New instance of type XPLAIN_EXTEND_STATEMENT */
extern T0* GE_new156(T1 initialize);
/* New instance of type XPLAIN_EXTENSION */
extern T0* GE_new157(T1 initialize);
/* New instance of type XPLAIN_EXTEND_ATTRIBUTE */
extern T0* GE_new158(T1 initialize);
/* New instance of type XPLAIN_EXTENSION_EXPRESSION */
extern T0* GE_new159(T1 initialize);
/* New instance of type XPLAIN_SELECTION_LIST */
extern T0* GE_new161(T1 initialize);
/* New instance of type XPLAIN_SORT_NODE */
extern T0* GE_new162(T1 initialize);
/* New instance of type XPLAIN_EXPRESSION_NODE */
extern T0* GE_new164(T1 initialize);
/* New instance of type XPLAIN_PROCEDURE_STATEMENT */
extern T0* GE_new165(T1 initialize);
/* New instance of type XPLAIN_SQL_STATEMENT */
extern T0* GE_new166(T1 initialize);
/* New instance of type XPLAIN_STATEMENT_NODE */
extern T0* GE_new167(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_STATEMENT] */
extern T0* GE_new168(T6 a1, T1 initialize);
/* New instance of type SPECIAL [XPLAIN_SQL_STATEMENT] */
extern T0* GE_new169(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT] */
extern T0* GE_new170(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT] */
extern T0* GE_new171(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT] */
extern T0* GE_new172(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_TYPE] */
extern T0* GE_new173(T6 a1, T1 initialize);
/* New instance of type XPLAIN_TYPE_STATEMENT */
extern T0* GE_new174(T1 initialize);
/* New instance of type XPLAIN_UNIVERSE */
extern T0* GE_new175(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_BASE] */
extern T0* GE_new176(T6 a1, T1 initialize);
/* New instance of type XPLAIN_BASE_STATEMENT */
extern T0* GE_new177(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT] */
extern T0* GE_new178(T6 a1, T1 initialize);
/* New instance of type XPLAIN_VARIABLE */
extern T0* GE_new179(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_EXPRESSION] */
extern T0* GE_new180(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT] */
extern T0* GE_new181(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_REPRESENTATION] */
extern T0* GE_new182(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_BASE] */
extern T0* GE_new183(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_DOMAIN_RESTRICTION] */
extern T0* GE_new184(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE] */
extern T0* GE_new185(T6 a1, T1 initialize);
/* New instance of type SPECIAL [XPLAIN_PK_REPRESENTATION] */
extern T0* GE_new186(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_TYPE] */
extern T0* GE_new187(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_STATEMENT] */
extern T0* GE_new188(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_ATTRIBUTE_NAME] */
extern T0* GE_new190(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_DOMAIN_RESTRICTION] */
extern T0* GE_new191(T1 initialize);
/* New instance of type XPLAIN_A_PATTERN */
extern T0* GE_new192(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_A_NODE] */
extern T0* GE_new193(T6 a1, T1 initialize);
/* New instance of type XPLAIN_A_ENUMERATION */
extern T0* GE_new194(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_I_NODE] */
extern T0* GE_new195(T6 a1, T1 initialize);
/* New instance of type XPLAIN_I_ENUMERATION */
extern T0* GE_new196(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_A_NODE] */
extern T0* GE_new197(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_I_NODE] */
extern T0* GE_new199(T1 initialize);
/* New instance of type XPLAIN_TRAJECTORY */
extern T0* GE_new200(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_LOGICAL_EXPRESSION] */
extern T0* GE_new201(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_EXPRESSION] */
extern T0* GE_new202(T1 initialize);
/* New instance of type XPLAIN_LOGICAL_INFIX_EXPRESSION */
extern T0* GE_new203(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_EXPRESSION] */
extern T0* GE_new204(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE] */
extern T0* GE_new205(T6 a1, T1 initialize);
/* New instance of type XPLAIN_NOTNOT_EXPRESSION */
extern T0* GE_new206(T1 initialize);
/* New instance of type XPLAIN_NOT_EXPRESSION */
extern T0* GE_new207(T1 initialize);
/* New instance of type XPLAIN_PARAMETER_EXPRESSION */
extern T0* GE_new208(T1 initialize);
/* New instance of type XPLAIN_EQ_NULL_EXPRESSION */
extern T0* GE_new209(T1 initialize);
/* New instance of type XPLAIN_NE_NULL_EXPRESSION */
extern T0* GE_new210(T1 initialize);
/* New instance of type XPLAIN_INFIX_EXPRESSION */
extern T0* GE_new211(T1 initialize);
/* New instance of type XPLAIN_PARENTHESIS_EXPRESSION */
extern T0* GE_new212(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION] */
extern T0* GE_new213(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_VALUE_EXPRESSION] */
extern T0* GE_new214(T1 initialize);
/* New instance of type XPLAIN_SYSTEMDATE_EXPRESSION */
extern T0* GE_new215(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_SYSTEM_EXPRESSION] */
extern T0* GE_new216(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_SYSTEM_EXPRESSION] */
extern T0* GE_new217(T1 initialize);
/* New instance of type XPLAIN_LOGINNAME_EXPRESSION */
extern T0* GE_new218(T1 initialize);
/* New instance of type XPLAIN_IF_EXPRESSION */
extern T0* GE_new219(T1 initialize);
/* New instance of type XPLAIN_PREFIX_EXPRESSION */
extern T0* GE_new220(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_EXPRESSION_NODE] */
extern T0* GE_new221(T6 a1, T1 initialize);
/* New instance of type XPLAIN_COMBINE_FUNCTION */
extern T0* GE_new222(T1 initialize);
/* New instance of type XPLAIN_DATEF_FUNCTION */
extern T0* GE_new223(T1 initialize);
/* New instance of type XPLAIN_INTEGER_FUNCTION */
extern T0* GE_new224(T1 initialize);
/* New instance of type XPLAIN_REAL_FUNCTION */
extern T0* GE_new225(T1 initialize);
/* New instance of type XPLAIN_STRING_FUNCTION */
extern T0* GE_new226(T1 initialize);
/* New instance of type XPLAIN_STRING_EXPRESSION */
extern T0* GE_new227(T1 initialize);
/* New instance of type XPLAIN_NEWDATE_FUNCTION */
extern T0* GE_new228(T1 initialize);
/* New instance of type XPLAIN_ID_FUNCTION */
extern T0* GE_new229(T1 initialize);
/* New instance of type XPLAIN_NUMBER_EXPRESSION */
extern T0* GE_new230(T1 initialize);
/* New instance of type XPLAIN_UNMANAGED_PARAMETER_EXPRESSION */
extern T0* GE_new231(T1 initialize);
/* New instance of type XPLAIN_USER_FUNCTION */
extern T0* GE_new232(T1 initialize);
/* New instance of type XPLAIN_SQL_EXPRESSION */
extern T0* GE_new233(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME_NODE] */
extern T0* GE_new234(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME] */
extern T0* GE_new235(T1 initialize);
/* New instance of type XPLAIN_A_REPRESENTATION */
extern T0* GE_new236(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_REPRESENTATION] */
extern T0* GE_new237(T1 initialize);
/* New instance of type XPLAIN_B_REPRESENTATION */
extern T0* GE_new238(T1 initialize);
/* New instance of type XPLAIN_C_REPRESENTATION */
extern T0* GE_new239(T1 initialize);
/* New instance of type XPLAIN_D_REPRESENTATION */
extern T0* GE_new240(T1 initialize);
/* New instance of type XPLAIN_I_REPRESENTATION */
extern T0* GE_new241(T1 initialize);
/* New instance of type XPLAIN_M_REPRESENTATION */
extern T0* GE_new242(T1 initialize);
/* New instance of type XPLAIN_P_REPRESENTATION */
extern T0* GE_new243(T1 initialize);
/* New instance of type XPLAIN_R_REPRESENTATION */
extern T0* GE_new244(T1 initialize);
/* New instance of type XPLAIN_T_REPRESENTATION */
extern T0* GE_new245(T1 initialize);
/* New instance of type XPLAIN_PK_A_REPRESENTATION */
extern T0* GE_new246(T1 initialize);
/* New instance of type XPLAIN_A_REFERENCES */
extern T0* GE_new247(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_PK_REPRESENTATION] */
extern T0* GE_new248(T1 initialize);
/* New instance of type XPLAIN_PK_I_REPRESENTATION */
extern T0* GE_new249(T1 initialize);
/* New instance of type XPLAIN_I_REFERENCES */
extern T0* GE_new250(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_ATTRIBUTE] */
extern T0* GE_new251(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_ATTRIBUTE_NODE] */
extern T0* GE_new252(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE] */
extern T0* GE_new254(T1 initialize);
/* New instance of type XPLAIN_VARIABLE_EXPRESSION */
extern T0* GE_new255(T1 initialize);
/* New instance of type XPLAIN_VALUE */
extern T0* GE_new256(T1 initialize);
/* New instance of type XPLAIN_VALUE_EXPRESSION */
extern T0* GE_new257(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION] */
extern T0* GE_new258(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSERTION] */
extern T0* GE_new259(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_ASSERTION] */
extern T0* GE_new260(T6 a1, T1 initialize);
/* New instance of type XPLAIN_INDEX */
extern T0* GE_new261(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_UPDATE_STATEMENT] */
extern T0* GE_new262(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_DELETE_STATEMENT] */
extern T0* GE_new263(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_CASCADE_STATEMENT] */
extern T0* GE_new264(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_SUBJECT] */
extern T0* GE_new265(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE] */
extern T0* GE_new266(T6 a1, T1 initialize);
/* New instance of type XPLAIN_INSERT_STATEMENT */
extern T0* GE_new267(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_SELECTION_LIST] */
extern T0* GE_new268(T6 a1, T1 initialize);
/* New instance of type XPLAIN_GET_INSERT_STATEMENT */
extern T0* GE_new269(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_ASSIGNMENT] */
extern T0* GE_new271(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSIGNMENT_NODE] */
extern T0* GE_new272(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_ASSIGNMENT] */
extern T0* GE_new273(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION] */
extern T0* GE_new274(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_STATEMENT] */
extern T0* GE_new275(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_SELECTION_FUNCTION] */
extern T0* GE_new276(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION] */
extern T0* GE_new277(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_DELETE_STATEMENT] */
extern T0* GE_new278(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_SUBJECT] */
extern T0* GE_new279(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_UPDATE_STATEMENT] */
extern T0* GE_new280(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_VALUE_STATEMENT] */
extern T0* GE_new281(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_VALUE_STATEMENT] */
extern T0* GE_new282(T1 initialize);
/* New instance of type XPLAIN_SELECTION_EXPRESSION */
extern T0* GE_new283(T1 initialize);
/* New instance of type XPLAIN_LAST_AUTO_PK_EXPRESSION */
extern T0* GE_new285(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT] */
extern T0* GE_new286(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_VALUE_SELECTION_STATEMENT] */
extern T0* GE_new287(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION] */
extern T0* GE_new288(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION] */
extern T0* GE_new289(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_FUNCTION] */
extern T0* GE_new290(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_FUNCTION] */
extern T0* GE_new291(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_SELECTION] */
extern T0* GE_new292(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_GET_STATEMENT] */
extern T0* GE_new293(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_GET_STATEMENT] */
extern T0* GE_new294(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_EXTENSION] */
extern T0* GE_new295(T6 a1, T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_EXTEND_STATEMENT] */
extern T0* GE_new296(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTEND_STATEMENT] */
extern T0* GE_new297(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_EXTEND_ATTRIBUTE] */
extern T0* GE_new298(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION] */
extern T0* GE_new299(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_EXTEND_ATTRIBUTE] */
extern T0* GE_new300(T1 initialize);
/* New instance of type XPLAIN_EXTENSION_EXPRESSION_EXPRESSION */
extern T0* GE_new301(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION_EXPRESSION] */
extern T0* GE_new302(T1 initialize);
/* New instance of type XPLAIN_EXTENSION_FUNCTION_EXPRESSION */
extern T0* GE_new303(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION] */
extern T0* GE_new304(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_SORT_NODE] */
extern T0* GE_new305(T6 a1, T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_LIST] */
extern T0* GE_new306(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_SORT_NODE] */
extern T0* GE_new307(T1 initialize);
/* New instance of type XPLAIN_MAX_FUNCTION */
extern T0* GE_new308(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_FUNCTION] */
extern T0* GE_new309(T1 initialize);
/* New instance of type XPLAIN_MIN_FUNCTION */
extern T0* GE_new310(T1 initialize);
/* New instance of type XPLAIN_TOTAL_FUNCTION */
extern T0* GE_new311(T1 initialize);
/* New instance of type XPLAIN_COUNT_FUNCTION */
extern T0* GE_new312(T1 initialize);
/* New instance of type XPLAIN_ANY_FUNCTION */
extern T0* GE_new313(T1 initialize);
/* New instance of type XPLAIN_NIL_FUNCTION */
extern T0* GE_new314(T1 initialize);
/* New instance of type XPLAIN_SOME_FUNCTION */
extern T0* GE_new315(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_EXPRESSION_NODE] */
extern T0* GE_new316(T1 initialize);
/* New instance of type SPECIAL [detachable XPLAIN_STATEMENT_NODE] */
extern T0* GE_new317(T6 a1, T1 initialize);
/* New instance of type XPLAIN_PROCEDURE */
extern T0* GE_new318(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_PROCEDURE_STATEMENT] */
extern T0* GE_new319(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_SQL_STATEMENT] */
extern T0* GE_new320(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT_NODE] */
extern T0* GE_new321(T1 initialize);
/* New instance of type YY_FILE_BUFFER */
extern T0* GE_new322(T1 initialize);
/* New instance of type KL_STDIN_FILE */
extern T0* GE_new323(T1 initialize);
/* New instance of type XML_WRITER */
extern T0* GE_new325(T1 initialize);
/* New instance of type KL_TEXT_OUTPUT_FILE */
extern T0* GE_new326(T1 initialize);
/* New instance of type DS_LINKED_LIST [XPLAIN_STATEMENT] */
extern T0* GE_new327(T1 initialize);
/* New instance of type STD_FILES */
extern T0* GE_new328(T1 initialize);
/* New instance of type JOIN_LIST */
extern T0* GE_new329(T1 initialize);
/* New instance of type JOIN_NODE */
extern T0* GE_new330(T1 initialize);
/* New instance of type DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME] */
extern T0* GE_new335(T1 initialize);
/* New instance of type DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME] */
extern T0* GE_new336(T1 initialize);
/* New instance of type DS_LINKED_LIST [XPLAIN_ATTRIBUTE] */
extern T0* GE_new337(T1 initialize);
/* New instance of type DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE] */
extern T0* GE_new338(T1 initialize);
/* New instance of type DS_BILINKED_LIST [XPLAIN_STATEMENT] */
extern T0* GE_new339(T1 initialize);
/* New instance of type XPLAIN_B_RESTRICTION */
extern T0* GE_new342(T1 initialize);
/* New instance of type DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE] */
extern T0* GE_new344(T1 initialize);
/* New instance of type XPLAIN_LIKE_EXPRESSION */
extern T0* GE_new345(T1 initialize);
/* New instance of type XPLAIN_NOT_LIKE_EXPRESSION */
extern T0* GE_new346(T1 initialize);
/* New instance of type ARRAY [INTEGER_32] */
extern T0* GE_new347(T1 initialize);
/* New instance of type KL_ARRAY_ROUTINES [INTEGER_32] */
extern T0* GE_new348(T1 initialize);
/* New instance of type CELL [INTEGER_32] */
extern T0* GE_new350(T1 initialize);
/* New instance of type KL_ARRAY_ROUTINES [detachable ANY] */
extern T0* GE_new351(T1 initialize);
/* New instance of type KL_NULL_TEXT_OUTPUT_STREAM */
extern T0* GE_new352(T1 initialize);
/* New instance of type KL_STRING_OUTPUT_STREAM */
extern T0* GE_new354(T1 initialize);
/* New instance of type DS_CELL [INTEGER_32] */
extern T0* GE_new356(T1 initialize);
/* New instance of type ST_BOOLEAN_FORMATTER */
extern T0* GE_new358(T1 initialize);
/* New instance of type ST_CHARACTER_FORMATTER */
extern T0* GE_new359(T1 initialize);
/* New instance of type ST_FLOATING_POINT_FORMATTER */
extern T0* GE_new360(T1 initialize);
/* New instance of type ST_FIXED_POINT_FORMATTER */
extern T0* GE_new361(T1 initialize);
/* New instance of type ST_FIXED_OR_FLOATING_POINT_FORMATTER */
extern T0* GE_new362(T1 initialize);
/* New instance of type ST_DECIMAL_FORMATTER */
extern T0* GE_new363(T1 initialize);
/* New instance of type ST_UNSIGNED_OCTAL_FORMATTER */
extern T0* GE_new364(T1 initialize);
/* New instance of type ST_UNSIGNED_HEXADECIMAL_FORMATTER */
extern T0* GE_new365(T1 initialize);
/* New instance of type ST_UNSIGNED_DECIMAL_FORMATTER */
extern T0* GE_new366(T1 initialize);
/* New instance of type ST_POINTER_FORMATTER */
extern T0* GE_new367(T1 initialize);
/* New instance of type ST_STRING_FORMATTER */
extern T0* GE_new368(T1 initialize);
/* New instance of type KL_ANY_ROUTINES */
extern T0* GE_new369(T1 initialize);
/* New instance of type UC_STRING */
extern T0* GE_new370(T1 initialize);
/* New instance of type READABLE_STRING_32 */
extern T0* GE_new372(T1 initialize);
/* New instance of type SPECIAL [NATURAL_8] */
extern T0* GE_new373(T6 a1, T1 initialize);
/* New instance of type ARRAY [IMMUTABLE_STRING_32] */
extern T0* GE_new375(T1 initialize);
/* New instance of type SPECIAL [IMMUTABLE_STRING_32] */
extern T0* GE_new376(T6 a1, T1 initialize);
/* New instance of type detachable KL_EQUALITY_TESTER [XPLAIN_VALUE] */
extern T0* GE_new377(T1 initialize);
/* New instance of type detachable KL_EQUALITY_TESTER [STRING_8] */
extern T0* GE_new378(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_VALUE] */
extern T0* GE_new381(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_VALUE] */
extern T0* GE_new382(T6 a1, T1 initialize);
/* New instance of type DS_HASH_TABLE_CURSOR [XPLAIN_VALUE, STRING_8] */
extern T0* GE_new383(T1 initialize);
/* New instance of type detachable DS_LINKABLE [XPLAIN_SCANNER_STATE] */
extern T0* GE_new385(T1 initialize);
/* New instance of type XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE] */
extern T0* GE_new386(T1 initialize);
/* New instance of type XPLAIN_DATA_ATTRIBUTES_CURSOR */
extern T0* GE_new387(T1 initialize);
/* New instance of type XPLAIN_ATTRIBUTE_EXPRESSION */
extern T0* GE_new389(T1 initialize);
/* New instance of type DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8] */
extern T0* GE_new391(T1 initialize);
/* New instance of type DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT] */
extern T0* GE_new393(T1 initialize);
/* New instance of type DS_LINKED_STACK [STRING_8] */
extern T0* GE_new394(T1 initialize);
/* New instance of type DS_LINKED_LIST_CURSOR [XPLAIN_STATEMENT] */
extern T0* GE_new396(T1 initialize);
/* New instance of type detachable DS_LINKABLE [XPLAIN_STATEMENT] */
extern T0* GE_new397(T1 initialize);
/* New instance of type STRING_TO_INTEGER_CONVERTOR */
extern T0* GE_new398(T1 initialize);
/* New instance of type JOIN */
extern T0* GE_new401(T1 initialize);
/* New instance of type DS_HASH_SET [STRING_8] */
extern T0* GE_new402(T1 initialize);
/* New instance of type XPLAIN_F_REPRESENTATION */
extern T0* GE_new403(T1 initialize);
/* New instance of type EXCEPTIONS */
extern T0* GE_new405(T1 initialize);
/* New instance of type XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE] */
extern T0* GE_new408(T1 initialize);
/* New instance of type KL_INTEGER_ROUTINES */
extern T0* GE_new410(T1 initialize);
/* New instance of type [attached] ARRAY [DS_CELL [INTEGER_32]] */
extern T0* GE_new411(T1 initialize);
/* New instance of type SPECIAL [DS_CELL [INTEGER_32]] */
extern T0* GE_new412(T6 a1, T1 initialize);
/* New instance of type DS_CELL [REAL_64] */
extern T0* GE_new413(T1 initialize);
/* New instance of type KL_CHARACTER_BUFFER */
extern T0* GE_new414(T1 initialize);
/* New instance of type CONSOLE */
extern T0* GE_new415(T1 initialize);
/* New instance of type JOIN_TREE_NODE */
extern T0* GE_new416(T1 initialize);
/* New instance of type DS_LINKED_LIST [JOIN_TREE_NODE] */
extern T0* GE_new417(T1 initialize);
/* New instance of type detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME] */
extern T0* GE_new418(T1 initialize);
/* New instance of type detachable DS_LINKABLE [XPLAIN_ATTRIBUTE] */
extern T0* GE_new419(T1 initialize);
/* New instance of type detachable DS_BILINKABLE [XPLAIN_STATEMENT] */
extern T0* GE_new420(T1 initialize);
/* New instance of type DS_CELL [BOOLEAN] */
extern T0* GE_new421(T1 initialize);
/* New instance of type DS_CELL [CHARACTER_8] */
extern T0* GE_new422(T1 initialize);
/* New instance of type DS_ARRAYED_LIST [INTEGER_32] */
extern T0* GE_new423(T1 initialize);
/* New instance of type KL_DOUBLE_ROUTINES */
extern T0* GE_new424(T1 initialize);
/* New instance of type KL_PLATFORM */
extern T0* GE_new425(T1 initialize);
/* New instance of type DS_CELL [POINTER] */
extern T0* GE_new427(T1 initialize);
/* New instance of type SPECIAL [XPLAIN_ABSTRACT_OBJECT] */
extern T0* GE_new428(T6 a1, T1 initialize);
/* New instance of type detachable KL_EQUALITY_TESTER [XPLAIN_ABSTRACT_OBJECT] */
extern T0* GE_new429(T1 initialize);
/* New instance of type KL_SPECIAL_ROUTINES [XPLAIN_ABSTRACT_OBJECT] */
extern T0* GE_new430(T1 initialize);
/* New instance of type DS_HASH_TABLE_CURSOR [XPLAIN_ABSTRACT_OBJECT, STRING_8] */
extern T0* GE_new432(T1 initialize);
/* New instance of type detachable DS_LINKABLE [STRING_8] */
extern T0* GE_new434(T1 initialize);
/* New instance of type HEXADECIMAL_STRING_TO_INTEGER_CONVERTER */
extern T0* GE_new436(T1 initialize);
/* New instance of type INTEGER_OVERFLOW_CHECKER */
extern T0* GE_new437(T1 initialize);
/* New instance of type DS_HASH_SET_CURSOR [STRING_8] */
extern T0* GE_new438(T1 initialize);
/* New instance of type DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE] */
extern T0* GE_new439(T1 initialize);
/* New instance of type detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE] */
extern T0* GE_new440(T1 initialize);
/* New instance of type detachable DS_LINKABLE [JOIN_TREE_NODE] */
extern T0* GE_new441(T1 initialize);
/* New instance of type DS_LINKED_LIST_CURSOR [JOIN_TREE_NODE] */
extern T0* GE_new442(T1 initialize);
/* New instance of type DS_ARRAYED_LIST_CURSOR [INTEGER_32] */
extern T0* GE_new443(T1 initialize);
/* New instance of type XPLAIN_VIRTUAL_ATTRIBUTE */
extern T0* GE_new445(T1 initialize);
/* New instance of type XPLAIN_EXTENSION_ATTRIBUTE */
extern T0* GE_new446(T1 initialize);
/* New instance of type XPLAIN_ASSERTION_EXPRESSION */
extern T0* GE_new448(T1 initialize);
/* New instance of type UC_UTF8_ROUTINES */
extern T0* GE_new450(T1 initialize);
/* New instance of type SPECIAL [NATURAL_64] */
extern T0* GE_new452(T6 a1, T1 initialize);
/* New instance of type detachable KL_EQUALITY_TESTER [XPLAIN_TYPE] */
extern T0* GE_new453(T1 initialize);
/* New instance of type detachable DS_HASH_TABLE_CURSOR [INTEGER_32, XPLAIN_TYPE] */
extern T0* GE_new455(T1 initialize);
/* New instance of type DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME_NODE] */
extern T0* GE_new456(T1 initialize);
/* New instance of type detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME_NODE] */
extern T0* GE_new457(T1 initialize);
/* XPLAIN2SQL.make */
extern T0* T24c9(GE_context* ac);
/* XML_GENERATOR.dump_statements */
extern void T67f19(GE_context* ac, T0* C, T0* a1, T0* a2);
/* KL_TEXT_OUTPUT_FILE.close */
extern void T326f28(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.old_close */
extern void T326f30(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.default_pointer */
extern T14 T326f16(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.file_close */
extern void T326f34(GE_context* ac, T0* C, T14 a1);
/* KL_TEXT_OUTPUT_FILE.put_string */
extern void T326f27(GE_context* ac, T0* C, T0* a1);
/* KL_TEXT_OUTPUT_FILE.old_put_string */
extern void T326f32(GE_context* ac, T0* C, T0* a1);
/* KL_TEXT_OUTPUT_FILE.file_ps */
extern void T326f35(GE_context* ac, T0* C, T14 a1, T14 a2, T6 a3);
/* KL_STRING_ROUTINES.as_string */
extern T0* T108f1(GE_context* ac, T0* C, T0* a1);
/* STRING_8.string */
extern T0* T17f19(GE_context* ac, T0* C);
/* STRING_8.make_from_string */
extern T0* T17c51(GE_context* ac, T0* a1);
/* SPECIAL [CHARACTER_8].copy_data */
extern void T15f12(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3, T6 a4);
/* SPECIAL [CHARACTER_8].force */
extern void T15f17(GE_context* ac, T0* C, T2 a1, T6 a2);
/* SPECIAL [CHARACTER_8].extend */
extern void T15f18(GE_context* ac, T0* C, T2 a1);
/* SPECIAL [CHARACTER_8].move_data */
extern void T15f16(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* SPECIAL [CHARACTER_8].overlapping_move */
extern void T15f20(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* SPECIAL [CHARACTER_8].fill_with */
extern void T15f14(GE_context* ac, T0* C, T2 a1, T6 a2, T6 a3);
/* INTEGER_32.min */
extern T6 T6f14(GE_context* ac, T6* C, T6 a1);
/* INTEGER_32.is_greater_equal */
extern T1 T6f9(GE_context* ac, T6* C, T6 a1);
/* SPECIAL [CHARACTER_8].non_overlapping_move */
extern void T15f19(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* STRING_8.area_lower */
extern T6 T17f9(GE_context* ac, T0* C);
/* SPECIAL [CHARACTER_8].make_empty */
extern void T15f15(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [CHARACTER_8].make_empty */
extern T0* T15c15(GE_context* ac, T6 a1);
/* KL_ANY_ROUTINES.same_types */
extern T1 T369f1(GE_context* ac, T0* C, T0* a1, T0* a2);
/* KL_STRING_ROUTINES.any_ */
extern T0* T108f3(GE_context* ac, T0* C);
/* KL_ANY_ROUTINES.default_create */
extern T0* T369c2(GE_context* ac);
/* KL_TEXT_OUTPUT_FILE.string_ */
extern T0* T326f9(GE_context* ac, T0* C);
/* KL_STRING_ROUTINES.default_create */
extern T0* T108c8(GE_context* ac);
/* XML_WRITER.xml */
extern T0* T325f15(GE_context* ac, T0* C);
/* XML_GENERATOR.die */
extern void T67f21(GE_context* ac, T0* C, T6 a1);
/* XML_GENERATOR.std */
extern T0* T67f4(GE_context* ac, T0* C);
/* KL_STANDARD_FILES.default_create */
extern T0* T39c4(GE_context* ac);
/* KL_TEXT_OUTPUT_FILE.is_open_write */
extern T1 T326f14(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.old_is_open_write */
extern T1 T326f8(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.open_write */
extern void T326f26(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.is_closed */
extern T1 T326f13(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.old_is_closed */
extern T1 T326f11(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.old_open_write */
extern void T326f31(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.open_write */
extern void T326f31p1(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.file_open */
extern T14 T326f19(GE_context* ac, T0* C, T14 a1, T6 a2);
/* KL_TEXT_OUTPUT_FILE.internal_name_pointer */
extern T0* T326f18(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.string_name */
extern T0* T326f12(GE_context* ac, T0* C);
/* STRING_8.as_string_8 */
extern T0* T17f13(GE_context* ac, T0* C);
/* STRING_8.put_code */
extern void T17f40(GE_context* ac, T0* C, T10 a1, T6 a2);
/* STRING_8.reset_hash_codes */
extern void T17f37(GE_context* ac, T0* C);
/* STRING_8.valid_code */
extern T1 T17f24(GE_context* ac, T0* C, T10 a1);
/* NATURAL_32.is_less_equal */
extern T1 T10f2(GE_context* ac, T10* C, T10 a1);
/* INTEGER_32.to_natural_32 */
extern T10 T6f15(GE_context* ac, T6* C);
/* STRING_8.code */
extern T10 T17f10(GE_context* ac, T0* C, T6 a1);
/* STRING_8.set_count */
extern void T17f39(GE_context* ac, T0* C, T6 a1);
/* STRING_8.make */
extern void T17f33(GE_context* ac, T0* C, T6 a1);
/* STRING_8.make */
extern T0* T17c33(GE_context* ac, T6 a1);
/* SPECIAL [CHARACTER_8].make_filled */
extern T0* T15c11(GE_context* ac, T2 a1, T6 a2);
/* KL_TEXT_OUTPUT_FILE.make */
extern T0* T326c24(GE_context* ac, T0* a1);
/* KL_TEXT_OUTPUT_FILE.old_make */
extern void T326f29(GE_context* ac, T0* C, T0* a1);
/* KL_TEXT_OUTPUT_FILE.make_with_name */
extern void T326f33(GE_context* ac, T0* C, T0* a1);
/* STRING_8.make_empty */
extern T0* T17c41(GE_context* ac);
/* KL_TEXT_OUTPUT_FILE.set_name */
extern void T326f36(GE_context* ac, T0* C, T0* a1);
/* FILE_INFO.file_name_to_pointer */
extern T0* T112f11(GE_context* ac, T0* C, T0* a1, T0* a2);
/* C_STRING.set_string */
extern void T29f8(GE_context* ac, T0* C, T0* a1);
/* C_STRING.set_substring */
extern void T29f9(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* MANAGED_POINTER.put_natural_8 */
extern void T111f12(GE_context* ac, T0* C, T8 a1, T6 a2);
/* POINTER.memory_copy */
extern void T14f11(GE_context* ac, T14* C, T14 a1, T6 a2);
/* POINTER.c_memcpy */
extern void T14f15(GE_context* ac, T14* C, T14 a1, T14 a2, T6 a3);
/* NATURAL_32.to_natural_8 */
extern T8 T10f3(GE_context* ac, T10* C);
/* C_STRING.make_shared_from_pointer_and_count */
extern T0* T29c7(GE_context* ac, T14 a1, T6 a2);
/* MANAGED_POINTER.share_from_pointer */
extern T0* T111c11(GE_context* ac, T14 a1, T6 a2);
/* MANAGED_POINTER.increment_counter */
extern void T111f13(GE_context* ac, T0* C);
/* UTF_CONVERTER.escaped_utf_32_substring_into_utf_8_0_pointer */
extern void T349f9(GE_context* ac, T349* C, T0* a1, T6 a2, T6 a3, T0* a4, T6 a5, T0* a6);
/* UTF_CONVERTER.to_natural_32 */
extern T10 T349f5(GE_context* ac, T349* C, T0* a1);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.parsed_natural_32 */
extern T10 T436f12(GE_context* ac, T0* C);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.parse_string_with_type */
extern void T436f19(GE_context* ac, T0* C, T0* a1, T6 a2);
/* NATURAL_32.is_valid_character_8_code */
extern T1 T10f14(GE_context* ac, T10* C);
/* CHARACTER_32.is_character_8 */
extern T1 T3f3(GE_context* ac, T3* C);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.parse_character */
extern void T436f22(GE_context* ac, T0* C, T2 a1);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.overflowed */
extern T1 T436f16(GE_context* ac, T0* C);
/* INTEGER_OVERFLOW_CHECKER.will_overflow */
extern T1 T437f7(GE_context* ac, T0* C, T11 a1, T11 a2, T6 a3, T6 a4);
/* NATURAL_64.is_greater */
extern T1 T11f5(GE_context* ac, T11* C, T11 a1);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.overflow_checker */
extern T0* T436f15(GE_context* ac, T0* C);
/* INTEGER_OVERFLOW_CHECKER.make */
extern T0* T437c13(GE_context* ac);
/* NATURAL_64.to_natural_64 */
extern T11 T11f8(GE_context* ac, T11* C);
/* NATURAL_32.to_natural_64 */
extern T11 T10f18(GE_context* ac, T10* C);
/* NATURAL_16.to_natural_64 */
extern T11 T9f3(GE_context* ac, T9* C);
/* NATURAL_8.to_natural_64 */
extern T11 T8f7(GE_context* ac, T8* C);
/* INTEGER_64.to_natural_64 */
extern T11 T7f7(GE_context* ac, T7* C);
/* INTEGER_16.to_natural_64 */
extern T11 T5f3(GE_context* ac, T5* C);
/* INTEGER_8.to_natural_64 */
extern T11 T4f3(GE_context* ac, T4* C);
/* SPECIAL [NATURAL_64].extend */
extern void T452f5(GE_context* ac, T0* C, T11 a1);
/* SPECIAL [NATURAL_64].make_empty */
extern T0* T452c4(GE_context* ac, T6 a1);
/* STRING_8.has */
extern T1 T17f23(GE_context* ac, T0* C, T2 a1);
/* INTEGER_32.to_natural_64 */
extern T11 T6f30(GE_context* ac, T6* C);
/* CHARACTER_8.is_less_equal */
extern T1 T2f18(GE_context* ac, T2* C, T2 a1);
/* CHARACTER_8.is_less */
extern T1 T2f21(GE_context* ac, T2* C, T2 a1);
/* CHARACTER_8.natural_32_code */
extern T10 T2f22(GE_context* ac, T2* C);
/* CHARACTER_8.is_greater_equal */
extern T1 T2f20(GE_context* ac, T2* C, T2 a1);
/* CHARACTER_8.is_hexa_digit */
extern T1 T2f19(GE_context* ac, T2* C);
/* NATURAL_8.is_greater */
extern T1 T8f2(GE_context* ac, T8* C, T8 a1);
/* CHARACTER_8.character_types */
extern T8 T2f5(GE_context* ac, T2* C, T6 a1);
/* CHARACTER_8.internal_character_types */
extern T0* T2f7(GE_context* ac, T2* C);
/* SPECIAL [NATURAL_8].fill_with */
extern void T373f7(GE_context* ac, T0* C, T8 a1, T6 a2, T6 a3);
/* SPECIAL [NATURAL_8].extend */
extern void T373f6(GE_context* ac, T0* C, T8 a1);
/* SPECIAL [NATURAL_8].make_empty */
extern void T373f5(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [NATURAL_8].make_empty */
extern T0* T373c5(GE_context* ac, T6 a1);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.reset */
extern void T436f18(GE_context* ac, T0* C, T6 a1);
/* UTF_CONVERTER.ctoi_convertor */
extern T0* T349f6(GE_context* ac, T349* C);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.set_trailing_separators_acceptable */
extern void T436f21(GE_context* ac, T0* C, T1 a1);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.set_leading_separators_acceptable */
extern void T436f20(GE_context* ac, T0* C, T1 a1);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.make */
extern T0* T436c17(GE_context* ac);
/* UTF_CONVERTER.is_hexa_decimal */
extern T1 T349f4(GE_context* ac, T349* C, T0* a1);
/* HEXADECIMAL_STRING_TO_INTEGER_CONVERTER.is_integral_integer */
extern T1 T436f14(GE_context* ac, T0* C);
/* STRING_8.character_32_item */
extern T3 T17f31(GE_context* ac, T0* C, T6 a1);
/* UTF_CONVERTER.utf_8_bytes_count */
extern T6 T349f1(GE_context* ac, T349* C, T0* a1, T6 a2, T6 a3);
/* INTEGER_32.do_nothing */
extern void T6f33(GE_context* ac, T6* C);
/* FILE_INFO.multi_byte_to_utf_16 */
extern T6 T112f10(GE_context* ac, T0* C, T14 a1, T14 a2, T6 a3);
/* FILE_INFO.default_pointer */
extern T14 T112f9(GE_context* ac, T0* C);
/* C_STRING.item */
extern T14 T29f3(GE_context* ac, T0* C);
/* C_STRING.make */
extern T0* T29c6(GE_context* ac, T0* a1);
/* C_STRING.make_empty */
extern void T29f4(GE_context* ac, T0* C, T6 a1);
/* C_STRING.make_empty */
extern T0* T29c4(GE_context* ac, T6 a1);
/* UTF_CONVERTER.escaped_utf_32_substring_into_utf_16_0_pointer */
extern void T349f8(GE_context* ac, T349* C, T0* a1, T6 a2, T6 a3, T0* a4, T6 a5, T0* a6);
/* MANAGED_POINTER.put_natural_16 */
extern void T111f14(GE_context* ac, T0* C, T9 a1, T6 a2);
/* NATURAL_32.to_natural_16 */
extern T9 T10f9(GE_context* ac, T10* C);
/* NATURAL_32.is_greater */
extern T1 T10f8(GE_context* ac, T10* C, T10 a1);
/* UTF_CONVERTER.utf_16_bytes_count */
extern T6 T349f2(GE_context* ac, T349* C, T0* a1, T6 a2, T6 a3);
/* MANAGED_POINTER.resize */
extern void T111f10(GE_context* ac, T0* C, T6 a1);
/* POINTER.memory_set */
extern void T14f10(GE_context* ac, T14* C, T6 a1, T6 a2);
/* POINTER.c_memset */
extern void T14f14(GE_context* ac, T14* C, T14 a1, T6 a2, T6 a3);
/* EXCEPTIONS.raise */
extern void T405f2(GE_context* ac, T0* C, T0* a1);
/* DEVELOPER_EXCEPTION.raise */
extern void T100f16(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.raise */
extern void T20f19(GE_context* ac, T0* C, T0* a1);
/* DEVELOPER_EXCEPTION.code */
extern T6 T100f8(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.default_pointer */
extern T14 T20f9(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.set_last_exception */
extern void T20f17(GE_context* ac, T0* C, T0* a1);
/* CELL [detachable EXCEPTION].put */
extern void T25f2(GE_context* ac, T0* C, T0* a1);
/* CELL [detachable EXCEPTION].put */
extern T0* T25c2(GE_context* ac, T0* a1);
/* ISE_EXCEPTION_MANAGER.last_exception_cell */
extern T0* T20f2(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.in_rescue */
extern T1 T20f8(GE_context* ac, T0* C);
/* DEVELOPER_EXCEPTION.is_ignored */
extern T1 T100f7(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.is_ignored */
extern T1 T20f13(GE_context* ac, T0* C, T0* a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].has */
extern T1 T26f34(GE_context* ac, T0* C, T6 a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].same_keys */
extern T1 T26f26(GE_context* ac, T0* C, T6 a1, T6 a2);
/* HASH_TABLE [INTEGER_32, INTEGER_32].hash_code_of */
extern T6 T26f25(GE_context* ac, T0* C, T6 a1);
/* INTEGER_32.hash_code */
extern T6 T6f18(GE_context* ac, T6* C);
/* ISE_EXCEPTION_MANAGER.ignored_exceptions */
extern T0* T20f3(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].make */
extern T0* T26c35(GE_context* ac, T6 a1);
/* SPECIAL [INTEGER_32].make_filled */
extern T0* T105c7(GE_context* ac, T6 a1, T6 a2);
/* SPECIAL [INTEGER_32].fill_with */
extern void T105f10(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* SPECIAL [INTEGER_32].extend */
extern void T105f11(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [BOOLEAN].make_filled */
extern T0* T106c4(GE_context* ac, T1 a1, T6 a2);
/* SPECIAL [BOOLEAN].fill_with */
extern void T106f7(GE_context* ac, T0* C, T1 a1, T6 a2, T6 a3);
/* SPECIAL [BOOLEAN].extend */
extern void T106f9(GE_context* ac, T0* C, T1 a1);
/* SPECIAL [BOOLEAN].make_empty */
extern void T106f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [INTEGER_32].make_empty */
extern void T105f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [INTEGER_32].make_empty */
extern T0* T105c6(GE_context* ac, T6 a1);
/* PRIMES.higher_prime */
extern T6 T104f1(GE_context* ac, T0* C, T6 a1);
/* PRIMES.is_prime */
extern T1 T104f3(GE_context* ac, T0* C, T6 a1);
/* PRIMES.default_create */
extern T0* T104c5(GE_context* ac);
/* DEVELOPER_EXCEPTION.exception_manager */
extern T0* T100f6(GE_context* ac, T0* C);
/* DEVELOPER_EXCEPTION.default_create */
extern T0* T100c10(GE_context* ac);
/* EXCEPTIONS.default_create */
extern T0* T405c1(GE_context* ac);
/* MANAGED_POINTER.default_pointer */
extern T14 T111f4(GE_context* ac, T0* C);
/* POINTER.memory_realloc */
extern T14 T14f2(GE_context* ac, T14* C, T6 a1);
/* POINTER.c_realloc */
extern T14 T14f7(GE_context* ac, T14* C, T14 a1, T6 a2);
/* INTEGER_32.max */
extern T6 T6f6(GE_context* ac, T6* C, T6 a1);
/* MANAGED_POINTER.make */
extern T0* T111c8(GE_context* ac, T6 a1);
/* POINTER.memory_calloc */
extern T14 T14f6(GE_context* ac, T14* C, T6 a1, T6 a2);
/* POINTER.c_calloc */
extern T14 T14f5(GE_context* ac, T14* C, T6 a1, T6 a2);
/* KL_TEXT_OUTPUT_FILE.buffered_file_info */
extern T0* T326f23(GE_context* ac, T0* C);
/* FILE_INFO.make */
extern T0* T112c13(GE_context* ac);
/* FILE_INFO.make_filled_area */
extern void T112f15(GE_context* ac, T0* C, T8 a1, T6 a2);
/* SPECIAL [NATURAL_8].make_filled */
extern T0* T373c4(GE_context* ac, T8 a1, T6 a2);
/* FILE_INFO.stat_size */
extern T6 T112f7(GE_context* ac, T0* C);
/* XML_WRITER.stop_tag */
extern void T325f26(GE_context* ac, T0* C);
/* DS_LINKED_STACK [STRING_8].remove */
extern void T394f6(GE_context* ac, T0* C);
/* XML_WRITER.new_line_after_closing_tag */
extern void T325f32(GE_context* ac, T0* C, T0* a1);
/* XML_WRITER.new_line */
extern void T325f34(GE_context* ac, T0* C);
/* DS_LINKED_STACK [STRING_8].item */
extern T0* T394f3(GE_context* ac, T0* C);
/* XML_WRITER.extend */
extern void T325f31(GE_context* ac, T0* C, T0* a1);
/* STRING_8.append_string */
extern void T17f43(GE_context* ac, T0* C, T0* a1);
/* STRING_8.append */
extern void T17f34(GE_context* ac, T0* C, T0* a1);
/* STRING_8.resize */
extern void T17f36(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [CHARACTER_8].aliased_resized_area_with_default */
extern T0* T15f3(GE_context* ac, T0* C, T2 a1, T6 a2);
/* SPECIAL [CHARACTER_8].aliased_resized_area */
extern T0* T15f4(GE_context* ac, T0* C, T6 a1);
/* STRING_8.additional_space */
extern T6 T17f8(GE_context* ac, T0* C);
/* STRING_8.capacity */
extern T6 T17f7(GE_context* ac, T0* C);
/* STRING_8.is_empty */
extern T1 T17f14(GE_context* ac, T0* C);
/* XML_WRITER.indent */
extern void T325f30(GE_context* ac, T0* C);
/* STRING_8.make_filled */
extern T0* T17c44(GE_context* ac, T2 a1, T6 a2);
/* STRING_8.fill_character */
extern void T17f49(GE_context* ac, T0* C, T2 a1);
/* XML_WRITER.on_new_line */
extern T1 T325f11(GE_context* ac, T0* C);
/* XML_WRITER.assure_last_tag_written */
extern void T325f29(GE_context* ac, T0* C);
/* XML_WRITER.empty_tag_closing_chars */
extern T0* T325f12(GE_context* ac, T0* C);
/* XML_WRITER.clear_attributes */
extern void T325f33(GE_context* ac, T0* C);
/* [attached] ARRAY [[attached] STRING_8].make_filled */
extern void T35f7(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* [attached] ARRAY [[attached] STRING_8].make_filled */
extern T0* T35c7(GE_context* ac, T0* a1, T6 a2, T6 a3);
/* [attached] ARRAY [[attached] STRING_8].make_filled_area */
extern void T35f8(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [[attached] STRING_8].make_filled */
extern T0* T36c10(GE_context* ac, T0* a1, T6 a2);
/* SPECIAL [[attached] STRING_8].fill_with */
extern void T36f9(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [[attached] STRING_8].extend */
extern void T36f12(GE_context* ac, T0* C, T0* a1);
/* SPECIAL [[attached] STRING_8].make_empty */
extern void T36f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [[attached] STRING_8].make_empty */
extern T0* T36c6(GE_context* ac, T6 a1);
/* XML_WRITER.new_line_before_starting_tag */
extern void T325f35(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].forth */
extern void T327f13(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].cursor_forth */
extern void T327f17(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].add_traversing_cursor */
extern void T327f18(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_STATEMENT].set_next_cursor */
extern void T396f9(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].remove_traversing_cursor */
extern void T327f19(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_STATEMENT].set */
extern void T396f8(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].item_for_iteration */
extern T0* T327f7(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].cursor_item */
extern T0* T327f5(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].after */
extern T1 T327f8(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].cursor_after */
extern T1 T327f9(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].start */
extern void T327f12(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].cursor_start */
extern void T327f16(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].cursor_off */
extern T1 T327f10(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_STATEMENT].off */
extern T1 T396f6(GE_context* ac, T0* C);
/* XML_WRITER.start_tag */
extern void T325f25(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_STACK [STRING_8].put */
extern void T394f5(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [STRING_8].put_right */
extern void T434f4(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [STRING_8].make */
extern T0* T434c3(GE_context* ac, T0* a1);
/* XML_WRITER.add_header_iso_8859_1_encoding */
extern void T325f24(GE_context* ac, T0* C);
/* XML_WRITER.add_header */
extern void T325f28(GE_context* ac, T0* C, T0* a1);
/* XML_WRITER.make_with_capacity */
extern T0* T325c23(GE_context* ac, T6 a1);
/* XML_WRITER.clear */
extern void T325f27(GE_context* ac, T0* C);
/* DS_LINKED_STACK [STRING_8].wipe_out */
extern void T394f7(GE_context* ac, T0* C);
/* STRING_8.wipe_out */
extern void T17f42(GE_context* ac, T0* C);
/* DS_LINKED_STACK [STRING_8].make */
extern T0* T394c4(GE_context* ac);
/* XPLAIN_PARSER.syntax_error */
extern T1 T65f307(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.close */
extern void T31f42(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.old_close */
extern void T31f44(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.default_pointer */
extern T14 T31f20(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.file_close */
extern void T31f47(GE_context* ac, T0* C, T14 a1);
/* XPLAIN_PARSER.parse */
extern void T65f510(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_pop_last_value */
extern void T65f522(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.yy_push_error_value */
extern void T65f521(GE_context* ac, T0* C);
/* KL_SPECIAL_ROUTINES [detachable ANY].force */
extern void T124f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [ANY].fill_with */
extern void T38f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [ANY].extend */
extern void T38f11(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable ANY].aliased_resized_area */
extern T0* T124f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [ANY].aliased_resized_area */
extern T0* T38f3(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.yy_do_action */
extern void T65f520(GE_context* ac, T0* C, T6 a1);
extern T1 T65f520ot1(T0* a1, T0** a2);
extern T1 T65f520ot2(T0* a1, T0** a2);
/* XPLAIN_STATEMENT_NODE.make */
extern T0* T167c3(GE_context* ac, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT_NODE].force */
extern void T321f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_STATEMENT_NODE].fill_with */
extern void T317f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_STATEMENT_NODE].extend */
extern void T317f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT_NODE].aliased_resized_area */
extern T0* T321f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_STATEMENT_NODE].aliased_resized_area */
extern T0* T317f4(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_SQL_STATEMENT].force */
extern void T320f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_SQL_STATEMENT].fill_with */
extern void T169f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_SQL_STATEMENT].extend */
extern void T169f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_SQL_STATEMENT].aliased_resized_area */
extern T0* T320f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_SQL_STATEMENT].aliased_resized_area */
extern T0* T169f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_SQL_STATEMENT.make */
extern T0* T166c4(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_PROCEDURE_STATEMENT].aliased_resized_area */
extern T0* T319f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT].aliased_resized_area */
extern T0* T171f4(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_PROCEDURE_STATEMENT].force */
extern void T319f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT].fill_with */
extern void T171f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT].extend */
extern void T171f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.new_procedure_statement */
extern T0* T65f332(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3, T0* a4);
/* XPLAIN_PROCEDURE_STATEMENT.make */
extern T0* T165c4(GE_context* ac, T0* a1);
/* XPLAIN_PROCEDURE.make */
extern T0* T318c19(GE_context* ac, T0* a1, T0* a2, T6 a3, T0* a4);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].put_last */
extern void T339f14(GE_context* ac, T0* C, T0* a1);
/* detachable DS_BILINKABLE [XPLAIN_STATEMENT].put_right */
extern void T420f5(GE_context* ac, T0* C, T0* a1);
/* detachable DS_BILINKABLE [XPLAIN_STATEMENT].attach_left */
extern void T420f6(GE_context* ac, T0* C, T0* a1);
/* detachable DS_BILINKABLE [XPLAIN_STATEMENT].make */
extern T0* T420c4(GE_context* ac, T0* a1);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].make */
extern T0* T339c11(GE_context* ac);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].set_internal_cursor */
extern void T339f15(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].new_cursor */
extern T0* T339f8(GE_context* ac, T0* C);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].make */
extern T0* T393c8(GE_context* ac, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].put_last */
extern void T335f14(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME].put_right */
extern void T418f4(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME].make */
extern T0* T418c3(GE_context* ac, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].make */
extern T0* T335c11(GE_context* ac);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].set_internal_cursor */
extern void T335f15(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].new_cursor */
extern T0* T335f5(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME].make */
extern T0* T336c8(GE_context* ac, T0* a1);
/* XPLAIN_PROCEDURE.abstract_make */
extern void T318f23(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXPRESSION_NODE.make */
extern T0* T164c6(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_EXPRESSION_NODE.make_node */
extern void T164f7(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXPRESSION_NODE.give_column_names */
extern void T164f8(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXPRESSION_NODE].force */
extern void T316f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_EXPRESSION_NODE].fill_with */
extern void T221f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_EXPRESSION_NODE].extend */
extern void T221f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXPRESSION_NODE].aliased_resized_area */
extern T0* T316f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_EXPRESSION_NODE].aliased_resized_area */
extern T0* T221f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_SOME_FUNCTION.default_create */
extern T0* T315c13(GE_context* ac);
/* XPLAIN_NIL_FUNCTION.default_create */
extern T0* T314c13(GE_context* ac);
/* XPLAIN_ANY_FUNCTION.default_create */
extern T0* T313c13(GE_context* ac);
/* XPLAIN_COUNT_FUNCTION.default_create */
extern T0* T312c13(GE_context* ac);
/* XPLAIN_TOTAL_FUNCTION.default_create */
extern T0* T311c13(GE_context* ac);
/* XPLAIN_MIN_FUNCTION.default_create */
extern T0* T310c13(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_FUNCTION].force */
extern void T309f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_FUNCTION].fill_with */
extern void T290f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_FUNCTION].extend */
extern void T290f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_FUNCTION].aliased_resized_area */
extern T0* T309f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_FUNCTION].aliased_resized_area */
extern T0* T290f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_MAX_FUNCTION.default_create */
extern T0* T308c13(GE_context* ac);
/* XPLAIN_SORT_NODE.make */
extern T0* T162c4(GE_context* ac, T0* a1, T1 a2, T0* a3);
/* XPLAIN_ATTRIBUTE_NAME.abstracttype */
extern T0* T138f6(GE_context* ac, T0* C);
extern T1 T138f6ot1(T0* a1, T0** a2);
/* XPLAIN_SORT_NODE.make_node */
extern void T162f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SORT_NODE].force */
extern void T307f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SORT_NODE].fill_with */
extern void T305f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SORT_NODE].extend */
extern void T305f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SORT_NODE].aliased_resized_area */
extern T0* T307f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_SORT_NODE].aliased_resized_area */
extern T0* T305f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_SELECTION_LIST.set_identification_text */
extern void T161f11(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_LIST].force */
extern void T306f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SELECTION_LIST].fill_with */
extern void T268f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SELECTION_LIST].extend */
extern void T268f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_LIST].aliased_resized_area */
extern T0* T306f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_SELECTION_LIST].aliased_resized_area */
extern T0* T268f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_SELECTION_LIST.make */
extern T0* T161c10(GE_context* ac, T0* a1, T0* a2, T0* a3, T0* a4);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION].force */
extern void T304f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SELECTION].fill_with */
extern void T292f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SELECTION].extend */
extern void T292f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION].aliased_resized_area */
extern T0* T304f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_SELECTION].aliased_resized_area */
extern T0* T292f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.make */
extern T0* T303c20(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_ATTRIBUTE_NAME_NODE.last */
extern T0* T137f5(GE_context* ac, T0* C);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION_EXPRESSION].force */
extern void T302f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION].fill_with */
extern void T258f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION].extend */
extern void T258f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION_EXPRESSION].aliased_resized_area */
extern T0* T302f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION].aliased_resized_area */
extern T0* T258f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.make */
extern T0* T301c14(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_EXTEND_ATTRIBUTE].force */
extern void T300f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_EXTEND_ATTRIBUTE].fill_with */
extern void T298f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_EXTEND_ATTRIBUTE].extend */
extern void T298f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_EXTEND_ATTRIBUTE].aliased_resized_area */
extern T0* T300f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_EXTEND_ATTRIBUTE].aliased_resized_area */
extern T0* T298f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_EXTEND_ATTRIBUTE.make */
extern T0* T158c3(GE_context* ac, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION].aliased_resized_area */
extern T0* T299f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_EXTENSION].aliased_resized_area */
extern T0* T295f4(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION].force */
extern void T299f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_EXTENSION].fill_with */
extern void T295f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_EXTENSION].extend */
extern void T295f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.make */
extern T0* T157c40(GE_context* ac, T0* a1, T0* a2, T0* a3, T0* a4);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.set_extension */
extern void T303f21(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_SELECTION_FUNCTION.set_predicate */
extern void T154f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_NAME_NODE.set_prefix_table */
extern void T137f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.make */
extern T0* T389c27(GE_context* ac, T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.supports_left_outer_join */
extern T1 T303f11(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.set_extension */
extern void T303f21p1(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.set_extension */
extern void T301f15(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.make_abstract_type */
extern void T157f41(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.representation */
extern T0* T301f4(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].make */
extern T0* T337c16(GE_context* ac);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].set_internal_cursor */
extern void T337f20(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].new_cursor */
extern T0* T337f6(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].make */
extern T0* T338c10(GE_context* ac, T0* a1);
/* XPLAIN_UNIVERSE.has */
extern T1 T175f3(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].has */
extern T1 T391f29(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].search_position */
extern void T391f40(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].hash_position */
extern T6 T391f27(GE_context* ac, T0* C, T0* a1);
/* STRING_8.hash_code */
extern T6 T17f30(GE_context* ac, T0* C);
/* detachable KL_EQUALITY_TESTER [STRING_8].test */
extern T1 T378f1(GE_context* ac, T0* C, T0* a1, T0* a2);
/* STRING_8.is_equal */
extern T1 T17f18(GE_context* ac, T0* C, T0* a1);
/* SPECIAL [CHARACTER_8].same_items */
extern T1 T15f6(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3, T6 a4);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].key_storage_item */
extern T0* T391f24(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].clashes_item */
extern T6 T391f34(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].slots_item */
extern T6 T391f35(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTEND_STATEMENT].force */
extern void T297f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_EXTEND_STATEMENT].fill_with */
extern void T296f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_EXTEND_STATEMENT].extend */
extern void T296f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTEND_STATEMENT].aliased_resized_area */
extern T0* T297f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_EXTEND_STATEMENT].aliased_resized_area */
extern T0* T296f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_EXTEND_STATEMENT.make */
extern T0* T156c4(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_GET_STATEMENT].force */
extern void T294f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_GET_STATEMENT].fill_with */
extern void T293f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_GET_STATEMENT].extend */
extern void T293f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_GET_STATEMENT].aliased_resized_area */
extern T0* T294f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_GET_STATEMENT].aliased_resized_area */
extern T0* T293f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_GET_STATEMENT.make */
extern T0* T155c4(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_FUNCTION].force */
extern void T291f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SELECTION_FUNCTION].fill_with */
extern void T276f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SELECTION_FUNCTION].extend */
extern void T276f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_FUNCTION].aliased_resized_area */
extern T0* T291f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_SELECTION_FUNCTION].aliased_resized_area */
extern T0* T276f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_SELECTION_FUNCTION.make */
extern T0* T154c10(GE_context* ac, T0* a1, T0* a2, T0* a3, T0* a4);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].force */
extern void T289f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].fill_with */
extern void T288f7(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].extend */
extern void T288f9(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].aliased_resized_area */
extern T0* T289f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].aliased_resized_area */
extern T0* T288f3(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_VALUE_SELECTION_STATEMENT].force */
extern void T287f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT].fill_with */
extern void T286f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT].extend */
extern void T286f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_VALUE_SELECTION_STATEMENT].aliased_resized_area */
extern T0* T287f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT].aliased_resized_area */
extern T0* T286f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_VALUE_SELECTION_STATEMENT.make */
extern T0* T152c4(GE_context* ac, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.make */
extern T0* T285c26(GE_context* ac, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.make */
extern T0* T283c26(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE_STATEMENT].force */
extern void T282f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_VALUE_STATEMENT].fill_with */
extern void T281f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_VALUE_STATEMENT].extend */
extern void T281f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE_STATEMENT].aliased_resized_area */
extern T0* T282f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_VALUE_STATEMENT].aliased_resized_area */
extern T0* T281f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.new_value_statement */
extern T0* T65f288(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_VALUE_STATEMENT.make */
extern T0* T151c5(GE_context* ac, T0* a1);
/* XPLAIN_VALUE.make */
extern T0* T256c8(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_VALUE.inherited_make */
extern void T256f9(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ATTRIBUTE_NAME.set_attribute */
extern void T138f18(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_UPDATE_STATEMENT].force */
extern void T280f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_UPDATE_STATEMENT].fill_with */
extern void T262f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_UPDATE_STATEMENT].extend */
extern void T262f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_UPDATE_STATEMENT].aliased_resized_area */
extern T0* T280f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_UPDATE_STATEMENT].aliased_resized_area */
extern T0* T262f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_UPDATE_STATEMENT.make */
extern T0* T150c6(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_PARSER.get_known_value */
extern T0* T65f285(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SUBJECT].force */
extern void T279f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SUBJECT].fill_with */
extern void T265f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_SUBJECT].extend */
extern void T265f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SUBJECT].aliased_resized_area */
extern T0* T279f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_SUBJECT].aliased_resized_area */
extern T0* T265f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_SUBJECT.make */
extern T0* T149c3(GE_context* ac, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_DELETE_STATEMENT].force */
extern void T278f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_DELETE_STATEMENT].fill_with */
extern void T263f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_DELETE_STATEMENT].extend */
extern void T263f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_DELETE_STATEMENT].aliased_resized_area */
extern T0* T278f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_DELETE_STATEMENT].aliased_resized_area */
extern T0* T263f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_DELETE_STATEMENT.make */
extern T0* T148c5(GE_context* ac, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].force */
extern void T277f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].fill_with */
extern void T274f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].extend */
extern void T274f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].aliased_resized_area */
extern T0* T277f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].aliased_resized_area */
extern T0* T274f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_CASCADE_FUNCTION_EXPRESSION.make */
extern T0* T147c4(GE_context* ac, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_STATEMENT].aliased_resized_area */
extern T0* T275f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_CASCADE_STATEMENT].aliased_resized_area */
extern T0* T264f4(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_STATEMENT].force */
extern void T275f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_CASCADE_STATEMENT].fill_with */
extern void T264f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_CASCADE_STATEMENT].extend */
extern void T264f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CASCADE_STATEMENT.make */
extern T0* T146c14(GE_context* ac, T0* a1, T0* a2, T0* a3, T0* a4);
/* XPLAIN_ATTRIBUTE_NAME.make_from_attribute */
extern T0* T138c19(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ASSIGNMENT].force */
extern void T273f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_ASSIGNMENT].fill_with */
extern void T271f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_ASSIGNMENT].extend */
extern void T271f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ASSIGNMENT].aliased_resized_area */
extern T0* T273f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_ASSIGNMENT].aliased_resized_area */
extern T0* T271f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_ASSIGNMENT.make */
extern T0* T145c3(GE_context* ac, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSIGNMENT_NODE].force */
extern void T272f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE].fill_with */
extern void T266f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE].extend */
extern void T266f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSIGNMENT_NODE].aliased_resized_area */
extern T0* T272f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE].aliased_resized_area */
extern T0* T266f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_ASSIGNMENT_NODE.make */
extern T0* T144c3(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_GET_INSERT_STATEMENT.make */
extern T0* T269c7(GE_context* ac, T0* a1, T0* a2, T1 a3, T0* a4);
/* XPLAIN_INSERT_STATEMENT.make */
extern T0* T267c6(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_PARSER.warn_attributes_with_inits */
extern void T65f538(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INDEX.make */
extern T0* T261c6(GE_context* ac, T0* a1, T0* a2, T1 a3, T1 a4, T0* a5);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSERTION].aliased_resized_area */
extern T0* T259f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_ASSERTION].aliased_resized_area */
extern T0* T260f3(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSERTION].force */
extern void T259f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_ASSERTION].fill_with */
extern void T260f7(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_ASSERTION].extend */
extern void T260f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.is_complex */
extern T1 T143f31(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.uses_non_data_attributes */
extern T1 T303f6(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.uses_non_data_attributes */
extern T1 T301f3(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.is_function */
extern T1 T143f13(GE_context* ac, T0* C);
extern T1 T143f13ot1(T0* a1);
/* XPLAIN_ASSERTION.make */
extern T0* T143c43(GE_context* ac, T0* a1, T0* a2, T0* a3, T0* a4, T0* a5);
/* XPLAIN_ASSERTION.make_abstract_type */
extern void T143f44(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_VALUE_EXPRESSION.make */
extern T0* T257c26(GE_context* ac, T0* a1);
/* XPLAIN_UNIVERSE.find_value */
extern T0* T175f2(GE_context* ac, T0* C, T0* a1);
extern T1 T175f2ot1(T0* a1, T0** a2);
/* XPLAIN_UNIVERSE.find_object */
extern T0* T175f5(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].found_item */
extern T0* T391f28(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].item_storage_item */
extern T0* T391f22(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].found */
extern T1 T391f21(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].search */
extern void T391f37(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.make */
extern T0* T255c26(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.silence_compiler_logical_expression */
extern T0* T65f309(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_NAME.set_object */
extern void T138f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.get_known_base_or_type */
extern T0* T65f308(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNIVERSE.find_base_or_type */
extern T0* T175f4(GE_context* ac, T0* C, T0* a1);
extern T1 T175f4ot1(T0* a1, T0** a2);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE].force */
extern void T254f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_ATTRIBUTE].fill_with */
extern void T251f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_ATTRIBUTE].extend */
extern void T251f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE].aliased_resized_area */
extern T0* T254f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_ATTRIBUTE].aliased_resized_area */
extern T0* T251f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_ATTRIBUTE.make */
extern T0* T142c18(GE_context* ac, T0* a1, T0* a2, T1 a3, T1 a4, T1 a5, T1 a6);
/* XPLAIN_ATTRIBUTE_NAME.abstracttype_if_known */
extern T0* T138f7(GE_context* ac, T0* C);
extern T1 T138f7ot1(T0* a1, T0** a2);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ATTRIBUTE_NODE].force */
extern void T252f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE].fill_with */
extern void T185f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE].extend */
extern void T185f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ATTRIBUTE_NODE].aliased_resized_area */
extern T0* T252f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE].aliased_resized_area */
extern T0* T185f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_ATTRIBUTE_NODE.make */
extern T0* T141c3(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_I_REFERENCES.make */
extern T0* T250c4(GE_context* ac);
/* XPLAIN_I_REFERENCES.make_xplain_domain_restriction */
extern void T250f7(GE_context* ac, T0* C, T1 a1);
/* XPLAIN_PK_I_REPRESENTATION.make */
extern T0* T249c14(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_PK_REPRESENTATION].force */
extern void T248f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_PK_REPRESENTATION].fill_with */
extern void T186f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_PK_REPRESENTATION].extend */
extern void T186f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_PK_REPRESENTATION].aliased_resized_area */
extern T0* T248f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_PK_REPRESENTATION].aliased_resized_area */
extern T0* T186f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PK_I_REPRESENTATION.set_domain_restriction */
extern void T249f15(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_I_REFERENCES.check_attachment */
extern void T250f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_A_REFERENCES.check_attachment */
extern void T247f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_PK_A_REPRESENTATION.set_domain_restriction */
extern void T246f16(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_A_REFERENCES.make */
extern T0* T247c4(GE_context* ac);
/* XPLAIN_A_REFERENCES.make_xplain_domain_restriction */
extern void T247f6(GE_context* ac, T0* C, T1 a1);
/* XPLAIN_PK_A_REPRESENTATION.make */
extern T0* T246c15(GE_context* ac, T6 a1);
/* XPLAIN_T_REPRESENTATION.default_create */
extern T0* T245c11(GE_context* ac);
/* XPLAIN_R_REPRESENTATION.make */
extern T0* T244c12(GE_context* ac, T6 a1, T6 a2);
/* XPLAIN_P_REPRESENTATION.default_create */
extern T0* T243c11(GE_context* ac);
/* XPLAIN_M_REPRESENTATION.default_create */
extern T0* T242c10(GE_context* ac);
/* XPLAIN_I_REPRESENTATION.make */
extern T0* T241c11(GE_context* ac, T6 a1);
/* XPLAIN_D_REPRESENTATION.default_create */
extern T0* T240c10(GE_context* ac);
/* XPLAIN_C_REPRESENTATION.make */
extern T0* T239c12(GE_context* ac, T6 a1);
/* XPLAIN_B_REPRESENTATION.default_create */
extern T0* T238c11(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_REPRESENTATION].force */
extern void T237f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_REPRESENTATION].fill_with */
extern void T182f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_REPRESENTATION].extend */
extern void T182f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_REPRESENTATION].aliased_resized_area */
extern T0* T237f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_REPRESENTATION].aliased_resized_area */
extern T0* T182f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_A_REPRESENTATION.make */
extern T0* T236c12(GE_context* ac, T6 a1);
/* XPLAIN_PARSER.format */
extern T0* T65f292(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_SCIENTIFIC_FORMATTER.format */
extern T0* T103f23(GE_context* ac, T0* C, T0* a1, T0* a2);
/* KL_STRING_OUTPUT_STREAM.set_string */
extern void T354f4(GE_context* ac, T0* C, T0* a1);
/* ST_SCIENTIFIC_FORMATTER.do_format_to */
extern void T103f31(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T103f31ot1(T0* a1, T0** a2);
extern T1 T103f31ot2(T0* a1, T0** a2);
/* KL_STRING_OUTPUT_STREAM.put_string */
extern void T354f7(GE_context* ac, T0* C, T0* a1);
/* KL_STRING_OUTPUT_STREAM.string_ */
extern T0* T354f2(GE_context* ac, T0* C);
/* KL_NULL_TEXT_OUTPUT_STREAM.put_string */
extern void T352f5(GE_context* ac, T0* C, T0* a1);
/* CHARACTER_8.out */
extern T0* T2f3(GE_context* ac, T2* C);
/* STRING_8.append_character */
extern void T17f46(GE_context* ac, T0* C, T2 a1);
/* ST_SCIENTIFIC_FORMATTER.internal_parameter_formatter */
extern T0* T103f17(GE_context* ac, T0* C, T2 a1);
/* KL_STRING_OUTPUT_STREAM.put_character */
extern void T354f6(GE_context* ac, T0* C, T2 a1);
/* KL_NULL_TEXT_OUTPUT_STREAM.put_character */
extern void T352f4(GE_context* ac, T0* C, T2 a1);
/* ST_SCIENTIFIC_FORMATTER.set_error */
extern void T103f34(GE_context* ac, T0* C, T0* a1);
/* ST_SCIENTIFIC_FORMATTER.has_error */
extern T1 T103f19(GE_context* ac, T0* C);
/* KL_STRING_OUTPUT_STREAM.put_substring */
extern void T354f5(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* KL_NULL_TEXT_OUTPUT_STREAM.put_substring */
extern void T352f3(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* ST_SCIENTIFIC_FORMATTER.reset_error */
extern void T103f33(GE_context* ac, T0* C);
/* KL_STRING_ROUTINES.new_empty_string */
extern T0* T108f2(GE_context* ac, T0* C, T0* a1, T6 a2);
/* KL_STRING_ROUTINES.cloned_string */
extern T0* T108f5(GE_context* ac, T0* C, T0* a1);
/* STRING_8.twin */
extern T0* T17f20(GE_context* ac, T0* C);
/* STRING_8.copy */
extern void T17f53(GE_context* ac, T0* C, T0* a1);
/* SPECIAL [CHARACTER_8].resized_area */
extern T0* T15f7(GE_context* ac, T0* C, T6 a1);
/* ST_SCIENTIFIC_FORMATTER.string_ */
extern T0* T103f20(GE_context* ac, T0* C);
/* XPLAIN_PARSER.formatter */
extern T0* T65f497(GE_context* ac, T0* C);
/* XPLAIN_PARSER.scientific_formatter */
extern T0* T65f505(GE_context* ac, T0* C);
/* ST_SCIENTIFIC_FORMATTER.make */
extern T0* T103c30(GE_context* ac);
/* ST_SCIENTIFIC_FORMATTER.make_with_escape */
extern void T103f32(GE_context* ac, T0* C, T2 a1);
/* ST_STRING_FORMATTER.make */
extern T0* T368c12(GE_context* ac);
/* ST_POINTER_FORMATTER.make */
extern T0* T367c12(GE_context* ac);
/* ST_UNSIGNED_DECIMAL_FORMATTER.make */
extern T0* T366c19(GE_context* ac);
/* ST_UNSIGNED_DECIMAL_FORMATTER.make */
extern void T366f19p1(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.make */
extern T0* T365c19(GE_context* ac);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.make */
extern void T365f19p1(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.make */
extern T0* T364c19(GE_context* ac);
/* ST_UNSIGNED_OCTAL_FORMATTER.make */
extern void T364f19p1(GE_context* ac, T0* C);
/* ST_DECIMAL_FORMATTER.make */
extern T0* T363c19(GE_context* ac);
/* ST_DECIMAL_FORMATTER.make */
extern void T363f19p1(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.make */
extern T0* T362c25(GE_context* ac);
/* DS_ARRAYED_LIST [INTEGER_32].make */
extern T0* T423c10(GE_context* ac, T6 a1);
/* DS_ARRAYED_LIST [INTEGER_32].set_internal_cursor */
extern void T423f14(GE_context* ac, T0* C, T0* a1);
/* DS_ARRAYED_LIST [INTEGER_32].new_cursor */
extern T0* T423f6(GE_context* ac, T0* C);
/* DS_ARRAYED_LIST_CURSOR [INTEGER_32].make */
extern T0* T443c5(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [INTEGER_32].make */
extern T0* T117f2(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [INTEGER_32].default_create */
extern T0* T117c5(GE_context* ac);
/* KL_STRING_OUTPUT_STREAM.make */
extern T0* T354c3(GE_context* ac, T0* a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.make */
extern void T362f25p1(GE_context* ac, T0* C);
/* ST_FIXED_POINT_FORMATTER.make */
extern T0* T361c24(GE_context* ac);
/* ST_FIXED_POINT_FORMATTER.make */
extern void T361f24p1(GE_context* ac, T0* C);
/* ST_FLOATING_POINT_FORMATTER.make */
extern T0* T360c25(GE_context* ac);
/* ST_FLOATING_POINT_FORMATTER.make */
extern void T360f25p1(GE_context* ac, T0* C);
/* ST_CHARACTER_FORMATTER.make */
extern T0* T359c13(GE_context* ac);
/* ST_BOOLEAN_FORMATTER.make */
extern T0* T358c16(GE_context* ac);
/* ST_SCIENTIFIC_FORMATTER.make_with_escape */
extern void T103f32p1(GE_context* ac, T0* C, T2 a1);
/* ARRAY [ANY].make_filled */
extern T0* T37c5(GE_context* ac, T0* a1, T6 a2, T6 a3);
/* ARRAY [ANY].make_filled_area */
extern void T37f6(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [ANY].make_filled */
extern T0* T38c9(GE_context* ac, T0* a1, T6 a2);
/* SPECIAL [ANY].make_empty */
extern void T38f5(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [ANY].make_empty */
extern T0* T38c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME].force */
extern void T235f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME].fill_with */
extern void T190f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME].extend */
extern void T190f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME].aliased_resized_area */
extern T0* T235f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME].aliased_resized_area */
extern T0* T190f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_ATTRIBUTE_NAME.make */
extern T0* T138c16(GE_context* ac, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME_NODE].force */
extern void T234f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE].fill_with */
extern void T205f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE].extend */
extern void T205f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME_NODE].aliased_resized_area */
extern T0* T234f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE].aliased_resized_area */
extern T0* T205f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_ATTRIBUTE_NAME_NODE.make */
extern T0* T137c6(GE_context* ac, T0* a1, T0* a2);
/* INTEGER_32.out */
extern T0* T6f11(GE_context* ac, T6* C);
/* STRING_8.append_integer */
extern void T17f48(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_SQL_EXPRESSION.make */
extern T0* T233c26(GE_context* ac, T0* a1);
/* XPLAIN_USER_FUNCTION.make */
extern T0* T232c27(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.make */
extern T0* T231c26(GE_context* ac, T0* a1);
/* XPLAIN_ATTRIBUTE_NAME.full_name */
extern T0* T138f5(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.make */
extern T0* T230c26(GE_context* ac, T0* a1);
/* XPLAIN_STRING_EXPRESSION.make */
extern T0* T227c26(GE_context* ac, T0* a1);
/* XPLAIN_ID_FUNCTION.make */
extern T0* T229c26(GE_context* ac, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.make */
extern T0* T228c28(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_PARSER.newdate_default_days */
extern T0* T65f286(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.make */
extern T0* T226c26(GE_context* ac, T0* a1);
/* XPLAIN_REAL_FUNCTION.make */
extern T0* T225c26(GE_context* ac, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.make */
extern T0* T224c26(GE_context* ac, T0* a1);
/* XPLAIN_DATEF_FUNCTION.make */
extern T0* T223c26(GE_context* ac, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.make */
extern T0* T222c26(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.silence_compiler_expression */
extern T0* T65f481(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.make */
extern T0* T220c27(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_PREFIX_EXPRESSION.make_one_operand */
extern void T220f29(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.make */
extern T0* T219c28(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_INFIX_EXPRESSION.make */
extern T0* T211c28(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_INFIX_EXPRESSION.make_two_operands */
extern void T211f30(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LOGINNAME_EXPRESSION.default_create */
extern T0* T218c25(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_SYSTEM_EXPRESSION].force */
extern void T217f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_SYSTEM_EXPRESSION].fill_with */
extern void T216f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_SYSTEM_EXPRESSION].extend */
extern void T216f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_SYSTEM_EXPRESSION].aliased_resized_area */
extern T0* T217f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_SYSTEM_EXPRESSION].aliased_resized_area */
extern T0* T216f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.default_create */
extern T0* T215c25(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_VALUE_EXPRESSION].force */
extern void T214f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION].fill_with */
extern void T213f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION].extend */
extern void T213f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_VALUE_EXPRESSION].aliased_resized_area */
extern T0* T214f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION].aliased_resized_area */
extern T0* T213f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.make */
extern T0* T212c26(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.new_logical_infix_expression */
extern T0* T65f336(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_NOT_LIKE_EXPRESSION.make */
extern T0* T346c29(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_NOT_LIKE_EXPRESSION.make_infix */
extern void T346f31(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_NOT_LIKE_EXPRESSION.make_two_operands */
extern void T346f32(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_NOT_LIKE_EXPRESSION.xplain_operator */
extern T0* T346f22(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.make */
extern T0* T345c29(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_LIKE_EXPRESSION.make_infix */
extern void T345f31(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_LIKE_EXPRESSION.make_two_operands */
extern void T345f32(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LIKE_EXPRESSION.xplain_operator */
extern T0* T345f21(GE_context* ac, T0* C);
/* STRING_8.same_string */
extern T1 T17f22(GE_context* ac, T0* C, T0* a1);
/* STRING_8.same_characters */
extern T1 T17f27(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3, T6 a4);
/* XPLAIN_NE_NULL_EXPRESSION.make */
extern T0* T210c27(GE_context* ac, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.make */
extern T0* T209c27(GE_context* ac, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.make */
extern T0* T208c26(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.is_parameter_declared */
extern T1 T65f335(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_NAME_NODE.has */
extern T1 T137f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_NAME.is_equal */
extern T1 T138f12(GE_context* ac, T0* C, T0* a1);
/* KL_STRING_ROUTINES.same_string */
extern T1 T108f6(GE_context* ac, T0* C, T0* a1, T0* a2);
/* STRING_8.item_code */
extern T6 T17f29(GE_context* ac, T0* C, T6 a1);
/* KL_STRING_ROUTINES.elks_same_string */
extern T1 T108f7(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ATTRIBUTE_NAME.string_ */
extern T0* T138f13(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.make */
extern T0* T207c28(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_EXPRESSION].aliased_resized_area */
extern T0* T204f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_EXPRESSION].aliased_resized_area */
extern T0* T180f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_NOTNOT_EXPRESSION.make */
extern T0* T206c26(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.get_object_if_valid_tree */
extern T0* T65f331(GE_context* ac, T0* C, T0* a1);
extern T1 T65f331ot1(T0* a1, T0** a2);
extern T1 T65f331ot2(T0* a1, T0** a2);
extern T1 T65f331ot3(T0* a1, T0** a2);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.make */
extern T0* T135c26(GE_context* ac, T1 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_EXPRESSION].force */
extern void T204f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_EXPRESSION].fill_with */
extern void T180f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_EXPRESSION].extend */
extern void T180f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.make */
extern T0* T203c29(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.make_two_operands */
extern void T203f30(GE_context* ac, T0* C, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_EXPRESSION].aliased_resized_area */
extern T0* T202f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_LOGICAL_EXPRESSION].aliased_resized_area */
extern T0* T201f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_LOGICAL_EXPRESSION.make */
extern T0* T133c26(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_EXPRESSION].force */
extern void T202f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_LOGICAL_EXPRESSION].fill_with */
extern void T201f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_LOGICAL_EXPRESSION].extend */
extern void T201f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.new_logical_expression */
extern T0* T65f326(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* KL_SPECIAL_ROUTINES [STRING_8].aliased_resized_area */
extern T0* T125f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [[attached] STRING_8].aliased_resized_area */
extern T0* T36f4(GE_context* ac, T0* C, T6 a1);
/* STRING_8.insert_character */
extern void T17f45(GE_context* ac, T0* C, T2 a1, T6 a2);
/* XPLAIN_TRAJECTORY.make */
extern T0* T200c7(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_TRAJECTORY.make_xplain_domain_restriction */
extern void T200f8(GE_context* ac, T0* C, T1 a1);
/* STRING_8.to_integer */
extern T6 T17f17(GE_context* ac, T0* C);
/* STRING_TO_INTEGER_CONVERTOR.parsed_integer */
extern T6 T398f13(GE_context* ac, T0* C);
/* STRING_TO_INTEGER_CONVERTOR.parse_string_with_type */
extern void T398f17(GE_context* ac, T0* C, T0* a1, T6 a2);
/* STRING_TO_INTEGER_CONVERTOR.parse_character */
extern void T398f23(GE_context* ac, T0* C, T2 a1);
/* STRING_TO_INTEGER_CONVERTOR.overflowed */
extern T1 T398f15(GE_context* ac, T0* C);
/* STRING_TO_INTEGER_CONVERTOR.overflow_checker */
extern T0* T398f14(GE_context* ac, T0* C);
/* CHARACTER_8.is_digit */
extern T1 T2f17(GE_context* ac, T2* C);
/* STRING_TO_INTEGER_CONVERTOR.reset */
extern void T398f22(GE_context* ac, T0* C, T6 a1);
/* STRING_8.ctoi_convertor */
extern T0* T17f25(GE_context* ac, T0* C);
/* STRING_TO_INTEGER_CONVERTOR.set_trailing_separators_acceptable */
extern void T398f21(GE_context* ac, T0* C, T1 a1);
/* STRING_TO_INTEGER_CONVERTOR.set_leading_separators_acceptable */
extern void T398f20(GE_context* ac, T0* C, T1 a1);
/* STRING_TO_INTEGER_CONVERTOR.set_trailing_separators */
extern void T398f19(GE_context* ac, T0* C, T0* a1);
/* STRING_TO_INTEGER_CONVERTOR.set_leading_separators */
extern void T398f18(GE_context* ac, T0* C, T0* a1);
/* STRING_TO_INTEGER_CONVERTOR.make */
extern T0* T398c16(GE_context* ac);
/* STRING_8.is_integer */
extern T1 T17f21(GE_context* ac, T0* C);
/* STRING_8.is_valid_integer_or_natural */
extern T1 T17f26(GE_context* ac, T0* C, T6 a1);
/* STRING_TO_INTEGER_CONVERTOR.is_integral_integer */
extern T1 T398f12(GE_context* ac, T0* C);
/* KL_SPECIAL_ROUTINES [XPLAIN_I_NODE].force */
extern void T199f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_I_NODE].fill_with */
extern void T195f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_I_NODE].extend */
extern void T195f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_I_NODE].aliased_resized_area */
extern T0* T199f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_I_NODE].aliased_resized_area */
extern T0* T195f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_I_NODE.make */
extern T0* T132c4(GE_context* ac, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [XPLAIN_A_NODE].force */
extern void T197f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_A_NODE].fill_with */
extern void T193f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_A_NODE].extend */
extern void T193f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_A_NODE].aliased_resized_area */
extern T0* T197f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_A_NODE].aliased_resized_area */
extern T0* T193f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_A_NODE.make */
extern T0* T131c5(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_I_ENUMERATION.make */
extern T0* T196c12(GE_context* ac, T0* a1);
/* XPLAIN_I_ENUMERATION.make_xplain_domain_restriction */
extern void T196f13(GE_context* ac, T0* C, T1 a1);
/* XPLAIN_A_ENUMERATION.make */
extern T0* T194c6(GE_context* ac, T0* a1);
/* XPLAIN_A_ENUMERATION.make_xplain_domain_restriction */
extern void T194f7(GE_context* ac, T0* C, T1 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_DOMAIN_RESTRICTION].aliased_resized_area */
extern T0* T191f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_DOMAIN_RESTRICTION].aliased_resized_area */
extern T0* T184f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_A_PATTERN.make */
extern T0* T192c5(GE_context* ac, T0* a1);
/* XPLAIN_A_PATTERN.make_xplain_domain_restriction */
extern void T192f6(GE_context* ac, T0* C, T1 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_DOMAIN_RESTRICTION].force */
extern void T191f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_DOMAIN_RESTRICTION].fill_with */
extern void T184f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_DOMAIN_RESTRICTION].extend */
extern void T184f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.report_warning */
extern void T65f537(GE_context* ac, T0* C, T0* a1);
/* KL_STDERR_FILE.put_integer */
extern void T40f9(GE_context* ac, T0* C, T6 a1);
/* KL_STDERR_FILE.put_integer_64 */
extern void T40f11(GE_context* ac, T0* C, T7 a1);
/* INTEGER_32.to_integer_64 */
extern T7 T6f21(GE_context* ac, T6* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].last */
extern T0* T120f5(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].is_empty */
extern T1 T120f7(GE_context* ac, T0* C);
/* XPLAIN_PARSER.std */
extern T0* T65f343(GE_context* ac, T0* C);
/* XPLAIN_PARSER.get_known_type */
extern T0* T65f315(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNIVERSE.find_base */
extern T0* T175f7(GE_context* ac, T0* C, T0* a1);
extern T1 T175f7ot1(T0* a1, T0** a2);
/* XPLAIN_UNIVERSE.find_type */
extern T0* T175f6(GE_context* ac, T0* C, T0* a1);
extern T1 T175f6ot1(T0* a1, T0** a2);
/* XPLAIN_PARSER.error_unknown_attribute */
extern void T65f536(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_UNIVERSE.delete */
extern void T175f12(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].remove_found_item */
extern void T391f39(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].unset_found_item */
extern void T391f42(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].remove_position */
extern void T391f48(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].key_storage_put */
extern void T391f47(GE_context* ac, T0* C, T0* a1, T6 a2);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].item_storage_put */
extern void T391f43(GE_context* ac, T0* C, T0* a1, T6 a2);
/* KL_SPECIAL_ROUTINES [XPLAIN_ABSTRACT_OBJECT].force */
extern void T430f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_ABSTRACT_OBJECT].fill_with */
extern void T428f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_ABSTRACT_OBJECT].extend */
extern void T428f10(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].key_storage_keep_head */
extern void T391f57(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [[attached] STRING_8].keep_head */
extern void T36f7(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [[attached] STRING_8].set_count */
extern void T36f11(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].item_storage_keep_head */
extern void T391f56(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ABSTRACT_OBJECT].keep_head */
extern void T428f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ABSTRACT_OBJECT].set_count */
extern void T428f9(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].clashes_put */
extern void T391f45(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].slots_put */
extern void T391f46(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].move_cursors_forth */
extern void T391f55(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE_CURSOR [XPLAIN_ABSTRACT_OBJECT, STRING_8].set_position */
extern void T432f9(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE_CURSOR [XPLAIN_ABSTRACT_OBJECT, STRING_8].set_next_cursor */
extern void T432f8(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE_CURSOR [XPLAIN_ABSTRACT_OBJECT, STRING_8].set_after */
extern void T432f7(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].internal_set_key_equality_tester */
extern void T391f54(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNIVERSE.std */
extern T0* T175f9(GE_context* ac, T0* C);
/* XPLAIN_PARSER.immediate_output_mode */
extern T1 T65f312(GE_context* ac, T0* C);
/* XPLAIN_PARSER.get_known_object */
extern T0* T65f311(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_STATEMENT].force */
extern void T188f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT].fill_with */
extern void T178f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT].extend */
extern void T178f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_STATEMENT].aliased_resized_area */
extern T0* T188f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT].aliased_resized_area */
extern T0* T178f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_CONSTANT_STATEMENT.make */
extern T0* T130c4(GE_context* ac, T0* a1);
/* XPLAIN_VARIABLE.make */
extern T0* T179c9(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_REQUIRED.make */
extern T0* T122c4(GE_context* ac, T1 a1);
/* XPLAIN_PARSER.write_pending_init */
extern void T65f535(GE_context* ac, T0* C);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_TYPE].force */
extern void T187f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_TYPE].fill_with */
extern void T173f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_TYPE].extend */
extern void T173f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_TYPE].aliased_resized_area */
extern T0* T187f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_TYPE].aliased_resized_area */
extern T0* T173f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_TYPE.make */
extern T0* T129c30(GE_context* ac, T0* a1, T0* a2, T0* a3);
/* XPLAIN_I_REFERENCES.set_owner */
extern void T250f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_A_REFERENCES.set_owner */
extern void T247f7(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].put_last */
extern void T337f17(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE].put_right */
extern void T419f4(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE].make */
extern T0* T419c3(GE_context* ac, T0* a1);
/* XPLAIN_ATTRIBUTE.set_abstracttype */
extern void T142f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE.is_abstracttype_attached */
extern T1 T142f9(GE_context* ac, T0* C);
/* XPLAIN_TYPE.make_abstract_type */
extern void T129f32(GE_context* ac, T0* C, T0* a1, T0* a2);
/* KL_SPECIAL_ROUTINES [XPLAIN_BASE].force */
extern void T183f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_BASE].fill_with */
extern void T176f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_BASE].extend */
extern void T176f10(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_BASE].aliased_resized_area */
extern T0* T183f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_BASE].aliased_resized_area */
extern T0* T176f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.new_base */
extern T0* T65f295(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* XPLAIN_BASE.make */
extern T0* T128c11(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_B_RESTRICTION.make */
extern T0* T342c4(GE_context* ac, T1 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].aliased_resized_area */
extern T0* T181f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].aliased_resized_area */
extern T0* T172f4(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].force */
extern void T181f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].fill_with */
extern void T172f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].extend */
extern void T172f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT.make */
extern T0* T127c5(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_VARIABLE.set_value */
extern void T179f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE.has_value */
extern T1 T179f6(GE_context* ac, T0* C);
/* XPLAIN_UNIVERSE.find_variable */
extern T0* T175f8(GE_context* ac, T0* C, T0* a1);
extern T1 T175f8ot1(T0* a1, T0** a2);
/* XPLAIN_BASE_STATEMENT.make */
extern T0* T177c4(GE_context* ac, T0* a1);
/* XPLAIN_UNIVERSE.add */
extern void T175f11(GE_context* ac, T0* C, T0* a1, T0* a2);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].force */
extern void T391f38(GE_context* ac, T0* C, T0* a1, T0* a2);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].resize */
extern void T391f44(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].clashes_resize */
extern void T391f53(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [INTEGER_32].aliased_resized_area_with_default */
extern T0* T117f4(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [INTEGER_32].aliased_resized_area_with_default */
extern T0* T105f5(GE_context* ac, T0* C, T6 a1, T6 a2);
/* SPECIAL [INTEGER_32].aliased_resized_area */
extern T0* T105f4(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].special_integer_ */
extern T0* T391f32(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].key_storage_resize */
extern void T391f52(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].item_storage_resize */
extern void T391f51(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ABSTRACT_OBJECT].aliased_resized_area */
extern T0* T430f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_ABSTRACT_OBJECT].aliased_resized_area */
extern T0* T428f4(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].slots_resize */
extern void T391f50(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].new_modulus */
extern T6 T391f26(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].new_capacity */
extern T6 T391f25(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.universe */
extern T0* T65f362(GE_context* ac, T0* C);
/* XPLAIN_UNIVERSE.make */
extern T0* T175c10(GE_context* ac);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].make_equal */
extern T0* T391c36(GE_context* ac, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].make_with_equality_testers */
extern void T391f41(GE_context* ac, T0* C, T6 a1, T0* a2, T0* a3);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].make_sparse_container */
extern void T391f49(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].set_internal_cursor */
extern void T391f62(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].new_cursor */
extern T0* T391f31(GE_context* ac, T0* C);
/* DS_HASH_TABLE_CURSOR [XPLAIN_ABSTRACT_OBJECT, STRING_8].make */
extern T0* T432c6(GE_context* ac, T0* a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].make_slots */
extern void T391f61(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].make_clashes */
extern void T391f60(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].make_key_storage */
extern void T391f59(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [STRING_8].make */
extern T0* T125f2(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [STRING_8].default_create */
extern T0* T125c3(GE_context* ac);
/* DS_HASH_TABLE [XPLAIN_ABSTRACT_OBJECT, STRING_8].make_item_storage */
extern void T391f58(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ABSTRACT_OBJECT].make */
extern T0* T430f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ABSTRACT_OBJECT].make_empty */
extern T0* T428c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ABSTRACT_OBJECT].default_create */
extern T0* T430c3(GE_context* ac);
/* detachable KL_EQUALITY_TESTER [STRING_8].default_create */
extern T0* T378c2(GE_context* ac);
/* detachable KL_EQUALITY_TESTER [XPLAIN_ABSTRACT_OBJECT].default_create */
extern T0* T429c1(GE_context* ac);
/* XPLAIN_TYPE_STATEMENT.make */
extern T0* T174c4(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT].aliased_resized_area */
extern T0* T170f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [detachable XPLAIN_STATEMENT].aliased_resized_area */
extern T0* T168f4(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT].force */
extern void T170f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [detachable XPLAIN_STATEMENT].fill_with */
extern void T168f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [detachable XPLAIN_STATEMENT].extend */
extern void T168f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.equal */
extern T1 T65f334(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_STATEMENTS.add */
extern void T69f3(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].put_first */
extern void T327f14(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_STATEMENT].put_right */
extern void T397f4(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_STATEMENT].make */
extern T0* T397c3(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.use_mode */
extern T1 T65f329(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].back */
extern void T344f11(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].cursor_back */
extern void T120f19(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].add_traversing_cursor */
extern void T120f20(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].set_next_cursor */
extern void T344f13(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].remove_traversing_cursor */
extern void T120f21(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].set */
extern void T344f14(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].is_first */
extern T1 T344f7(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].cursor_is_first */
extern T1 T120f9(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].item */
extern T0* T344f6(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].finish */
extern void T344f10(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].cursor_finish */
extern void T120f18(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].cursor_off */
extern T1 T120f8(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].off */
extern T1 T344f8(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].new_cursor */
extern T0* T120f6(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].make */
extern T0* T344c9(GE_context* ac, T0* a1);
/* KL_SPECIAL_ROUTINES [STRING_8].force */
extern void T125f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* XPLAIN_PARSER.text */
extern T0* T65f328(GE_context* ac, T0* C);
/* KL_CHARACTER_BUFFER.substring */
extern T0* T414f6(GE_context* ac, T0* C, T6 a1, T6 a2);
/* XPLAIN_PARSER.report_error */
extern void T65f533(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.write_pending_statement */
extern void T65f534(GE_context* ac, T0* C);
/* XPLAIN_PARSER.write_pending_type */
extern void T65f552(GE_context* ac, T0* C);
/* XML_GENERATOR.dump_type */
extern void T67f20(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_PARSER.yy_push_last_value */
extern void T65f519(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.accept */
extern void T65f518(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_do_error_action */
extern void T65f516(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.report_eof_expected_error */
extern void T65f532(GE_context* ac, T0* C);
/* XPLAIN_PARSER.read_token */
extern void T65f515(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_execute_action */
extern void T65f531(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.default_action */
extern void T65f551(GE_context* ac, T0* C);
/* XPLAIN_PARSER.echo */
extern void T65f559(GE_context* ac, T0* C);
/* XPLAIN_PARSER.output */
extern void T65f562(GE_context* ac, T0* C, T0* a1);
/* KL_STDOUT_FILE.put_string */
extern void T115f6(GE_context* ac, T0* C, T0* a1);
/* CONSOLE.put_string */
extern void T415f21(GE_context* ac, T0* C, T0* a1);
/* CONSOLE.console_ps */
extern void T415f28(GE_context* ac, T0* C, T14 a1, T14 a2, T6 a3);
/* KL_STDOUT_FILE.console */
extern T0* T115f2(GE_context* ac, T0* C);
/* STD_FILES.output */
extern T0* T328f3(GE_context* ac, T0* C);
/* CONSOLE.make_open_stdout */
extern T0* T415c23(GE_context* ac, T0* a1);
/* CONSOLE.set_write_mode */
extern void T415f27(GE_context* ac, T0* C);
/* CONSOLE.console_def */
extern T14 T415f13(GE_context* ac, T0* C, T6 a1);
/* CONSOLE.make_with_name */
extern void T415f26(GE_context* ac, T0* C, T0* a1);
/* CONSOLE.default_pointer */
extern T14 T415f9(GE_context* ac, T0* C);
/* CONSOLE.set_name */
extern void T415f31(GE_context* ac, T0* C, T0* a1);
/* CONSOLE.buffered_file_info */
extern T0* T415f15(GE_context* ac, T0* C);
/* KL_STDOUT_FILE.io */
extern T0* T115f4(GE_context* ac, T0* C);
/* STD_FILES.set_output_default */
extern void T328f7(GE_context* ac, T0* C);
/* STD_FILES.default_create */
extern T0* T328c6(GE_context* ac);
/* KL_STDOUT_FILE.string_ */
extern T0* T115f1(GE_context* ac, T0* C);
/* KL_STANDARD_FILES.output */
extern T0* T39f2(GE_context* ac, T0* C);
/* KL_STDOUT_FILE.make */
extern T0* T115c5(GE_context* ac);
/* XPLAIN_PARSER.text_item */
extern T2 T65f470(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.preprocessor_use */
extern void T65f550(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].put_last */
extern void T120f11(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_SCANNER_STATE].put_right */
extern void T385f4(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_SCANNER_STATE].make */
extern T0* T385c3(GE_context* ac, T0* a1);
/* XPLAIN_SCANNER_STATE.make_use */
extern T0* T118c8(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_SCANNER_STATE.set_directory */
extern void T118f10(GE_context* ac, T0* C);
/* XPLAIN_SCANNER_STATE.do_make */
extern void T118f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.set_input_buffer */
extern void T65f558(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_load_input_buffer */
extern void T65f555(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_set_content */
extern void T65f544(GE_context* ac, T0* C, T0* a1);
/* KL_CHARACTER_BUFFER.count */
extern T6 T414f4(GE_context* ac, T0* C);
/* YY_FILE_BUFFER.set_position */
extern void T322f20(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* YY_FILE_BUFFER.set_index */
extern void T322f17(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.new_file_buffer */
extern T0* T65f342(GE_context* ac, T0* C, T0* a1);
/* YY_FILE_BUFFER.make */
extern T0* T322c16(GE_context* ac, T0* a1);
/* YY_FILE_BUFFER.make_with_size */
extern void T322f21(GE_context* ac, T0* C, T0* a1, T6 a2);
/* YY_FILE_BUFFER.set_file */
extern void T322f23(GE_context* ac, T0* C, T0* a1);
/* YY_FILE_BUFFER.set_file_with_size */
extern void T322f25(GE_context* ac, T0* C, T0* a1, T6 a2);
/* KL_CHARACTER_BUFFER.resize */
extern void T414f10(GE_context* ac, T0* C, T6 a1);
/* YY_FILE_BUFFER.flush */
extern void T322f26(GE_context* ac, T0* C);
/* KL_CHARACTER_BUFFER.put */
extern void T414f8(GE_context* ac, T0* C, T2 a1, T6 a2);
/* KL_TEXT_INPUT_FILE.end_of_input */
extern T1 T31f28(GE_context* ac, T0* C);
/* YY_FILE_BUFFER.new_default_buffer */
extern T0* T322f15(GE_context* ac, T0* C, T6 a1);
/* KL_CHARACTER_BUFFER.make */
extern T0* T414c7(GE_context* ac, T6 a1);
/* YY_FILE_BUFFER.default_capacity */
extern T6 T322f13(GE_context* ac, T0* C);
/* XPLAIN_PARSER.make_relative_path */
extern T0* T65f486(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.preprocessor_include */
extern void T65f549(GE_context* ac, T0* C);
/* XPLAIN_SCANNER_STATE.make_include */
extern T0* T118c7(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_PARSER.unquote_string */
extern T0* T65f466(GE_context* ac, T0* C, T0* a1);
/* STRING_8.remove */
extern void T17f52(GE_context* ac, T0* C, T6 a1);
/* STRING_8.right_adjust */
extern void T17f47(GE_context* ac, T0* C);
/* CHARACTER_8.is_space */
extern T1 T2f2(GE_context* ac, T2* C);
/* XPLAIN_PARSER.conditional_parse_domain */
extern void T65f548(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.less */
extern void T65f557(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.read_character */
extern void T65f556(GE_context* ac, T0* C);
/* YY_FILE_BUFFER.set_beginning_of_line */
extern void T322f19(GE_context* ac, T0* C, T1 a1);
/* XPLAIN_PARSER.set_start_condition */
extern void T65f547(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.yy_set_line_column */
extern void T65f546(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_execute_eof_action */
extern void T65f530(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.terminate */
extern void T65f545(GE_context* ac, T0* C);
/* XPLAIN_PARSER.wrap */
extern T1 T65f304(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].remove_last */
extern void T120f12(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].set_last_cell */
extern void T120f16(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_SCANNER_STATE].forget_right */
extern void T385f5(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].move_last_cursors_after */
extern void T120f15(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_SCANNER_STATE].set_after */
extern void T344f12(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].wipe_out */
extern void T120f14(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].move_all_cursors_after */
extern void T120f17(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_refill_input_buffer */
extern void T65f529(GE_context* ac, T0* C);
/* YY_FILE_BUFFER.fill */
extern void T322f18(GE_context* ac, T0* C);
/* KL_CHARACTER_BUFFER.fill_from_stream */
extern T6 T414f5(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* KL_STDIN_FILE.read_to_string */
extern T6 T323f7(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* STRING_8.subcopy */
extern void T17f60(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3, T6 a4);
/* CONSOLE.read_stream */
extern void T415f32(GE_context* ac, T0* C, T6 a1);
/* CONSOLE.read_stream_thread_aware */
extern void T415f33(GE_context* ac, T0* C, T6 a1);
/* C_STRING.read_string_into */
extern void T29f10(GE_context* ac, T0* C, T0* a1);
/* C_STRING.read_substring_into */
extern void T29f11(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* NATURAL_8.to_natural_32 */
extern T10 T8f10(GE_context* ac, T8* C);
/* MANAGED_POINTER.read_natural_8 */
extern T8 T111f7(GE_context* ac, T0* C, T6 a1);
/* TYPED_POINTER [NATURAL_8].memory_copy */
extern void T406f2(GE_context* ac, T406* C, T14 a1, T6 a2);
/* TYPED_POINTER [NATURAL_8].c_memcpy */
extern void T406f3(GE_context* ac, T406* C, T14 a1, T14 a2, T6 a3);
/* STRING_8.grow */
extern void T17f62(GE_context* ac, T0* C, T6 a1);
/* CONSOLE.console_readstream */
extern T6 T415f17(GE_context* ac, T0* C, T14 a1, T14 a2, T6 a3);
/* C_STRING.set_count */
extern void T29f5(GE_context* ac, T0* C, T6 a1);
/* CONSOLE.read_data_buffer */
extern T0* T415f16(GE_context* ac, T0* C);
/* KL_STDIN_FILE.any_ */
extern T0* T323f8(GE_context* ac, T0* C);
/* CONSOLE.end_of_file */
extern T1 T415f7(GE_context* ac, T0* C);
/* CONSOLE.console_eof */
extern T1 T415f10(GE_context* ac, T0* C, T14 a1);
/* KL_STDIN_FILE.console */
extern T0* T323f5(GE_context* ac, T0* C);
/* STD_FILES.input */
extern T0* T328f5(GE_context* ac, T0* C);
/* CONSOLE.make_open_stdin */
extern T0* T415c24(GE_context* ac, T0* a1);
/* CONSOLE.set_read_mode */
extern void T415f30(GE_context* ac, T0* C);
/* KL_STDIN_FILE.io */
extern T0* T323f6(GE_context* ac, T0* C);
/* STRING_8.put */
extern void T17f56(GE_context* ac, T0* C, T2 a1, T6 a2);
/* KL_TEXT_INPUT_FILE.read_to_string */
extern T6 T31f33(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* KL_TEXT_INPUT_FILE.dummy_kl_character_buffer */
extern T0* T31f37(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.old_read_to_string */
extern T6 T31f36(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* KL_TEXT_INPUT_FILE.file_gss */
extern T6 T31f38(GE_context* ac, T0* C, T14 a1, T14 a2, T6 a3);
/* SPECIAL [CHARACTER_8].item_address */
extern T14 T15f8(GE_context* ac, T0* C, T6 a1);
/* KL_TEXT_INPUT_FILE.any_ */
extern T0* T31f34(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.old_end_of_file */
extern T1 T31f30(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.file_feof */
extern T1 T31f32(GE_context* ac, T0* C, T14 a1);
/* KL_STDIN_FILE.read_character */
extern void T323f11(GE_context* ac, T0* C);
/* CONSOLE.read_character */
extern void T415f25(GE_context* ac, T0* C);
/* CONSOLE.console_readchar */
extern T2 T415f14(GE_context* ac, T0* C, T14 a1);
/* KL_TEXT_INPUT_FILE.read_character */
extern void T31f50(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.old_read_character */
extern void T31f51(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.file_gc */
extern T2 T31f31(GE_context* ac, T0* C, T14 a1);
/* YY_FILE_BUFFER.compact_left */
extern void T322f22(GE_context* ac, T0* C);
/* KL_CHARACTER_BUFFER.move_left */
extern void T414f9(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* YY_FILE_BUFFER.resize */
extern void T322f24(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_null_trans_state */
extern T6 T65f303(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.yy_previous_state */
extern T6 T65f302(GE_context* ac, T0* C);
/* XPLAIN_PARSER.fatal_error */
extern void T65f528(GE_context* ac, T0* C, T0* a1);
/* KL_CHARACTER_BUFFER.item */
extern T2 T414f3(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [INTEGER_32].force */
extern void T117f6(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* KL_SPECIAL_ROUTINES [INTEGER_32].aliased_resized_area */
extern T0* T117f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* XPLAIN_PARSER.special_integer_ */
extern T0* T65f337(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_init_value_stacks */
extern void T65f514(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_clear_all */
extern void T65f523(GE_context* ac, T0* C);
/* XPLAIN_PARSER.clear_all */
extern void T65f539(GE_context* ac, T0* C);
/* XPLAIN_PARSER.clear_stacks */
extern void T65f553(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_clear_value_stacks */
extern void T65f560(GE_context* ac, T0* C);
/* SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT].keep_head */
extern void T286f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT].set_count */
extern void T286f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_VALUE_STATEMENT].keep_head */
extern void T281f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_VALUE_STATEMENT].set_count */
extern void T281f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_UPDATE_STATEMENT].keep_head */
extern void T262f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_UPDATE_STATEMENT].set_count */
extern void T262f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_SQL_STATEMENT].keep_head */
extern void T169f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_SQL_STATEMENT].set_count */
extern void T169f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT].keep_head */
extern void T171f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT].set_count */
extern void T171f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_GET_STATEMENT].keep_head */
extern void T293f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_GET_STATEMENT].set_count */
extern void T293f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTEND_STATEMENT].keep_head */
extern void T296f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTEND_STATEMENT].set_count */
extern void T296f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_DELETE_STATEMENT].keep_head */
extern void T263f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_DELETE_STATEMENT].set_count */
extern void T263f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].keep_head */
extern void T274f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].set_count */
extern void T274f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CASCADE_STATEMENT].keep_head */
extern void T264f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CASCADE_STATEMENT].set_count */
extern void T264f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].keep_head */
extern void T172f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].set_count */
extern void T172f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT].keep_head */
extern void T178f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT].set_count */
extern void T178f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_STATEMENT].keep_head */
extern void T168f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_STATEMENT].set_count */
extern void T168f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_STATEMENT_NODE].keep_head */
extern void T317f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_STATEMENT_NODE].set_count */
extern void T317f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXPRESSION_NODE].keep_head */
extern void T221f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXPRESSION_NODE].set_count */
extern void T221f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_FUNCTION].keep_head */
extern void T290f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_FUNCTION].set_count */
extern void T290f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SORT_NODE].keep_head */
extern void T305f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SORT_NODE].set_count */
extern void T305f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION_LIST].keep_head */
extern void T268f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION_LIST].set_count */
extern void T268f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION].keep_head */
extern void T292f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION].set_count */
extern void T292f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION].keep_head */
extern void T258f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION].set_count */
extern void T258f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_EXTEND_ATTRIBUTE].keep_head */
extern void T298f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_EXTEND_ATTRIBUTE].set_count */
extern void T298f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTENSION].keep_head */
extern void T295f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTENSION].set_count */
extern void T295f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION_FUNCTION].keep_head */
extern void T276f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION_FUNCTION].set_count */
extern void T276f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].keep_head */
extern void T288f5(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].set_count */
extern void T288f8(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SUBJECT].keep_head */
extern void T265f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SUBJECT].set_count */
extern void T265f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ASSIGNMENT].keep_head */
extern void T271f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ASSIGNMENT].set_count */
extern void T271f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE].keep_head */
extern void T266f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE].set_count */
extern void T266f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ASSERTION].keep_head */
extern void T260f5(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ASSERTION].set_count */
extern void T260f8(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE].keep_head */
extern void T251f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE].set_count */
extern void T251f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE].keep_head */
extern void T185f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE].set_count */
extern void T185f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_PK_REPRESENTATION].keep_head */
extern void T186f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_PK_REPRESENTATION].set_count */
extern void T186f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_REPRESENTATION].keep_head */
extern void T182f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_REPRESENTATION].set_count */
extern void T182f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_TYPE].keep_head */
extern void T173f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_TYPE].set_count */
extern void T173f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME].keep_head */
extern void T190f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME].set_count */
extern void T190f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE].keep_head */
extern void T205f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE].set_count */
extern void T205f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_SYSTEM_EXPRESSION].keep_head */
extern void T216f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_SYSTEM_EXPRESSION].set_count */
extern void T216f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION].keep_head */
extern void T213f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION].set_count */
extern void T213f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_EXPRESSION].keep_head */
extern void T180f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_EXPRESSION].set_count */
extern void T180f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_LOGICAL_EXPRESSION].keep_head */
extern void T201f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_LOGICAL_EXPRESSION].set_count */
extern void T201f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_I_NODE].keep_head */
extern void T195f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_I_NODE].set_count */
extern void T195f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_A_NODE].keep_head */
extern void T193f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_A_NODE].set_count */
extern void T193f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_DOMAIN_RESTRICTION].keep_head */
extern void T184f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_DOMAIN_RESTRICTION].set_count */
extern void T184f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_BASE].keep_head */
extern void T176f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_BASE].set_count */
extern void T176f9(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [INTEGER_32].keep_head */
extern void T105f12(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [INTEGER_32].set_count */
extern void T105f13(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [ANY].keep_head */
extern void T38f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [ANY].set_count */
extern void T38f10(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.abort */
extern void T65f517(GE_context* ac, T0* C);
/* STRING_8.plus */
extern T0* T17f5(GE_context* ac, T0* C, T0* a1);
/* STRING_8.append_string_general */
extern void T17f35(GE_context* ac, T0* C, T0* a1);
/* STRING_8.append */
extern void T17f35p1(GE_context* ac, T0* C, T0* a1);
/* STRING_8.append_code */
extern void T17f38(GE_context* ac, T0* C, T10 a1);
/* STRING_8.new_string */
extern T0* T17f6(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_PARSER.set_mwgenerator */
extern void T65f509(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.make */
extern T0* T67c18(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.make_with_file */
extern T0* T65c508(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_PARSER.make */
extern void T65f512(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.set_sqlgenerator */
extern void T65f526(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STATEMENTS.make */
extern T0* T69c2(GE_context* ac);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].make */
extern T0* T327c11(GE_context* ac);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].set_internal_cursor */
extern void T327f15(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_STATEMENT].new_cursor */
extern T0* T327f6(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_STATEMENT].make */
extern T0* T396c7(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.make_parser_skeleton */
extern void T65f525(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_build_parser_tables */
extern void T65f542(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yycheck_template */
extern T0* T65f480(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yyfixed_array */
extern T0* T65f501(GE_context* ac, T0* C, T0* a1);
/* KL_SPECIAL_ROUTINES [INTEGER_32].to_special */
extern T0* T117f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_10 */
extern void T65f598(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yyarray_subcopy */
extern void T65f628(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3, T6 a4, T6 a5);
/* KL_ARRAY_ROUTINES [INTEGER_32].subcopy */
extern void T348f2(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3, T6 a4, T6 a5);
/* ARRAY [INTEGER_32].subcopy */
extern void T347f6(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3, T6 a4);
/* SPECIAL [INTEGER_32].copy_data */
extern void T105f14(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3, T6 a4);
/* SPECIAL [INTEGER_32].force */
extern void T105f9(GE_context* ac, T0* C, T6 a1, T6 a2);
/* SPECIAL [INTEGER_32].move_data */
extern void T105f15(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* SPECIAL [INTEGER_32].overlapping_move */
extern void T105f17(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* SPECIAL [INTEGER_32].non_overlapping_move */
extern void T105f16(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* XPLAIN_PARSER.integer_array_ */
extern T0* T65f506(GE_context* ac, T0* C);
/* KL_ARRAY_ROUTINES [INTEGER_32].default_create */
extern T0* T348c1(GE_context* ac);
/* XPLAIN_PARSER.yycheck_template_9 */
extern void T65f597(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_8 */
extern void T65f596(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_7 */
extern void T65f595(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_6 */
extern void T65f594(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_5 */
extern void T65f593(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_4 */
extern void T65f592(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_3 */
extern void T65f591(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_2 */
extern void T65f590(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yycheck_template_1 */
extern void T65f589(GE_context* ac, T0* C, T0* a1);
/* ARRAY [INTEGER_32].make_filled */
extern T0* T347c4(GE_context* ac, T6 a1, T6 a2, T6 a3);
/* ARRAY [INTEGER_32].make_filled_area */
extern void T347f5(GE_context* ac, T0* C, T6 a1, T6 a2);
/* XPLAIN_PARSER.yytable_template */
extern T0* T65f479(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yytable_template_10 */
extern void T65f588(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_9 */
extern void T65f587(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_8 */
extern void T65f586(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_7 */
extern void T65f585(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_6 */
extern void T65f584(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_5 */
extern void T65f583(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_4 */
extern void T65f582(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_3 */
extern void T65f581(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_2 */
extern void T65f580(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytable_template_1 */
extern void T65f579(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yypgoto_template */
extern T0* T65f478(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yypact_template */
extern T0* T65f477(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yypact_template_4 */
extern void T65f578(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yypact_template_3 */
extern void T65f577(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yypact_template_2 */
extern void T65f576(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yypact_template_1 */
extern void T65f575(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yydefgoto_template */
extern T0* T65f476(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yydefact_template */
extern T0* T65f475(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yydefact_template_4 */
extern void T65f574(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yydefact_template_3 */
extern void T65f573(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yydefact_template_2 */
extern void T65f572(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yydefact_template_1 */
extern void T65f571(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytypes2_template */
extern T0* T65f474(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yytypes1_template */
extern T0* T65f473(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yytypes1_template_4 */
extern void T65f570(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytypes1_template_3 */
extern void T65f569(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytypes1_template_2 */
extern void T65f568(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytypes1_template_1 */
extern void T65f567(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yyr1_template */
extern T0* T65f472(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yyr1_template_2 */
extern void T65f566(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yyr1_template_1 */
extern void T65f565(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytranslate_template */
extern T0* T65f471(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yytranslate_template_2 */
extern void T65f564(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yytranslate_template_1 */
extern void T65f563(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_create_value_stacks */
extern void T65f541(GE_context* ac, T0* C);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_VALUE_SELECTION_STATEMENT].make */
extern T0* T287f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_VALUE_SELECTION_STATEMENT].make_empty */
extern T0* T286c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_VALUE_SELECTION_STATEMENT].default_create */
extern T0* T287c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE_STATEMENT].make */
extern T0* T282f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_VALUE_STATEMENT].make_empty */
extern T0* T281c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE_STATEMENT].default_create */
extern T0* T282c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_UPDATE_STATEMENT].make */
extern T0* T280f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_UPDATE_STATEMENT].make_empty */
extern T0* T262c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_UPDATE_STATEMENT].default_create */
extern T0* T280c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_SQL_STATEMENT].make */
extern T0* T320f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_SQL_STATEMENT].make_empty */
extern T0* T169c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_SQL_STATEMENT].default_create */
extern T0* T320c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_PROCEDURE_STATEMENT].make */
extern T0* T319f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_PROCEDURE_STATEMENT].make_empty */
extern T0* T171c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_PROCEDURE_STATEMENT].default_create */
extern T0* T319c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_GET_STATEMENT].make */
extern T0* T294f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_GET_STATEMENT].make_empty */
extern T0* T293c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_GET_STATEMENT].default_create */
extern T0* T294c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTEND_STATEMENT].make */
extern T0* T297f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTEND_STATEMENT].make_empty */
extern T0* T296c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTEND_STATEMENT].default_create */
extern T0* T297c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_DELETE_STATEMENT].make */
extern T0* T278f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_DELETE_STATEMENT].make_empty */
extern T0* T263c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_DELETE_STATEMENT].default_create */
extern T0* T278c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].make */
extern T0* T277f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].make_empty */
extern T0* T274c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_FUNCTION_EXPRESSION].default_create */
extern T0* T277c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_STATEMENT].make */
extern T0* T275f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CASCADE_STATEMENT].make_empty */
extern T0* T264c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CASCADE_STATEMENT].default_create */
extern T0* T275c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].make */
extern T0* T181f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].make_empty */
extern T0* T172c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT].default_create */
extern T0* T181c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_STATEMENT].make */
extern T0* T188f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_CONSTANT_STATEMENT].make_empty */
extern T0* T178c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_CONSTANT_STATEMENT].default_create */
extern T0* T188c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT].make */
extern T0* T170f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_STATEMENT].make_empty */
extern T0* T168c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT].default_create */
extern T0* T170c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT_NODE].make */
extern T0* T321f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_STATEMENT_NODE].make_empty */
extern T0* T317c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_STATEMENT_NODE].default_create */
extern T0* T321c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXPRESSION_NODE].make */
extern T0* T316f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXPRESSION_NODE].make_empty */
extern T0* T221c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXPRESSION_NODE].default_create */
extern T0* T316c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_FUNCTION].make */
extern T0* T309f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_FUNCTION].make_empty */
extern T0* T290c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_FUNCTION].default_create */
extern T0* T309c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SORT_NODE].make */
extern T0* T307f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SORT_NODE].make_empty */
extern T0* T305c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SORT_NODE].default_create */
extern T0* T307c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_LIST].make */
extern T0* T306f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION_LIST].make_empty */
extern T0* T268c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_LIST].default_create */
extern T0* T306c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION].make */
extern T0* T304f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION].make_empty */
extern T0* T292c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION].default_create */
extern T0* T304c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION_EXPRESSION].make */
extern T0* T302f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTENSION_EXPRESSION].make_empty */
extern T0* T258c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION_EXPRESSION].default_create */
extern T0* T302c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_EXTEND_ATTRIBUTE].make */
extern T0* T300f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_EXTEND_ATTRIBUTE].make_empty */
extern T0* T298c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_EXTEND_ATTRIBUTE].default_create */
extern T0* T300c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION].make */
extern T0* T299f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_EXTENSION].make_empty */
extern T0* T295c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_EXTENSION].default_create */
extern T0* T299c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_FUNCTION].make */
extern T0* T291f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SELECTION_FUNCTION].make_empty */
extern T0* T276c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SELECTION_FUNCTION].default_create */
extern T0* T291c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].make */
extern T0* T289f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].make_empty */
extern T0* T288c4(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_NON_ATTRIBUTE_EXPRESSION].default_create */
extern T0* T289c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SUBJECT].make */
extern T0* T279f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_SUBJECT].make_empty */
extern T0* T265c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_SUBJECT].default_create */
extern T0* T279c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_ASSIGNMENT].make */
extern T0* T273f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ASSIGNMENT].make_empty */
extern T0* T271c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ASSIGNMENT].default_create */
extern T0* T273c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSIGNMENT_NODE].make */
extern T0* T272f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ASSIGNMENT_NODE].make_empty */
extern T0* T266c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSIGNMENT_NODE].default_create */
extern T0* T272c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSERTION].make */
extern T0* T259f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ASSERTION].make_empty */
extern T0* T260c4(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ASSERTION].default_create */
extern T0* T259c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE].make */
extern T0* T254f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE].make_empty */
extern T0* T251c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE].default_create */
extern T0* T254c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ATTRIBUTE_NODE].make */
extern T0* T252f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_ATTRIBUTE_NODE].make_empty */
extern T0* T185c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_ATTRIBUTE_NODE].default_create */
extern T0* T252c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_PK_REPRESENTATION].make */
extern T0* T248f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_PK_REPRESENTATION].make_empty */
extern T0* T186c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_PK_REPRESENTATION].default_create */
extern T0* T248c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_REPRESENTATION].make */
extern T0* T237f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_REPRESENTATION].make_empty */
extern T0* T182c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_REPRESENTATION].default_create */
extern T0* T237c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_TYPE].make */
extern T0* T187f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [detachable XPLAIN_TYPE].make_empty */
extern T0* T173c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable XPLAIN_TYPE].default_create */
extern T0* T187c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME].make */
extern T0* T235f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME].make_empty */
extern T0* T190c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME].default_create */
extern T0* T235c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME_NODE].make */
extern T0* T234f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_ATTRIBUTE_NAME_NODE].make_empty */
extern T0* T205c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_ATTRIBUTE_NAME_NODE].default_create */
extern T0* T234c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_SYSTEM_EXPRESSION].make */
extern T0* T217f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_SYSTEM_EXPRESSION].make_empty */
extern T0* T216c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_SYSTEM_EXPRESSION].default_create */
extern T0* T217c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_VALUE_EXPRESSION].make */
extern T0* T214f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_LOGICAL_VALUE_EXPRESSION].make_empty */
extern T0* T213c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_VALUE_EXPRESSION].default_create */
extern T0* T214c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_EXPRESSION].make */
extern T0* T204f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_EXPRESSION].make_empty */
extern T0* T180c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_EXPRESSION].default_create */
extern T0* T204c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_EXPRESSION].make */
extern T0* T202f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_LOGICAL_EXPRESSION].make_empty */
extern T0* T201c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_LOGICAL_EXPRESSION].default_create */
extern T0* T202c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_I_NODE].make */
extern T0* T199f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_I_NODE].make_empty */
extern T0* T195c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_I_NODE].default_create */
extern T0* T199c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_A_NODE].make */
extern T0* T197f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_A_NODE].make_empty */
extern T0* T193c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_A_NODE].default_create */
extern T0* T197c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_DOMAIN_RESTRICTION].make */
extern T0* T191f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_DOMAIN_RESTRICTION].make_empty */
extern T0* T184c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_DOMAIN_RESTRICTION].default_create */
extern T0* T191c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [XPLAIN_BASE].make */
extern T0* T183f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_BASE].make_empty */
extern T0* T176c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_BASE].default_create */
extern T0* T183c3(GE_context* ac);
/* KL_SPECIAL_ROUTINES [detachable ANY].make */
extern T0* T124f2(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [detachable ANY].default_create */
extern T0* T124c3(GE_context* ac);
/* XPLAIN_PARSER.make_scanner_with_file */
extern void T65f513(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SCANNER_STATE.make_file */
extern T0* T118c6(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_PARSER.make_compressed_scanner_skeleton_with_file */
extern void T65f527(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.make_with_buffer */
extern void T65f543(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_initialize */
extern void T65f554(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_initialize */
extern void T65f554p1(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_build_tables */
extern void T65f561(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_accept_template */
extern T0* T65f496(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_fixed_array */
extern T0* T65f503(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_accept_template_3 */
extern void T65f627(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_array_subcopy */
extern void T65f629(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3, T6 a4, T6 a5);
/* XPLAIN_PARSER.yy_accept_template_2 */
extern void T65f626(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_accept_template_1 */
extern void T65f625(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_meta_template */
extern T0* T65f495(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_ec_template */
extern T0* T65f494(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_ec_template_2 */
extern void T65f624(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_ec_template_1 */
extern void T65f623(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_def_template */
extern T0* T65f493(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_def_template_3 */
extern void T65f622(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_def_template_2 */
extern void T65f621(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_def_template_1 */
extern void T65f620(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_base_template */
extern T0* T65f492(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_base_template_3 */
extern void T65f619(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_base_template_2 */
extern void T65f618(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_base_template_1 */
extern void T65f617(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template */
extern T0* T65f491(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_chk_template_9 */
extern void T65f616(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template_8 */
extern void T65f615(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template_7 */
extern void T65f614(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template_6 */
extern void T65f613(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template_5 */
extern void T65f612(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template_4 */
extern void T65f611(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template_3 */
extern void T65f610(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template_2 */
extern void T65f609(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_chk_template_1 */
extern void T65f608(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template */
extern T0* T65f490(GE_context* ac, T0* C);
/* XPLAIN_PARSER.yy_nxt_template_9 */
extern void T65f607(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template_8 */
extern void T65f606(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template_7 */
extern void T65f605(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template_6 */
extern void T65f604(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template_5 */
extern void T65f603(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template_4 */
extern void T65f602(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template_3 */
extern void T65f601(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template_2 */
extern void T65f600(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.yy_nxt_template_1 */
extern void T65f599(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.do_make */
extern void T65f524(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].make */
extern T0* T120c10(GE_context* ac);
/* DS_LINKED_LIST [XPLAIN_SCANNER_STATE].set_internal_cursor */
extern void T120f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARSER.make_compressed_scanner_skeleton */
extern void T65f540(GE_context* ac, T0* C);
/* KL_STANDARD_FILES.input */
extern T0* T39f3(GE_context* ac, T0* C);
/* KL_STDIN_FILE.make */
extern T0* T323c10(GE_context* ac);
/* XPLAIN_PARSER.make_with_stdin */
extern T0* T65c507(GE_context* ac, T0* a1);
/* XPLAIN_PARSER.make_scanner_with_stdin */
extern void T65f511(GE_context* ac, T0* C);
/* XPLAIN_SCANNER_STATE.make_stdin */
extern T0* T118c5(GE_context* ac, T0* a1);
/* KL_TEXT_INPUT_FILE.is_open_read */
extern T1 T31f24(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.old_is_open_read */
extern T1 T31f21(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.open_read */
extern void T31f41(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.is_closed */
extern T1 T31f17(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.old_is_closed */
extern T1 T31f11(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.old_open_read */
extern void T31f45(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.open_read */
extern void T31f45p1(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.file_open */
extern T14 T31f23(GE_context* ac, T0* C, T14 a1, T6 a2);
/* KL_TEXT_INPUT_FILE.internal_name_pointer */
extern T0* T31f22(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.old_is_readable */
extern T1 T31f16(GE_context* ac, T0* C);
/* FILE_INFO.is_readable */
extern T1 T112f8(GE_context* ac, T0* C);
/* FILE_INFO.file_eaccess */
extern T1 T112f6(GE_context* ac, T0* C, T14 a1, T6 a2);
/* KL_TEXT_INPUT_FILE.buffered_file_info */
extern T0* T31f26(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.set_buffer */
extern void T31f49(GE_context* ac, T0* C);
/* FILE_INFO.fast_update */
extern void T112f14(GE_context* ac, T0* C, T0* a1, T0* a2);
/* FILE_INFO.eif_file_stat */
extern T6 T112f12(GE_context* ac, T0* C, T14 a1, T14 a2, T1 a3);
/* KL_TEXT_INPUT_FILE.old_exists */
extern T1 T31f15(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.file_exists */
extern T1 T31f27(GE_context* ac, T0* C, T14 a1);
/* KL_TEXT_INPUT_FILE.string_name */
extern T0* T31f12(GE_context* ac, T0* C);
/* KL_TEXT_INPUT_FILE.make */
extern T0* T31c39(GE_context* ac, T0* a1);
/* KL_TEXT_INPUT_FILE.make */
extern void T31f39p1(GE_context* ac, T0* C, T0* a1);
/* KL_TEXT_INPUT_FILE.old_make */
extern void T31f43(GE_context* ac, T0* C, T0* a1);
/* KL_TEXT_INPUT_FILE.make_with_name */
extern void T31f46(GE_context* ac, T0* C, T0* a1);
/* KL_TEXT_INPUT_FILE.set_name */
extern void T31f48(GE_context* ac, T0* C, T0* a1);
/* KL_TEXT_INPUT_FILE.string_ */
extern T0* T31f25(GE_context* ac, T0* C);
/* STRING_8.item */
extern T2 T17f11(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL65.make */
extern T0* T64c244(GE_context* ac);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].make_equal */
extern T0* T114c35(GE_context* ac, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].make_with_equality_testers */
extern void T114f39(GE_context* ac, T0* C, T6 a1, T0* a2, T0* a3);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].make_sparse_container */
extern void T114f48(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].set_internal_cursor */
extern void T114f61(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].new_cursor */
extern T0* T114f27(GE_context* ac, T0* C);
/* DS_HASH_TABLE_CURSOR [XPLAIN_VALUE, STRING_8].make */
extern T0* T383c6(GE_context* ac, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].unset_found_item */
extern void T114f40(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].make_slots */
extern void T114f60(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].new_modulus */
extern T6 T114f22(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].make_clashes */
extern void T114f59(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].make_key_storage */
extern void T114f58(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].make_item_storage */
extern void T114f57(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE].make */
extern T0* T381f2(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_VALUE].make_empty */
extern T0* T382c5(GE_context* ac, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE].default_create */
extern T0* T381c3(GE_context* ac);
/* detachable KL_EQUALITY_TESTER [XPLAIN_VALUE].default_create */
extern T0* T377c1(GE_context* ac);
/* SQL_GENERATOR_TSQL70.make */
extern T0* T63c243(GE_context* ac);
/* SQL_GENERATOR_TSQL2000.make */
extern T0* T62c243(GE_context* ac);
/* SQL_GENERATOR_TSQL2016.make */
extern T0* T61c243(GE_context* ac);
/* SQL_GENERATOR_SQLITE_3.make */
extern T0* T60c242(GE_context* ac);
/* SQL_GENERATOR_PGSQL_72.make */
extern T0* T59c266(GE_context* ac);
/* SQL_GENERATOR_PGSQL_73.make */
extern T0* T58c268(GE_context* ac);
/* SQL_GENERATOR_PGSQL_81.make */
extern T0* T57c269(GE_context* ac);
/* SQL_GENERATOR_PGSQL_82.make */
extern T0* T56c269(GE_context* ac);
/* SQL_GENERATOR_PGSQL_95.make */
extern T0* T55c269(GE_context* ac);
/* SQL_GENERATOR_ORACLE.make */
extern T0* T54c264(GE_context* ac);
/* SQL_GENERATOR_MYSQL322.make */
extern T0* T53c230(GE_context* ac);
/* SQL_GENERATOR_MYSQL4.make */
extern T0* T52c230(GE_context* ac);
/* SQL_GENERATOR_MYSQL5.make */
extern T0* T51c255(GE_context* ac);
/* SQL_GENERATOR_MSQL.make */
extern T0* T50c229(GE_context* ac);
/* SQL_GENERATOR_MSACCESS2000.make */
extern T0* T49c229(GE_context* ac);
/* SQL_GENERATOR_MSACCESS97.make */
extern T0* T48c229(GE_context* ac);
/* SQL_GENERATOR_FIREBIRD_21.make */
extern T0* T47c259(GE_context* ac);
/* SQL_GENERATOR_FIREBIRD_21.make */
extern void T47f259p1(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.make */
extern T0* T46c259(GE_context* ac);
/* SQL_GENERATOR_INTERBASE6.make */
extern void T46f259p1(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.make */
extern T0* T45c229(GE_context* ac);
/* SQL_GENERATOR_DB2_71.make */
extern T0* T44c260(GE_context* ac);
/* SQL_GENERATOR_DB2_6.make */
extern T0* T43c231(GE_context* ac);
/* SQL_GENERATOR_BASIC.make */
extern T0* T42c230(GE_context* ac);
/* SQL_GENERATOR_ANSI.make */
extern T0* T41c230(GE_context* ac);
/* KL_STDERR_FILE.put_character */
extern void T40f7(GE_context* ac, T0* C, T2 a1);
/* CONSOLE.put_character */
extern void T415f22(GE_context* ac, T0* C, T2 a1);
/* CONSOLE.console_pc */
extern void T415f29(GE_context* ac, T0* C, T14 a1, T2 a2);
/* KL_STDERR_FILE.console */
extern T0* T40f2(GE_context* ac, T0* C);
/* STD_FILES.error */
extern T0* T328f2(GE_context* ac, T0* C);
/* CONSOLE.make_open_stderr */
extern T0* T415c19(GE_context* ac, T0* a1);
/* KL_STDERR_FILE.io */
extern T0* T40f3(GE_context* ac, T0* C);
/* KL_STDERR_FILE.put_string */
extern void T40f6(GE_context* ac, T0* C, T0* a1);
/* KL_STDERR_FILE.string_ */
extern T0* T40f1(GE_context* ac, T0* C);
/* KL_STANDARD_FILES.error */
extern T0* T39f1(GE_context* ac, T0* C);
/* KL_STDERR_FILE.make */
extern T0* T40c5(GE_context* ac);
/* XPLAIN2SQL.std */
extern T0* T24f4(GE_context* ac, T0* C);
/* XPLAIN2SQL.valid_format_and_parameters */
extern T1 T24f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_SCIENTIFIC_FORMATTER.valid_format_and_parameters */
extern T1 T103f21(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_SCIENTIFIC_FORMATTER.null_output_stream */
extern T0* T103f18(GE_context* ac, T0* C);
/* KL_NULL_TEXT_OUTPUT_STREAM.make */
extern T0* T352c2(GE_context* ac, T0* a1);
/* KL_ARRAY_ROUTINES [detachable ANY].has_void */
extern T1 T351f1(GE_context* ac, T0* C, T0* a1);
/* ST_SCIENTIFIC_FORMATTER.any_array_ */
extern T0* T103f24(GE_context* ac, T0* C);
/* KL_ARRAY_ROUTINES [detachable ANY].default_create */
extern T0* T351c2(GE_context* ac);
/* XPLAIN2SQL.formatter */
extern T0* T24f7(GE_context* ac, T0* C);
/* XPLAIN2SQL.scientific_formatter */
extern T0* T24f8(GE_context* ac, T0* C);
/* INTEGER_32.is_less_equal */
extern T1 T6f4(GE_context* ac, T6* C, T6 a1);
/* STRING_8.keep_tail */
extern void T17f59(GE_context* ac, T0* C, T6 a1);
/* XPLAIN2SQL.equal */
extern T1 T24f2(GE_context* ac, T0* C, T0* a1, T0* a2);
/* STRING_8.substring */
extern T0* T17f16(GE_context* ac, T0* C, T6 a1, T6 a2);
/* KL_ARGUMENTS.argument */
extern T0* T34f2(GE_context* ac, T0* C, T6 a1);
/* IMMUTABLE_STRING_32.as_string_8 */
extern T0* T19f6(GE_context* ac, T0* C);
/* IMMUTABLE_STRING_32.code */
extern T10 T19f5(GE_context* ac, T0* C, T6 a1);
/* ARGUMENTS_32.argument */
extern T0* T113f2(GE_context* ac, T0* C, T6 a1);
/* ARRAY [IMMUTABLE_STRING_32].item */
extern T0* T375f5(GE_context* ac, T0* C, T6 a1);
/* ARGUMENTS_32.internal_argument_array */
extern T0* T113f3(GE_context* ac, T0* C);
/* ARRAY [IMMUTABLE_STRING_32].put */
extern void T375f8(GE_context* ac, T0* C, T0* a1, T6 a2);
/* ARRAY [IMMUTABLE_STRING_32].compare_objects */
extern void T375f7(GE_context* ac, T0* C);
/* ARRAY [IMMUTABLE_STRING_32].make_filled */
extern T0* T375c6(GE_context* ac, T0* a1, T6 a2, T6 a3);
/* ARRAY [IMMUTABLE_STRING_32].make_filled_area */
extern void T375f9(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [IMMUTABLE_STRING_32].make_filled */
extern T0* T376c4(GE_context* ac, T0* a1, T6 a2);
/* SPECIAL [IMMUTABLE_STRING_32].fill_with */
extern void T376f7(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [IMMUTABLE_STRING_32].extend */
extern void T376f8(GE_context* ac, T0* C, T0* a1);
/* SPECIAL [IMMUTABLE_STRING_32].make_empty */
extern void T376f6(GE_context* ac, T0* C, T6 a1);
/* IMMUTABLE_STRING_32.make_empty */
extern T0* T19c7(GE_context* ac);
/* IMMUTABLE_STRING_32.make */
extern void T19f8(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [CHARACTER_32].make_filled */
extern T0* T16c4(GE_context* ac, T3 a1, T6 a2);
/* SPECIAL [CHARACTER_32].fill_with */
extern void T16f6(GE_context* ac, T0* C, T3 a1, T6 a2, T6 a3);
/* SPECIAL [CHARACTER_32].extend */
extern void T16f8(GE_context* ac, T0* C, T3 a1);
/* SPECIAL [CHARACTER_32].make_empty */
extern void T16f5(GE_context* ac, T0* C, T6 a1);
/* KL_ARGUMENTS.internal_arguments */
extern T0* T34f3(GE_context* ac, T0* C);
/* ARGUMENTS_32.default_create */
extern T0* T113c5(GE_context* ac);
/* INTEGER_32.is_greater */
extern T1 T6f13(GE_context* ac, T6* C, T6 a1);
/* XPLAIN2SQL.die */
extern void T24f11(GE_context* ac, T0* C, T6 a1);
/* XPLAIN2SQL.show_usage */
extern void T24f10(GE_context* ac, T0* C);
/* KL_ARGUMENTS.argument_count */
extern T6 T34f4(GE_context* ac, T0* C);
/* XPLAIN2SQL.arguments */
extern T0* T24f5(GE_context* ac, T0* C);
/* KL_ARGUMENTS.make */
extern T0* T34c5(GE_context* ac);
/* ISE_EXCEPTION_MANAGER.set_exception_data */
extern void T20f16(GE_context* ac, T0* C, T6 a1, T1 a2, T6 a3, T6 a4, T0* a5, T0* a6, T0* a7, T0* a8, T0* a9, T0* a10, T6 a11, T1 a12);
/* ISE_EXCEPTION_MANAGER.exception_from_data */
extern T0* T20f10(GE_context* ac, T0* C);
extern T1 T20f10ot1(T0* a1, T0** a2);
extern T1 T20f10ot2(T0* a1, T0** a2);
extern T1 T20f10ot3(T0* a1, T0** a2);
extern T1 T20f10ot4(T0* a1, T0** a2);
extern T1 T20f10ot5(T0* a1, T0** a2);
extern T1 T20f10ot6(T0* a1, T0** a2);
extern T1 T20f10ot7(T0* a1, T0** a2);
/* COM_FAILURE.set_exception_information */
extern void T83f15(GE_context* ac, T0* C, T0* a1);
/* COM_FAILURE.ccom_hresult_to_string */
extern T0* T83f11(GE_context* ac, T0* C, T6 a1);
/* INTEGER_32.to_hex_string */
extern T0* T6f22(GE_context* ac, T6* C);
/* INTEGER_32.to_hex_character */
extern T2 T6f26(GE_context* ac, T6* C);
/* STRING_8.fill_blank */
extern void T17f58(GE_context* ac, T0* C);
/* COM_FAILURE.set_hresult_code */
extern void T83f14(GE_context* ac, T0* C, T6 a1);
/* OPERATING_SYSTEM_FAILURE.set_error_code */
extern void T82f9(GE_context* ac, T0* C, T6 a1);
/* IO_FAILURE.set_error_code */
extern void T81f11(GE_context* ac, T0* C, T6 a1);
/* OPERATING_SYSTEM_SIGNAL_FAILURE.set_signal_code */
extern void T80f9(GE_context* ac, T0* C, T6 a1);
/* INVARIANT_VIOLATION.set_is_entry */
extern void T79f9(GE_context* ac, T0* C, T1 a1);
/* ROUTINE_FAILURE.set_class_name */
extern void T74f10(GE_context* ac, T0* C, T0* a1);
/* ROUTINE_FAILURE.set_routine_name */
extern void T74f9(GE_context* ac, T0* C, T0* a1);
/* ISE_EXCEPTION_MANAGER.exception_from_code */
extern T0* T20f12(GE_context* ac, T0* C, T6 a1);
/* SERIALIZATION_FAILURE.default_create */
extern T0* T102c6(GE_context* ac);
/* OLD_VIOLATION.default_create */
extern T0* T76c6(GE_context* ac);
/* COM_FAILURE.default_create */
extern T0* T83c12(GE_context* ac);
/* ADDRESS_APPLIED_TO_MELTED_FEATURE.default_create */
extern T0* T101c6(GE_context* ac);
/* MISMATCH_FAILURE.default_create */
extern T0* T99c6(GE_context* ac);
/* OPERATING_SYSTEM_FAILURE.default_create */
extern T0* T82c7(GE_context* ac);
/* IO_FAILURE.set_code */
extern void T81f9(GE_context* ac, T0* C, T6 a1);
/* IO_FAILURE.default_create */
extern T0* T81c8(GE_context* ac);
/* EXCEPTION_IN_SIGNAL_HANDLER_FAILURE.default_create */
extern T0* T98c6(GE_context* ac);
/* VOID_ASSIGNED_TO_EXPANDED.default_create */
extern T0* T97c6(GE_context* ac);
/* EXTERNAL_FAILURE.default_create */
extern T0* T96c6(GE_context* ac);
/* CREATE_ON_DEFERRED.default_create */
extern T0* T95c6(GE_context* ac);
/* RESUMPTION_FAILURE.default_create */
extern T0* T94c6(GE_context* ac);
/* RESCUE_FAILURE.default_create */
extern T0* T93c6(GE_context* ac);
/* EIFFEL_RUNTIME_PANIC.set_code */
extern void T84f9(GE_context* ac, T0* C, T6 a1);
/* EIFFEL_RUNTIME_PANIC.code */
extern T6 T84f7(GE_context* ac, T0* C);
/* EIFFEL_RUNTIME_PANIC.default_create */
extern T0* T84c8(GE_context* ac);
/* OPERATING_SYSTEM_SIGNAL_FAILURE.default_create */
extern T0* T80c7(GE_context* ac);
/* LOOP_INVARIANT_VIOLATION.default_create */
extern T0* T92c6(GE_context* ac);
/* VARIANT_VIOLATION.default_create */
extern T0* T91c6(GE_context* ac);
/* BAD_INSPECT_VALUE.default_create */
extern T0* T90c6(GE_context* ac);
/* ROUTINE_FAILURE.default_create */
extern T0* T74c8(GE_context* ac);
/* CHECK_VIOLATION.default_create */
extern T0* T89c6(GE_context* ac);
/* INVARIANT_VIOLATION.default_create */
extern T0* T79c7(GE_context* ac);
/* FLOATING_POINT_FAILURE.default_create */
extern T0* T88c6(GE_context* ac);
/* POSTCONDITION_VIOLATION.default_create */
extern T0* T87c6(GE_context* ac);
/* PRECONDITION_VIOLATION.default_create */
extern T0* T86c6(GE_context* ac);
/* NO_MORE_MEMORY.set_code */
extern void T78f10(GE_context* ac, T0* C, T6 a1);
/* NO_MORE_MEMORY.code */
extern T6 T78f7(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.no_memory_exception_object_cell */
extern T0* T20f7(GE_context* ac, T0* C);
/* CELL [NO_MORE_MEMORY].put */
extern T0* T28c2(GE_context* ac, T0* a1);
/* NO_MORE_MEMORY.default_create */
extern T0* T78c8(GE_context* ac);
/* VOID_TARGET.default_create */
extern T0* T72c6(GE_context* ac);
/* ISE_EXCEPTION_MANAGER.exception_data */
extern T0* T20f11(GE_context* ac, T0* C);
/* CELL [detachable TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN]].put */
extern void T27f2(GE_context* ac, T0* C, T0* a1);
/* CELL [detachable TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN]].put */
extern T0* T27c2(GE_context* ac, T0* a1);
/* ISE_EXCEPTION_MANAGER.exception_data_cell */
extern T0* T20f6(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.once_raise */
extern void T20f15(GE_context* ac, T0* C, T0* a1);
/* ISE_EXCEPTION_MANAGER.last_exception */
extern T0* T20f1(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.init_exception_manager */
extern void T20f14(GE_context* ac, T0* C);
/* CELL [NO_MORE_MEMORY].do_nothing */
extern void T28f3(GE_context* ac, T0* C);
/* CELL [detachable EXCEPTION].do_nothing */
extern void T25f3(GE_context* ac, T0* C);
/* CELL [detachable TUPLE [INTEGER_32, INTEGER_32, INTEGER_32, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, STRING_8, INTEGER_32, BOOLEAN]].do_nothing */
extern void T27f3(GE_context* ac, T0* C);
/* ISE_EXCEPTION_MANAGER.unraisable_exceptions */
extern T0* T20f5(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].force */
extern void T26f37(GE_context* ac, T0* C, T6 a1, T6 a2);
/* HASH_TABLE [INTEGER_32, INTEGER_32].position */
extern T6 T26f22(GE_context* ac, T0* C);
/* SPECIAL [BOOLEAN].force */
extern void T106f5(GE_context* ac, T0* C, T1 a1, T6 a2);
/* HASH_TABLE [INTEGER_32, INTEGER_32].deleted_position */
extern T6 T26f21(GE_context* ac, T0* C, T6 a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].add_space */
extern void T26f39(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].accommodate */
extern void T26f40(GE_context* ac, T0* C, T6 a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].set_indexes_map */
extern void T26f44(GE_context* ac, T0* C, T0* a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].set_deleted_marks */
extern void T26f43(GE_context* ac, T0* C, T0* a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].set_keys */
extern void T26f42(GE_context* ac, T0* C, T0* a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].set_content */
extern void T26f41(GE_context* ac, T0* C, T0* a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].put */
extern void T26f45(GE_context* ac, T0* C, T6 a1, T6 a2);
/* HASH_TABLE [INTEGER_32, INTEGER_32].set_conflict */
extern void T26f47(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].found */
extern T1 T26f31(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].occupied */
extern T1 T26f29(GE_context* ac, T0* C, T6 a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].empty_duplicate */
extern T0* T26f28(GE_context* ac, T0* C, T6 a1);
/* HASH_TABLE [INTEGER_32, INTEGER_32].compare_objects */
extern void T26f46(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].soon_full */
extern T1 T26f20(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].not_found */
extern T1 T26f19(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].internal_search */
extern void T26f38(GE_context* ac, T0* C, T6 a1);
/* ISE_EXCEPTION_MANAGER.unignorable_exceptions */
extern T0* T20f4(GE_context* ac, T0* C);
/* HASH_TABLE [INTEGER_32, INTEGER_32].do_nothing */
extern void T26f36(GE_context* ac, T0* C);
/* KL_TEXT_OUTPUT_FILE.dispose */
extern void T326f25(GE_context* ac, T0* C);
/* MANAGED_POINTER.dispose */
extern void T111f9(GE_context* ac, T0* C);
/* POINTER.memory_free */
extern void T14f9(GE_context* ac, T14* C);
/* POINTER.default_pointer */
extern T14 T14f8(GE_context* ac, T14* C);
/* POINTER.c_free */
extern void T14f12(GE_context* ac, T14* C, T14 a1);
/* KL_TEXT_INPUT_FILE.dispose */
extern void T31f40(GE_context* ac, T0* C);
/* ST_STRING_FORMATTER.set_align_left */
extern void T368f13(GE_context* ac, T0* C);
/* ST_POINTER_FORMATTER.set_align_left */
extern void T367f13(GE_context* ac, T0* C);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_align_left */
extern void T366f20(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_align_left */
extern void T365f20(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_align_left */
extern void T364f20(GE_context* ac, T0* C);
/* ST_DECIMAL_FORMATTER.set_align_left */
extern void T363f20(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_align_left */
extern void T362f26(GE_context* ac, T0* C);
/* ST_FIXED_POINT_FORMATTER.set_align_left */
extern void T361f25(GE_context* ac, T0* C);
/* ST_FLOATING_POINT_FORMATTER.set_align_left */
extern void T360f26(GE_context* ac, T0* C);
/* ST_CHARACTER_FORMATTER.set_align_left */
extern void T359f14(GE_context* ac, T0* C);
/* ST_BOOLEAN_FORMATTER.set_align_left */
extern void T358f17(GE_context* ac, T0* C);
/* ST_STRING_FORMATTER.set_align_center */
extern void T368f14(GE_context* ac, T0* C);
/* ST_POINTER_FORMATTER.set_align_center */
extern void T367f14(GE_context* ac, T0* C);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_align_center */
extern void T366f21(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_align_center */
extern void T365f21(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_align_center */
extern void T364f21(GE_context* ac, T0* C);
/* ST_DECIMAL_FORMATTER.set_align_center */
extern void T363f21(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_align_center */
extern void T362f27(GE_context* ac, T0* C);
/* ST_FIXED_POINT_FORMATTER.set_align_center */
extern void T361f26(GE_context* ac, T0* C);
/* ST_FLOATING_POINT_FORMATTER.set_align_center */
extern void T360f27(GE_context* ac, T0* C);
/* ST_CHARACTER_FORMATTER.set_align_center */
extern void T359f15(GE_context* ac, T0* C);
/* ST_BOOLEAN_FORMATTER.set_align_center */
extern void T358f18(GE_context* ac, T0* C);
/* ST_STRING_FORMATTER.set_padding_character */
extern void T368f15(GE_context* ac, T0* C, T2 a1);
/* ST_POINTER_FORMATTER.set_padding_character */
extern void T367f15(GE_context* ac, T0* C, T2 a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_padding_character */
extern void T366f22(GE_context* ac, T0* C, T2 a1);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_padding_character */
extern void T365f22(GE_context* ac, T0* C, T2 a1);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_padding_character */
extern void T364f22(GE_context* ac, T0* C, T2 a1);
/* ST_DECIMAL_FORMATTER.set_padding_character */
extern void T363f22(GE_context* ac, T0* C, T2 a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_padding_character */
extern void T362f28(GE_context* ac, T0* C, T2 a1);
/* ST_FIXED_POINT_FORMATTER.set_padding_character */
extern void T361f27(GE_context* ac, T0* C, T2 a1);
/* ST_FLOATING_POINT_FORMATTER.set_padding_character */
extern void T360f28(GE_context* ac, T0* C, T2 a1);
/* ST_CHARACTER_FORMATTER.set_padding_character */
extern void T359f16(GE_context* ac, T0* C, T2 a1);
/* ST_BOOLEAN_FORMATTER.set_padding_character */
extern void T358f19(GE_context* ac, T0* C, T2 a1);
/* ST_STRING_FORMATTER.set_space_sign_enabled */
extern void T368f16(GE_context* ac, T0* C, T1 a1);
/* ST_POINTER_FORMATTER.set_space_sign_enabled */
extern void T367f16(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_space_sign_enabled */
extern void T366f23(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_space_sign_enabled */
extern void T365f23(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_space_sign_enabled */
extern void T364f23(GE_context* ac, T0* C, T1 a1);
/* ST_DECIMAL_FORMATTER.set_space_sign_enabled */
extern void T363f23(GE_context* ac, T0* C, T1 a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_space_sign_enabled */
extern void T362f29(GE_context* ac, T0* C, T1 a1);
/* ST_FIXED_POINT_FORMATTER.set_space_sign_enabled */
extern void T361f28(GE_context* ac, T0* C, T1 a1);
/* ST_FLOATING_POINT_FORMATTER.set_space_sign_enabled */
extern void T360f29(GE_context* ac, T0* C, T1 a1);
/* ST_CHARACTER_FORMATTER.set_space_sign_enabled */
extern void T359f17(GE_context* ac, T0* C, T1 a1);
/* ST_BOOLEAN_FORMATTER.set_space_sign_enabled */
extern void T358f20(GE_context* ac, T0* C, T1 a1);
/* ST_STRING_FORMATTER.set_plus_sign_enabled */
extern void T368f17(GE_context* ac, T0* C, T1 a1);
/* ST_POINTER_FORMATTER.set_plus_sign_enabled */
extern void T367f17(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_plus_sign_enabled */
extern void T366f24(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_plus_sign_enabled */
extern void T365f24(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_plus_sign_enabled */
extern void T364f24(GE_context* ac, T0* C, T1 a1);
/* ST_DECIMAL_FORMATTER.set_plus_sign_enabled */
extern void T363f24(GE_context* ac, T0* C, T1 a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_plus_sign_enabled */
extern void T362f30(GE_context* ac, T0* C, T1 a1);
/* ST_FIXED_POINT_FORMATTER.set_plus_sign_enabled */
extern void T361f29(GE_context* ac, T0* C, T1 a1);
/* ST_FLOATING_POINT_FORMATTER.set_plus_sign_enabled */
extern void T360f30(GE_context* ac, T0* C, T1 a1);
/* ST_CHARACTER_FORMATTER.set_plus_sign_enabled */
extern void T359f18(GE_context* ac, T0* C, T1 a1);
/* ST_BOOLEAN_FORMATTER.set_plus_sign_enabled */
extern void T358f21(GE_context* ac, T0* C, T1 a1);
/* ST_STRING_FORMATTER.set_width */
extern void T368f18(GE_context* ac, T0* C, T6 a1);
/* ST_POINTER_FORMATTER.set_width */
extern void T367f18(GE_context* ac, T0* C, T6 a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_width */
extern void T366f25(GE_context* ac, T0* C, T6 a1);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_width */
extern void T365f25(GE_context* ac, T0* C, T6 a1);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_width */
extern void T364f25(GE_context* ac, T0* C, T6 a1);
/* ST_DECIMAL_FORMATTER.set_width */
extern void T363f25(GE_context* ac, T0* C, T6 a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_width */
extern void T362f31(GE_context* ac, T0* C, T6 a1);
/* ST_FIXED_POINT_FORMATTER.set_width */
extern void T361f30(GE_context* ac, T0* C, T6 a1);
/* ST_FLOATING_POINT_FORMATTER.set_width */
extern void T360f31(GE_context* ac, T0* C, T6 a1);
/* ST_CHARACTER_FORMATTER.set_width */
extern void T359f19(GE_context* ac, T0* C, T6 a1);
/* ST_BOOLEAN_FORMATTER.set_width */
extern void T358f22(GE_context* ac, T0* C, T6 a1);
/* ST_STRING_FORMATTER.set_precision */
extern void T368f19(GE_context* ac, T0* C, T6 a1);
/* ST_POINTER_FORMATTER.set_precision */
extern void T367f19(GE_context* ac, T0* C, T6 a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_precision */
extern void T366f26(GE_context* ac, T0* C, T6 a1);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_precision */
extern void T365f26(GE_context* ac, T0* C, T6 a1);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_precision */
extern void T364f26(GE_context* ac, T0* C, T6 a1);
/* ST_DECIMAL_FORMATTER.set_precision */
extern void T363f26(GE_context* ac, T0* C, T6 a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_precision */
extern void T362f32(GE_context* ac, T0* C, T6 a1);
/* ST_FIXED_POINT_FORMATTER.set_precision */
extern void T361f31(GE_context* ac, T0* C, T6 a1);
/* ST_FLOATING_POINT_FORMATTER.set_precision */
extern void T360f32(GE_context* ac, T0* C, T6 a1);
/* ST_CHARACTER_FORMATTER.set_precision */
extern void T359f20(GE_context* ac, T0* C, T6 a1);
/* ST_BOOLEAN_FORMATTER.set_precision */
extern void T358f23(GE_context* ac, T0* C, T6 a1);
/* ST_STRING_FORMATTER.format_to */
extern void T368f20(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T368f20ot1(T0* a1, T0** a2);
/* ST_STRING_FORMATTER.string_format_to */
extern void T368f23(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_STRING_FORMATTER.justify_format_to */
extern void T368f25(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_STRING_FORMATTER.center_format_to */
extern void T368f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_STRING_FORMATTER.right_format_to */
extern void T368f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_STRING_FORMATTER.left_format_to */
extern void T368f26(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_POINTER_FORMATTER.format_to */
extern void T367f20(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_POINTER_FORMATTER.pointer_format_to */
extern void T367f23(GE_context* ac, T0* C, T14 a1, T0* a2);
/* ST_POINTER_FORMATTER.justify_format_to */
extern void T367f25(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_POINTER_FORMATTER.center_format_to */
extern void T367f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_POINTER_FORMATTER.right_format_to */
extern void T367f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_POINTER_FORMATTER.left_format_to */
extern void T367f26(GE_context* ac, T0* C, T0* a1, T0* a2);
/* POINTER.out */
extern T0* T14f4(GE_context* ac, T14* C);
/* ST_UNSIGNED_DECIMAL_FORMATTER.format_to */
extern void T366f27(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T366f27ot1(T0* a1, T0** a2);
/* ST_UNSIGNED_DECIMAL_FORMATTER.integer_format_to */
extern void T366f30(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_DECIMAL_FORMATTER.integer_format_to */
extern void T366f30p1(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_DECIMAL_FORMATTER.justify_format_to */
extern void T366f37(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_DECIMAL_FORMATTER.center_format_to */
extern void T366f36(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_DECIMAL_FORMATTER.right_format_to */
extern void T366f35(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_DECIMAL_FORMATTER.left_format_to */
extern void T366f34(GE_context* ac, T0* C, T0* a1, T0* a2);
/* STRING_8.precede */
extern void T17f57(GE_context* ac, T0* C, T2 a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.append_to_string */
extern void T366f33(GE_context* ac, T0* C, T6 a1, T0* a2);
/* INTEGER_32.abs */
extern T6 T6f24(GE_context* ac, T6* C);
/* INTEGER_32.abs_ref */
extern T6 T6f28(GE_context* ac, T6* C);
/* ST_UNSIGNED_DECIMAL_FORMATTER.append_abs_to_string */
extern void T366f32(GE_context* ac, T0* C, T6 a1, T0* a2);
/* KL_INTEGER_ROUTINES.mod */
extern T6 T410f3(GE_context* ac, T0* C, T6 a1, T6 a2);
/* KL_INTEGER_ROUTINES.div */
extern T6 T410f2(GE_context* ac, T0* C, T6 a1, T6 a2);
/* ST_UNSIGNED_DECIMAL_FORMATTER.integer_ */
extern T0* T366f15(GE_context* ac, T0* C);
/* KL_INTEGER_ROUTINES.default_create */
extern T0* T410c6(GE_context* ac);
/* KL_PLATFORM.minimum_integer */
extern T6 T425f1(GE_context* ac, T0* C);
/* ST_UNSIGNED_DECIMAL_FORMATTER.platform */
extern T0* T366f13(GE_context* ac, T0* C);
/* KL_PLATFORM.default_create */
extern T0* T425c2(GE_context* ac);
/* KL_STRING_ROUTINES.wipe_out */
extern void T108f9(GE_context* ac, T0* C, T0* a1);
/* STRING_8.keep_head */
extern void T17f54(GE_context* ac, T0* C, T6 a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.string_ */
extern T0* T366f12(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.format_to */
extern void T365f27(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T365f27ot1(T0* a1, T0** a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.integer_format_to */
extern void T365f30(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.integer_format_to */
extern void T365f30p1(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.justify_format_to */
extern void T365f37(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.center_format_to */
extern void T365f36(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.right_format_to */
extern void T365f35(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.left_format_to */
extern void T365f34(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.append_to_string */
extern void T365f33(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.append_abs_to_string */
extern void T365f32(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.integer_ */
extern T0* T365f15(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.platform */
extern T0* T365f13(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.string_ */
extern T0* T365f12(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.format_to */
extern void T364f27(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T364f27ot1(T0* a1, T0** a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.integer_format_to */
extern void T364f30(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.integer_format_to */
extern void T364f30p1(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.justify_format_to */
extern void T364f37(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.center_format_to */
extern void T364f36(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.right_format_to */
extern void T364f35(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.left_format_to */
extern void T364f34(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.append_to_string */
extern void T364f33(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.append_abs_to_string */
extern void T364f32(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.integer_ */
extern T0* T364f15(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.platform */
extern T0* T364f13(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.string_ */
extern T0* T364f12(GE_context* ac, T0* C);
/* ST_DECIMAL_FORMATTER.format_to */
extern void T363f27(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T363f27ot1(T0* a1, T0** a2);
/* ST_DECIMAL_FORMATTER.integer_format_to */
extern void T363f30(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_DECIMAL_FORMATTER.justify_format_to */
extern void T363f37(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_DECIMAL_FORMATTER.center_format_to */
extern void T363f36(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_DECIMAL_FORMATTER.right_format_to */
extern void T363f35(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_DECIMAL_FORMATTER.left_format_to */
extern void T363f34(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_DECIMAL_FORMATTER.append_to_string */
extern void T363f33(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_DECIMAL_FORMATTER.append_abs_to_string */
extern void T363f32(GE_context* ac, T0* C, T6 a1, T0* a2);
/* ST_DECIMAL_FORMATTER.integer_ */
extern T0* T363f15(GE_context* ac, T0* C);
/* ST_DECIMAL_FORMATTER.platform */
extern T0* T363f13(GE_context* ac, T0* C);
/* ST_DECIMAL_FORMATTER.string_ */
extern T0* T363f12(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.format_to */
extern void T362f33(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T362f33ot1(T0* a1, T0** a2);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.double_format_to */
extern void T362f36(GE_context* ac, T0* C, T13 a1, T0* a2);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.double_format_to */
extern void T362f36p0(GE_context* ac, T0* C, T13 a1, T0* a2);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.center_format_to */
extern void T362f42(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_DECIMAL_FORMATTER.set_align_right */
extern void T363f31(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.right_format_to */
extern void T362f41(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.left_format_to */
extern void T362f40(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.string_ */
extern T0* T362f21(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.build_integer_and_fractional_parts */
extern void T362f38(GE_context* ac, T0* C, T13 a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.append_integer_to_string */
extern void T362f43(GE_context* ac, T0* C, T6 a1, T6 a2, T0* a3);
/* DS_ARRAYED_LIST [INTEGER_32].replace */
extern void T423f13(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_ARRAYED_LIST [INTEGER_32].item */
extern T6 T423f9(GE_context* ac, T0* C, T6 a1);
/* KL_DOUBLE_ROUTINES.truncated_to_integer */
extern T6 T424f4(GE_context* ac, T0* C, T13 a1);
/* KL_DOUBLE_ROUTINES.rounded_to_integer */
extern T6 T424f3(GE_context* ac, T0* C, T13 a1);
/* REAL_64.rounded */
extern T6 T13f15(GE_context* ac, T13* C);
/* REAL_64.sign */
extern T6 T13f16(GE_context* ac, T13* C);
/* REAL_64.is_greater */
extern T1 T13f4(GE_context* ac, T13* C, T13 a1);
/* REAL_64.floor */
extern T6 T13f9(GE_context* ac, T13* C);
/* DS_ARRAYED_LIST [INTEGER_32].force_last */
extern void T423f12(GE_context* ac, T0* C, T6 a1);
/* DS_ARRAYED_LIST [INTEGER_32].resize */
extern void T423f16(GE_context* ac, T0* C, T6 a1);
/* DS_ARRAYED_LIST [INTEGER_32].new_capacity */
extern T6 T423f8(GE_context* ac, T0* C, T6 a1);
/* DS_ARRAYED_LIST [INTEGER_32].extendible */
extern T1 T423f7(GE_context* ac, T0* C, T6 a1);
/* DS_ARRAYED_LIST [INTEGER_32].wipe_out */
extern void T423f11(GE_context* ac, T0* C);
/* DS_ARRAYED_LIST [INTEGER_32].move_all_cursors_after */
extern void T423f15(GE_context* ac, T0* C);
/* DS_ARRAYED_LIST_CURSOR [INTEGER_32].set_next_cursor */
extern void T443f7(GE_context* ac, T0* C, T0* a1);
/* DS_ARRAYED_LIST_CURSOR [INTEGER_32].set_after */
extern void T443f6(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.double_format_to */
extern void T362f36p1(GE_context* ac, T0* C, T13 a1, T0* a2);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.justify_format_to */
extern void T362f39(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.ten_power */
extern T13 T362f20(GE_context* ac, T0* C, T6 a1);
/* KL_DOUBLE_ROUTINES.floor_to_integer */
extern T6 T424f2(GE_context* ac, T0* C, T13 a1);
/* KL_DOUBLE_ROUTINES.log10 */
extern T13 T424f1(GE_context* ac, T0* C, T13 a1);
/* KL_DOUBLE_ROUTINES.old_log10 */
extern T13 T424f5(GE_context* ac, T0* C, T13 a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.double_ */
extern T0* T362f18(GE_context* ac, T0* C);
/* KL_DOUBLE_ROUTINES.default_create */
extern T0* T424c6(GE_context* ac);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.double_sign */
extern T6 T362f17(GE_context* ac, T0* C, T13 a1);
/* REAL_64.abs */
extern T13 T13f6(GE_context* ac, T13* C);
/* REAL_64.abs_ref */
extern T13 T13f10(GE_context* ac, T13* C);
/* REAL_64.zero */
extern T13 T13f14(GE_context* ac, T13* C);
/* REAL_64.default_create */
extern T13 T13c18(GE_context* ac);
/* ST_FIXED_POINT_FORMATTER.format_to */
extern void T361f32(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T361f32ot1(T0* a1, T0** a2);
/* ST_FIXED_POINT_FORMATTER.double_format_to */
extern void T361f35(GE_context* ac, T0* C, T13 a1, T0* a2);
/* ST_FIXED_POINT_FORMATTER.center_format_to */
extern void T361f40(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FIXED_POINT_FORMATTER.right_format_to */
extern void T361f39(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FIXED_POINT_FORMATTER.left_format_to */
extern void T361f38(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FIXED_POINT_FORMATTER.string_ */
extern T0* T361f17(GE_context* ac, T0* C);
/* ST_FIXED_POINT_FORMATTER.build_integer_and_fractional_parts */
extern void T361f37(GE_context* ac, T0* C, T13 a1);
/* ST_FIXED_POINT_FORMATTER.append_integer_to_string */
extern void T361f41(GE_context* ac, T0* C, T6 a1, T6 a2, T0* a3);
/* ST_FIXED_POINT_FORMATTER.double_ */
extern T0* T361f22(GE_context* ac, T0* C);
/* ST_FIXED_POINT_FORMATTER.double_sign */
extern T6 T361f21(GE_context* ac, T0* C, T13 a1);
/* ST_FLOATING_POINT_FORMATTER.format_to */
extern void T360f33(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T360f33ot1(T0* a1, T0** a2);
/* ST_FLOATING_POINT_FORMATTER.double_format_to */
extern void T360f36(GE_context* ac, T0* C, T13 a1, T0* a2);
/* ST_FLOATING_POINT_FORMATTER.justify_format_to */
extern void T360f39(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FLOATING_POINT_FORMATTER.center_format_to */
extern void T360f43(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FLOATING_POINT_FORMATTER.right_format_to */
extern void T360f42(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FLOATING_POINT_FORMATTER.left_format_to */
extern void T360f41(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_FLOATING_POINT_FORMATTER.string_ */
extern T0* T360f21(GE_context* ac, T0* C);
/* ST_FLOATING_POINT_FORMATTER.build_integer_and_fractional_parts */
extern void T360f38(GE_context* ac, T0* C, T13 a1);
/* ST_FLOATING_POINT_FORMATTER.append_integer_to_string */
extern void T360f40(GE_context* ac, T0* C, T6 a1, T6 a2, T0* a3);
/* ST_FLOATING_POINT_FORMATTER.ten_power */
extern T13 T360f20(GE_context* ac, T0* C, T6 a1);
/* ST_FLOATING_POINT_FORMATTER.double_ */
extern T0* T360f19(GE_context* ac, T0* C);
/* ST_FLOATING_POINT_FORMATTER.double_sign */
extern T6 T360f18(GE_context* ac, T0* C, T13 a1);
/* ST_CHARACTER_FORMATTER.format_to */
extern void T359f21(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_CHARACTER_FORMATTER.character_format_to */
extern void T359f24(GE_context* ac, T0* C, T2 a1, T0* a2);
/* ST_CHARACTER_FORMATTER.justify_format_to */
extern void T359f26(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_CHARACTER_FORMATTER.center_format_to */
extern void T359f29(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_CHARACTER_FORMATTER.right_format_to */
extern void T359f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_CHARACTER_FORMATTER.left_format_to */
extern void T359f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_BOOLEAN_FORMATTER.format_to */
extern void T358f24(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_BOOLEAN_FORMATTER.boolean_format_to */
extern void T358f27(GE_context* ac, T0* C, T1 a1, T0* a2);
/* ST_BOOLEAN_FORMATTER.justify_format_to */
extern void T358f29(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_BOOLEAN_FORMATTER.center_format_to */
extern void T358f32(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_BOOLEAN_FORMATTER.right_format_to */
extern void T358f31(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_BOOLEAN_FORMATTER.left_format_to */
extern void T358f30(GE_context* ac, T0* C, T0* a1, T0* a2);
/* ST_STRING_FORMATTER.reset_options */
extern void T368f21(GE_context* ac, T0* C);
/* ST_STRING_FORMATTER.reset_options */
extern void T368f21p1(GE_context* ac, T0* C);
/* ST_STRING_FORMATTER.set_align_right */
extern void T368f24(GE_context* ac, T0* C);
/* ST_POINTER_FORMATTER.reset_options */
extern void T367f21(GE_context* ac, T0* C);
/* ST_POINTER_FORMATTER.set_align_right */
extern void T367f24(GE_context* ac, T0* C);
/* ST_UNSIGNED_DECIMAL_FORMATTER.reset_options */
extern void T366f28(GE_context* ac, T0* C);
/* ST_UNSIGNED_DECIMAL_FORMATTER.reset_options */
extern void T366f28p1(GE_context* ac, T0* C);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_align_right */
extern void T366f31(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.reset_options */
extern void T365f28(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.reset_options */
extern void T365f28p1(GE_context* ac, T0* C);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_align_right */
extern void T365f31(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.reset_options */
extern void T364f28(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.reset_options */
extern void T364f28p1(GE_context* ac, T0* C);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_align_right */
extern void T364f31(GE_context* ac, T0* C);
/* ST_DECIMAL_FORMATTER.reset_options */
extern void T363f28(GE_context* ac, T0* C);
/* ST_DECIMAL_FORMATTER.reset_options */
extern void T363f28p1(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.reset_options */
extern void T362f34(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.reset_options */
extern void T362f34p1(GE_context* ac, T0* C);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_align_right */
extern void T362f37(GE_context* ac, T0* C);
/* ST_FIXED_POINT_FORMATTER.reset_options */
extern void T361f33(GE_context* ac, T0* C);
/* ST_FIXED_POINT_FORMATTER.reset_options */
extern void T361f33p1(GE_context* ac, T0* C);
/* ST_FIXED_POINT_FORMATTER.set_align_right */
extern void T361f36(GE_context* ac, T0* C);
/* ST_FLOATING_POINT_FORMATTER.reset_options */
extern void T360f34(GE_context* ac, T0* C);
/* ST_FLOATING_POINT_FORMATTER.reset_options */
extern void T360f34p1(GE_context* ac, T0* C);
/* ST_FLOATING_POINT_FORMATTER.set_align_right */
extern void T360f37(GE_context* ac, T0* C);
/* ST_CHARACTER_FORMATTER.reset_options */
extern void T359f22(GE_context* ac, T0* C);
/* ST_CHARACTER_FORMATTER.set_align_right */
extern void T359f25(GE_context* ac, T0* C);
/* ST_BOOLEAN_FORMATTER.reset_options */
extern void T358f25(GE_context* ac, T0* C);
/* ST_BOOLEAN_FORMATTER.set_align_right */
extern void T358f28(GE_context* ac, T0* C);
/* ST_STRING_FORMATTER.set_lowercase */
extern void T368f22(GE_context* ac, T0* C, T1 a1);
/* ST_POINTER_FORMATTER.set_lowercase */
extern void T367f22(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.set_lowercase */
extern void T366f29(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.set_lowercase */
extern void T365f29(GE_context* ac, T0* C, T1 a1);
/* ST_UNSIGNED_OCTAL_FORMATTER.set_lowercase */
extern void T364f29(GE_context* ac, T0* C, T1 a1);
/* ST_DECIMAL_FORMATTER.set_lowercase */
extern void T363f29(GE_context* ac, T0* C, T1 a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.set_lowercase */
extern void T362f35(GE_context* ac, T0* C, T1 a1);
/* ST_FIXED_POINT_FORMATTER.set_lowercase */
extern void T361f34(GE_context* ac, T0* C, T1 a1);
/* ST_FLOATING_POINT_FORMATTER.set_lowercase */
extern void T360f35(GE_context* ac, T0* C, T1 a1);
/* ST_CHARACTER_FORMATTER.set_lowercase */
extern void T359f23(GE_context* ac, T0* C, T1 a1);
/* ST_BOOLEAN_FORMATTER.set_lowercase */
extern void T358f26(GE_context* ac, T0* C, T1 a1);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].set */
extern void T408f14(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.set */
extern void T387f14(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].set */
extern void T386f15(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].set */
extern void T338f13(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].set_current_cell */
extern void T408f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.set_current_cell */
extern void T387f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].set_current_cell */
extern void T386f18(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].set_current_cell */
extern void T338f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].set_after */
extern void T408f16(GE_context* ac, T0* C);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.set_after */
extern void T387f16(GE_context* ac, T0* C);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].set_after */
extern void T386f17(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].set_after */
extern void T338f15(GE_context* ac, T0* C);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].set_next_cursor */
extern void T408f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.set_next_cursor */
extern void T387f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].set_next_cursor */
extern void T386f16(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].set_next_cursor */
extern void T338f14(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_value */
extern void T67f27(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_type */
extern void T67f22(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.dump_columns */
extern void T67f36(GE_context* ac, T0* C, T0* a1);
extern T1 T67f36ot1(T0* a1, T0** a2);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.forth */
extern void T387f12(GE_context* ac, T0* C);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.is_not_virtual_attribute */
extern T1 T387f8(GE_context* ac, T0* C);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.forth */
extern void T387f12p1(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].cursor_forth */
extern void T337f22(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].add_traversing_cursor */
extern void T337f23(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].remove_traversing_cursor */
extern void T337f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.item */
extern T0* T387f7(GE_context* ac, T0* C);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.start */
extern void T387f11(GE_context* ac, T0* C);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.start */
extern void T387f11p1(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].cursor_start */
extern void T337f21(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].cursor_off */
extern T1 T337f12(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].is_empty */
extern T1 T337f7(GE_context* ac, T0* C);
/* XML_WRITER.set_attribute */
extern void T325f36(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XML_WRITER.make_valid_attribute_value */
extern T0* T325f13(GE_context* ac, T0* C, T0* a1);
/* STRING_8.insert_string */
extern void T17f61(GE_context* ac, T0* C, T0* a1, T6 a2);
/* XML_WRITER.do_set_attribute */
extern void T325f37(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XML_WRITER.add_attribute */
extern void T325f39(GE_context* ac, T0* C, T0* a1);
/* [attached] ARRAY [[attached] STRING_8].put */
extern void T35f9(GE_context* ac, T0* C, T0* a1, T6 a2);
/* [attached] ARRAY [[attached] STRING_8].resize */
extern void T35f11(GE_context* ac, T0* C, T6 a1, T6 a2);
/* [attached] ARRAY [[attached] STRING_8].conservative_resize_with_default */
extern void T35f10(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [[attached] STRING_8].move_data */
extern void T36f13(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* SPECIAL [[attached] STRING_8].overlapping_move */
extern void T36f15(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* SPECIAL [[attached] STRING_8].force */
extern void T36f16(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [[attached] STRING_8].non_overlapping_move */
extern void T36f14(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* [attached] ARRAY [[attached] STRING_8].set_area */
extern void T35f12(GE_context* ac, T0* C, T0* a1);
/* SPECIAL [[attached] STRING_8].aliased_resized_area_with_default */
extern T0* T36f5(GE_context* ac, T0* C, T0* a1, T6 a2);
/* [attached] ARRAY [[attached] STRING_8].empty_area */
extern T1 T35f6(GE_context* ac, T0* C);
/* [attached] ARRAY [[attached] STRING_8].count */
extern T6 T35f5(GE_context* ac, T0* C);
/* XML_WRITER.set_value */
extern void T325f38(GE_context* ac, T0* C, T0* a1);
/* XML_WRITER.exist_attribute */
extern T1 T325f14(GE_context* ac, T0* C, T0* a1);
/* XML_WRITER.string_ */
extern T0* T325f22(GE_context* ac, T0* C);
/* XML_GENERATOR.set_sp_name */
extern void T67f35(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XML_GENERATOR.as_c_string */
extern T0* T67f8(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.as_some_string */
extern T0* T67f11(GE_context* ac, T0* C, T0* a1, T2 a2);
/* STRING_8.index_of */
extern T6 T17f28(GE_context* ac, T0* C, T2 a1, T6 a2);
/* XML_GENERATOR.as_eiffel_string */
extern T0* T67f7(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.set_names */
extern void T67f34(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3, T0* a4, T0* a5, T0* a6);
/* XML_GENERATOR.as_ncname */
extern T0* T67f5(GE_context* ac, T0* C, T0* a1);
/* UC_STRING.as_string */
extern T0* T370f10(GE_context* ac, T0* C);
/* UC_STRING.to_utf8 */
extern T0* T370f8(GE_context* ac, T0* C);
/* UC_STRING.byte_item */
extern T2 T370f13(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.old_item */
extern T2 T370f9(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.set_count */
extern void T370f21(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.reset_byte_index_cache */
extern void T370f29(GE_context* ac, T0* C);
/* UC_STRING.insert_character */
extern void T370f20(GE_context* ac, T0* C, T2 a1, T6 a2);
/* UC_STRING.put_character_at_byte_index */
extern void T370f27(GE_context* ac, T0* C, T2 a1, T6 a2, T6 a3);
/* UC_STRING.put_code_at_byte_index */
extern void T370f34(GE_context* ac, T0* C, T6 a1, T6 a2, T6 a3);
/* KL_INTEGER_ROUTINES.to_character */
extern T2 T410f5(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.integer_ */
extern T0* T370f17(GE_context* ac, T0* C);
/* UC_STRING.put_byte */
extern void T370f31(GE_context* ac, T0* C, T2 a1, T6 a2);
/* UC_STRING.old_put */
extern void T370f32(GE_context* ac, T0* C, T2 a1, T6 a2);
/* UC_STRING.reset_hash_codes */
extern void T370f35(GE_context* ac, T0* C);
/* UC_STRING.move_bytes_right */
extern void T370f26(GE_context* ac, T0* C, T6 a1, T6 a2);
/* UC_STRING.resize_byte_storage */
extern void T370f25(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.old_set_count */
extern void T370f30(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.resize */
extern void T370f33(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.byte_capacity */
extern T6 T370f14(GE_context* ac, T0* C);
/* UC_STRING.capacity */
extern T6 T370f14p1(GE_context* ac, T0* C);
/* UC_UTF8_ROUTINES.character_byte_count */
extern T6 T450f4(GE_context* ac, T0* C, T2 a1);
/* UC_STRING.utf8 */
extern T0* T370f12(GE_context* ac, T0* C);
/* UC_UTF8_ROUTINES.default_create */
extern T0* T450c10(GE_context* ac);
/* UC_STRING.byte_index */
extern T6 T370f15(GE_context* ac, T0* C, T6 a1);
/* UC_UTF8_ROUTINES.encoded_byte_count */
extern T6 T450f1(GE_context* ac, T0* C, T2 a1);
/* UC_STRING.append_character */
extern void T370f28(GE_context* ac, T0* C, T2 a1);
/* XML_GENERATOR.is_name_first */
extern T1 T67f10(GE_context* ac, T0* C, T6 a1);
/* XML_GENERATOR.is_letter */
extern T1 T67f15(GE_context* ac, T0* C, T6 a1);
/* XML_GENERATOR.is_ideographic */
extern T1 T67f17(GE_context* ac, T0* C, T6 a1);
/* XML_GENERATOR.is_base_char */
extern T1 T67f16(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.put */
extern void T370f19(GE_context* ac, T0* C, T2 a1, T6 a2);
/* UC_STRING.move_bytes_left */
extern void T370f24(GE_context* ac, T0* C, T6 a1, T6 a2);
/* XML_GENERATOR.is_name_char */
extern T1 T67f9(GE_context* ac, T0* C, T6 a1);
/* XML_GENERATOR.is_extender */
extern T1 T67f14(GE_context* ac, T0* C, T6 a1);
/* XML_GENERATOR.is_combining_char */
extern T1 T67f13(GE_context* ac, T0* C, T6 a1);
/* XML_GENERATOR.is_digit */
extern T1 T67f12(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.item_code */
extern T6 T370f11(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.item_code_at_byte_index */
extern T6 T370f16(GE_context* ac, T0* C, T6 a1);
/* UC_UTF8_ROUTINES.encoded_next_value */
extern T6 T450f3(GE_context* ac, T0* C, T2 a1);
/* UC_UTF8_ROUTINES.encoded_first_value */
extern T6 T450f2(GE_context* ac, T0* C, T2 a1);
/* UC_STRING.make_from_utf8 */
extern T0* T370c18(GE_context* ac, T0* a1);
/* UC_STRING.append_utf8 */
extern void T370f23(GE_context* ac, T0* C, T0* a1);
/* UC_STRING.make */
extern void T370f22(GE_context* ac, T0* C, T6 a1);
/* UC_STRING.make */
extern void T370f22p1(GE_context* ac, T0* C, T6 a1);
/* XML_GENERATOR.code_common_identifier */
extern T0* T67f6(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_insert */
extern void T67f23(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XML_GENERATOR.write_get_insert */
extern void T67f24(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_TSQL65.write_get_insert */
extern void T64f337(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_TSQL65.create_get_insert */
extern void T64f338(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* XPLAIN_PK_I_REPRESENTATION.write_with_quotes */
extern T1 T249f13(GE_context* ac, T0* C);
/* XPLAIN_PK_A_REPRESENTATION.write_with_quotes */
extern T1 T246f14(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.do_create_select_list */
extern void T64f339(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_TSQL65.commandseparator */
extern T0* T64f42(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_NAME.q_sql_select_name */
extern T0* T138f11(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_do_create_select_list */
extern void T64f340(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_TSQL65.create_predicate */
extern void T64f302(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sql_predicate */
extern T0* T64f96(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sql_select_joins */
extern T0* T64f59(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_select_joins_oldstyle */
extern T0* T64f144(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.equal */
extern T1 T64f182(GE_context* ac, T0* C, T0* a1, T0* a2);
/* JOIN_LIST.first */
extern T0* T329f10(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sql_select_joins_ansi92 */
extern T0* T64f143(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.string_ */
extern T0* T64f181(GE_context* ac, T0* C);
/* JOIN.is_inner_join */
extern T1 T401f10(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.ansi92joinssupported */
extern T1 T64f142(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_LIST.show_only_identifier_column */
extern T1 T161f7(GE_context* ac, T0* C);
extern T1 T161f7ot1(T0* a1, T0** a2);
/* JOIN_LIST.finalize */
extern void T329f13(GE_context* ac, T0* C, T0* a1);
/* JOIN_TREE_NODE.generate_join_nodes */
extern T0* T416f11(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* DS_LINKED_LIST [JOIN_TREE_NODE].forth */
extern void T417f15(GE_context* ac, T0* C);
/* DS_LINKED_LIST [JOIN_TREE_NODE].cursor_forth */
extern void T417f19(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [JOIN_TREE_NODE].add_traversing_cursor */
extern void T417f20(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [JOIN_TREE_NODE].set_next_cursor */
extern void T442f9(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [JOIN_TREE_NODE].remove_traversing_cursor */
extern void T417f21(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [JOIN_TREE_NODE].set */
extern void T442f8(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* JOIN_NODE.set_next */
extern void T330f5(GE_context* ac, T0* C, T0* a1);
/* JOIN_NODE.last */
extern T0* T330f3(GE_context* ac, T0* C);
/* DS_LINKED_LIST [JOIN_TREE_NODE].item_for_iteration */
extern T0* T417f9(GE_context* ac, T0* C);
/* DS_LINKED_LIST [JOIN_TREE_NODE].cursor_item */
extern T0* T417f8(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [JOIN_TREE_NODE].after */
extern T1 T417f6(GE_context* ac, T0* C);
/* DS_LINKED_LIST [JOIN_TREE_NODE].cursor_after */
extern T1 T417f7(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [JOIN_TREE_NODE].start */
extern void T417f14(GE_context* ac, T0* C);
/* DS_LINKED_LIST [JOIN_TREE_NODE].cursor_start */
extern void T417f18(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [JOIN_TREE_NODE].cursor_off */
extern T1 T417f12(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [JOIN_TREE_NODE].off */
extern T1 T442f6(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].wipe_out */
extern void T439f33(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].slots_wipe_out */
extern void T439f43(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].clashes_wipe_out */
extern void T439f42(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].key_storage_wipe_out */
extern void T439f41(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].item_storage_wipe_out */
extern void T439f40(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].unset_found_item */
extern void T439f39(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].move_all_cursors_after */
extern void T439f38(GE_context* ac, T0* C);
/* detachable DS_HASH_TABLE_CURSOR [INTEGER_32, XPLAIN_TYPE].set_next_cursor */
extern void T455f8(GE_context* ac, T0* C, T0* a1);
/* detachable DS_HASH_TABLE_CURSOR [INTEGER_32, XPLAIN_TYPE].set_after */
extern void T455f7(GE_context* ac, T0* C);
/* JOIN_TREE_NODE.table_counter */
extern T0* T416f12(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].make */
extern T0* T439c32(GE_context* ac, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].make_with_equality_testers */
extern void T439f37(GE_context* ac, T0* C, T6 a1, T0* a2, T0* a3);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].make_sparse_container */
extern void T439f49(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].set_internal_cursor */
extern void T439f54(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].new_cursor */
extern T0* T439f30(GE_context* ac, T0* C);
/* detachable DS_HASH_TABLE_CURSOR [INTEGER_32, XPLAIN_TYPE].make */
extern T0* T455c6(GE_context* ac, T0* a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].make_slots */
extern void T439f53(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].new_modulus */
extern T6 T439f29(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].make_clashes */
extern void T439f52(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].make_key_storage */
extern void T439f51(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].make_item_storage */
extern void T439f50(GE_context* ac, T0* C, T6 a1);
/* detachable KL_EQUALITY_TESTER [XPLAIN_TYPE].default_create */
extern T0* T453c2(GE_context* ac);
/* JOIN_TREE_NODE.set_prefix_table */
extern void T416f18(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].forth */
extern void T440f14(GE_context* ac, T0* C);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].cursor_forth */
extern void T440f17(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].add_traversing_cursor */
extern void T440f18(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME_NODE].set_next_cursor */
extern void T456f9(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].remove_traversing_cursor */
extern void T440f19(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME_NODE].set */
extern void T456f8(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].item_for_iteration */
extern T0* T440f7(GE_context* ac, T0* C);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].cursor_item */
extern T0* T440f5(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].after */
extern T1 T440f8(GE_context* ac, T0* C);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].cursor_after */
extern T1 T440f9(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].start */
extern void T440f13(GE_context* ac, T0* C);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].cursor_start */
extern void T440f16(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].cursor_off */
extern T1 T440f10(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME_NODE].off */
extern T1 T456f6(GE_context* ac, T0* C);
/* JOIN_TREE_NODE.increment_usage */
extern void T416f17(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].put */
extern void T439f36(GE_context* ac, T0* C, T6 a1, T0* a2);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].key_storage_put */
extern void T439f48(GE_context* ac, T0* C, T0* a1, T6 a2);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].slots_put */
extern void T439f47(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].clashes_put */
extern void T439f46(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].slots_item */
extern T6 T439f22(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].clashes_item */
extern T6 T439f20(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].item_storage_put */
extern void T439f45(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].search_position */
extern void T439f44(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].hash_position */
extern T6 T439f25(GE_context* ac, T0* C, T0* a1);
/* detachable KL_EQUALITY_TESTER [XPLAIN_TYPE].test */
extern T1 T453f1(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T453f1oe1(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.is_equal */
extern T1 T143f42(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.is_equal */
extern T1 T157f39(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.is_equal */
extern T1 T129f29(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].key_storage_item */
extern T0* T439f24(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].replace */
extern void T439f35(GE_context* ac, T0* C, T6 a1, T0* a2);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].found_item */
extern T6 T439f27(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].item_storage_item */
extern T6 T439f26(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].found */
extern T1 T439f28(GE_context* ac, T0* C);
/* DS_HASH_TABLE [INTEGER_32, XPLAIN_TYPE].search */
extern void T439f34(GE_context* ac, T0* C, T0* a1);
/* JOIN_NODE.make */
extern T0* T330c4(GE_context* ac, T0* a1, T0* a2);
/* JOIN.make */
extern T0* T401c11(GE_context* ac, T0* a1, T0* a2, T0* a3, T0* a4, T0* a5, T0* a6, T1 a7, T1 a8, T1 a9);
/* XPLAIN_ATTRIBUTE_NAME.sqlcolumnidentifier */
extern T0* T138f9(GE_context* ac, T0* C, T0* a1);
/* JOIN_TREE_NODE.alias_name */
extern T0* T416f8(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ATTRIBUTE_NAME.type */
extern T0* T138f10(GE_context* ac, T0* C);
extern T1 T138f10ot1(T0* a1, T0** a2);
/* JOIN_TREE_NODE.has_children */
extern T1 T416f9(GE_context* ac, T0* C);
/* DS_LINKED_LIST [JOIN_TREE_NODE].is_empty */
extern T1 T417f11(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_LIST.add_to_join */
extern void T161f13(GE_context* ac, T0* C, T0* a1, T0* a2);
/* JOIN_LIST.extend */
extern void T329f14(GE_context* ac, T0* C, T0* a1, T0* a2);
/* JOIN_TREE_NODE.get_immediate_child */
extern T0* T416f10(GE_context* ac, T0* C, T0* a1, T1 a2);
/* JOIN_TREE_NODE.append_child */
extern void T416f16(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3, T1 a4);
/* DS_LINKED_LIST [JOIN_TREE_NODE].put_last */
extern void T417f16(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [JOIN_TREE_NODE].put_right */
extern void T441f4(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [JOIN_TREE_NODE].make */
extern T0* T441c3(GE_context* ac, T0* a1);
/* JOIN_TREE_NODE.make */
extern T0* T416c14(GE_context* ac, T0* a1, T1 a2, T1 a3, T1 a4);
/* DS_LINKED_LIST [JOIN_TREE_NODE].make */
extern T0* T417c13(GE_context* ac);
/* DS_LINKED_LIST [JOIN_TREE_NODE].set_internal_cursor */
extern void T417f17(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [JOIN_TREE_NODE].new_cursor */
extern T0* T417f10(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [JOIN_TREE_NODE].make */
extern T0* T442c7(GE_context* ac, T0* a1);
/* JOIN_LIST.existential_join_optimisation */
extern T1 T329f9(GE_context* ac, T0* C);
/* JOIN_TREE_NODE.add_additional_item */
extern void T416f15(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].put_last */
extern void T440f12(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME_NODE].put_right */
extern void T457f4(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE_NAME_NODE].make */
extern T0* T457c3(GE_context* ac, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].make */
extern T0* T440c11(GE_context* ac);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].set_internal_cursor */
extern void T440f15(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME_NODE].new_cursor */
extern T0* T440f6(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME_NODE].make */
extern T0* T456c7(GE_context* ac, T0* a1);
/* JOIN_TREE_NODE.has_immediate_child */
extern T1 T416f13(GE_context* ac, T0* C, T0* a1, T1 a2);
/* XPLAIN_SELECTION_LIST.add_to_join */
extern void T161f13p1(GE_context* ac, T0* C, T0* a1, T0* a2);
/* JOIN_LIST.disable_existential_join_optimisation */
extern void T329f15(GE_context* ac, T0* C);
/* JOIN_LIST.enable_existential_join_optimisation */
extern void T329f16(GE_context* ac, T0* C);
/* JOIN_LIST.make */
extern T0* T329c12(GE_context* ac, T0* a1);
/* KL_STDOUT_FILE.put_character */
extern void T115f7(GE_context* ac, T0* C, T2 a1);
/* XPLAIN_ATTRIBUTE_NAME.quoted_name */
extern T0* T138f8(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.std */
extern T0* T64f22(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_LIST.type */
extern T0* T161f6(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_get_insert */
extern void T63f335(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_TSQL70.create_get_insert */
extern void T63f336(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_TSQL70.do_create_select_list */
extern void T63f337(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_TSQL70.commandseparator */
extern T0* T63f42(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.do_do_create_select_list */
extern void T63f338(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_TSQL70.create_predicate */
extern void T63f301(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sql_predicate */
extern T0* T63f96(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sql_select_joins */
extern T0* T63f59(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_select_joins_oldstyle */
extern T0* T63f143(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.equal */
extern T1 T63f181(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sql_select_joins_ansi92 */
extern T0* T63f142(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.string_ */
extern T0* T63f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.ansi92joinssupported */
extern T1 T63f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.std */
extern T0* T63f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_get_insert */
extern void T62f335(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_TSQL2000.create_get_insert */
extern void T62f336(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_TSQL2000.do_create_select_list */
extern void T62f337(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_TSQL2000.commandseparator */
extern T0* T62f42(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.do_do_create_select_list */
extern void T62f338(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_TSQL2000.create_predicate */
extern void T62f301(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sql_predicate */
extern T0* T62f96(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sql_select_joins */
extern T0* T62f59(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_select_joins_oldstyle */
extern T0* T62f143(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.equal */
extern T1 T62f181(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sql_select_joins_ansi92 */
extern T0* T62f142(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.string_ */
extern T0* T62f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.ansi92joinssupported */
extern T1 T62f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.std */
extern T0* T62f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_get_insert */
extern void T61f331(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_TSQL2016.create_get_insert */
extern void T61f332(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_TSQL2016.do_create_select_list */
extern void T61f333(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_TSQL2016.commandseparator */
extern T0* T61f42(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.do_do_create_select_list */
extern void T61f334(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_TSQL2016.create_predicate */
extern void T61f301(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sql_predicate */
extern T0* T61f96(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sql_select_joins */
extern T0* T61f59(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_select_joins_oldstyle */
extern T0* T61f143(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.equal */
extern T1 T61f181(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sql_select_joins_ansi92 */
extern T0* T61f142(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.string_ */
extern T0* T61f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.ansi92joinssupported */
extern T1 T61f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.std */
extern T0* T61f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_get_insert */
extern void T60f309(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_SQLITE_3.create_get_insert */
extern void T60f310(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_SQLITE_3.do_create_select_list */
extern void T60f311(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_SQLITE_3.commandseparator */
extern T0* T60f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.do_do_create_select_list */
extern void T60f312(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_SQLITE_3.create_predicate */
extern void T60f292(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sql_predicate */
extern T0* T60f73(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sql_select_joins */
extern T0* T60f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_select_joins_oldstyle */
extern T0* T60f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.equal */
extern T1 T60f163(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sql_select_joins_ansi92 */
extern T0* T60f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.string_ */
extern T0* T60f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.ansi92joinssupported */
extern T1 T60f129(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.std */
extern T0* T60f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.write_get_insert */
extern void T59f355(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_72.create_get_insert */
extern void T59f356(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_72.do_create_select_list */
extern void T59f357(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_72.commandseparator */
extern T0* T59f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.do_do_create_select_list */
extern void T59f358(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_72.create_predicate */
extern void T59f320(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sql_predicate */
extern T0* T59f94(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sql_select_joins */
extern T0* T59f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_select_joins_oldstyle */
extern T0* T59f156(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.equal */
extern T1 T59f196(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sql_select_joins_ansi92 */
extern T0* T59f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.string_ */
extern T0* T59f195(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.ansi92joinssupported */
extern T1 T59f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.std */
extern T0* T59f106(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_get_insert */
extern void T58f359(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_73.create_get_insert */
extern void T58f360(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_73.do_create_select_list */
extern void T58f361(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_73.commandseparator */
extern T0* T58f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.do_do_create_select_list */
extern void T58f362(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_73.create_predicate */
extern void T58f322(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sql_predicate */
extern T0* T58f94(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sql_select_joins */
extern T0* T58f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_select_joins_oldstyle */
extern T0* T58f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.equal */
extern T1 T58f196(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sql_select_joins_ansi92 */
extern T0* T58f157(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.string_ */
extern T0* T58f195(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.ansi92joinssupported */
extern T1 T58f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.std */
extern T0* T58f106(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_get_insert */
extern void T57f360(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_81.create_get_insert */
extern void T57f361(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_81.do_create_select_list */
extern void T57f362(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_81.commandseparator */
extern T0* T57f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.do_do_create_select_list */
extern void T57f363(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_81.create_predicate */
extern void T57f323(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sql_predicate */
extern T0* T57f94(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sql_select_joins */
extern T0* T57f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_select_joins_oldstyle */
extern T0* T57f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.equal */
extern T1 T57f197(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sql_select_joins_ansi92 */
extern T0* T57f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.string_ */
extern T0* T57f196(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.ansi92joinssupported */
extern T1 T57f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.std */
extern T0* T57f107(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_get_insert */
extern void T56f360(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_82.create_get_insert */
extern void T56f361(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_82.do_create_select_list */
extern void T56f362(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_82.commandseparator */
extern T0* T56f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.do_do_create_select_list */
extern void T56f363(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_82.create_predicate */
extern void T56f323(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sql_predicate */
extern T0* T56f94(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sql_select_joins */
extern T0* T56f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_select_joins_oldstyle */
extern T0* T56f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.equal */
extern T1 T56f197(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sql_select_joins_ansi92 */
extern T0* T56f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.string_ */
extern T0* T56f196(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.ansi92joinssupported */
extern T1 T56f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.std */
extern T0* T56f107(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_get_insert */
extern void T55f358(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_95.create_get_insert */
extern void T55f359(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_PGSQL_95.do_create_select_list */
extern void T55f360(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_95.commandseparator */
extern T0* T55f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.do_do_create_select_list */
extern void T55f361(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_95.create_predicate */
extern void T55f323(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sql_predicate */
extern T0* T55f94(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sql_select_joins */
extern T0* T55f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_select_joins_oldstyle */
extern T0* T55f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.equal */
extern T1 T55f197(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sql_select_joins_ansi92 */
extern T0* T55f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.string_ */
extern T0* T55f196(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.ansi92joinssupported */
extern T1 T55f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.std */
extern T0* T55f107(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_get_insert */
extern void T54f350(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_ORACLE.create_get_insert */
extern void T54f351(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_ORACLE.do_create_select_list */
extern void T54f352(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_ORACLE.commandseparator */
extern T0* T54f45(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.do_do_create_select_list */
extern void T54f353(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_ORACLE.create_predicate */
extern void T54f319(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sql_predicate */
extern T0* T54f96(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sql_select_joins */
extern T0* T54f56(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_select_joins_oldstyle */
extern T0* T54f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.equal */
extern T1 T54f194(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sql_select_joins_ansi92 */
extern T0* T54f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.string_ */
extern T0* T54f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.ansi92joinssupported */
extern T1 T54f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.std */
extern T0* T54f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.write_get_insert */
extern void T53f296(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MYSQL322.create_get_insert */
extern void T53f297(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MYSQL322.do_create_select_list */
extern void T53f298(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MYSQL322.commandseparator */
extern T0* T53f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.do_do_create_select_list */
extern void T53f299(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MYSQL322.create_predicate */
extern void T53f279(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sql_predicate */
extern T0* T53f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sql_select_joins */
extern T0* T53f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_select_joins_oldstyle */
extern T0* T53f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.equal */
extern T1 T53f161(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sql_select_joins_ansi92 */
extern T0* T53f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.string_ */
extern T0* T53f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.ansi92joinssupported */
extern T1 T53f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.std */
extern T0* T53f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.write_get_insert */
extern void T52f296(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MYSQL4.create_get_insert */
extern void T52f297(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MYSQL4.do_create_select_list */
extern void T52f298(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MYSQL4.commandseparator */
extern T0* T52f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.do_do_create_select_list */
extern void T52f299(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MYSQL4.create_predicate */
extern void T52f279(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sql_predicate */
extern T0* T52f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sql_select_joins */
extern T0* T52f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_select_joins_oldstyle */
extern T0* T52f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.equal */
extern T1 T52f161(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sql_select_joins_ansi92 */
extern T0* T52f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.string_ */
extern T0* T52f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.ansi92joinssupported */
extern T1 T52f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.std */
extern T0* T52f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_get_insert */
extern void T51f339(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MYSQL5.create_get_insert */
extern void T51f340(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MYSQL5.do_create_select_list */
extern void T51f341(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MYSQL5.commandseparator */
extern T0* T51f42(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.do_do_create_select_list */
extern void T51f342(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MYSQL5.create_predicate */
extern void T51f310(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sql_predicate */
extern T0* T51f93(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sql_select_joins */
extern T0* T51f57(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_select_joins_oldstyle */
extern T0* T51f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.equal */
extern T1 T51f184(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sql_select_joins_ansi92 */
extern T0* T51f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.string_ */
extern T0* T51f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.ansi92joinssupported */
extern T1 T51f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.std */
extern T0* T51f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.write_get_insert */
extern void T50f295(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MSQL.create_get_insert */
extern void T50f296(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MSQL.do_create_select_list */
extern void T50f297(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MSQL.commandseparator */
extern T0* T50f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.do_do_create_select_list */
extern void T50f298(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MSQL.create_predicate */
extern void T50f278(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sql_predicate */
extern T0* T50f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sql_select_joins */
extern T0* T50f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_select_joins_oldstyle */
extern T0* T50f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.equal */
extern T1 T50f160(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sql_select_joins_ansi92 */
extern T0* T50f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.string_ */
extern T0* T50f159(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.ansi92joinssupported */
extern T1 T50f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.std */
extern T0* T50f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.write_get_insert */
extern void T49f295(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MSACCESS2000.create_get_insert */
extern void T49f296(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MSACCESS2000.do_create_select_list */
extern void T49f297(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MSACCESS2000.commandseparator */
extern T0* T49f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.do_do_create_select_list */
extern void T49f298(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MSACCESS2000.create_predicate */
extern void T49f278(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sql_predicate */
extern T0* T49f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sql_select_joins */
extern T0* T49f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_select_joins_oldstyle */
extern T0* T49f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.equal */
extern T1 T49f160(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sql_select_joins_ansi92 */
extern T0* T49f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.string_ */
extern T0* T49f159(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.ansi92joinssupported */
extern T1 T49f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.std */
extern T0* T49f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.write_get_insert */
extern void T48f295(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MSACCESS97.create_get_insert */
extern void T48f296(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_MSACCESS97.do_create_select_list */
extern void T48f297(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MSACCESS97.commandseparator */
extern T0* T48f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.do_do_create_select_list */
extern void T48f298(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_MSACCESS97.create_predicate */
extern void T48f278(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sql_predicate */
extern T0* T48f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sql_select_joins */
extern T0* T48f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_select_joins_oldstyle */
extern T0* T48f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.equal */
extern T1 T48f160(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sql_select_joins_ansi92 */
extern T0* T48f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.string_ */
extern T0* T48f159(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.ansi92joinssupported */
extern T1 T48f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.std */
extern T0* T48f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_get_insert */
extern void T47f348(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_FIREBIRD_21.create_get_insert */
extern void T47f349(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_FIREBIRD_21.do_create_select_list */
extern void T47f350(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_FIREBIRD_21.commandseparator */
extern T0* T47f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.do_do_create_select_list */
extern void T47f351(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_FIREBIRD_21.create_predicate */
extern void T47f314(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sql_predicate */
extern T0* T47f96(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_joins */
extern T0* T47f57(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_joins_oldstyle */
extern T0* T47f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.equal */
extern T1 T47f190(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_joins_ansi92 */
extern T0* T47f152(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.string_ */
extern T0* T47f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.ansi92joinssupported */
extern T1 T47f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.std */
extern T0* T47f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.write_get_insert */
extern void T46f347(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_INTERBASE6.create_get_insert */
extern void T46f348(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_INTERBASE6.do_create_select_list */
extern void T46f349(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_INTERBASE6.commandseparator */
extern T0* T46f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.do_do_create_select_list */
extern void T46f350(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_INTERBASE6.create_predicate */
extern void T46f314(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sql_predicate */
extern T0* T46f96(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sql_select_joins */
extern T0* T46f57(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_select_joins_oldstyle */
extern T0* T46f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.equal */
extern T1 T46f190(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sql_select_joins_ansi92 */
extern T0* T46f152(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.string_ */
extern T0* T46f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.ansi92joinssupported */
extern T1 T46f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.std */
extern T0* T46f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.write_get_insert */
extern void T45f295(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_FOXPRO.create_get_insert */
extern void T45f296(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_FOXPRO.do_create_select_list */
extern void T45f297(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_FOXPRO.commandseparator */
extern T0* T45f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.do_do_create_select_list */
extern void T45f298(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_FOXPRO.create_predicate */
extern void T45f278(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sql_predicate */
extern T0* T45f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sql_select_joins */
extern T0* T45f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_select_joins_oldstyle */
extern T0* T45f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.equal */
extern T1 T45f160(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sql_select_joins_ansi92 */
extern T0* T45f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.string_ */
extern T0* T45f159(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.ansi92joinssupported */
extern T1 T45f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.std */
extern T0* T45f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_get_insert */
extern void T44f346(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_DB2_71.create_get_insert */
extern void T44f347(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_DB2_71.do_create_select_list */
extern void T44f348(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_DB2_71.commandseparator */
extern T0* T44f42(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.do_do_create_select_list */
extern void T44f349(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_DB2_71.create_predicate */
extern void T44f315(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sql_predicate */
extern T0* T44f92(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sql_select_joins */
extern T0* T44f56(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_select_joins_oldstyle */
extern T0* T44f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.equal */
extern T1 T44f190(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sql_select_joins_ansi92 */
extern T0* T44f152(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.string_ */
extern T0* T44f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.ansi92joinssupported */
extern T1 T44f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.std */
extern T0* T44f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.write_get_insert */
extern void T43f297(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_DB2_6.create_get_insert */
extern void T43f298(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_DB2_6.do_create_select_list */
extern void T43f299(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_DB2_6.commandseparator */
extern T0* T43f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.do_do_create_select_list */
extern void T43f300(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_DB2_6.create_predicate */
extern void T43f280(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sql_predicate */
extern T0* T43f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sql_select_joins */
extern T0* T43f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_select_joins_oldstyle */
extern T0* T43f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.equal */
extern T1 T43f162(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sql_select_joins_ansi92 */
extern T0* T43f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.string_ */
extern T0* T43f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.ansi92joinssupported */
extern T1 T43f129(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.std */
extern T0* T43f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.write_get_insert */
extern void T42f296(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_BASIC.create_get_insert */
extern void T42f297(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_BASIC.do_create_select_list */
extern void T42f298(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_BASIC.commandseparator */
extern T0* T42f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.do_do_create_select_list */
extern void T42f299(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_BASIC.create_predicate */
extern void T42f279(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sql_predicate */
extern T0* T42f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sql_select_joins */
extern T0* T42f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_select_joins_oldstyle */
extern T0* T42f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.equal */
extern T1 T42f161(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sql_select_joins_ansi92 */
extern T0* T42f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.string_ */
extern T0* T42f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.ansi92joinssupported */
extern T1 T42f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.std */
extern T0* T42f22(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.write_get_insert */
extern void T41f296(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_ANSI.create_get_insert */
extern void T41f297(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T0* a4);
/* SQL_GENERATOR_ANSI.do_create_select_list */
extern void T41f298(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_ANSI.commandseparator */
extern T0* T41f43(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.do_do_create_select_list */
extern void T41f299(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_ANSI.create_predicate */
extern void T41f279(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sql_predicate */
extern T0* T41f72(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sql_select_joins */
extern T0* T41f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_select_joins_oldstyle */
extern T0* T41f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.equal */
extern T1 T41f161(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sql_select_joins_ansi92 */
extern T0* T41f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.string_ */
extern T0* T41f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.ansi92joinssupported */
extern T1 T41f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.std */
extern T0* T41f22(GE_context* ac, T0* C);
/* XML_GENERATOR.write_constant_assignment */
extern void T67f25(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XML_GENERATOR.write_constant */
extern void T67f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE.sqlname */
extern T0* T179f4(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_delete */
extern void T67f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XML_GENERATOR.write_update */
extern void T67f29(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XML_GENERATOR.write_select_value */
extern void T67f30(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE.sqlname */
extern T0* T256f4(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_select_function */
extern void T67f38(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_FUNCTION.type */
extern T0* T154f7(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_select_function */
extern void T64f341(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_select_function */
extern void T64f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_select_function */
extern void T63f339(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_select_function */
extern void T63f341(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_select_function */
extern void T62f339(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_select_function */
extern void T62f341(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_select_function */
extern void T61f335(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_select_function */
extern void T61f337(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_select_function */
extern void T60f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_select_function */
extern void T60f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_select_function */
extern void T59f359(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_select_function */
extern void T59f361(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_return_cursor */
extern void T59f348(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_select_function */
extern void T59f361p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_start_cursor */
extern void T59f347(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_select_function */
extern void T58f363(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_select_function */
extern void T58f365(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_return_cursor */
extern void T58f350(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_select_function */
extern void T58f365p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_start_cursor */
extern void T58f349(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_select_function */
extern void T57f364(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_select_function */
extern void T57f366(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_return_cursor */
extern void T57f351(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_select_function */
extern void T57f366p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_start_cursor */
extern void T57f350(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_select_function */
extern void T56f364(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_select_function */
extern void T56f366(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_return_cursor */
extern void T56f351(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_select_function */
extern void T56f366p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_start_cursor */
extern void T56f350(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_select_function */
extern void T55f362(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_select_function */
extern void T55f364(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_return_cursor */
extern void T55f367(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_select_function */
extern void T55f364p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_start_cursor */
extern void T55f366(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_select_function */
extern void T54f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_select_function */
extern void T54f356(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_select_function */
extern void T54f356p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_select_function */
extern void T53f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_select_function */
extern void T53f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_select_function */
extern void T52f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_select_function */
extern void T52f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_select_function */
extern void T51f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_select_function */
extern void T51f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_select_function */
extern void T50f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_select_function */
extern void T50f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_select_function */
extern void T49f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_select_function */
extern void T49f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_select_function */
extern void T48f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_select_function */
extern void T48f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_select_function */
extern void T47f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_select_function */
extern void T47f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_select_function */
extern void T47f354p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_select_function */
extern void T46f351(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_select_function */
extern void T46f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_select_function */
extern void T46f353p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_select_function */
extern void T45f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_select_function */
extern void T45f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_select_function */
extern void T44f350(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_select_function */
extern void T44f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_select_function */
extern void T44f352p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_select_function */
extern void T43f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_select_function */
extern void T43f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_select_function */
extern void T42f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_select_function */
extern void T42f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_select_function */
extern void T41f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_select_function */
extern void T41f302(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_select */
extern void T67f31(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_extend */
extern void T67f32(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_select_list */
extern void T67f39(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_select_list */
extern void T64f342(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_select_list */
extern void T64f344(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_select_list */
extern void T63f340(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_select_list */
extern void T63f342(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_select_list */
extern void T62f340(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_select_list */
extern void T62f342(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_select_list */
extern void T61f336(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_select_list */
extern void T61f338(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_select_list */
extern void T60f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_select_list */
extern void T60f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_select_list */
extern void T59f360(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_select_list */
extern void T59f362(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_select_list */
extern void T59f362p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_select_list */
extern void T58f364(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_select_list */
extern void T58f366(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_select_list */
extern void T58f366p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_select_list */
extern void T57f365(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_select_list */
extern void T57f367(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_select_list */
extern void T57f367p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_select_list */
extern void T56f365(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_select_list */
extern void T56f367(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_select_list */
extern void T56f367p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_select_list */
extern void T55f363(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_select_list */
extern void T55f365(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_select_list */
extern void T55f365p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_select_list */
extern void T54f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_select_list */
extern void T54f357(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_select_list */
extern void T54f357p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_select_list */
extern void T53f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_select_list */
extern void T53f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_select_list */
extern void T52f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_select_list */
extern void T52f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_select_list */
extern void T51f344(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_select_list */
extern void T51f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_select_list */
extern void T50f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_select_list */
extern void T50f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_select_list */
extern void T49f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_select_list */
extern void T49f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_select_list */
extern void T48f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_select_list */
extern void T48f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_select_list */
extern void T47f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_select_list */
extern void T47f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_select_list */
extern void T47f355p1(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].forth */
extern void T338f12(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].item */
extern T0* T338f6(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].start */
extern void T338f11(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.write_select_list */
extern void T46f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_select_list */
extern void T46f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_select_list */
extern void T46f354p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_select_list */
extern void T45f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_select_list */
extern void T45f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_select_list */
extern void T44f351(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_select_list */
extern void T44f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_select_list */
extern void T44f353p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_select_list */
extern void T43f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_select_list */
extern void T43f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_select_list */
extern void T42f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_select_list */
extern void T42f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_select_list */
extern void T41f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_select_list */
extern void T41f303(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_procedure */
extern void T67f33(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.last_value_selection_statement */
extern T0* T318f9(GE_context* ac, T0* C);
extern T1 T318f9ot1(T0* a1, T0** a2);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].back */
extern void T393f10(GE_context* ac, T0* C);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].cursor_back */
extern void T339f21(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].add_traversing_cursor */
extern void T339f18(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].set_next_cursor */
extern void T393f14(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].remove_traversing_cursor */
extern void T339f19(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].set */
extern void T393f13(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].item */
extern T0* T393f6(GE_context* ac, T0* C);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].finish */
extern void T393f9(GE_context* ac, T0* C);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].cursor_finish */
extern void T339f20(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].cursor_off */
extern T1 T339f10(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].off */
extern T1 T393f7(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_LIST.write_select */
extern void T161f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_FUNCTION.write_select */
extern void T154f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.last_get_statement */
extern T0* T318f16(GE_context* ac, T0* C);
extern T1 T318f16ot1(T0* a1, T0** a2);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME].forth */
extern void T336f10(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].cursor_forth */
extern void T335f17(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].add_traversing_cursor */
extern void T335f18(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME].set_next_cursor */
extern void T336f12(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].remove_traversing_cursor */
extern void T335f19(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME].set */
extern void T336f11(GE_context* ac, T0* C, T0* a1, T1 a2, T1 a3);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME].item */
extern T0* T336f6(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME].start */
extern void T336f9(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].cursor_start */
extern void T335f16(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].cursor_off */
extern T1 T335f10(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE_NAME].off */
extern T1 T336f7(GE_context* ac, T0* C);
/* XPLAIN_PROCEDURE.sqlname */
extern T0* T318f10(GE_context* ac, T0* C, T0* a1);
/* XML_GENERATOR.write_sql */
extern void T67f37(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.hack_anode */
extern void T157f42(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_NAME_NODE.set_next */
extern void T137f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.hack_anode */
extern void T143f45(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.hack_anode */
extern void T129f33(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_BASE.hack_anode */
extern void T128f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.write_drop */
extern void T318f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE.write_drop */
extern void T256f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE.write_drop */
extern void T179f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.write_drop */
extern void T157f45(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.write_drop */
extern void T143f47(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.write_drop */
extern void T129f34(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_BASE.write_drop */
extern void T128f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_ATTRIBUTE.set_init_default */
extern void T446f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VIRTUAL_ATTRIBUTE.set_init_default */
extern void T445f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE.set_init_default */
extern void T142f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_ATTRIBUTE.set_init */
extern void T446f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VIRTUAL_ATTRIBUTE.set_init */
extern void T445f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE.set_init */
extern void T142f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_ATTRIBUTE.set_required */
extern void T446f21(GE_context* ac, T0* C, T1 a1);
/* XPLAIN_VIRTUAL_ATTRIBUTE.set_required */
extern void T445f21(GE_context* ac, T0* C, T1 a1);
/* XPLAIN_ATTRIBUTE.set_required */
extern void T142f23(GE_context* ac, T0* C, T1 a1);
/* XPLAIN_EXTENSION_ATTRIBUTE.write_drop */
extern void T446f18(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_VIRTUAL_ATTRIBUTE.write_drop */
extern void T445f18(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ATTRIBUTE.write_drop */
extern void T142f22(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_T_REPRESENTATION.set_domain_restriction */
extern void T245f12(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_R_REPRESENTATION.set_domain_restriction */
extern void T244f13(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_P_REPRESENTATION.set_domain_restriction */
extern void T243f12(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_M_REPRESENTATION.set_domain_restriction */
extern void T242f11(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_I_REPRESENTATION.set_domain_restriction */
extern void T241f12(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_D_REPRESENTATION.set_domain_restriction */
extern void T240f11(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_C_REPRESENTATION.set_domain_restriction */
extern void T239f13(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_B_REPRESENTATION.set_domain_restriction */
extern void T238f12(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_A_REPRESENTATION.set_domain_restriction */
extern void T236f13(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION_EXPRESSION.add_to_join */
extern void T448f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ATTRIBUTE_EXPRESSION.add_to_join */
extern void T389f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_NOT_LIKE_EXPRESSION.add_to_join */
extern void T346f30(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LIKE_EXPRESSION.add_to_join */
extern void T345f30(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.add_to_join */
extern void T285f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_SELECTION_EXPRESSION.add_to_join */
extern void T283f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_VALUE_EXPRESSION.add_to_join */
extern void T257f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_VARIABLE_EXPRESSION.add_to_join */
extern void T255f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_SQL_EXPRESSION.add_to_join */
extern void T233f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_USER_FUNCTION.add_to_join */
extern void T232f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.add_to_join */
extern void T231f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_NUMBER_EXPRESSION.add_to_join */
extern void T230f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ID_FUNCTION.add_to_join */
extern void T229f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_NEWDATE_FUNCTION.add_to_join */
extern void T228f29(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_STRING_EXPRESSION.add_to_join */
extern void T227f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_STRING_FUNCTION.add_to_join */
extern void T226f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_REAL_FUNCTION.add_to_join */
extern void T225f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_INTEGER_FUNCTION.add_to_join */
extern void T224f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_DATEF_FUNCTION.add_to_join */
extern void T223f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_COMBINE_FUNCTION.add_to_join */
extern void T222f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_PREFIX_EXPRESSION.add_to_join */
extern void T220f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_IF_EXPRESSION.add_to_join */
extern void T219f29(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LOGINNAME_EXPRESSION.add_to_join */
extern void T218f26(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_SYSTEMDATE_EXPRESSION.add_to_join */
extern void T215f26(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_PARENTHESIS_EXPRESSION.add_to_join */
extern void T212f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_INFIX_EXPRESSION.add_to_join */
extern void T211f29(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_NE_NULL_EXPRESSION.add_to_join */
extern void T210f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EQ_NULL_EXPRESSION.add_to_join */
extern void T209f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_PARAMETER_EXPRESSION.add_to_join */
extern void T208f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_NOT_EXPRESSION.add_to_join */
extern void T207f29(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_NOTNOT_EXPRESSION.add_to_join */
extern void T206f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.add_to_join */
extern void T203f31(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.add_to_join */
extern void T203f31p1(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.string_ */
extern T0* T203f19(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.add_to_join */
extern void T159f28(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.add_to_join */
extern void T135f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_LOGICAL_EXPRESSION.add_to_join */
extern void T133f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.write_drop_attribute */
extern void T157f46(GE_context* ac, T0* C, T0* a1, T0* a2);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].delete */
extern void T337f25(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].set_last_cell */
extern void T337f28(GE_context* ac, T0* C, T0* a1);
/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE].forget_right */
extern void T419f5(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].set_first_cell */
extern void T337f27(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].move_all_cursors_after */
extern void T337f26(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.write_drop_attribute */
extern void T143f48(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TYPE.write_drop_attribute */
extern void T129f35(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.add_assertion */
extern void T157f47(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VIRTUAL_ATTRIBUTE.make */
extern T0* T445c17(GE_context* ac, T0* a1);
/* XPLAIN_VIRTUAL_ATTRIBUTE.inherited_make */
extern void T445f22(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T1 a4, T1 a5, T1 a6);
/* XPLAIN_ASSERTION.add_assertion */
extern void T143f49(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.add_assertion */
extern void T129f36(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.add_extension */
extern void T157f48(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_ATTRIBUTE.make */
extern T0* T446c17(GE_context* ac, T0* a1);
/* XPLAIN_EXTENSION_ATTRIBUTE.inherited_make */
extern void T446f22(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3, T1 a4, T1 a5, T1 a6);
/* XPLAIN_ASSERTION.add_extension */
extern void T143f50(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.add_extension */
extern void T129f37(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.next_constraint_number */
extern void T157f44(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.next_constraint_number */
extern void T143f46(GE_context* ac, T0* C);
/* XPLAIN_TYPE.next_constraint_number */
extern void T129f31(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.remove_extension */
extern void T157f49(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].remove_at */
extern void T337f29(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].remove_at_cursor */
extern void T337f30(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].move_all_cursors */
extern void T337f33(GE_context* ac, T0* C, T0* a1, T0* a2);
/* detachable DS_LINKABLE [XPLAIN_ATTRIBUTE].put */
extern void T419f6(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].remove_last */
extern void T337f32(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].move_last_cursors_after */
extern void T337f35(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].wipe_out */
extern void T337f34(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].is_last */
extern T1 T338f9(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].cursor_is_last */
extern T1 T337f15(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].remove_first */
extern void T337f31(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].is_first */
extern T1 T338f8(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].cursor_is_first */
extern T1 T337f14(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].forth */
extern void T337f19(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].item_for_iteration */
extern T0* T337f11(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].cursor_item */
extern T0* T337f9(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].after */
extern T1 T337f10(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].cursor_after */
extern T1 T337f8(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].start */
extern void T337f18(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.remove_extension */
extern void T143f51(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.remove_extension */
extern void T129f38(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_GET_INSERT_STATEMENT.write */
extern void T269f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INSERT_STATEMENT.write */
extern void T267f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_BASE_STATEMENT.write */
extern void T177f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE_STATEMENT.write */
extern void T174f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_STATEMENT.write */
extern void T166f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE_STATEMENT.write */
extern void T165f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTEND_STATEMENT.write */
extern void T156f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_GET_STATEMENT.write */
extern void T155f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_SELECTION_STATEMENT.write */
extern void T152f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_STATEMENT.write */
extern void T151f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UPDATE_STATEMENT.write */
extern void T150f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DELETE_STATEMENT.write */
extern void T148f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CASCADE_STATEMENT.write */
extern void T146f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CONSTANT_STATEMENT.write */
extern void T130f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT.write */
extern void T127f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_GET_INSERT_STATEMENT.optimize_for_procedure */
extern void T269f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INSERT_STATEMENT.optimize_for_procedure */
extern void T267f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_BASE_STATEMENT.optimize_for_procedure */
extern void T177f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE_STATEMENT.optimize_for_procedure */
extern void T174f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_STATEMENT.optimize_for_procedure */
extern void T166f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE_STATEMENT.optimize_for_procedure */
extern void T165f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTEND_STATEMENT.optimize_for_procedure */
extern void T156f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.set_no_update_optimization */
extern void T157f43(GE_context* ac, T0* C, T1 a1);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].forth */
extern void T393f12(GE_context* ac, T0* C);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].cursor_forth */
extern void T339f17(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST_CURSOR [XPLAIN_STATEMENT].start */
extern void T393f11(GE_context* ac, T0* C);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].cursor_start */
extern void T339f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.is_update_optimization_supported */
extern T1 T303f18(GE_context* ac, T0* C);
/* XPLAIN_GET_STATEMENT.optimize_for_procedure */
extern void T155f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_SELECTION_STATEMENT.optimize_for_procedure */
extern void T152f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_STATEMENT.optimize_for_procedure */
extern void T151f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UPDATE_STATEMENT.optimize_for_procedure */
extern void T150f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DELETE_STATEMENT.optimize_for_procedure */
extern void T148f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CASCADE_STATEMENT.optimize_for_procedure */
extern void T146f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CONSTANT_STATEMENT.optimize_for_procedure */
extern void T130f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT.optimize_for_procedure */
extern void T127f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_GET_INSERT_STATEMENT.cleanup */
extern void T269f10(GE_context* ac, T0* C);
/* XPLAIN_INSERT_STATEMENT.cleanup */
extern void T267f9(GE_context* ac, T0* C);
/* XPLAIN_BASE_STATEMENT.cleanup */
extern void T177f7(GE_context* ac, T0* C);
/* XPLAIN_TYPE_STATEMENT.cleanup */
extern void T174f7(GE_context* ac, T0* C);
/* XPLAIN_SQL_STATEMENT.cleanup */
extern void T166f7(GE_context* ac, T0* C);
/* XPLAIN_PROCEDURE_STATEMENT.cleanup */
extern void T165f7(GE_context* ac, T0* C);
/* XPLAIN_EXTEND_STATEMENT.cleanup */
extern void T156f7(GE_context* ac, T0* C);
/* XPLAIN_GET_STATEMENT.cleanup */
extern void T155f7(GE_context* ac, T0* C);
/* XPLAIN_VALUE_SELECTION_STATEMENT.cleanup */
extern void T152f7(GE_context* ac, T0* C);
/* XPLAIN_VALUE_STATEMENT.cleanup */
extern void T151f8(GE_context* ac, T0* C);
/* XPLAIN_VALUE_STATEMENT.universe */
extern T0* T151f3(GE_context* ac, T0* C);
/* XPLAIN_UPDATE_STATEMENT.cleanup */
extern void T150f9(GE_context* ac, T0* C);
/* XPLAIN_DELETE_STATEMENT.cleanup */
extern void T148f8(GE_context* ac, T0* C);
/* XPLAIN_CASCADE_STATEMENT.cleanup */
extern void T146f17(GE_context* ac, T0* C);
/* XPLAIN_CONSTANT_STATEMENT.cleanup */
extern void T130f7(GE_context* ac, T0* C);
/* XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT.cleanup */
extern void T127f8(GE_context* ac, T0* C);
/* XPLAIN_B_RESTRICTION.check_attachment */
extern void T342f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TRAJECTORY.check_attachment */
extern void T200f9(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T200f9ot1(T0* a1, T0** a2);
extern T1 T200f9ot2(T0* a1, T0** a2);
/* XPLAIN_TRAJECTORY.std */
extern T0* T200f5(GE_context* ac, T0* C);
/* XPLAIN_I_ENUMERATION.check_attachment */
extern void T196f14(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T196f14ot1(T0* a1, T0** a2);
extern T1 T196f14ot2(T0* a1, T0** a2);
/* XPLAIN_I_ENUMERATION.double_cell */
extern T0* T196f8(GE_context* ac, T0* C, T13 a1);
/* DS_CELL [REAL_64].make */
extern T0* T413c4(GE_context* ac, T13 a1);
/* XPLAIN_I_ENUMERATION.format */
extern T0* T196f7(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_I_ENUMERATION.formatter */
extern T0* T196f9(GE_context* ac, T0* C);
/* XPLAIN_I_ENUMERATION.scientific_formatter */
extern T0* T196f10(GE_context* ac, T0* C);
/* XPLAIN_I_ENUMERATION.integer_cell */
extern T0* T196f6(GE_context* ac, T0* C, T6 a1);
/* DS_CELL [INTEGER_32].make */
extern T0* T356c4(GE_context* ac, T6 a1);
/* INTEGER_32.make_from_reference */
extern T6 T6c34(GE_context* ac, T0* a1);
/* XPLAIN_I_ENUMERATION.std */
extern T0* T196f5(GE_context* ac, T0* C);
/* KL_INTEGER_ROUTINES.power */
extern T6 T410f1(GE_context* ac, T0* C, T6 a1, T6 a2);
/* KL_INTEGER_ROUTINES.is_even */
extern T1 T410f4(GE_context* ac, T0* C, T6 a1);
/* XPLAIN_I_ENUMERATION.integer_ */
extern T0* T196f4(GE_context* ac, T0* C);
/* XPLAIN_A_ENUMERATION.check_attachment */
extern void T194f8(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T194f8ot1(T0* a1, T0** a2);
/* XPLAIN_A_NODE.to_sqlcode */
extern T0* T131f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_A_ENUMERATION.std */
extern T0* T194f4(GE_context* ac, T0* C);
/* XPLAIN_A_PATTERN.check_attachment */
extern void T192f7(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_REQUIRED.check_attachment */
extern void T122f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.set_options */
extern void T64f245(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_TSQL70.set_options */
extern void T63f244(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_TSQL2000.set_options */
extern void T62f244(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_TSQL2016.set_options */
extern void T61f244(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_SQLITE_3.set_options */
extern void T60f243(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_PGSQL_72.set_options */
extern void T59f267(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_PGSQL_73.set_options */
extern void T58f269(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_PGSQL_81.set_options */
extern void T57f270(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_PGSQL_82.set_options */
extern void T56f270(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_PGSQL_95.set_options */
extern void T55f270(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_ORACLE.set_options */
extern void T54f265(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_MYSQL322.set_options */
extern void T53f231(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_MYSQL4.set_options */
extern void T52f231(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_MYSQL5.set_options */
extern void T51f256(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_MSQL.set_options */
extern void T50f230(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_MSACCESS2000.set_options */
extern void T49f230(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_MSACCESS97.set_options */
extern void T48f230(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_FIREBIRD_21.set_options */
extern void T47f260(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_INTERBASE6.set_options */
extern void T46f260(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_FOXPRO.set_options */
extern void T45f230(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_DB2_71.set_options */
extern void T44f261(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_DB2_6.set_options */
extern void T43f232(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_BASIC.set_options */
extern void T42f231(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_ANSI.set_options */
extern void T41f231(GE_context* ac, T0* C, T1 a1, T1 a2, T1 a3, T1 a4, T1 a5, T1 a6, T1 a7, T1 a8, T1 a9, T1 a10, T1 a11, T1 a12, T1 a13);
/* SQL_GENERATOR_TSQL65.set_primary_key_format */
extern void T64f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.set_primary_key_format */
extern void T63f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.set_primary_key_format */
extern void T62f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.set_primary_key_format */
extern void T61f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.set_primary_key_format */
extern void T60f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.set_primary_key_format */
extern void T59f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.set_primary_key_format */
extern void T58f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.set_primary_key_format */
extern void T57f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.set_primary_key_format */
extern void T56f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.set_primary_key_format */
extern void T55f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.set_primary_key_format */
extern void T54f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.set_primary_key_format */
extern void T53f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.set_primary_key_format */
extern void T52f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.set_primary_key_format */
extern void T51f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.set_primary_key_format */
extern void T50f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.set_primary_key_format */
extern void T49f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.set_primary_key_format */
extern void T48f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.set_primary_key_format */
extern void T47f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.set_primary_key_format */
extern void T46f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.set_primary_key_format */
extern void T45f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.set_primary_key_format */
extern void T44f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.set_primary_key_format */
extern void T43f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.set_primary_key_format */
extern void T42f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.set_primary_key_format */
extern void T41f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.set_sequence_name_format */
extern void T64f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.valid_format_and_parameters */
extern T1 T64f62(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.formatter */
extern T0* T64f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.scientific_formatter */
extern T0* T64f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.set_sequence_name_format */
extern void T63f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.valid_format_and_parameters */
extern T1 T63f62(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.formatter */
extern T0* T63f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.scientific_formatter */
extern T0* T63f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.set_sequence_name_format */
extern void T62f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.valid_format_and_parameters */
extern T1 T62f62(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.formatter */
extern T0* T62f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.scientific_formatter */
extern T0* T62f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.set_sequence_name_format */
extern void T61f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.valid_format_and_parameters */
extern T1 T61f62(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.formatter */
extern T0* T61f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.scientific_formatter */
extern T0* T61f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.set_sequence_name_format */
extern void T60f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.valid_format_and_parameters */
extern T1 T60f81(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.formatter */
extern T0* T60f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.scientific_formatter */
extern T0* T60f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.set_sequence_name_format */
extern void T59f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.valid_format_and_parameters */
extern T1 T59f61(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.formatter */
extern T0* T59f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.scientific_formatter */
extern T0* T59f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.set_sequence_name_format */
extern void T58f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.valid_format_and_parameters */
extern T1 T58f61(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.formatter */
extern T0* T58f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.scientific_formatter */
extern T0* T58f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.set_sequence_name_format */
extern void T57f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.valid_format_and_parameters */
extern T1 T57f61(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.formatter */
extern T0* T57f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.scientific_formatter */
extern T0* T57f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.set_sequence_name_format */
extern void T56f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.valid_format_and_parameters */
extern T1 T56f61(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.formatter */
extern T0* T56f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.scientific_formatter */
extern T0* T56f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.set_sequence_name_format */
extern void T55f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.valid_format_and_parameters */
extern T1 T55f61(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.formatter */
extern T0* T55f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.scientific_formatter */
extern T0* T55f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.set_sequence_name_format */
extern void T54f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.valid_format_and_parameters */
extern T1 T54f62(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.formatter */
extern T0* T54f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.scientific_formatter */
extern T0* T54f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.set_sequence_name_format */
extern void T53f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.valid_format_and_parameters */
extern T1 T53f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.formatter */
extern T0* T53f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.scientific_formatter */
extern T0* T53f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.set_sequence_name_format */
extern void T52f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.valid_format_and_parameters */
extern T1 T52f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.formatter */
extern T0* T52f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.scientific_formatter */
extern T0* T52f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.set_sequence_name_format */
extern void T51f258(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.valid_format_and_parameters */
extern T1 T51f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.formatter */
extern T0* T51f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.scientific_formatter */
extern T0* T51f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.set_sequence_name_format */
extern void T50f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.valid_format_and_parameters */
extern T1 T50f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.formatter */
extern T0* T50f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.scientific_formatter */
extern T0* T50f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.set_sequence_name_format */
extern void T49f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.valid_format_and_parameters */
extern T1 T49f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.formatter */
extern T0* T49f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.scientific_formatter */
extern T0* T49f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.set_sequence_name_format */
extern void T48f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.valid_format_and_parameters */
extern T1 T48f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.formatter */
extern T0* T48f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.scientific_formatter */
extern T0* T48f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.set_sequence_name_format */
extern void T47f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.valid_format_and_parameters */
extern T1 T47f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.formatter */
extern T0* T47f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.scientific_formatter */
extern T0* T47f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.set_sequence_name_format */
extern void T46f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.valid_format_and_parameters */
extern T1 T46f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.formatter */
extern T0* T46f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.scientific_formatter */
extern T0* T46f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.set_sequence_name_format */
extern void T45f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.valid_format_and_parameters */
extern T1 T45f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.formatter */
extern T0* T45f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.scientific_formatter */
extern T0* T45f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.set_sequence_name_format */
extern void T44f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.valid_format_and_parameters */
extern T1 T44f62(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.formatter */
extern T0* T44f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.scientific_formatter */
extern T0* T44f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.set_sequence_name_format */
extern void T43f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.valid_format_and_parameters */
extern T1 T43f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.formatter */
extern T0* T43f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.scientific_formatter */
extern T0* T43f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.set_sequence_name_format */
extern void T42f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.valid_format_and_parameters */
extern T1 T42f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.formatter */
extern T0* T42f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.scientific_formatter */
extern T0* T42f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.set_sequence_name_format */
extern void T41f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.valid_format_and_parameters */
extern T1 T41f80(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.formatter */
extern T0* T41f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.scientific_formatter */
extern T0* T41f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_end */
extern void T64f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_end */
extern void T64f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_end */
extern void T63f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_end */
extern void T63f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_end */
extern void T62f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_end */
extern void T62f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_end */
extern void T61f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_end */
extern void T61f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_end */
extern void T60f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_end */
extern void T60f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_end */
extern void T59f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_end */
extern void T59f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_end */
extern void T58f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_end */
extern void T58f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_end */
extern void T57f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_end */
extern void T57f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_end */
extern void T56f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_end */
extern void T56f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_end */
extern void T55f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_end */
extern void T55f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_end */
extern void T54f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_end */
extern void T54f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_end */
extern void T53f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_end */
extern void T53f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_end */
extern void T52f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_end */
extern void T52f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_end */
extern void T51f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_end */
extern void T51f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_end */
extern void T50f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_end */
extern void T50f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_end */
extern void T49f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_end */
extern void T49f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_end */
extern void T48f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_end */
extern void T48f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_end */
extern void T47f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_end */
extern void T47f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_end */
extern void T46f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_end */
extern void T46f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_end */
extern void T45f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_end */
extern void T45f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_end */
extern void T44f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_end */
extern void T44f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_end */
extern void T43f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_end */
extern void T43f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_end */
extern void T42f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_end */
extern void T42f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_end */
extern void T41f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_end */
extern void T41f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_use_database */
extern void T64f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_use_database */
extern void T64f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.end_with_go */
extern void T64f297(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_use_database */
extern void T63f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_use_database */
extern void T63f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.end_with_go */
extern void T63f296(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_use_database */
extern void T62f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_use_database */
extern void T62f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.end_with_go */
extern void T62f296(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_use_database */
extern void T61f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_use_database */
extern void T61f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.end_with_go */
extern void T61f296(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_use_database */
extern void T60f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_use_database */
extern void T60f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_use_database */
extern void T59f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_use_database */
extern void T59f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_use_database */
extern void T58f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_use_database */
extern void T58f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_use_database */
extern void T57f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_use_database */
extern void T57f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_use_database */
extern void T56f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_use_database */
extern void T56f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_use_database */
extern void T55f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_use_database */
extern void T55f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_use_database */
extern void T54f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_use_database */
extern void T54f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_use_database */
extern void T53f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_use_database */
extern void T53f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_use_database */
extern void T52f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_use_database */
extern void T52f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_use_database */
extern void T51f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_use_database */
extern void T51f282(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_use_database */
extern void T50f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_use_database */
extern void T50f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_use_database */
extern void T49f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_use_database */
extern void T49f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_use_database */
extern void T48f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_use_database */
extern void T48f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_use_database */
extern void T47f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_use_database */
extern void T47f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_use_database */
extern void T47f286p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_use_database */
extern void T46f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_use_database */
extern void T46f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_use_database */
extern void T46f286p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_use_database */
extern void T45f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_use_database */
extern void T45f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_use_database */
extern void T44f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_use_database */
extern void T44f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_use_database */
extern void T43f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_use_database */
extern void T43f258(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_use_database */
extern void T42f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_use_database */
extern void T42f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_use_database */
extern void T41f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_use_database */
extern void T41f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_base */
extern void T64f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_domain */
extern void T64f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.rule_identifier */
extern T0* T64f45(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.createdomaincheck */
extern T1 T64f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.domain_identifier */
extern T0* T64f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.no_space_identifier */
extern T0* T64f139(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.maxidentifierlength */
extern T6 T64f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.domainnameprefix */
extern T0* T64f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.createdomains */
extern T1 T64f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.domainssupported */
extern T1 T64f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_base */
extern void T63f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_domain */
extern void T63f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.rule_identifier */
extern T0* T63f45(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.createdomaincheck */
extern T1 T63f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.domain_identifier */
extern T0* T63f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.no_space_identifier */
extern T0* T63f138(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.maxidentifierlength */
extern T6 T63f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.domainnameprefix */
extern T0* T63f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.createdomains */
extern T1 T63f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.domainssupported */
extern T1 T63f132(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_base */
extern void T62f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_domain */
extern void T62f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.rule_identifier */
extern T0* T62f45(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.createdomaincheck */
extern T1 T62f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.domain_identifier */
extern T0* T62f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.no_space_identifier */
extern T0* T62f138(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.maxidentifierlength */
extern T6 T62f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.domainnameprefix */
extern T0* T62f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.createdomains */
extern T1 T62f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.domainssupported */
extern T1 T62f132(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_base */
extern void T61f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_domain */
extern void T61f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.rule_identifier */
extern T0* T61f45(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.createdomaincheck */
extern T1 T61f44(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.domain_identifier */
extern T0* T61f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.no_space_identifier */
extern T0* T61f138(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.maxidentifierlength */
extern T6 T61f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.domainnameprefix */
extern T0* T61f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.createdomains */
extern T1 T61f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.domainssupported */
extern T1 T61f132(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_base */
extern void T60f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_domain */
extern void T60f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.domain_null_or_not_null */
extern T0* T60f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.domainnullallowed */
extern T1 T60f128(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.domainnotnullallowed */
extern T1 T60f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.domainnulldefault */
extern T1 T60f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.domain_identifier */
extern T0* T60f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.domainnameprefix */
extern T0* T60f124(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.createdomains */
extern T1 T60f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.domainssupported */
extern T1 T60f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.write_base */
extern void T59f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_domain */
extern void T59f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.domain_null_or_not_null */
extern T0* T59f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.domainnullallowed */
extern T1 T59f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.domainnotnullallowed */
extern T1 T59f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.domainnulldefault */
extern T1 T59f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.domain_identifier */
extern T0* T59f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.domainnameprefix */
extern T0* T59f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createdomains */
extern T1 T59f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.domainssupported */
extern T1 T59f146(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_base */
extern void T58f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_domain */
extern void T58f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.domain_null_or_not_null */
extern T0* T58f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.domainnullallowed */
extern T1 T58f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.domainnotnullallowed */
extern T1 T58f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.domainnulldefault */
extern T1 T58f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.domain_identifier */
extern T0* T58f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.domainnameprefix */
extern T0* T58f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.createdomains */
extern T1 T58f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.domainssupported */
extern T1 T58f148(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_base */
extern void T57f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_domain */
extern void T57f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.domain_null_or_not_null */
extern T0* T57f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.domainnullallowed */
extern T1 T57f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.domainnotnullallowed */
extern T1 T57f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.domainnulldefault */
extern T1 T57f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.domain_identifier */
extern T0* T57f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.domainnameprefix */
extern T0* T57f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.createdomains */
extern T1 T57f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.domainssupported */
extern T1 T57f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_base */
extern void T56f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_domain */
extern void T56f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.domain_null_or_not_null */
extern T0* T56f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.domainnullallowed */
extern T1 T56f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.domainnotnullallowed */
extern T1 T56f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.domainnulldefault */
extern T1 T56f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.domain_identifier */
extern T0* T56f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.domainnameprefix */
extern T0* T56f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.createdomains */
extern T1 T56f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.domainssupported */
extern T1 T56f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_base */
extern void T55f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_domain */
extern void T55f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.domain_null_or_not_null */
extern T0* T55f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.domainnullallowed */
extern T1 T55f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.domainnotnullallowed */
extern T1 T55f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.domainnulldefault */
extern T1 T55f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.domain_identifier */
extern T0* T55f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.domainnameprefix */
extern T0* T55f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.createdomains */
extern T1 T55f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.domainssupported */
extern T1 T55f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_base */
extern void T54f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_domain */
extern void T54f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.domain_null_or_not_null */
extern T0* T54f44(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.domainnullallowed */
extern T1 T54f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.domainnotnullallowed */
extern T1 T54f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.domainnulldefault */
extern T1 T54f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.domain_identifier */
extern T0* T54f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.domainnameprefix */
extern T0* T54f147(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.createdomains */
extern T1 T54f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.domainssupported */
extern T1 T54f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.write_base */
extern void T53f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_domain */
extern void T53f258(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.domain_null_or_not_null */
extern T0* T53f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.domainnullallowed */
extern T1 T53f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.domainnotnullallowed */
extern T1 T53f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.domainnulldefault */
extern T1 T53f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.domain_identifier */
extern T0* T53f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.domainnameprefix */
extern T0* T53f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.createdomains */
extern T1 T53f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.domainssupported */
extern T1 T53f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.write_base */
extern void T52f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_domain */
extern void T52f258(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.domain_null_or_not_null */
extern T0* T52f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.domainnullallowed */
extern T1 T52f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.domainnotnullallowed */
extern T1 T52f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.domainnulldefault */
extern T1 T52f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.domain_identifier */
extern T0* T52f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.domainnameprefix */
extern T0* T52f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.createdomains */
extern T1 T52f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.domainssupported */
extern T1 T52f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_base */
extern void T51f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_domain */
extern void T51f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.domain_null_or_not_null */
extern T0* T51f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.domainnullallowed */
extern T1 T51f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.domainnotnullallowed */
extern T1 T51f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.domainnulldefault */
extern T1 T51f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.domain_identifier */
extern T0* T51f44(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.domainnameprefix */
extern T0* T51f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createdomains */
extern T1 T51f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.domainssupported */
extern T1 T51f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.write_base */
extern void T50f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_domain */
extern void T50f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.domain_null_or_not_null */
extern T0* T50f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.domainnullallowed */
extern T1 T50f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.domainnotnullallowed */
extern T1 T50f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.domainnulldefault */
extern T1 T50f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.domain_identifier */
extern T0* T50f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.domainnameprefix */
extern T0* T50f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.createdomains */
extern T1 T50f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.domainssupported */
extern T1 T50f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.write_base */
extern void T49f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_domain */
extern void T49f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.domain_null_or_not_null */
extern T0* T49f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.domainnullallowed */
extern T1 T49f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.domainnotnullallowed */
extern T1 T49f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.domainnulldefault */
extern T1 T49f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.domain_identifier */
extern T0* T49f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.domainnameprefix */
extern T0* T49f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.createdomains */
extern T1 T49f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.domainssupported */
extern T1 T49f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.write_base */
extern void T48f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_domain */
extern void T48f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.domain_null_or_not_null */
extern T0* T48f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.domainnullallowed */
extern T1 T48f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.domainnotnullallowed */
extern T1 T48f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.domainnulldefault */
extern T1 T48f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.domain_identifier */
extern T0* T48f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.domainnameprefix */
extern T0* T48f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.createdomains */
extern T1 T48f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.domainssupported */
extern T1 T48f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_base */
extern void T47f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_domain */
extern void T47f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.domain_null_or_not_null */
extern T0* T47f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.domainnullallowed */
extern T1 T47f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.domainnotnullallowed */
extern T1 T47f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.domainnulldefault */
extern T1 T47f148(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.domain_identifier */
extern T0* T47f44(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.domainnameprefix */
extern T0* T47f146(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createdomains */
extern T1 T47f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.domainssupported */
extern T1 T47f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.write_base */
extern void T46f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_domain */
extern void T46f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.domain_null_or_not_null */
extern T0* T46f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.domainnullallowed */
extern T1 T46f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.domainnotnullallowed */
extern T1 T46f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.domainnulldefault */
extern T1 T46f148(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.domain_identifier */
extern T0* T46f44(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.domainnameprefix */
extern T0* T46f146(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createdomains */
extern T1 T46f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.domainssupported */
extern T1 T46f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.write_base */
extern void T45f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_domain */
extern void T45f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.domain_null_or_not_null */
extern T0* T45f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.domainnullallowed */
extern T1 T45f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.domainnotnullallowed */
extern T1 T45f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.domainnulldefault */
extern T1 T45f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.domain_identifier */
extern T0* T45f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.domainnameprefix */
extern T0* T45f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.createdomains */
extern T1 T45f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.domainssupported */
extern T1 T45f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_base */
extern void T44f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_domain */
extern void T44f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.domain_null_or_not_null */
extern T0* T44f45(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.domainnullallowed */
extern T1 T44f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.domainnotnullallowed */
extern T1 T44f148(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.domainnulldefault */
extern T1 T44f147(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.domain_identifier */
extern T0* T44f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.domainnameprefix */
extern T0* T44f145(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createdomains */
extern T1 T44f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.domainssupported */
extern T1 T44f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.write_base */
extern void T43f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_domain */
extern void T43f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.domain_null_or_not_null */
extern T0* T43f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.domainnullallowed */
extern T1 T43f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.domainnotnullallowed */
extern T1 T43f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.domainnulldefault */
extern T1 T43f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.domain_identifier */
extern T0* T43f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.domainnameprefix */
extern T0* T43f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.createdomains */
extern T1 T43f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.domainssupported */
extern T1 T43f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.write_base */
extern void T42f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_domain */
extern void T42f258(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.domain_null_or_not_null */
extern T0* T42f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.domainnullallowed */
extern T1 T42f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.domainnotnullallowed */
extern T1 T42f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.domainnulldefault */
extern T1 T42f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.domain_identifier */
extern T0* T42f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.domainnameprefix */
extern T0* T42f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.createdomains */
extern T1 T42f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.domainssupported */
extern T1 T42f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.write_base */
extern void T41f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_domain */
extern void T41f258(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.domain_null_or_not_null */
extern T0* T41f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.domainnullallowed */
extern T1 T41f127(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.domainnotnullallowed */
extern T1 T41f126(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.domainnulldefault */
extern T1 T41f125(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.domain_identifier */
extern T0* T41f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.domainnameprefix */
extern T0* T41f123(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.createdomains */
extern T1 T41f32(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.domainssupported */
extern T1 T41f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_constant_assignment */
extern void T64f252(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.create_constant_assignment */
extern void T64f273(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.write_constant_assignment */
extern void T63f251(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.create_constant_assignment */
extern void T63f272(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.write_constant_assignment */
extern void T62f251(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.create_constant_assignment */
extern void T62f272(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.write_constant_assignment */
extern void T61f251(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.create_constant_assignment */
extern void T61f272(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.write_constant_assignment */
extern void T60f250(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.create_constant_assignment */
extern void T60f271(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.write_constant_assignment */
extern void T59f274(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.create_constant_assignment */
extern void T59f295(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.write_constant_assignment */
extern void T58f276(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.create_constant_assignment */
extern void T58f297(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.write_constant_assignment */
extern void T57f277(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.create_constant_assignment */
extern void T57f298(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.write_constant_assignment */
extern void T56f277(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.create_constant_assignment */
extern void T56f298(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.write_constant_assignment */
extern void T55f277(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.create_constant_assignment */
extern void T55f298(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.write_constant_assignment */
extern void T54f272(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.create_constant_assignment */
extern void T54f293(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.write_constant_assignment */
extern void T53f238(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.create_constant_assignment */
extern void T53f259(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.write_constant_assignment */
extern void T52f238(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.create_constant_assignment */
extern void T52f259(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.write_constant_assignment */
extern void T51f263(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.create_constant_assignment */
extern void T51f284(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.write_constant_assignment */
extern void T50f237(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.create_constant_assignment */
extern void T50f258(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.write_constant_assignment */
extern void T49f237(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.create_constant_assignment */
extern void T49f258(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.write_constant_assignment */
extern void T48f237(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.create_constant_assignment */
extern void T48f258(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.write_constant_assignment */
extern void T47f267(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.create_constant_assignment */
extern void T47f288(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.write_constant_assignment */
extern void T46f267(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.create_constant_assignment */
extern void T46f288(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.write_constant_assignment */
extern void T45f237(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.create_constant_assignment */
extern void T45f258(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.write_constant_assignment */
extern void T44f268(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.create_constant_assignment */
extern void T44f289(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.write_constant_assignment */
extern void T43f239(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.create_constant_assignment */
extern void T43f260(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.write_constant_assignment */
extern void T42f238(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.create_constant_assignment */
extern void T42f259(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.write_constant_assignment */
extern void T41f238(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.create_constant_assignment */
extern void T41f259(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.write_constant */
extern void T64f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_constant */
extern void T64f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_constant */
extern void T64f274p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_constant */
extern void T63f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_constant */
extern void T63f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_constant */
extern void T63f273p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_constant */
extern void T62f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_constant */
extern void T62f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_constant */
extern void T62f273p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_constant */
extern void T61f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_constant */
extern void T61f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_constant */
extern void T61f273p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_constant */
extern void T60f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_constant */
extern void T60f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_constant */
extern void T59f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_constant */
extern void T59f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_constant */
extern void T58f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_constant */
extern void T58f298(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_constant */
extern void T57f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_constant */
extern void T57f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_constant */
extern void T56f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_constant */
extern void T56f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_constant */
extern void T55f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_constant */
extern void T55f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_constant */
extern void T54f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_constant */
extern void T54f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_constant */
extern void T53f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_constant */
extern void T53f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_constant */
extern void T52f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_constant */
extern void T52f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_constant */
extern void T51f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_constant */
extern void T51f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_constant */
extern void T50f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_constant */
extern void T50f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_constant */
extern void T49f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_constant */
extern void T49f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_constant */
extern void T48f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_constant */
extern void T48f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_constant */
extern void T47f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_constant */
extern void T47f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_constant */
extern void T46f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_constant */
extern void T46f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_constant */
extern void T45f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_constant */
extern void T45f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_constant */
extern void T44f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_constant */
extern void T44f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_constant */
extern void T43f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_constant */
extern void T43f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_constant */
extern void T42f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_constant */
extern void T42f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_constant */
extern void T41f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_constant */
extern void T41f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_drop */
extern void T64f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_drop */
extern void T63f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_drop */
extern void T62f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_drop */
extern void T61f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_drop */
extern void T60f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_drop */
extern void T59f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_drop */
extern void T58f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_drop */
extern void T57f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_drop */
extern void T56f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_drop */
extern void T55f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_drop */
extern void T54f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_drop */
extern void T53f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_drop */
extern void T52f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_drop */
extern void T51f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_drop */
extern void T50f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_drop */
extern void T49f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_drop */
extern void T48f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_drop */
extern void T47f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_drop */
extern void T46f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_drop */
extern void T45f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_drop */
extern void T44f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_drop */
extern void T43f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_drop */
extern void T42f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_drop */
extern void T41f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_assertion */
extern void T64f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_assertion */
extern void T64f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_assertion */
extern void T64f275p1(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.sqlselect */
extern T0* T303f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.sqlselect */
extern T0* T301f7(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.viewcolumnssupported */
extern T1 T64f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.createviewsql */
extern T0* T64f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.drop_view_if_exist */
extern void T64f298(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.viewssupported */
extern T1 T64f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.createassert */
extern T1 T64f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_assertion */
extern void T63f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_assertion */
extern void T63f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_assertion */
extern void T63f274p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.viewcolumnssupported */
extern T1 T63f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.createviewsql */
extern T0* T63f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.drop_view_if_exist */
extern void T63f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.viewssupported */
extern T1 T63f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.createassert */
extern T1 T63f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_assertion */
extern void T62f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_assertion */
extern void T62f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_assertion */
extern void T62f274p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.viewcolumnssupported */
extern T1 T62f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.createviewsql */
extern T0* T62f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.drop_view_if_exist */
extern void T62f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.viewssupported */
extern T1 T62f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.createassert */
extern T1 T62f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_assertion */
extern void T61f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_assertion */
extern void T61f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_assertion */
extern void T61f274p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.viewcolumnssupported */
extern T1 T61f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.createviewsql */
extern T0* T61f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.drop_view_if_exist */
extern void T61f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.viewssupported */
extern T1 T61f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.createassert */
extern T1 T61f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_assertion */
extern void T60f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_assertion */
extern void T60f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.createviewsql */
extern T0* T60f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.drop_view_if_exist */
extern void T60f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.viewssupported */
extern T1 T60f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.createassert */
extern T1 T60f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.write_assertion */
extern void T59f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_assertion */
extern void T59f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.viewcolumnssupported */
extern T1 T59f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createviewsql */
extern T0* T59f49(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.drop_view_if_exist */
extern void T59f318(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.viewssupported */
extern T1 T59f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createassert */
extern T1 T59f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_assertion */
extern void T58f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_assertion */
extern void T58f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.viewcolumnssupported */
extern T1 T58f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.drop_view_if_exist */
extern void T58f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.viewssupported */
extern T1 T58f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.createassert */
extern T1 T58f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_assertion */
extern void T57f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_assertion */
extern void T57f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.viewcolumnssupported */
extern T1 T57f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.drop_view_if_exist */
extern void T57f321(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.viewssupported */
extern T1 T57f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.createassert */
extern T1 T57f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_assertion */
extern void T56f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_assertion */
extern void T56f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.viewcolumnssupported */
extern T1 T56f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.drop_view_if_exist */
extern void T56f321(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.viewssupported */
extern T1 T56f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.createassert */
extern T1 T56f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_assertion */
extern void T55f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_assertion */
extern void T55f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.viewcolumnssupported */
extern T1 T55f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.drop_view_if_exist */
extern void T55f321(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.viewssupported */
extern T1 T55f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.createassert */
extern T1 T55f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_assertion */
extern void T54f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_assertion */
extern void T54f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.viewcolumnssupported */
extern T1 T54f52(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.createviewsql */
extern T0* T54f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.drop_view_if_exist */
extern void T54f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.viewssupported */
extern T1 T54f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.createassert */
extern T1 T54f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.write_assertion */
extern void T53f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_assertion */
extern void T53f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.viewcolumnssupported */
extern T1 T53f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.createviewsql */
extern T0* T53f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.drop_view_if_exist */
extern void T53f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.viewssupported */
extern T1 T53f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.createassert */
extern T1 T53f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.write_assertion */
extern void T52f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_assertion */
extern void T52f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.viewcolumnssupported */
extern T1 T52f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.createviewsql */
extern T0* T52f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.drop_view_if_exist */
extern void T52f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.viewssupported */
extern T1 T52f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.createassert */
extern T1 T52f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_assertion */
extern void T51f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_assertion */
extern void T51f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.viewcolumnssupported */
extern T1 T51f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createviewsql */
extern T0* T51f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.drop_view_if_exist */
extern void T51f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.viewssupported */
extern T1 T51f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createassert */
extern T1 T51f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.write_assertion */
extern void T50f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_assertion */
extern void T50f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.viewcolumnssupported */
extern T1 T50f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.createviewsql */
extern T0* T50f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.drop_view_if_exist */
extern void T50f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.viewssupported */
extern T1 T50f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.createassert */
extern T1 T50f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.write_assertion */
extern void T49f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_assertion */
extern void T49f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.viewcolumnssupported */
extern T1 T49f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.createviewsql */
extern T0* T49f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.drop_view_if_exist */
extern void T49f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.viewssupported */
extern T1 T49f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.createassert */
extern T1 T49f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.write_assertion */
extern void T48f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_assertion */
extern void T48f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.viewcolumnssupported */
extern T1 T48f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.createviewsql */
extern T0* T48f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.drop_view_if_exist */
extern void T48f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.viewssupported */
extern T1 T48f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.createassert */
extern T1 T48f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_assertion */
extern void T47f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_assertion */
extern void T47f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.viewcolumnssupported */
extern T1 T47f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createviewsql */
extern T0* T47f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.drop_view_if_exist */
extern void T47f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.viewssupported */
extern T1 T47f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createassert */
extern T1 T47f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.write_assertion */
extern void T46f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_assertion */
extern void T46f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.viewcolumnssupported */
extern T1 T46f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createviewsql */
extern T0* T46f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.drop_view_if_exist */
extern void T46f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.viewssupported */
extern T1 T46f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createassert */
extern T1 T46f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.write_assertion */
extern void T45f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_assertion */
extern void T45f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.viewcolumnssupported */
extern T1 T45f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.createviewsql */
extern T0* T45f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.drop_view_if_exist */
extern void T45f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.viewssupported */
extern T1 T45f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.createassert */
extern T1 T45f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_assertion */
extern void T44f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_assertion */
extern void T44f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.viewcolumnssupported */
extern T1 T44f52(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createviewsql */
extern T0* T44f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.drop_view_if_exist */
extern void T44f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.viewssupported */
extern T1 T44f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createassert */
extern T1 T44f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.write_assertion */
extern void T43f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_assertion */
extern void T43f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.viewcolumnssupported */
extern T1 T43f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.createviewsql */
extern T0* T43f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.drop_view_if_exist */
extern void T43f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.viewssupported */
extern T1 T43f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.createassert */
extern T1 T43f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.write_assertion */
extern void T42f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_assertion */
extern void T42f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.viewcolumnssupported */
extern T1 T42f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.createviewsql */
extern T0* T42f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.drop_view_if_exist */
extern void T42f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.viewssupported */
extern T1 T42f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.createassert */
extern T1 T42f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.write_assertion */
extern void T41f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_assertion */
extern void T41f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.viewcolumnssupported */
extern T1 T41f50(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.createviewsql */
extern T0* T41f48(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.drop_view_if_exist */
extern void T41f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.viewssupported */
extern T1 T41f34(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.createassert */
extern T1 T41f33(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_index */
extern void T64f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_index */
extern void T64f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_index */
extern void T64f276p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.index_name */
extern T0* T64f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.clusteredindexsupported */
extern T1 T64f54(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.createindex */
extern T1 T64f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.indexsupported */
extern T1 T64f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_index */
extern void T63f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_index */
extern void T63f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_index */
extern void T63f275p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.index_name */
extern T0* T63f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.clusteredindexsupported */
extern T1 T63f54(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.createindex */
extern T1 T63f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.indexsupported */
extern T1 T63f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_index */
extern void T62f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_index */
extern void T62f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_index */
extern void T62f275p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.index_name */
extern T0* T62f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.clusteredindexsupported */
extern T1 T62f54(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.createindex */
extern T1 T62f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.indexsupported */
extern T1 T62f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_index */
extern void T61f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_index */
extern void T61f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_index */
extern void T61f275p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.index_name */
extern T0* T61f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.clusteredindexsupported */
extern T1 T61f54(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.createindex */
extern T1 T61f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.indexsupported */
extern T1 T61f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_index */
extern void T60f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_index */
extern void T60f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.index_name */
extern T0* T60f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.clusteredindexsupported */
extern T1 T60f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.createindex */
extern T1 T60f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.indexsupported */
extern T1 T60f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.write_index */
extern void T59f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_index */
extern void T59f298(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.index_name */
extern T0* T59f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.clusteredindexsupported */
extern T1 T59f52(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createindex */
extern T1 T59f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.indexsupported */
extern T1 T59f147(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_index */
extern void T58f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_index */
extern void T58f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.index_name */
extern T0* T58f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.clusteredindexsupported */
extern T1 T58f52(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.createindex */
extern T1 T58f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.indexsupported */
extern T1 T58f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_index */
extern void T57f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_index */
extern void T57f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.index_name */
extern T0* T57f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.clusteredindexsupported */
extern T1 T57f52(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.createindex */
extern T1 T57f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.indexsupported */
extern T1 T57f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_index */
extern void T56f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_index */
extern void T56f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.index_name */
extern T0* T56f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.clusteredindexsupported */
extern T1 T56f52(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.createindex */
extern T1 T56f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.indexsupported */
extern T1 T56f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_index */
extern void T55f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_index */
extern void T55f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.index_name */
extern T0* T55f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.clusteredindexsupported */
extern T1 T55f52(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.createindex */
extern T1 T55f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.indexsupported */
extern T1 T55f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_index */
extern void T54f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_index */
extern void T54f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.index_name */
extern T0* T54f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.clusteredindexsupported */
extern T1 T54f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.createindex */
extern T1 T54f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.indexsupported */
extern T1 T54f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.write_index */
extern void T53f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_index */
extern void T53f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.index_name */
extern T0* T53f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.clusteredindexsupported */
extern T1 T53f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.createindex */
extern T1 T53f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.indexsupported */
extern T1 T53f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.write_index */
extern void T52f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_index */
extern void T52f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.index_name */
extern T0* T52f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.clusteredindexsupported */
extern T1 T52f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.createindex */
extern T1 T52f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.indexsupported */
extern T1 T52f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_index */
extern void T51f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_index */
extern void T51f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.index_name */
extern T0* T51f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.clusteredindexsupported */
extern T1 T51f54(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createindex */
extern T1 T51f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.indexsupported */
extern T1 T51f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.write_index */
extern void T50f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_index */
extern void T50f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.index_name */
extern T0* T50f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.clusteredindexsupported */
extern T1 T50f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.createindex */
extern T1 T50f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.indexsupported */
extern T1 T50f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.write_index */
extern void T49f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_index */
extern void T49f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.index_name */
extern T0* T49f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.clusteredindexsupported */
extern T1 T49f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.createindex */
extern T1 T49f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.indexsupported */
extern T1 T49f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.write_index */
extern void T48f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_index */
extern void T48f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.index_name */
extern T0* T48f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.clusteredindexsupported */
extern T1 T48f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.createindex */
extern T1 T48f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.indexsupported */
extern T1 T48f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_index */
extern void T47f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_index */
extern void T47f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.index_name */
extern T0* T47f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.clusteredindexsupported */
extern T1 T47f54(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createindex */
extern T1 T47f36(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.indexsupported */
extern T1 T47f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.write_index */
extern void T46f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_index */
extern void T46f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.index_name */
extern T0* T46f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.clusteredindexsupported */
extern T1 T46f54(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createindex */
extern T1 T46f36(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.indexsupported */
extern T1 T46f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.write_index */
extern void T45f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_index */
extern void T45f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.index_name */
extern T0* T45f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.clusteredindexsupported */
extern T1 T45f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.createindex */
extern T1 T45f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.indexsupported */
extern T1 T45f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_index */
extern void T44f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_index */
extern void T44f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.index_name */
extern T0* T44f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.clusteredindexsupported */
extern T1 T44f53(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createindex */
extern T1 T44f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.indexsupported */
extern T1 T44f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.write_index */
extern void T43f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_index */
extern void T43f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.index_name */
extern T0* T43f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.clusteredindexsupported */
extern T1 T43f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.createindex */
extern T1 T43f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.indexsupported */
extern T1 T43f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.write_index */
extern void T42f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_index */
extern void T42f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.index_name */
extern T0* T42f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.clusteredindexsupported */
extern T1 T42f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.createindex */
extern T1 T42f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.indexsupported */
extern T1 T42f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.write_index */
extern void T41f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_index */
extern void T41f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.index_name */
extern T0* T41f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.clusteredindexsupported */
extern T1 T41f51(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.createindex */
extern T1 T41f35(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.indexsupported */
extern T1 T41f120(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_insert */
extern void T64f257(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.create_insert */
extern void T64f277(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.set_nocount_off */
extern void T64f300(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.create_insert */
extern void T64f277p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T64f301(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_TSQL65.table_has_identity_column */
extern T1 T64f57(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.set_nocount_on */
extern void T64f299(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_insert */
extern void T63f256(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.create_insert */
extern void T63f276(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.set_nocount_off */
extern void T63f299(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.create_insert */
extern void T63f276p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T63f300(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_TSQL70.table_has_identity_column */
extern T1 T63f57(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.set_nocount_on */
extern void T63f298(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_insert */
extern void T62f256(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.create_insert */
extern void T62f276(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.set_nocount_off */
extern void T62f299(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.create_insert */
extern void T62f276p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T62f300(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_TSQL2000.table_has_identity_column */
extern T1 T62f57(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.set_nocount_on */
extern void T62f298(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_insert */
extern void T61f256(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.create_insert */
extern void T61f276(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.set_nocount_off */
extern void T61f299(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.create_insert */
extern void T61f276p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T61f300(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_TSQL2016.table_has_identity_column */
extern T1 T61f57(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.set_nocount_on */
extern void T61f298(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_insert */
extern void T60f255(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_SQLITE_3.create_insert */
extern void T60f275(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_SQLITE_3.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T60f291(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_PGSQL_72.write_insert */
extern void T59f279(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.create_insert */
extern void T59f299(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T59f319(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_PGSQL_73.write_insert */
extern void T58f281(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.create_insert */
extern void T58f301(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T58f321(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_PGSQL_81.write_insert */
extern void T57f282(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_81.create_insert */
extern void T57f302(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_81.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T57f322(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_PGSQL_82.write_insert */
extern void T56f282(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_82.create_insert */
extern void T56f302(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_82.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T56f322(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_PGSQL_95.write_insert */
extern void T55f282(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_95.create_insert */
extern void T55f302(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_95.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T55f322(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_ORACLE.write_insert */
extern void T54f277(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ORACLE.create_insert */
extern void T54f297(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ORACLE.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T54f318(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_MYSQL322.write_insert */
extern void T53f243(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL322.create_insert */
extern void T53f263(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL322.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T53f278(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_MYSQL4.write_insert */
extern void T52f243(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL4.create_insert */
extern void T52f263(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL4.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T52f278(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_MYSQL5.write_insert */
extern void T51f268(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.create_insert */
extern void T51f288(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T51f309(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_MSQL.write_insert */
extern void T50f242(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSQL.create_insert */
extern void T50f262(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSQL.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T50f277(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_MSACCESS2000.write_insert */
extern void T49f242(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS2000.create_insert */
extern void T49f262(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS2000.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T49f277(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_MSACCESS97.write_insert */
extern void T48f242(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS97.create_insert */
extern void T48f262(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS97.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T48f277(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_FIREBIRD_21.write_insert */
extern void T47f272(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.create_insert */
extern void T47f292(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T47f313(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_INTERBASE6.write_insert */
extern void T46f272(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.create_insert */
extern void T46f292(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T46f313(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_FOXPRO.write_insert */
extern void T45f242(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FOXPRO.create_insert */
extern void T45f262(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FOXPRO.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T45f277(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_DB2_71.write_insert */
extern void T44f273(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.create_insert */
extern void T44f293(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T44f314(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_DB2_6.write_insert */
extern void T43f244(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_6.create_insert */
extern void T43f264(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_6.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T43f279(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_BASIC.write_insert */
extern void T42f243(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_BASIC.create_insert */
extern void T42f263(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_BASIC.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T42f278(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_ANSI.write_insert */
extern void T41f243(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ANSI.create_insert */
extern void T41f263(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ANSI.create_sync_auto_generated_primary_key_with_supplied_value */
extern void T41f278(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SQL_GENERATOR_TSQL65.write_delete */
extern void T64f258(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.create_delete */
extern void T64f278(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.write_delete */
extern void T63f257(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.create_delete */
extern void T63f277(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.write_delete */
extern void T62f257(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.create_delete */
extern void T62f277(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.write_delete */
extern void T61f257(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.create_delete */
extern void T61f277(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.write_delete */
extern void T60f256(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.create_delete */
extern void T60f276(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.write_delete */
extern void T59f280(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.create_delete */
extern void T59f300(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.write_delete */
extern void T58f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.create_delete */
extern void T58f302(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.write_delete */
extern void T57f283(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.create_delete */
extern void T57f303(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.write_delete */
extern void T56f283(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.create_delete */
extern void T56f303(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.write_delete */
extern void T55f283(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.create_delete */
extern void T55f303(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.write_delete */
extern void T54f278(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.create_delete */
extern void T54f298(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.write_delete */
extern void T53f244(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.create_delete */
extern void T53f264(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.write_delete */
extern void T52f244(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.create_delete */
extern void T52f264(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.write_delete */
extern void T51f269(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.create_delete */
extern void T51f289(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.write_delete */
extern void T50f243(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.create_delete */
extern void T50f263(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.write_delete */
extern void T49f243(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.create_delete */
extern void T49f263(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.write_delete */
extern void T48f243(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.create_delete */
extern void T48f263(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.write_delete */
extern void T47f273(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.create_delete */
extern void T47f293(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.write_delete */
extern void T46f273(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.create_delete */
extern void T46f293(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.write_delete */
extern void T45f243(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.create_delete */
extern void T45f263(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.write_delete */
extern void T44f274(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.create_delete */
extern void T44f294(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.write_delete */
extern void T43f245(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.create_delete */
extern void T43f265(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.write_delete */
extern void T42f244(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.create_delete */
extern void T42f264(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.write_delete */
extern void T41f244(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.create_delete */
extern void T41f264(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.write_update */
extern void T64f259(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.create_update */
extern void T64f279(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T64f279ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_TSQL65.output_update_from_clause */
extern void T64f306(GE_context* ac, T0* C, T0* a1, T0* a2);
/* JOIN_LIST.is_empty */
extern T1 T329f8(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.output_update_join_clause */
extern void T64f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.output_update_extend_from_clause */
extern void T64f304(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.supportsqualifiedsetinupdate */
extern T1 T64f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.output_update_extend_join_clause */
extern void T64f303(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.supportsjoininupdate */
extern T1 T64f63(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.make */
extern T0* T159c27(GE_context* ac, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.write_update */
extern void T63f258(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.create_update */
extern void T63f278(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T63f278ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_TSQL70.output_update_from_clause */
extern void T63f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.output_update_join_clause */
extern void T63f304(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.output_update_extend_from_clause */
extern void T63f303(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.supportsqualifiedsetinupdate */
extern T1 T63f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.output_update_extend_join_clause */
extern void T63f302(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.supportsjoininupdate */
extern T1 T63f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_update */
extern void T62f258(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.create_update */
extern void T62f278(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T62f278ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_TSQL2000.output_update_from_clause */
extern void T62f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.output_update_join_clause */
extern void T62f304(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.output_update_extend_from_clause */
extern void T62f303(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.supportsqualifiedsetinupdate */
extern T1 T62f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.output_update_extend_join_clause */
extern void T62f302(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.supportsjoininupdate */
extern T1 T62f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_update */
extern void T61f258(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.create_update */
extern void T61f278(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T61f278ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_TSQL2016.output_update_from_clause */
extern void T61f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.output_update_join_clause */
extern void T61f304(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.output_update_extend_from_clause */
extern void T61f303(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.supportsqualifiedsetinupdate */
extern T1 T61f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.output_update_extend_join_clause */
extern void T61f302(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.supportsjoininupdate */
extern T1 T61f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_update */
extern void T60f257(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_SQLITE_3.create_update */
extern void T60f277(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T60f277ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_SQLITE_3.output_update_from_clause */
extern void T60f296(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.output_update_join_clause */
extern void T60f295(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.output_update_extend_from_clause */
extern void T60f294(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.supportsqualifiedsetinupdate */
extern T1 T60f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.output_update_extend_join_clause */
extern void T60f293(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_SQLITE_3.supportsjoininupdate */
extern T1 T60f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.write_update */
extern void T59f281(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.create_update */
extern void T59f301(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T59f301ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_72.output_update_from_clause */
extern void T59f324(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.output_update_join_clause */
extern void T59f323(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.output_update_extend_from_clause */
extern void T59f322(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.supportsqualifiedsetinupdate */
extern T1 T59f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.output_update_extend_join_clause */
extern void T59f321(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.supportsjoininupdate */
extern T1 T59f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_update */
extern void T58f283(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.create_update */
extern void T58f303(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T58f303ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_73.output_update_from_clause */
extern void T58f326(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.output_update_join_clause */
extern void T58f325(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.output_update_extend_from_clause */
extern void T58f324(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.supportsqualifiedsetinupdate */
extern T1 T58f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.output_update_extend_join_clause */
extern void T58f323(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.supportsjoininupdate */
extern T1 T58f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_update */
extern void T57f284(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_81.create_update */
extern void T57f304(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T57f304ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_81.output_update_from_clause */
extern void T57f327(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sql_update_joins */
extern T0* T57f95(GE_context* ac, T0* C, T1 a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.output_update_join_clause */
extern void T57f326(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.output_update_extend_from_clause */
extern void T57f325(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.supportsqualifiedsetinupdate */
extern T1 T57f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.output_update_extend_join_clause */
extern void T57f324(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_81.supportsjoininupdate */
extern T1 T57f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_update */
extern void T56f284(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_82.create_update */
extern void T56f304(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T56f304ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_82.output_update_from_clause */
extern void T56f327(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sql_update_joins */
extern T0* T56f95(GE_context* ac, T0* C, T1 a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.output_update_join_clause */
extern void T56f326(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.output_update_extend_from_clause */
extern void T56f325(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.supportsqualifiedsetinupdate */
extern T1 T56f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.output_update_extend_join_clause */
extern void T56f324(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_82.supportsjoininupdate */
extern T1 T56f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_update */
extern void T55f284(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_95.create_update */
extern void T55f304(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T55f304ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_95.output_update_from_clause */
extern void T55f327(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sql_update_joins */
extern T0* T55f95(GE_context* ac, T0* C, T1 a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.output_update_join_clause */
extern void T55f326(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.output_update_extend_from_clause */
extern void T55f325(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.supportsqualifiedsetinupdate */
extern T1 T55f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.output_update_extend_join_clause */
extern void T55f324(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_95.supportsjoininupdate */
extern T1 T55f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_update */
extern void T54f279(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ORACLE.create_update */
extern void T54f299(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T54f299ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_ORACLE.output_update_from_clause */
extern void T54f323(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.output_update_join_clause */
extern void T54f322(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.output_update_extend_from_clause */
extern void T54f321(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.supportsqualifiedsetinupdate */
extern T1 T54f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.output_update_extend_join_clause */
extern void T54f320(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ORACLE.supportsjoininupdate */
extern T1 T54f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.write_update */
extern void T53f245(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL322.create_update */
extern void T53f265(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T53f265ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MYSQL322.output_update_from_clause */
extern void T53f283(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.output_update_join_clause */
extern void T53f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.output_update_extend_from_clause */
extern void T53f281(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.supportsqualifiedsetinupdate */
extern T1 T53f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.output_update_extend_join_clause */
extern void T53f280(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL322.supportsjoininupdate */
extern T1 T53f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.write_update */
extern void T52f245(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL4.create_update */
extern void T52f265(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T52f265ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MYSQL4.output_update_from_clause */
extern void T52f283(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.output_update_join_clause */
extern void T52f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.output_update_extend_from_clause */
extern void T52f281(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.supportsqualifiedsetinupdate */
extern T1 T52f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.output_update_extend_join_clause */
extern void T52f280(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL4.supportsjoininupdate */
extern T1 T52f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_update */
extern void T51f270(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.create_update */
extern void T51f290(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T51f290ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MYSQL5.output_update_from_clause */
extern void T51f314(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.output_update_join_clause */
extern void T51f313(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.output_update_extend_from_clause */
extern void T51f312(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.supportsqualifiedsetinupdate */
extern T1 T51f62(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.output_update_extend_join_clause */
extern void T51f311(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.output_update_extend_join_clause */
extern void T51f311p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.supportsjoininupdate */
extern T1 T51f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.write_update */
extern void T50f244(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSQL.create_update */
extern void T50f264(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T50f264ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MSQL.output_update_from_clause */
extern void T50f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.output_update_join_clause */
extern void T50f281(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.output_update_extend_from_clause */
extern void T50f280(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.supportsqualifiedsetinupdate */
extern T1 T50f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.output_update_extend_join_clause */
extern void T50f279(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSQL.supportsjoininupdate */
extern T1 T50f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.write_update */
extern void T49f244(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS2000.create_update */
extern void T49f264(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T49f264ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MSACCESS2000.output_update_from_clause */
extern void T49f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.output_update_join_clause */
extern void T49f281(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.output_update_extend_from_clause */
extern void T49f280(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.supportsqualifiedsetinupdate */
extern T1 T49f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.output_update_extend_join_clause */
extern void T49f279(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS2000.supportsjoininupdate */
extern T1 T49f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.write_update */
extern void T48f244(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS97.create_update */
extern void T48f264(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T48f264ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MSACCESS97.output_update_from_clause */
extern void T48f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.output_update_join_clause */
extern void T48f281(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.output_update_extend_from_clause */
extern void T48f280(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.supportsqualifiedsetinupdate */
extern T1 T48f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.output_update_extend_join_clause */
extern void T48f279(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS97.supportsjoininupdate */
extern T1 T48f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_update */
extern void T47f274(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.create_update */
extern void T47f294(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T47f294ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_FIREBIRD_21.output_update_from_clause */
extern void T47f318(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.output_update_join_clause */
extern void T47f317(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.output_update_extend_from_clause */
extern void T47f316(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.supportsqualifiedsetinupdate */
extern T1 T47f62(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.output_update_extend_join_clause */
extern void T47f315(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.supportsjoininupdate */
extern T1 T47f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.write_update */
extern void T46f274(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.create_update */
extern void T46f294(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T46f294ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_INTERBASE6.output_update_from_clause */
extern void T46f318(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.output_update_join_clause */
extern void T46f317(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.output_update_extend_from_clause */
extern void T46f316(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.supportsqualifiedsetinupdate */
extern T1 T46f62(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.output_update_extend_join_clause */
extern void T46f315(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.supportsjoininupdate */
extern T1 T46f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.write_update */
extern void T45f244(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FOXPRO.create_update */
extern void T45f264(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T45f264ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_FOXPRO.output_update_from_clause */
extern void T45f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.output_update_join_clause */
extern void T45f281(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.output_update_extend_from_clause */
extern void T45f280(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.supportsqualifiedsetinupdate */
extern T1 T45f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.output_update_extend_join_clause */
extern void T45f279(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FOXPRO.supportsjoininupdate */
extern T1 T45f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_update */
extern void T44f275(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.create_update */
extern void T44f295(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T44f295ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_DB2_71.output_update_from_clause */
extern void T44f319(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.output_update_join_clause */
extern void T44f318(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.output_update_extend_from_clause */
extern void T44f317(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.supportsqualifiedsetinupdate */
extern T1 T44f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.output_update_extend_join_clause */
extern void T44f316(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.supportsjoininupdate */
extern T1 T44f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.write_update */
extern void T43f246(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_6.create_update */
extern void T43f266(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T43f266ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_DB2_6.output_update_from_clause */
extern void T43f284(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.output_update_join_clause */
extern void T43f283(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.output_update_extend_from_clause */
extern void T43f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.supportsqualifiedsetinupdate */
extern T1 T43f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.output_update_extend_join_clause */
extern void T43f281(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_6.supportsjoininupdate */
extern T1 T43f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.write_update */
extern void T42f245(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_BASIC.create_update */
extern void T42f265(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T42f265ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_BASIC.output_update_from_clause */
extern void T42f283(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.output_update_join_clause */
extern void T42f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.output_update_extend_from_clause */
extern void T42f281(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.supportsqualifiedsetinupdate */
extern T1 T42f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.output_update_extend_join_clause */
extern void T42f280(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_BASIC.supportsjoininupdate */
extern T1 T42f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.write_update */
extern void T41f245(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ANSI.create_update */
extern void T41f265(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T41f265ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_ANSI.output_update_from_clause */
extern void T41f283(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.output_update_join_clause */
extern void T41f282(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.output_update_extend_from_clause */
extern void T41f281(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.supportsqualifiedsetinupdate */
extern T1 T41f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.output_update_extend_join_clause */
extern void T41f280(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ANSI.supportsjoininupdate */
extern T1 T41f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_value */
extern void T64f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_value */
extern void T64f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_value_assign */
extern void T64f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_value_assign_outside_sp */
extern void T64f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_create_value_assign */
extern void T64f334(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_value_assign_inside_sp */
extern void T64f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.optional_create_value_declare */
extern void T64f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_value_declare */
extern void T64f326(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].force */
extern void T114f37(GE_context* ac, T0* C, T0* a1, T0* a2);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].key_storage_put */
extern void T114f47(GE_context* ac, T0* C, T0* a1, T6 a2);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].slots_put */
extern void T114f46(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].clashes_put */
extern void T114f45(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].slots_item */
extern T6 T114f23(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].clashes_item */
extern T6 T114f21(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].hash_position */
extern T6 T114f26(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].resize */
extern void T114f44(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].clashes_resize */
extern void T114f56(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].special_integer_ */
extern T0* T114f30(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].key_storage_resize */
extern void T114f55(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].item_storage_resize */
extern void T114f54(GE_context* ac, T0* C, T6 a1);
/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE].aliased_resized_area */
extern T0* T381f1(GE_context* ac, T0* C, T0* a1, T6 a2);
/* SPECIAL [XPLAIN_VALUE].aliased_resized_area */
extern T0* T382f3(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].key_storage_item */
extern T0* T114f29(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].slots_resize */
extern void T114f53(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].new_capacity */
extern T6 T114f25(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].item_storage_put */
extern void T114f43(GE_context* ac, T0* C, T0* a1, T6 a2);
/* KL_SPECIAL_ROUTINES [XPLAIN_VALUE].force */
extern void T381f4(GE_context* ac, T0* C, T0* a1, T0* a2, T6 a3);
/* SPECIAL [XPLAIN_VALUE].fill_with */
extern void T382f8(GE_context* ac, T0* C, T0* a1, T6 a2, T6 a3);
/* SPECIAL [XPLAIN_VALUE].extend */
extern void T382f10(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].search_position */
extern void T114f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_value_declare_outside_sp */
extern void T64f333(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_create_value_declare */
extern void T64f336(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_value_declare_inside_sp */
extern void T64f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.is_value_declared */
extern T1 T64f97(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].has */
extern T1 T114f31(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_value */
extern void T63f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_value */
extern void T63f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_value_assign */
extern void T63f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_value_assign_outside_sp */
extern void T63f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.do_create_value_assign */
extern void T63f333(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_value_assign_inside_sp */
extern void T63f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.optional_create_value_declare */
extern void T63f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_value_declare */
extern void T63f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_value_declare_outside_sp */
extern void T63f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.do_create_value_declare */
extern void T63f334(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_value_declare_inside_sp */
extern void T63f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.is_value_declared */
extern T1 T63f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_value */
extern void T62f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_value */
extern void T62f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_value_assign */
extern void T62f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_value_assign_outside_sp */
extern void T62f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.do_create_value_assign */
extern void T62f333(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_value_assign_inside_sp */
extern void T62f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.optional_create_value_declare */
extern void T62f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_value_declare */
extern void T62f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_value_declare_outside_sp */
extern void T62f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.do_create_value_declare */
extern void T62f334(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_value_declare_inside_sp */
extern void T62f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.is_value_declared */
extern T1 T62f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_value */
extern void T61f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_value */
extern void T61f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_value_assign */
extern void T61f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_value_assign_outside_sp */
extern void T61f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.do_create_value_assign */
extern void T61f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_value_assign_inside_sp */
extern void T61f324(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.optional_create_value_declare */
extern void T61f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_value_declare */
extern void T61f323(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_value_declare_outside_sp */
extern void T61f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.do_create_value_declare */
extern void T61f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_value_declare_inside_sp */
extern void T61f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.is_value_declared */
extern T1 T61f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_value */
extern void T60f258(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_value */
extern void T60f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_value_assign */
extern void T60f298(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_value_assign_outside_sp */
extern void T60f304(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE.quoted_name */
extern T0* T256f5(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.valuetablename */
extern T0* T60f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.createtemporaryvaluetable */
extern T1 T60f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.temporarytablessupported */
extern T1 T60f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.optional_create_value_declare */
extern void T60f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_value_declare */
extern void T60f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_value_declare_outside_sp */
extern void T60f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_value_alter_table */
extern void T60f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_value_create_table */
extern void T60f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.finishtemporaryvaluetablestatement */
extern T0* T60f83(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.finishtemporarytablestatement */
extern T0* T60f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.createtemporarytablestatement */
extern T0* T60f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.is_value_data_type_changed */
extern T1 T60f75(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].item */
extern T0* T114f32(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].item_storage_item */
extern T0* T114f34(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_SQLITE_3.is_value_declared */
extern T1 T60f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_value */
extern void T59f282(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_value */
extern void T59f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_value_assign */
extern void T59f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_value_assign_outside_sp */
extern void T59f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.valuetablename */
extern T0* T59f96(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createtemporaryvaluetable */
extern T1 T59f107(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.temporarytablessupported */
extern T1 T59f172(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_value_assign_inside_sp */
extern void T59f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.optional_create_value_declare */
extern void T59f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_value_declare */
extern void T59f344(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_value_declare_outside_sp */
extern void T59f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_value_alter_table */
extern void T59f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_value_create_table */
extern void T59f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.finishtemporaryvaluetablestatement */
extern T0* T59f108(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.finishtemporarytablestatement */
extern T0* T59f101(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createtemporarytablestatement */
extern T0* T59f99(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_value_declare_inside_sp */
extern void T59f351(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.is_value_declared */
extern T1 T59f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_value */
extern void T58f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_value */
extern void T58f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_value_assign */
extern void T58f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_value_assign_outside_sp */
extern void T58f348(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.valuetablename */
extern T0* T58f96(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.createtemporaryvaluetable */
extern T1 T58f107(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.temporarytablessupported */
extern T1 T58f172(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_value_assign_inside_sp */
extern void T58f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.optional_create_value_declare */
extern void T58f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_value_declare */
extern void T58f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_value_declare_outside_sp */
extern void T58f356(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_value_alter_table */
extern void T58f358(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_value_create_table */
extern void T58f357(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.finishtemporaryvaluetablestatement */
extern T0* T58f108(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.finishtemporarytablestatement */
extern T0* T58f101(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.createtemporarytablestatement */
extern T0* T58f99(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_value_declare_inside_sp */
extern void T58f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.is_value_declared */
extern T1 T58f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_value */
extern void T57f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_value */
extern void T57f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_value_assign */
extern void T57f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_value_assign_outside_sp */
extern void T57f349(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.valuetablename */
extern T0* T57f97(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.createtemporaryvaluetable */
extern T1 T57f108(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.temporarytablessupported */
extern T1 T57f172(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_value_assign_inside_sp */
extern void T57f348(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.optional_create_value_declare */
extern void T57f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_value_declare */
extern void T57f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_value_declare_outside_sp */
extern void T57f357(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_value_alter_table */
extern void T57f359(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_value_create_table */
extern void T57f358(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.finishtemporaryvaluetablestatement */
extern T0* T57f109(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.finishtemporarytablestatement */
extern T0* T57f102(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.createtemporarytablestatement */
extern T0* T57f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_value_declare_inside_sp */
extern void T57f356(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.is_value_declared */
extern T1 T57f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_value */
extern void T56f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_value */
extern void T56f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_value_assign */
extern void T56f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_value_assign_outside_sp */
extern void T56f349(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.valuetablename */
extern T0* T56f97(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.createtemporaryvaluetable */
extern T1 T56f108(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.temporarytablessupported */
extern T1 T56f172(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_value_assign_inside_sp */
extern void T56f348(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.optional_create_value_declare */
extern void T56f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_value_declare */
extern void T56f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_value_declare_outside_sp */
extern void T56f357(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_value_alter_table */
extern void T56f359(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_value_create_table */
extern void T56f358(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.finishtemporaryvaluetablestatement */
extern T0* T56f109(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.finishtemporarytablestatement */
extern T0* T56f102(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.createtemporarytablestatement */
extern T0* T56f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_value_declare_inside_sp */
extern void T56f356(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.is_value_declared */
extern T1 T56f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_value */
extern void T55f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_value */
extern void T55f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_value_assign */
extern void T55f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_value_assign_outside_sp */
extern void T55f349(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.valuetablename */
extern T0* T55f97(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.createtemporaryvaluetable */
extern T1 T55f108(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.temporarytablessupported */
extern T1 T55f172(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_value_assign_inside_sp */
extern void T55f348(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.optional_create_value_declare */
extern void T55f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_value_declare */
extern void T55f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_value_declare_outside_sp */
extern void T55f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_value_alter_table */
extern void T55f357(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_value_create_table */
extern void T55f356(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.finishtemporaryvaluetablestatement */
extern T0* T55f109(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.finishtemporarytablestatement */
extern T0* T55f102(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.createtemporarytablestatement */
extern T0* T55f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_value_declare_inside_sp */
extern void T55f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.is_value_declared */
extern T1 T55f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_value */
extern void T54f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_value */
extern void T54f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_value_assign */
extern void T54f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_value_assign_outside_sp */
extern void T54f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.valuetablename */
extern T0* T54f98(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.createtemporaryvaluetable */
extern T1 T54f103(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.create_value_assign_inside_sp */
extern void T54f344(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.optional_create_value_declare */
extern void T54f324(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_value_declare */
extern void T54f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_value_declare_outside_sp */
extern void T54f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_value_alter_table */
extern void T54f349(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_value_create_table */
extern void T54f348(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.finishtemporaryvaluetablestatement */
extern T0* T54f104(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.create_value_declare_inside_sp */
extern void T54f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.is_value_declared */
extern T1 T54f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_value */
extern void T53f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_value */
extern void T53f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_value_assign */
extern void T53f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_value_assign_outside_sp */
extern void T53f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.valuetablename */
extern T0* T53f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.createtemporaryvaluetable */
extern T1 T53f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.temporarytablessupported */
extern T1 T53f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.optional_create_value_declare */
extern void T53f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_value_declare */
extern void T53f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_value_declare_outside_sp */
extern void T53f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_value_alter_table */
extern void T53f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_value_create_table */
extern void T53f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.finishtemporaryvaluetablestatement */
extern T0* T53f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.finishtemporarytablestatement */
extern T0* T53f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.createtemporarytablestatement */
extern T0* T53f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.is_value_data_type_changed */
extern T1 T53f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.is_value_declared */
extern T1 T53f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_value */
extern void T52f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_value */
extern void T52f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_value_assign */
extern void T52f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_value_assign_outside_sp */
extern void T52f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.valuetablename */
extern T0* T52f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.createtemporaryvaluetable */
extern T1 T52f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.temporarytablessupported */
extern T1 T52f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.optional_create_value_declare */
extern void T52f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_value_declare */
extern void T52f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_value_declare_outside_sp */
extern void T52f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_value_alter_table */
extern void T52f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_value_create_table */
extern void T52f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.finishtemporaryvaluetablestatement */
extern T0* T52f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.finishtemporarytablestatement */
extern T0* T52f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.createtemporarytablestatement */
extern T0* T52f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.is_value_data_type_changed */
extern T1 T52f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.is_value_declared */
extern T1 T52f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_value */
extern void T51f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_value */
extern void T51f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_value_assign */
extern void T51f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_value_assign_outside_sp */
extern void T51f336(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.format */
extern T0* T51f66(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.create_value_assign_inside_sp */
extern void T51f335(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.optional_create_value_declare */
extern void T51f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_value_declare */
extern void T51f334(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_value_declare_outside_sp */
extern void T51f338(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_value_declare_inside_sp */
extern void T51f337(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.is_value_declared */
extern T1 T51f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_value */
extern void T50f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_value */
extern void T50f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_value_assign */
extern void T50f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_value_assign_outside_sp */
extern void T50f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.valuetablename */
extern T0* T50f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.createtemporaryvaluetable */
extern T1 T50f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.temporarytablessupported */
extern T1 T50f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.optional_create_value_declare */
extern void T50f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_value_declare */
extern void T50f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_value_declare_outside_sp */
extern void T50f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_value_alter_table */
extern void T50f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_value_create_table */
extern void T50f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.finishtemporaryvaluetablestatement */
extern T0* T50f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.finishtemporarytablestatement */
extern T0* T50f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.createtemporarytablestatement */
extern T0* T50f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.is_value_data_type_changed */
extern T1 T50f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.is_value_declared */
extern T1 T50f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_value */
extern void T49f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_value */
extern void T49f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_value_assign */
extern void T49f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_value_assign_outside_sp */
extern void T49f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.valuetablename */
extern T0* T49f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.createtemporaryvaluetable */
extern T1 T49f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.temporarytablessupported */
extern T1 T49f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.optional_create_value_declare */
extern void T49f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_value_declare */
extern void T49f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_value_declare_outside_sp */
extern void T49f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_value_alter_table */
extern void T49f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_value_create_table */
extern void T49f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.finishtemporaryvaluetablestatement */
extern T0* T49f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.finishtemporarytablestatement */
extern T0* T49f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.createtemporarytablestatement */
extern T0* T49f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.is_value_data_type_changed */
extern T1 T49f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.is_value_declared */
extern T1 T49f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_value */
extern void T48f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_value */
extern void T48f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_value_assign */
extern void T48f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_value_assign_outside_sp */
extern void T48f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.valuetablename */
extern T0* T48f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.createtemporaryvaluetable */
extern T1 T48f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.temporarytablessupported */
extern T1 T48f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.optional_create_value_declare */
extern void T48f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_value_declare */
extern void T48f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_value_declare_outside_sp */
extern void T48f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_value_alter_table */
extern void T48f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_value_create_table */
extern void T48f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.finishtemporaryvaluetablestatement */
extern T0* T48f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.finishtemporarytablestatement */
extern T0* T48f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.createtemporarytablestatement */
extern T0* T48f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.is_value_data_type_changed */
extern T1 T48f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.is_value_declared */
extern T1 T48f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_value */
extern void T47f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_value */
extern void T47f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_value_assign */
extern void T47f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_value_assign_outside_sp */
extern void T47f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.valuetablename */
extern T0* T47f98(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createtemporaryvaluetable */
extern T1 T47f103(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.create_value_assign_inside_sp */
extern void T47f342(GE_context* ac, T0* C, T0* a1);
extern T1 T47f342ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_FIREBIRD_21.optional_create_value_declare */
extern void T47f319(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_value_declare */
extern void T47f341(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_value_declare_outside_sp */
extern void T47f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_value_alter_table */
extern void T47f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_value_create_table */
extern void T47f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.finishtemporaryvaluetablestatement */
extern T0* T47f104(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createtemporarytablestatement */
extern T0* T47f99(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.create_value_declare_inside_sp */
extern void T47f344(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.is_value_declared */
extern T1 T47f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_value */
extern void T46f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_value */
extern void T46f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_value_assign */
extern void T46f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_value_assign_outside_sp */
extern void T46f342(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.valuetablename */
extern T0* T46f98(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createtemporaryvaluetable */
extern T1 T46f103(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.temporarytablessupported */
extern T1 T46f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.create_value_assign_inside_sp */
extern void T46f341(GE_context* ac, T0* C, T0* a1);
extern T1 T46f341ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_INTERBASE6.optional_create_value_declare */
extern void T46f319(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_value_declare */
extern void T46f340(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_value_declare_outside_sp */
extern void T46f344(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_value_alter_table */
extern void T46f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_value_create_table */
extern void T46f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.finishtemporaryvaluetablestatement */
extern T0* T46f104(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.finishtemporarytablestatement */
extern T0* T46f101(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createtemporarytablestatement */
extern T0* T46f99(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.create_value_declare_inside_sp */
extern void T46f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.is_value_declared */
extern T1 T46f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_value */
extern void T45f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_value */
extern void T45f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_value_assign */
extern void T45f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_value_assign_outside_sp */
extern void T45f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.valuetablename */
extern T0* T45f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.createtemporaryvaluetable */
extern T1 T45f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.temporarytablessupported */
extern T1 T45f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.optional_create_value_declare */
extern void T45f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_value_declare */
extern void T45f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_value_declare_outside_sp */
extern void T45f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_value_alter_table */
extern void T45f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_value_create_table */
extern void T45f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.finishtemporaryvaluetablestatement */
extern T0* T45f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.finishtemporarytablestatement */
extern T0* T45f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.createtemporarytablestatement */
extern T0* T45f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.is_value_data_type_changed */
extern T1 T45f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.is_value_declared */
extern T1 T45f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_value */
extern void T44f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_value */
extern void T44f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_value_assign */
extern void T44f321(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_value_assign_outside_sp */
extern void T44f341(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.valuetablename */
extern T0* T44f94(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createtemporaryvaluetable */
extern T1 T44f99(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.create_value_assign_inside_sp */
extern void T44f340(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.optional_create_value_declare */
extern void T44f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_value_declare */
extern void T44f339(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_value_declare_outside_sp */
extern void T44f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_value_alter_table */
extern void T44f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_value_create_table */
extern void T44f344(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.finishtemporaryvaluetablestatement */
extern T0* T44f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.finishtemporarytablestatement */
extern T0* T44f97(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createtemporarytablestatement */
extern T0* T44f95(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.create_value_declare_inside_sp */
extern void T44f342(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.is_value_declared */
extern T1 T44f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_value */
extern void T43f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_value */
extern void T43f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_value_assign */
extern void T43f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_value_assign_outside_sp */
extern void T43f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.valuetablename */
extern T0* T43f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.createtemporaryvaluetable */
extern T1 T43f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.temporarytablessupported */
extern T1 T43f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.optional_create_value_declare */
extern void T43f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_value_declare */
extern void T43f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_value_declare_outside_sp */
extern void T43f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_value_alter_table */
extern void T43f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_value_create_table */
extern void T43f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.finishtemporaryvaluetablestatement */
extern T0* T43f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.finishtemporarytablestatement */
extern T0* T43f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.createtemporarytablestatement */
extern T0* T43f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.is_value_data_type_changed */
extern T1 T43f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.is_value_declared */
extern T1 T43f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_value */
extern void T42f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_value */
extern void T42f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_value_assign */
extern void T42f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_value_assign_outside_sp */
extern void T42f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.valuetablename */
extern T0* T42f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.createtemporaryvaluetable */
extern T1 T42f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.temporarytablessupported */
extern T1 T42f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.optional_create_value_declare */
extern void T42f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_value_declare */
extern void T42f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_value_declare_outside_sp */
extern void T42f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_value_alter_table */
extern void T42f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_value_create_table */
extern void T42f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.finishtemporaryvaluetablestatement */
extern T0* T42f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.finishtemporarytablestatement */
extern T0* T42f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.createtemporarytablestatement */
extern T0* T42f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.is_value_data_type_changed */
extern T1 T42f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.is_value_declared */
extern T1 T42f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_value */
extern void T41f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_value */
extern void T41f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_value_assign */
extern void T41f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_value_assign_outside_sp */
extern void T41f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.valuetablename */
extern T0* T41f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.createtemporaryvaluetable */
extern T1 T41f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.temporarytablessupported */
extern T1 T41f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.optional_create_value_declare */
extern void T41f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_value_declare */
extern void T41f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_value_declare_outside_sp */
extern void T41f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_value_alter_table */
extern void T41f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_value_create_table */
extern void T41f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.finishtemporaryvaluetablestatement */
extern T0* T41f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.finishtemporarytablestatement */
extern T0* T41f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.createtemporarytablestatement */
extern T0* T41f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.is_value_data_type_changed */
extern T1 T41f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.is_value_declared */
extern T1 T41f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_select_value */
extern void T64f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_select_value */
extern void T64f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_select_value_outside_sp */
extern void T64f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_create_select_value */
extern void T64f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_select_value_inside_sp */
extern void T64f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_select_value */
extern void T63f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_select_value */
extern void T63f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_select_value_outside_sp */
extern void T63f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.do_create_select_value */
extern void T63f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_select_value_inside_sp */
extern void T63f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_select_value */
extern void T62f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_select_value */
extern void T62f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_select_value_outside_sp */
extern void T62f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.do_create_select_value */
extern void T62f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_select_value_inside_sp */
extern void T62f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_select_value */
extern void T61f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_select_value */
extern void T61f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_select_value_outside_sp */
extern void T61f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.do_create_select_value */
extern void T61f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_select_value_inside_sp */
extern void T61f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_select_value */
extern void T60f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_select_value */
extern void T60f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_select_value_outside_sp */
extern void T60f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.format */
extern T0* T60f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.write_select_value */
extern void T59f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_select_value */
extern void T59f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_select_value_outside_sp */
extern void T59f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.format */
extern T0* T59f77(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.create_select_value_inside_sp */
extern void T59f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_select_value */
extern void T58f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_select_value */
extern void T58f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_select_value_outside_sp */
extern void T58f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.format */
extern T0* T58f77(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.create_select_value_inside_sp */
extern void T58f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_select_value */
extern void T57f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_select_value */
extern void T57f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_select_value_outside_sp */
extern void T57f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.format */
extern T0* T57f77(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.create_select_value_inside_sp */
extern void T57f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_select_value */
extern void T56f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_select_value */
extern void T56f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_select_value_outside_sp */
extern void T56f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.format */
extern T0* T56f77(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.create_select_value_inside_sp */
extern void T56f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_select_value */
extern void T55f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_select_value */
extern void T55f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_select_value_outside_sp */
extern void T55f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.format */
extern T0* T55f77(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.create_select_value_inside_sp */
extern void T55f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_select_value */
extern void T54f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_select_value */
extern void T54f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_select_value_outside_sp */
extern void T54f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.format */
extern T0* T54f65(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.create_select_value_inside_sp */
extern void T54f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_select_value */
extern void T53f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_select_value */
extern void T53f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_select_value_outside_sp */
extern void T53f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.format */
extern T0* T53f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.write_select_value */
extern void T52f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_select_value */
extern void T52f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_select_value_outside_sp */
extern void T52f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.format */
extern T0* T52f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.write_select_value */
extern void T51f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_select_value */
extern void T51f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_select_value_outside_sp */
extern void T51f318(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_select_value_inside_sp */
extern void T51f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_select_value */
extern void T50f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_select_value */
extern void T50f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_select_value_outside_sp */
extern void T50f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.format */
extern T0* T50f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.write_select_value */
extern void T49f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_select_value */
extern void T49f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_select_value_outside_sp */
extern void T49f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.format */
extern T0* T49f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.write_select_value */
extern void T48f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_select_value */
extern void T48f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_select_value_outside_sp */
extern void T48f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.format */
extern T0* T48f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.write_select_value */
extern void T47f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_select_value */
extern void T47f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_select_value_outside_sp */
extern void T47f322(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.format */
extern T0* T47f66(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.create_select_value_inside_sp */
extern void T47f321(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_select_value */
extern void T46f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_select_value */
extern void T46f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_select_value_outside_sp */
extern void T46f322(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.format */
extern T0* T46f66(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.create_select_value_inside_sp */
extern void T46f321(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_select_value */
extern void T45f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_select_value */
extern void T45f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_select_value_outside_sp */
extern void T45f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.format */
extern T0* T45f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.write_select_value */
extern void T44f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_select_value */
extern void T44f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_select_value_outside_sp */
extern void T44f323(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.format */
extern T0* T44f65(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.create_select_value_inside_sp */
extern void T44f322(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_select_value */
extern void T43f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_select_value */
extern void T43f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_select_value_outside_sp */
extern void T43f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.format */
extern T0* T43f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.write_select_value */
extern void T42f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_select_value */
extern void T42f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_select_value_outside_sp */
extern void T42f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.format */
extern T0* T42f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.write_select_value */
extern void T41f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_select_value */
extern void T41f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_select_value_outside_sp */
extern void T41f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.format */
extern T0* T41f63(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.write_select */
extern void T64f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_select */
extern void T63f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_select */
extern void T62f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_select */
extern void T61f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_select */
extern void T60f260(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_select */
extern void T59f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_select */
extern void T58f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_select */
extern void T57f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_select */
extern void T56f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_select */
extern void T55f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_select */
extern void T54f282(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_select */
extern void T53f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_select */
extern void T52f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_select */
extern void T51f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_select */
extern void T50f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_select */
extern void T49f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_select */
extern void T48f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_select */
extern void T47f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_select */
extern void T46f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_select */
extern void T45f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_select */
extern void T44f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_select */
extern void T43f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_select */
extern void T42f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_select */
extern void T41f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_extend */
extern void T64f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_extend_create_index */
extern void T64f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.format */
extern T0* T64f67(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.extension_index_name */
extern T0* T64f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.createextendindex */
extern T1 T64f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.extendindexsupported */
extern T1 T64f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.create_extend */
extern void T64f283(GE_context* ac, T0* C, T0* a1);
extern T1 T64f283ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_TSQL65.tabtab */
extern T0* T64f65(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.q_sql_insert_name */
extern T0* T157f13(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.sql_insert_name */
extern T0* T157f22(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.outer_sqlvalue */
extern T0* T301f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.sqlfromaliasname */
extern T0* T301f5(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.add_to_join */
extern void T303f22(GE_context* ac, T0* C, T0* a1, T0* a2);
/* JOIN_LIST.add_join_to_aggregate */
extern void T329f17(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3, T1 a4);
/* XPLAIN_SELECTION_FUNCTION.add_to_join */
extern void T154f13(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_SELECTION_FUNCTION.add_to_join */
extern void T154f13p1(GE_context* ac, T0* C, T0* a1, T0* a2);
/* DS_LINKED_LIST [JOIN_TREE_NODE].last */
extern T0* T417f5(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE].first */
extern T0* T337f13(GE_context* ac, T0* C);
/* JOIN_LIST.copy_role_to_next */
extern void T329f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_NAME.set_role */
extern void T138f20(GE_context* ac, T0* C, T0* a1);
/* JOIN_LIST.revert_alist */
extern T0* T329f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.add_to_join */
extern void T301f16(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.create_extend_view */
extern void T64f282(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.can_write_extend_as_view */
extern T1 T64f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.can_write_extend_as_view */
extern T1 T64f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_extend */
extern void T63f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_extend_create_index */
extern void T63f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.format */
extern T0* T63f67(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.extension_index_name */
extern T0* T63f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.createextendindex */
extern T1 T63f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.extendindexsupported */
extern T1 T63f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.create_extend */
extern void T63f282(GE_context* ac, T0* C, T0* a1);
extern T1 T63f282ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_TSQL70.tabtab */
extern T0* T63f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.create_extend_view */
extern void T63f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.can_write_extend_as_view */
extern T1 T63f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.can_write_extend_as_view */
extern T1 T63f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_extend */
extern void T62f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_extend_create_index */
extern void T62f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.format */
extern T0* T62f67(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.extension_index_name */
extern T0* T62f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.createextendindex */
extern T1 T62f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.extendindexsupported */
extern T1 T62f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.create_extend */
extern void T62f282(GE_context* ac, T0* C, T0* a1);
extern T1 T62f282ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_TSQL2000.tabtab */
extern T0* T62f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.create_extend_view */
extern void T62f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.can_write_extend_as_view */
extern T1 T62f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.can_write_extend_as_view */
extern T1 T62f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_extend */
extern void T61f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_extend_create_index */
extern void T61f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.format */
extern T0* T61f67(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.extension_index_name */
extern T0* T61f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.createextendindex */
extern T1 T61f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.extendindexsupported */
extern T1 T61f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.create_extend */
extern void T61f282(GE_context* ac, T0* C, T0* a1);
extern T1 T61f282ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_TSQL2016.tabtab */
extern T0* T61f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.create_extend_view */
extern void T61f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.can_write_extend_as_view */
extern T1 T61f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.can_write_extend_as_view */
extern T1 T61f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_extend */
extern void T60f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_extend_create_index */
extern void T60f282(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.extension_index_name */
extern T0* T60f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.createextendindex */
extern T1 T60f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.extendindexsupported */
extern T1 T60f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.create_extend */
extern void T60f281(GE_context* ac, T0* C, T0* a1);
extern T1 T60f281ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_SQLITE_3.coalescesupported */
extern T1 T60f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.create_extend_create_table */
extern void T60f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.temporarytableprimarykey */
extern T0* T60f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.primarykeyconstraint */
extern T0* T60f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.drop_temporary_table_if_exist */
extern void T60f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_extend_view */
extern void T60f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.can_write_extend_as_view */
extern T1 T60f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_extend */
extern void T59f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_extend */
extern void T59f305(GE_context* ac, T0* C, T0* a1);
extern T1 T59f305ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_72.coalescesupported */
extern T1 T59f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_extend_create_table */
extern void T59f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.end_if */
extern void T59f350(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_extend_create_index */
extern void T59f349(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.extension_index_name */
extern T0* T59f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.createextendindex */
extern T1 T59f98(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.extendindexsupported */
extern T1 T59f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_extend_create_table */
extern void T59f330p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.temporarytableprimarykey */
extern T0* T59f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.primarykeyconstraint */
extern T0* T59f173(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.safe_sql */
extern T0* T59f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.safe_string */
extern T0* T59f161(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_temporary_table_if_exist */
extern void T59f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_extend_view */
extern void T59f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.can_write_extend_as_view */
extern T1 T59f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.can_write_extend_as_view */
extern T1 T59f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_extend */
extern void T58f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_extend */
extern void T58f307(GE_context* ac, T0* C, T0* a1);
extern T1 T58f307ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_73.coalescesupported */
extern T1 T58f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_extend_create_table */
extern void T58f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.end_if */
extern void T58f352(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_extend_create_index */
extern void T58f351(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.extension_index_name */
extern T0* T58f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.createextendindex */
extern T1 T58f98(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.extendindexsupported */
extern T1 T58f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_extend_create_table */
extern void T58f332p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.temporarytableprimarykey */
extern T0* T58f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.primarykeyconstraint */
extern T0* T58f173(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.safe_sql */
extern T0* T58f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.safe_string */
extern T0* T58f163(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_temporary_table_if_exist */
extern void T58f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_extend_view */
extern void T58f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.can_write_extend_as_view */
extern T1 T58f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.can_write_extend_as_view */
extern T1 T58f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_extend */
extern void T57f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_extend */
extern void T57f308(GE_context* ac, T0* C, T0* a1);
extern T1 T57f308ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_81.coalescesupported */
extern T1 T57f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_extend_create_table */
extern void T57f333(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.end_if */
extern void T57f353(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_extend_create_index */
extern void T57f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.extension_index_name */
extern T0* T57f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.createextendindex */
extern T1 T57f99(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.extendindexsupported */
extern T1 T57f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_extend_create_table */
extern void T57f333p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.temporarytableprimarykey */
extern T0* T57f101(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.primarykeyconstraint */
extern T0* T57f173(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.safe_sql */
extern T0* T57f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_temporary_table_if_exist */
extern void T57f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_extend_view */
extern void T57f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.can_write_extend_as_view */
extern T1 T57f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.can_write_extend_as_view */
extern T1 T57f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_extend */
extern void T56f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_extend */
extern void T56f308(GE_context* ac, T0* C, T0* a1);
extern T1 T56f308ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_82.coalescesupported */
extern T1 T56f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_extend_create_table */
extern void T56f333(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.end_if */
extern void T56f353(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_extend_create_index */
extern void T56f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.extension_index_name */
extern T0* T56f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.createextendindex */
extern T1 T56f99(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.extendindexsupported */
extern T1 T56f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_extend_create_table */
extern void T56f333p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.temporarytableprimarykey */
extern T0* T56f101(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.primarykeyconstraint */
extern T0* T56f173(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.safe_sql */
extern T0* T56f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_temporary_table_if_exist */
extern void T56f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_extend_view */
extern void T56f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.can_write_extend_as_view */
extern T1 T56f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.can_write_extend_as_view */
extern T1 T56f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_extend */
extern void T55f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_extend */
extern void T55f308(GE_context* ac, T0* C, T0* a1);
extern T1 T55f308ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_95.coalescesupported */
extern T1 T55f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_extend_create_table */
extern void T55f333(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.end_if */
extern void T55f351(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_extend_create_index */
extern void T55f350(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.extension_index_name */
extern T0* T55f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.createextendindex */
extern T1 T55f99(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.extendindexsupported */
extern T1 T55f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_extend_create_table */
extern void T55f333p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.temporarytableprimarykey */
extern T0* T55f101(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.primarykeyconstraint */
extern T0* T55f173(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.safe_sql */
extern T0* T55f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_temporary_table_if_exist */
extern void T55f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_extend_view */
extern void T55f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.can_write_extend_as_view */
extern T1 T55f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.can_write_extend_as_view */
extern T1 T55f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_extend */
extern void T54f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_extend_create_index */
extern void T54f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.extension_index_name */
extern T0* T54f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.createextendindex */
extern T1 T54f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.extendindexsupported */
extern T1 T54f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.create_extend */
extern void T54f303(GE_context* ac, T0* C, T0* a1);
extern T1 T54f303ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_ORACLE.coalescesupported */
extern T1 T54f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.create_extend_create_table */
extern void T54f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.finishtemporarytablestatement */
extern T0* T54f101(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.temporarytableprimarykey */
extern T0* T54f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.primarykeyconstraint */
extern T0* T54f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.drop_temporary_table_if_exist */
extern void T54f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_extend_view */
extern void T54f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.can_write_extend_as_view */
extern T1 T54f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.can_write_extend_as_view */
extern T1 T54f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_extend */
extern void T53f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_extend_create_index */
extern void T53f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.extension_index_name */
extern T0* T53f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.createextendindex */
extern T1 T53f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.extendindexsupported */
extern T1 T53f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.create_extend */
extern void T53f269(GE_context* ac, T0* C, T0* a1);
extern T1 T53f269ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MYSQL322.coalescesupported */
extern T1 T53f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.create_extend_create_table */
extern void T53f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.temporarytableprimarykey */
extern T0* T53f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.primarykeyconstraint */
extern T0* T53f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.drop_temporary_table_if_exist */
extern void T53f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_extend_view */
extern void T53f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.can_write_extend_as_view */
extern T1 T53f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_extend */
extern void T52f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_extend_create_index */
extern void T52f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.extension_index_name */
extern T0* T52f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.createextendindex */
extern T1 T52f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.extendindexsupported */
extern T1 T52f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.create_extend */
extern void T52f269(GE_context* ac, T0* C, T0* a1);
extern T1 T52f269ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MYSQL4.coalescesupported */
extern T1 T52f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.create_extend_create_table */
extern void T52f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.temporarytableprimarykey */
extern T0* T52f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.primarykeyconstraint */
extern T0* T52f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.drop_temporary_table_if_exist */
extern void T52f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_extend_view */
extern void T52f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.can_write_extend_as_view */
extern T1 T52f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_extend */
extern void T51f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_extend_create_index */
extern void T51f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.extension_index_name */
extern T0* T51f65(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.createextendindex */
extern T1 T51f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.extendindexsupported */
extern T1 T51f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.create_extend */
extern void T51f294(GE_context* ac, T0* C, T0* a1);
extern T1 T51f294ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MYSQL5.coalescesupported */
extern T1 T51f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.create_extend_create_table */
extern void T51f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.finishtemporarytablestatement */
extern T0* T51f97(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.temporarytableprimarykey */
extern T0* T51f96(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.primarykeyconstraint */
extern T0* T51f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createtemporarytablestatement */
extern T0* T51f95(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.temporarytablessupported */
extern T1 T51f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.drop_temporary_table_if_exist */
extern void T51f319(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_extend_view */
extern void T51f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.can_write_extend_as_view */
extern T1 T51f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.can_write_extend_as_view */
extern T1 T51f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_extend */
extern void T50f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_extend_create_index */
extern void T50f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.extension_index_name */
extern T0* T50f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.createextendindex */
extern T1 T50f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.extendindexsupported */
extern T1 T50f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.create_extend */
extern void T50f268(GE_context* ac, T0* C, T0* a1);
extern T1 T50f268ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MSQL.coalescesupported */
extern T1 T50f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.create_extend_create_table */
extern void T50f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.temporarytableprimarykey */
extern T0* T50f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.primarykeyconstraint */
extern T0* T50f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.drop_temporary_table_if_exist */
extern void T50f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_extend_view */
extern void T50f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.can_write_extend_as_view */
extern T1 T50f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_extend */
extern void T49f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_extend_create_index */
extern void T49f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.extension_index_name */
extern T0* T49f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.createextendindex */
extern T1 T49f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.extendindexsupported */
extern T1 T49f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.create_extend */
extern void T49f268(GE_context* ac, T0* C, T0* a1);
extern T1 T49f268ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MSACCESS2000.coalescesupported */
extern T1 T49f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.create_extend_create_table */
extern void T49f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.temporarytableprimarykey */
extern T0* T49f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.primarykeyconstraint */
extern T0* T49f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.drop_temporary_table_if_exist */
extern void T49f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_extend_view */
extern void T49f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.can_write_extend_as_view */
extern T1 T49f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_extend */
extern void T48f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_extend_create_index */
extern void T48f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.extension_index_name */
extern T0* T48f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.createextendindex */
extern T1 T48f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.extendindexsupported */
extern T1 T48f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.create_extend */
extern void T48f268(GE_context* ac, T0* C, T0* a1);
extern T1 T48f268ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_MSACCESS97.coalescesupported */
extern T1 T48f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.create_extend_create_table */
extern void T48f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.temporarytableprimarykey */
extern T0* T48f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.primarykeyconstraint */
extern T0* T48f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.drop_temporary_table_if_exist */
extern void T48f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_extend_view */
extern void T48f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.can_write_extend_as_view */
extern T1 T48f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_extend */
extern void T47f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_extend_create_index */
extern void T47f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_extend_create_index */
extern void T47f299p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.extension_index_name */
extern T0* T47f65(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.commit */
extern void T47f325(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createextendindex */
extern T1 T47f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.extendindexsupported */
extern T1 T47f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.create_extend */
extern void T47f298(GE_context* ac, T0* C, T0* a1);
extern T1 T47f298ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_FIREBIRD_21.coalescesupported */
extern T1 T47f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.create_extend_create_table */
extern void T47f324(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.temporarytableprimarykey */
extern T0* T47f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.primarykeyconstraint */
extern T0* T47f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.drop_temporary_table_if_exist */
extern void T47f323(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_extend_view */
extern void T47f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.can_write_extend_as_view */
extern T1 T47f37(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.can_write_extend_as_view */
extern T1 T47f37p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_extend */
extern void T46f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_extend_create_index */
extern void T46f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.extension_index_name */
extern T0* T46f65(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.createextendindex */
extern T1 T46f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.extendindexsupported */
extern T1 T46f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.create_extend */
extern void T46f298(GE_context* ac, T0* C, T0* a1);
extern T1 T46f298ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_INTERBASE6.coalescesupported */
extern T1 T46f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.create_extend_create_table */
extern void T46f324(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.temporarytableprimarykey */
extern T0* T46f100(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.primarykeyconstraint */
extern T0* T46f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.drop_temporary_table_if_exist */
extern void T46f323(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_extend_view */
extern void T46f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.can_write_extend_as_view */
extern T1 T46f37(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.can_write_extend_as_view */
extern T1 T46f37p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_extend */
extern void T45f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_extend_create_index */
extern void T45f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.extension_index_name */
extern T0* T45f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.createextendindex */
extern T1 T45f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.extendindexsupported */
extern T1 T45f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.create_extend */
extern void T45f268(GE_context* ac, T0* C, T0* a1);
extern T1 T45f268ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_FOXPRO.coalescesupported */
extern T1 T45f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.create_extend_create_table */
extern void T45f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.temporarytableprimarykey */
extern T0* T45f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.primarykeyconstraint */
extern T0* T45f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.drop_temporary_table_if_exist */
extern void T45f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_extend_view */
extern void T45f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.can_write_extend_as_view */
extern T1 T45f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_extend */
extern void T44f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_extend_create_index */
extern void T44f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.extension_index_name */
extern T0* T44f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.createextendindex */
extern T1 T44f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.extendindexsupported */
extern T1 T44f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.create_extend */
extern void T44f299(GE_context* ac, T0* C, T0* a1);
extern T1 T44f299ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_DB2_71.coalescesupported */
extern T1 T44f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.create_extend_create_table */
extern void T44f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.temporarytableprimarykey */
extern T0* T44f96(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.drop_temporary_table_if_exist */
extern void T44f324(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_extend_view */
extern void T44f298(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.can_write_extend_as_view */
extern T1 T44f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.can_write_extend_as_view */
extern T1 T44f36p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_extend */
extern void T43f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_extend_create_index */
extern void T43f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.extension_index_name */
extern T0* T43f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.createextendindex */
extern T1 T43f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.extendindexsupported */
extern T1 T43f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.create_extend */
extern void T43f270(GE_context* ac, T0* C, T0* a1);
extern T1 T43f270ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_DB2_6.coalescesupported */
extern T1 T43f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.create_extend_create_table */
extern void T43f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.temporarytableprimarykey */
extern T0* T43f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.primarykeyconstraint */
extern T0* T43f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.drop_temporary_table_if_exist */
extern void T43f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_extend_view */
extern void T43f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.can_write_extend_as_view */
extern T1 T43f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_extend */
extern void T42f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_extend_create_index */
extern void T42f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.extension_index_name */
extern T0* T42f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.createextendindex */
extern T1 T42f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.extendindexsupported */
extern T1 T42f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.create_extend */
extern void T42f269(GE_context* ac, T0* C, T0* a1);
extern T1 T42f269ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_BASIC.coalescesupported */
extern T1 T42f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.create_extend_create_table */
extern void T42f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.temporarytableprimarykey */
extern T0* T42f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.primarykeyconstraint */
extern T0* T42f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.drop_temporary_table_if_exist */
extern void T42f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_extend_view */
extern void T42f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.can_write_extend_as_view */
extern T1 T42f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_extend */
extern void T41f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_extend_create_index */
extern void T41f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.extension_index_name */
extern T0* T41f62(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.createextendindex */
extern T1 T41f37(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.extendindexsupported */
extern T1 T41f121(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.create_extend */
extern void T41f269(GE_context* ac, T0* C, T0* a1);
extern T1 T41f269ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_ANSI.coalescesupported */
extern T1 T41f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.create_extend_create_table */
extern void T41f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.temporarytableprimarykey */
extern T0* T41f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.primarykeyconstraint */
extern T0* T41f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.drop_temporary_table_if_exist */
extern void T41f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_extend_view */
extern void T41f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.can_write_extend_as_view */
extern T1 T41f36(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.echo */
extern void T64f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.echo */
extern void T63f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.echo */
extern void T62f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.echo */
extern void T61f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.echo */
extern void T60f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.echo */
extern void T59f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.echo */
extern void T58f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.echo */
extern void T57f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.echo */
extern void T56f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.echo */
extern void T55f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.echo */
extern void T54f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.echo */
extern void T53f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.echo */
extern void T52f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.echo */
extern void T51f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.echo */
extern void T50f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.echo */
extern void T49f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.echo */
extern void T48f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.echo */
extern void T47f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.echo */
extern void T46f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.echo */
extern void T45f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.echo */
extern void T44f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.echo */
extern void T43f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.echo */
extern void T42f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.echo */
extern void T41f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_echo */
extern void T64f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_echo */
extern void T64f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_echo */
extern void T63f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_echo */
extern void T63f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_echo */
extern void T62f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_echo */
extern void T62f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_echo */
extern void T61f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_echo */
extern void T61f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_echo */
extern void T60f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_echo */
extern void T60f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_echo */
extern void T59f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_echo */
extern void T59f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_echo */
extern void T58f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_echo */
extern void T58f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_echo */
extern void T57f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_echo */
extern void T57f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_echo */
extern void T56f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_echo */
extern void T56f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_echo */
extern void T55f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_echo */
extern void T55f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_echo */
extern void T54f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_echo */
extern void T54f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_echo */
extern void T53f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_echo */
extern void T53f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_echo */
extern void T52f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_echo */
extern void T52f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_echo */
extern void T51f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_echo */
extern void T51f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_echo */
extern void T50f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_echo */
extern void T50f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_echo */
extern void T49f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_echo */
extern void T49f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_echo */
extern void T48f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_echo */
extern void T48f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_echo */
extern void T47f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_echo */
extern void T47f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_echo */
extern void T46f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_echo */
extern void T46f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_echo */
extern void T45f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_echo */
extern void T45f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_echo */
extern void T44f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_echo */
extern void T44f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_echo */
extern void T43f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_echo */
extern void T43f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_echo */
extern void T42f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_echo */
extern void T42f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_echo */
extern void T41f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_echo */
extern void T41f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_procedure */
extern void T64f266(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.warn_about_unused_parameters */
extern void T318f22(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].forth */
extern void T335f13(GE_context* ac, T0* C);
/* XPLAIN_PROCEDURE.std */
extern T0* T318f15(GE_context* ac, T0* C);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].forth */
extern void T339f13(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].item_for_iteration */
extern T0* T335f9(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].cursor_item */
extern T0* T335f7(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].item_for_iteration */
extern T0* T339f7(GE_context* ac, T0* C);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].cursor_item */
extern T0* T339f6(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].after */
extern T1 T339f9(GE_context* ac, T0* C);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].cursor_after */
extern T1 T339f5(GE_context* ac, T0* C, T0* a1);
/* DS_BILINKED_LIST [XPLAIN_STATEMENT].start */
extern void T339f12(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].after */
extern T1 T335f8(GE_context* ac, T0* C);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].cursor_after */
extern T1 T335f6(GE_context* ac, T0* C, T0* a1);
/* DS_LINKED_LIST [XPLAIN_ATTRIBUTE_NAME].start */
extern void T335f12(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.create_procedure */
extern void T64f287(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.cleanup_after_write */
extern void T318f21(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_end */
extern void T64f318(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_body_statements */
extern void T64f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_body_start */
extern void T64f316(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_user_declaration */
extern void T64f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.storedprocedureuserdeclarationbeforebody */
extern T1 T64f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_header_end */
extern void T64f314(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_user_result */
extern void T64f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_result_parameter */
extern void T64f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.storedprocedureparamlistend */
extern T0* T64f73(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.storedprocedureparamliststart */
extern T0* T64f69(GE_context* ac, T0* C);
/* XPLAIN_PROCEDURE.quoted_name */
extern T0* T318f14(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_start */
extern void T64f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_start */
extern void T64f311p1(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].make */
extern T0* T114c38(GE_context* ac, T6 a1);
/* XPLAIN_PROCEDURE.optimize_statements */
extern void T318f20(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.coalescesupported */
extern T1 T64f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.conditional_drop_procedure */
extern void T64f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_procedure */
extern void T63f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_procedure */
extern void T63f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_end */
extern void T63f318(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sp_body_statements */
extern void T63f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_body_start */
extern void T63f316(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sp_user_declaration */
extern void T63f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.storedprocedureuserdeclarationbeforebody */
extern T1 T63f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sp_header_end */
extern void T63f314(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sp_user_result */
extern void T63f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_result_parameter */
extern void T63f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.storedprocedureparamlistend */
extern T0* T63f73(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.storedprocedureparamliststart */
extern T0* T63f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sp_start */
extern void T63f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_start */
extern void T63f311p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.coalescesupported */
extern T1 T63f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.conditional_drop_procedure */
extern void T63f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.do_drop_procedure */
extern void T63f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_procedure */
extern void T62f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_procedure */
extern void T62f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_end */
extern void T62f318(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sp_body_statements */
extern void T62f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_body_start */
extern void T62f316(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sp_user_declaration */
extern void T62f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.storedprocedureuserdeclarationbeforebody */
extern T1 T62f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sp_header_end */
extern void T62f314(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sp_user_result */
extern void T62f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_result_parameter */
extern void T62f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.storedprocedureparamlistend */
extern T0* T62f73(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.storedprocedureparamliststart */
extern T0* T62f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sp_start */
extern void T62f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_start */
extern void T62f311p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.coalescesupported */
extern T1 T62f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.conditional_drop_procedure */
extern void T62f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.do_drop_procedure */
extern void T62f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_procedure */
extern void T61f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_procedure */
extern void T61f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_end */
extern void T61f317(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sp_body_statements */
extern void T61f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_body_start */
extern void T61f315(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sp_user_declaration */
extern void T61f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.storedprocedureuserdeclarationbeforebody */
extern T1 T61f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sp_header_end */
extern void T61f313(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sp_user_result */
extern void T61f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_result_parameter */
extern void T61f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.storedprocedureparamlistend */
extern T0* T61f73(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.storedprocedureparamliststart */
extern T0* T61f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sp_start */
extern void T61f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_start */
extern void T61f310p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.coalescesupported */
extern T1 T61f38(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.conditional_drop_procedure */
extern void T61f285(GE_context* ac, T0* C, T0* a1);
/* KL_STDOUT_FILE.put_line */
extern void T115f8(GE_context* ac, T0* C, T0* a1);
/* KL_STDOUT_FILE.put_new_line */
extern void T115f9(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_procedure */
extern void T60f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_procedure */
extern void T59f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_procedure */
extern void T59f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_end */
extern void T59f338(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.plpgsql_block_demarcation */
extern T0* T59f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sp_body_statements */
extern void T59f337(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_body_start */
extern void T59f336(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sp_user_declaration */
extern void T59f335(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_type_name */
extern T0* T59f102(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.returns_rows */
extern T1 T318f12(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_user_declaration */
extern void T59f335p1(GE_context* ac, T0* C, T0* a1);
extern T1 T59f335p1ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_72.storedprocedureuserdeclarationbeforebody */
extern T1 T59f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sp_header_end */
extern void T59f334(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sp_user_result */
extern void T59f333(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_result_parameter */
extern void T59f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.storedprocedureparamlistend */
extern T0* T59f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.storedprocedureparamliststart */
extern T0* T59f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.storedprocedureparamliststartrequired */
extern T1 T59f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sp_start */
extern void T59f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.conditional_drop_procedure */
extern void T59f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_procedure */
extern void T58f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_procedure */
extern void T58f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_end */
extern void T58f340(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.plpgsql_block_demarcation */
extern T0* T58f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_body_statements */
extern void T58f339(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_body_start */
extern void T58f338(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_user_declaration */
extern void T58f337(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_type_name */
extern T0* T58f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_user_declaration */
extern void T58f337p1(GE_context* ac, T0* C, T0* a1);
extern T1 T58f337p1ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_73.storedprocedureuserdeclarationbeforebody */
extern T1 T58f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_header_end */
extern void T58f336(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_user_result */
extern void T58f335(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_result_parameter */
extern void T58f334(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.returns_value */
extern T1 T318f13(GE_context* ac, T0* C, T0* a1);
/* KL_STDERR_FILE.put_line */
extern void T40f8(GE_context* ac, T0* C, T0* a1);
/* KL_STDERR_FILE.put_new_line */
extern void T40f10(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.storedprocedureparamlistend */
extern T0* T58f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.storedprocedureparamliststart */
extern T0* T58f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.storedprocedureparamliststartrequired */
extern T1 T58f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_start */
extern void T58f333(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_sp_type */
extern void T58f354(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.sp_function_type */
extern T0* T318f11(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_73.drop_sp_type */
extern void T58f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.conditional_drop_procedure */
extern void T58f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_procedure */
extern void T57f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_procedure */
extern void T57f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_end */
extern void T57f341(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sp_body_statements */
extern void T57f340(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_body_start */
extern void T57f339(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sp_user_declaration */
extern void T57f338(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_type_name */
extern T0* T57f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_user_declaration */
extern void T57f338p1(GE_context* ac, T0* C, T0* a1);
extern T1 T57f338p1ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_81.storedprocedureuserdeclarationbeforebody */
extern T1 T57f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sp_header_end */
extern void T57f337(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sp_user_result */
extern void T57f336(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_result_parameter */
extern void T57f335(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.storedprocedureparamlistend */
extern T0* T57f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.storedprocedureparamliststart */
extern T0* T57f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.storedprocedureparamliststartrequired */
extern T1 T57f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sp_start */
extern void T57f334(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_sp_type */
extern void T57f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_sp_type */
extern void T57f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.conditional_drop_procedure */
extern void T57f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_procedure */
extern void T56f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_procedure */
extern void T56f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_end */
extern void T56f341(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sp_body_statements */
extern void T56f340(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_body_start */
extern void T56f339(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sp_user_declaration */
extern void T56f338(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_type_name */
extern T0* T56f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_user_declaration */
extern void T56f338p1(GE_context* ac, T0* C, T0* a1);
extern T1 T56f338p1ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_82.storedprocedureuserdeclarationbeforebody */
extern T1 T56f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sp_header_end */
extern void T56f337(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sp_user_result */
extern void T56f336(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_result_parameter */
extern void T56f335(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.storedprocedureparamlistend */
extern T0* T56f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.storedprocedureparamliststart */
extern T0* T56f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.storedprocedureparamliststartrequired */
extern T1 T56f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sp_start */
extern void T56f334(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_sp_type */
extern void T56f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_sp_type */
extern void T56f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.conditional_drop_procedure */
extern void T56f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_procedure */
extern void T55f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_procedure */
extern void T55f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_end */
extern void T55f341(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sp_body_statements */
extern void T55f340(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_body_start */
extern void T55f339(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sp_user_declaration */
extern void T55f338(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_type_name */
extern T0* T55f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_user_declaration */
extern void T55f338p1(GE_context* ac, T0* C, T0* a1);
extern T1 T55f338p1ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_95.storedprocedureuserdeclarationbeforebody */
extern T1 T55f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sp_header_end */
extern void T55f337(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sp_user_result */
extern void T55f336(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_result_parameter */
extern void T55f335(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.storedprocedureparamlistend */
extern T0* T55f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.storedprocedureparamliststart */
extern T0* T55f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.storedprocedureparamliststartrequired */
extern T1 T55f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sp_start */
extern void T55f334(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_sp_type */
extern void T55f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_sp_type */
extern void T55f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.conditional_drop_procedure */
extern void T55f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_procedure */
extern void T54f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_procedure */
extern void T54f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_end */
extern void T54f337(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sp_body_statements */
extern void T54f336(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_body_start */
extern void T54f335(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sp_user_declaration */
extern void T54f334(GE_context* ac, T0* C, T0* a1);
extern T1 T54f334ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_ORACLE.storedprocedureuserdeclarationbeforebody */
extern T1 T54f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sp_header_end */
extern void T54f333(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sp_user_result */
extern void T54f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_result_parameter */
extern void T54f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.storedprocedureparamlistend */
extern T0* T54f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.storedprocedureparamliststart */
extern T0* T54f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sp_start */
extern void T54f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.conditional_drop_procedure */
extern void T54f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_procedure */
extern void T53f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_procedure */
extern void T52f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_procedure */
extern void T51f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_procedure */
extern void T51f298(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_end */
extern void T51f328(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_end */
extern void T51f328p1(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_body_statements */
extern void T51f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_body_start */
extern void T51f326(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_user_declaration */
extern void T51f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.storedprocedureuserdeclarationbeforebody */
extern T1 T51f73(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_header_end */
extern void T51f324(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_user_result */
extern void T51f323(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_result_parameter */
extern void T51f322(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.storedprocedureparamlistend */
extern T0* T51f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.storedprocedureparamliststart */
extern T0* T51f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.storedprocedureparamliststartrequired */
extern T1 T51f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_start */
extern void T51f321(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_start */
extern void T51f321p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.conditional_drop_procedure */
extern void T51f297(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_procedure */
extern void T50f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_procedure */
extern void T49f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_procedure */
extern void T48f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_procedure */
extern void T47f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_procedure */
extern void T47f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_end */
extern void T47f333(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.end_new_separator */
extern void T47f335(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sp_body_statements */
extern void T47f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_body_start */
extern void T47f331(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sp_user_declaration */
extern void T47f330(GE_context* ac, T0* C, T0* a1);
extern T1 T47f330ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_FIREBIRD_21.storedprocedureuserdeclarationbeforebody */
extern T1 T47f73(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sp_header_end */
extern void T47f329(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sp_user_result */
extern void T47f328(GE_context* ac, T0* C, T0* a1);
extern T1 T47f328ot1(T0* a1, T0** a2);
extern T1 T47f328ot2(T0* a1, T0** a2);
/* XPLAIN_SELECTION_FUNCTION.representation */
extern T0* T154f6(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_result_parameter */
extern void T47f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.storedprocedureparamlistend */
extern T0* T47f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.storedprocedureparamliststart */
extern T0* T47f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sp_start */
extern void T47f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_start */
extern void T47f326p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.begin_new_separator */
extern void T47f334(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.conditional_drop_procedure */
extern void T47f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_procedure */
extern void T46f281(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_procedure */
extern void T46f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_end */
extern void T46f332(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.end_new_separator */
extern void T46f334(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sp_body_statements */
extern void T46f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_body_start */
extern void T46f330(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sp_user_declaration */
extern void T46f329(GE_context* ac, T0* C, T0* a1);
extern T1 T46f329ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_INTERBASE6.storedprocedureuserdeclarationbeforebody */
extern T1 T46f73(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sp_header_end */
extern void T46f328(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sp_user_result */
extern void T46f327(GE_context* ac, T0* C, T0* a1);
extern T1 T46f327ot1(T0* a1, T0** a2);
extern T1 T46f327ot2(T0* a1, T0** a2);
/* SQL_GENERATOR_INTERBASE6.sp_result_parameter */
extern void T46f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.storedprocedureparamlistend */
extern T0* T46f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.storedprocedureparamliststart */
extern T0* T46f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sp_start */
extern void T46f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_start */
extern void T46f325p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.begin_new_separator */
extern void T46f333(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.conditional_drop_procedure */
extern void T46f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_procedure */
extern void T45f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_procedure */
extern void T44f282(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_procedure */
extern void T44f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_end */
extern void T44f333(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sp_body_statements */
extern void T44f332(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_body_start */
extern void T44f331(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sp_user_declaration */
extern void T44f330(GE_context* ac, T0* C, T0* a1);
extern T1 T44f330ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_DB2_71.sp_header_end */
extern void T44f329(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sp_user_result */
extern void T44f328(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_result_parameter */
extern void T44f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.storedprocedureparamlistend */
extern T0* T44f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.storedprocedureparamliststart */
extern T0* T44f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.storedprocedureparamliststartrequired */
extern T1 T44f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sp_start */
extern void T44f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.conditional_drop_procedure */
extern void T44f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_procedure */
extern void T43f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_procedure */
extern void T42f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_procedure */
extern void T41f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_sql */
extern void T64f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_sql */
extern void T63f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_sql */
extern void T62f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_sql */
extern void T61f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_sql */
extern void T60f265(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_sql */
extern void T59f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_sql */
extern void T58f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_sql */
extern void T57f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_sql */
extern void T56f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_sql */
extern void T55f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_sql */
extern void T54f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_sql */
extern void T53f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_sql */
extern void T52f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_sql */
extern void T51f278(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_sql */
extern void T50f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_sql */
extern void T49f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_sql */
extern void T48f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_sql */
extern void T47f282(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_sql */
extern void T46f282(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_sql */
extern void T45f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_sql */
extern void T44f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_sql */
extern void T43f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_sql */
extern void T42f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_sql */
extern void T41f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_one_line_comment */
extern void T64f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.multilinecommentpostfix */
extern T0* T64f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.onelinecommentprefix */
extern T0* T64f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.multilinecommentprefix */
extern T0* T64f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.noonelinecommentssupported */
extern T1 T64f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_one_line_comment */
extern void T63f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.multilinecommentpostfix */
extern T0* T63f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.onelinecommentprefix */
extern T0* T63f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.multilinecommentprefix */
extern T0* T63f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.noonelinecommentssupported */
extern T1 T63f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_one_line_comment */
extern void T62f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.multilinecommentpostfix */
extern T0* T62f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.onelinecommentprefix */
extern T0* T62f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.multilinecommentprefix */
extern T0* T62f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.noonelinecommentssupported */
extern T1 T62f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_one_line_comment */
extern void T61f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.multilinecommentpostfix */
extern T0* T61f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.onelinecommentprefix */
extern T0* T61f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.multilinecommentprefix */
extern T0* T61f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.noonelinecommentssupported */
extern T1 T61f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_one_line_comment */
extern void T60f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.multilinecommentpostfix */
extern T0* T60f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.onelinecommentprefix */
extern T0* T60f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.multilinecommentprefix */
extern T0* T60f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.noonelinecommentssupported */
extern T1 T60f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.write_one_line_comment */
extern void T59f270(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.multilinecommentpostfix */
extern T0* T59f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.onelinecommentprefix */
extern T0* T59f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.multilinecommentprefix */
extern T0* T59f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.noonelinecommentssupported */
extern T1 T59f104(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_one_line_comment */
extern void T58f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.multilinecommentpostfix */
extern T0* T58f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.onelinecommentprefix */
extern T0* T58f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.multilinecommentprefix */
extern T0* T58f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.noonelinecommentssupported */
extern T1 T58f104(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_one_line_comment */
extern void T57f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.multilinecommentpostfix */
extern T0* T57f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.onelinecommentprefix */
extern T0* T57f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.multilinecommentprefix */
extern T0* T57f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.noonelinecommentssupported */
extern T1 T57f105(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_one_line_comment */
extern void T56f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.multilinecommentpostfix */
extern T0* T56f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.onelinecommentprefix */
extern T0* T56f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.multilinecommentprefix */
extern T0* T56f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.noonelinecommentssupported */
extern T1 T56f105(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_one_line_comment */
extern void T55f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.multilinecommentpostfix */
extern T0* T55f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.onelinecommentprefix */
extern T0* T55f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.multilinecommentprefix */
extern T0* T55f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.noonelinecommentssupported */
extern T1 T55f105(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_one_line_comment */
extern void T54f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.multilinecommentpostfix */
extern T0* T54f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.onelinecommentprefix */
extern T0* T54f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.multilinecommentprefix */
extern T0* T54f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.noonelinecommentssupported */
extern T1 T54f102(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.write_one_line_comment */
extern void T53f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.multilinecommentpostfix */
extern T0* T53f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.onelinecommentprefix */
extern T0* T53f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.multilinecommentprefix */
extern T0* T53f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.noonelinecommentssupported */
extern T1 T53f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.write_one_line_comment */
extern void T52f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.multilinecommentpostfix */
extern T0* T52f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.onelinecommentprefix */
extern T0* T52f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.multilinecommentprefix */
extern T0* T52f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.noonelinecommentssupported */
extern T1 T52f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_one_line_comment */
extern void T51f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.multilinecommentpostfix */
extern T0* T51f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.onelinecommentprefix */
extern T0* T51f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.multilinecommentprefix */
extern T0* T51f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.noonelinecommentssupported */
extern T1 T51f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.write_one_line_comment */
extern void T50f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.multilinecommentpostfix */
extern T0* T50f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.onelinecommentprefix */
extern T0* T50f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.multilinecommentprefix */
extern T0* T50f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.noonelinecommentssupported */
extern T1 T50f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.write_one_line_comment */
extern void T49f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.multilinecommentpostfix */
extern T0* T49f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.onelinecommentprefix */
extern T0* T49f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.multilinecommentprefix */
extern T0* T49f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.noonelinecommentssupported */
extern T1 T49f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.write_one_line_comment */
extern void T48f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.multilinecommentpostfix */
extern T0* T48f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.onelinecommentprefix */
extern T0* T48f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.multilinecommentprefix */
extern T0* T48f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.noonelinecommentssupported */
extern T1 T48f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_one_line_comment */
extern void T47f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.multilinecommentpostfix */
extern T0* T47f26(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.onelinecommentprefix */
extern T0* T47f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.multilinecommentprefix */
extern T0* T47f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.noonelinecommentssupported */
extern T1 T47f102(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.write_one_line_comment */
extern void T46f263(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.multilinecommentpostfix */
extern T0* T46f26(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.onelinecommentprefix */
extern T0* T46f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.multilinecommentprefix */
extern T0* T46f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.noonelinecommentssupported */
extern T1 T46f102(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.write_one_line_comment */
extern void T45f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.multilinecommentpostfix */
extern T0* T45f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.onelinecommentprefix */
extern T0* T45f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.multilinecommentprefix */
extern T0* T45f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.noonelinecommentssupported */
extern T1 T45f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_one_line_comment */
extern void T44f264(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.multilinecommentpostfix */
extern T0* T44f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.onelinecommentprefix */
extern T0* T44f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.multilinecommentprefix */
extern T0* T44f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.noonelinecommentssupported */
extern T1 T44f98(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.write_one_line_comment */
extern void T43f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.multilinecommentpostfix */
extern T0* T43f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.onelinecommentprefix */
extern T0* T43f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.multilinecommentprefix */
extern T0* T43f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.noonelinecommentssupported */
extern T1 T43f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.write_one_line_comment */
extern void T42f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.multilinecommentpostfix */
extern T0* T42f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.onelinecommentprefix */
extern T0* T42f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.multilinecommentprefix */
extern T0* T42f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.noonelinecommentssupported */
extern T1 T42f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.write_one_line_comment */
extern void T41f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.multilinecommentpostfix */
extern T0* T41f25(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.onelinecommentprefix */
extern T0* T41f24(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.multilinecommentprefix */
extern T0* T41f23(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.noonelinecommentssupported */
extern T1 T41f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_init */
extern void T64f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_init */
extern void T64f288(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].forth */
extern void T408f12(GE_context* ac, T0* C);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].is_initialized_attribute */
extern T1 T408f9(GE_context* ac, T0* C);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].forth */
extern void T408f12p1(GE_context* ac, T0* C);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].item */
extern T0* T408f8(GE_context* ac, T0* C);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].start */
extern void T408f11(GE_context* ac, T0* C);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].start */
extern void T408f11p1(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.init_trigger_name */
extern T0* T64f75(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.init_necessary */
extern T1 T64f39(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.expressionsindefaultclausesupported */
extern T1 T64f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_init */
extern void T63f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_init */
extern void T63f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.init_trigger_name */
extern T0* T63f75(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.init_necessary */
extern T1 T63f39(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.expressionsindefaultclausesupported */
extern T1 T63f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_init */
extern void T62f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_init */
extern void T62f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.init_trigger_name */
extern T0* T62f75(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.init_necessary */
extern T1 T62f39(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.expressionsindefaultclausesupported */
extern T1 T62f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_init */
extern void T61f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_init */
extern void T61f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.init_trigger_name */
extern T0* T61f75(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.init_necessary */
extern T1 T61f39(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.expressionsindefaultclausesupported */
extern T1 T61f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_init */
extern void T60f266(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_init */
extern void T60f284(GE_context* ac, T0* C, T0* a1);
/* STRING_8.remove_tail */
extern void T17f50(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_SQLITE_3.sql_init_expression */
extern T0* T60f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.init_necessary */
extern T1 T60f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_init */
extern void T59f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_init */
extern void T59f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_init_expression */
extern T0* T59f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.init_necessary */
extern T1 T59f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.expressionsindefaultclausesupported */
extern T1 T59f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_init */
extern void T58f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_init */
extern void T58f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_init_expression */
extern T0* T58f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.init_necessary */
extern T1 T58f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.expressionsindefaultclausesupported */
extern T1 T58f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_init */
extern void T57f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_init */
extern void T57f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_init_expression */
extern T0* T57f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.init_necessary */
extern T1 T57f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.expressionsindefaultclausesupported */
extern T1 T57f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_init */
extern void T56f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_init */
extern void T56f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_init_expression */
extern T0* T56f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.init_necessary */
extern T1 T56f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.expressionsindefaultclausesupported */
extern T1 T56f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_init */
extern void T55f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_init */
extern void T55f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_init_expression */
extern T0* T55f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.init_necessary */
extern T1 T55f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.expressionsindefaultclausesupported */
extern T1 T55f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_init */
extern void T54f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_init */
extern void T54f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_init_expression */
extern T0* T54f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.init_necessary */
extern T1 T54f39(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.expressionsindefaultclausesupported */
extern T1 T54f146(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.write_init */
extern void T53f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.init_necessary */
extern T1 T53f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.expressionsindefaultclausesupported */
extern T1 T53f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.write_init */
extern void T52f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.init_necessary */
extern T1 T52f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.expressionsindefaultclausesupported */
extern T1 T52f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_init */
extern void T51f279(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_init */
extern void T51f299(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_init_expression */
extern T0* T51f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.init_necessary */
extern T1 T51f39(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_init */
extern void T50f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.init_necessary */
extern T1 T50f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.expressionsindefaultclausesupported */
extern T1 T50f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.write_init */
extern void T49f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.init_necessary */
extern T1 T49f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.expressionsindefaultclausesupported */
extern T1 T49f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.write_init */
extern void T48f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.init_necessary */
extern T1 T48f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.expressionsindefaultclausesupported */
extern T1 T48f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_init */
extern void T47f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_init */
extern void T47f303(GE_context* ac, T0* C, T0* a1);
extern T1 T47f303ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_FIREBIRD_21.sql_init_expression */
extern T0* T47f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.init_necessary */
extern T1 T47f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_init */
extern void T46f283(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_init */
extern void T46f303(GE_context* ac, T0* C, T0* a1);
extern T1 T46f303ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_INTERBASE6.sql_init_expression */
extern T0* T46f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.init_necessary */
extern T1 T46f40(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_init */
extern void T45f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.init_necessary */
extern T1 T45f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.expressionsindefaultclausesupported */
extern T1 T45f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_init */
extern void T44f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_init */
extern void T44f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_init_expression */
extern T0* T44f73(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.init_necessary */
extern T1 T44f39(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_init */
extern void T43f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.init_necessary */
extern T1 T43f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_init */
extern void T42f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.init_necessary */
extern T1 T42f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.expressionsindefaultclausesupported */
extern T1 T42f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.write_init */
extern void T41f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.init_necessary */
extern T1 T41f38(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.expressionsindefaultclausesupported */
extern T1 T41f122(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_type */
extern void T64f269(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_sp_delete */
extern void T64f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_before_end_delete */
extern void T64f323(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_delete_declaration */
extern void T64f322(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.table_ts_name */
extern T0* T64f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.createtimestamp */
extern T1 T64f85(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.create_sp_update */
extern void T64f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_before_end_update */
extern void T64f321(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_update_declaration */
extern void T64f320(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.create_sp_insert */
extern void T64f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_get_auto_generated_primary_key */
extern T0* T64f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.supportsdefaultvalues */
extern T1 T64f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_insert_declaration */
extern void T64f319(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_TSQL65.sp_define_out_param */
extern T0* T64f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_return_parameter_format_string */
extern T0* T64f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.storedprocedurereturnparamliststart */
extern T0* T64f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.outputparameterssupported */
extern T1 T64f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.write_type */
extern void T64f269p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.forbid_update_of_primary_key */
extern void T64f296(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_primary_key_generator */
extern void T64f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_view */
extern void T64f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.createviews */
extern T1 T64f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.create_table */
extern void T64f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_table */
extern void T64f293p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.timestampdatatype */
extern T0* T64f93(GE_context* ac, T0* C);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].forth */
extern void T386f13(GE_context* ac, T0* C);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].is_generated_attribute */
extern T1 T386f9(GE_context* ac, T0* C);
extern T1 T386f9ot1(T0* a1, T0** a2);
/* XPLAIN_ASSERTION.is_simple */
extern T1 T143f26(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.is_literal */
extern T1 T143f25(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.is_literal */
extern T1 T301f10(GE_context* ac, T0* C);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].forth */
extern void T386f13p1(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.column_constraint_name */
extern T0* T64f92(GE_context* ac, T0* C, T0* a1, T0* a2);
/* DS_HASH_SET [STRING_8].force */
extern void T402f32(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_SET [STRING_8].slots_put */
extern void T402f39(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_SET [STRING_8].clashes_put */
extern void T402f38(GE_context* ac, T0* C, T6 a1, T6 a2);
/* DS_HASH_SET [STRING_8].slots_item */
extern T6 T402f26(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].clashes_item */
extern T6 T402f25(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].hash_position */
extern T6 T402f27(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_SET [STRING_8].resize */
extern void T402f37(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].clashes_resize */
extern void T402f48(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].special_integer_ */
extern T0* T402f28(GE_context* ac, T0* C);
/* DS_HASH_SET [STRING_8].key_storage_resize */
extern void T402f47(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].item_storage_resize */
extern void T402f46(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].key_storage_item */
extern T0* T402f19(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].item_storage_item */
extern T0* T402f29(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].slots_resize */
extern void T402f45(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].new_modulus */
extern T6 T402f20(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].new_capacity */
extern T6 T402f23(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].item_storage_put */
extern void T402f36(GE_context* ac, T0* C, T0* a1, T6 a2);
/* DS_HASH_SET [STRING_8].search_position */
extern void T402f33(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_SET [STRING_8].key_equality_tester */
extern T0* T402f17(GE_context* ac, T0* C);
/* DS_HASH_SET [STRING_8].unset_found_item */
extern void T402f35(GE_context* ac, T0* C);
/* DS_HASH_SET [STRING_8].has */
extern T1 T402f22(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.constraint_names */
extern T0* T64f152(GE_context* ac, T0* C);
/* DS_HASH_SET [STRING_8].make_equal */
extern T0* T402c31(GE_context* ac, T6 a1);
/* DS_HASH_SET [STRING_8].make */
extern void T402f34(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].set_internal_cursor */
extern void T402f44(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_SET [STRING_8].new_cursor */
extern T0* T402f21(GE_context* ac, T0* C);
/* DS_HASH_SET_CURSOR [STRING_8].make */
extern T0* T438c4(GE_context* ac, T0* a1);
/* DS_HASH_SET [STRING_8].make_slots */
extern void T402f43(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].make_clashes */
extern void T402f42(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].make_key_storage */
extern void T402f41(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_SET [STRING_8].make_item_storage */
extern void T402f40(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL65.make_valid_constraint_identifier */
extern T0* T64f151(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.maxconstraintidentifierlength */
extern T6 T64f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.constraintnamesupported */
extern T1 T64f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.inlineuniqueconstraintsupported */
extern T1 T64f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.uniqueconstraintsupported */
extern T1 T64f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.init_forced_default */
extern T1 T64f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.checksnullaftertrigger */
extern T1 T64f150(GE_context* ac, T0* C);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].item */
extern T0* T386f8(GE_context* ac, T0* C);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].start */
extern void T386f12(GE_context* ac, T0* C);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].start */
extern void T386f12p1(GE_context* ac, T0* C);
/* XPLAIN_PK_I_REPRESENTATION.pkdatatype */
extern T0* T249f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_A_REPRESENTATION.pkdatatype */
extern T0* T246f3(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_table_if_exist */
extern void T64f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.print */
extern void T64f324(GE_context* ac, T0* C, T0* a1);
/* STD_FILES.put_string */
extern void T328f8(GE_context* ac, T0* C, T0* a1);
/* STD_FILES.standard_default */
extern T0* T328f4(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.io */
extern T0* T64f98(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_type */
extern void T63f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_sp_delete */
extern void T63f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_before_end_delete */
extern void T63f323(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sp_delete_declaration */
extern void T63f322(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.table_ts_name */
extern T0* T63f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.createtimestamp */
extern T1 T63f85(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.create_sp_update */
extern void T63f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_before_end_update */
extern void T63f321(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sp_update_declaration */
extern void T63f320(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.create_sp_insert */
extern void T63f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_get_auto_generated_primary_key */
extern T0* T63f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.supportsdefaultvalues */
extern T1 T63f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sp_insert_declaration */
extern void T63f319(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_TSQL70.sp_define_out_param */
extern T0* T63f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_return_parameter_format_string */
extern T0* T63f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.storedprocedurereturnparamliststart */
extern T0* T63f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.outputparameterssupported */
extern T1 T63f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_type */
extern void T63f268p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.forbid_update_of_primary_key */
extern void T63f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_primary_key_generator */
extern void T63f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_view */
extern void T63f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.createviews */
extern T1 T63f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.create_table */
extern void T63f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_table */
extern void T63f292p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.timestampdatatype */
extern T0* T63f93(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.column_constraint_name */
extern T0* T63f92(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.constraint_names */
extern T0* T63f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.make_valid_constraint_identifier */
extern T0* T63f150(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.maxconstraintidentifierlength */
extern T6 T63f182(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.constraintnamesupported */
extern T1 T63f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.inlineuniqueconstraintsupported */
extern T1 T63f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.uniqueconstraintsupported */
extern T1 T63f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.init_forced_default */
extern T1 T63f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.checksnullaftertrigger */
extern T1 T63f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.drop_table_if_exist */
extern void T63f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_type */
extern void T62f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_sp_delete */
extern void T62f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_before_end_delete */
extern void T62f323(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sp_delete_declaration */
extern void T62f322(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.table_ts_name */
extern T0* T62f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.createtimestamp */
extern T1 T62f85(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.create_sp_update */
extern void T62f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_before_end_update */
extern void T62f321(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sp_update_declaration */
extern void T62f320(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.create_sp_insert */
extern void T62f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_get_auto_generated_primary_key */
extern T0* T62f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.supportsdefaultvalues */
extern T1 T62f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sp_insert_declaration */
extern void T62f319(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_TSQL2000.sp_define_out_param */
extern T0* T62f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_return_parameter_format_string */
extern T0* T62f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.storedprocedurereturnparamliststart */
extern T0* T62f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.outputparameterssupported */
extern T1 T62f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_type */
extern void T62f268p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.forbid_update_of_primary_key */
extern void T62f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_primary_key_generator */
extern void T62f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_view */
extern void T62f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.createviews */
extern T1 T62f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.create_table */
extern void T62f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_table */
extern void T62f292p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.timestampdatatype */
extern T0* T62f93(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.column_constraint_name */
extern T0* T62f92(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.constraint_names */
extern T0* T62f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.make_valid_constraint_identifier */
extern T0* T62f150(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.maxconstraintidentifierlength */
extern T6 T62f182(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.constraintnamesupported */
extern T1 T62f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.inlineuniqueconstraintsupported */
extern T1 T62f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.uniqueconstraintsupported */
extern T1 T62f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.init_forced_default */
extern T1 T62f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.checksnullaftertrigger */
extern T1 T62f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.drop_table_if_exist */
extern void T62f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_type */
extern void T61f268(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_sp_delete */
extern void T61f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_before_end_delete */
extern void T61f322(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sp_delete_declaration */
extern void T61f321(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.table_ts_name */
extern T0* T61f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.createtimestamp */
extern T1 T61f85(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.create_sp_update */
extern void T61f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_before_end_update */
extern void T61f320(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sp_update_declaration */
extern void T61f319(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.create_sp_insert */
extern void T61f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_get_auto_generated_primary_key */
extern T0* T61f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.supportsdefaultvalues */
extern T1 T61f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sp_insert_declaration */
extern void T61f318(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_TSQL2016.sp_define_out_param */
extern T0* T61f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_return_parameter_format_string */
extern T0* T61f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.storedprocedurereturnparamliststart */
extern T0* T61f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.outputparameterssupported */
extern T1 T61f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_type */
extern void T61f268p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.forbid_update_of_primary_key */
extern void T61f295(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_primary_key_generator */
extern void T61f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_view */
extern void T61f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.createviews */
extern T1 T61f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.create_table */
extern void T61f292(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_table */
extern void T61f292p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.timestampdatatype */
extern T0* T61f93(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.column_constraint_name */
extern T0* T61f92(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.constraint_names */
extern T0* T61f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.make_valid_constraint_identifier */
extern T0* T61f150(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.maxconstraintidentifierlength */
extern T6 T61f182(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.constraintnamesupported */
extern T1 T61f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.inlineuniqueconstraintsupported */
extern T1 T61f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.uniqueconstraintsupported */
extern T1 T61f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.init_forced_default */
extern T1 T61f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.checksnullaftertrigger */
extern T1 T61f149(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.drop_table_if_exist */
extern void T61f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_type */
extern void T60f267(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.forbid_update_of_primary_key */
extern void T60f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_primary_key_generator */
extern void T60f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_view */
extern void T60f287(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.createviews */
extern T1 T60f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.create_table */
extern void T60f286(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.timestampdatatype */
extern T0* T60f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.table_ts_name */
extern T0* T60f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.createtimestamp */
extern T1 T60f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.timestampsupported */
extern T1 T60f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.column_constraint_name */
extern T0* T60f69(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.constraint_names */
extern T0* T60f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.make_valid_constraint_identifier */
extern T0* T60f134(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.maxconstraintidentifierlength */
extern T6 T60f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.constraintnamesupported */
extern T1 T60f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.inlineuniqueconstraintsupported */
extern T1 T60f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.uniqueconstraintsupported */
extern T1 T60f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.init_forced_default */
extern T1 T60f65(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.checksnullaftertrigger */
extern T1 T60f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.drop_table_if_exist */
extern void T60f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_type */
extern void T59f291(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_sp_delete */
extern void T59f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_before_end_delete */
extern void T59f343(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sp_delete_declaration */
extern void T59f342(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.table_ts_name */
extern T0* T59f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.createtimestamp */
extern T1 T59f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.timestampsupported */
extern T1 T59f159(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_sp_update */
extern void T59f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_before_end_update */
extern void T59f341(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sp_update_declaration */
extern void T59f340(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.create_sp_insert */
extern void T59f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_get_auto_generated_primary_key */
extern T0* T59f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.supportsdefaultvalues */
extern T1 T59f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sp_insert_declaration */
extern void T59f339(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_PGSQL_72.sp_define_out_param */
extern T0* T59f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_return_parameter_format_string */
extern T0* T59f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.storedprocedurereturnparamliststart */
extern T0* T59f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.write_type */
extern void T59f291p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.forbid_update_of_primary_key */
extern void T59f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_primary_key_generator */
extern void T59f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_view */
extern void T59f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.createviews */
extern T1 T59f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_table */
extern void T59f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.timestampdatatype */
extern T0* T59f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.column_constraint_name */
extern T0* T59f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.constraint_names */
extern T0* T59f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.make_valid_constraint_identifier */
extern T0* T59f163(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.maxconstraintidentifierlength */
extern T6 T59f197(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.maxidentifierlength */
extern T6 T59f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.constraintnamesupported */
extern T1 T59f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.inlineuniqueconstraintsupported */
extern T1 T59f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.uniqueconstraintsupported */
extern T1 T59f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.init_forced_default */
extern T1 T59f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.checksnullaftertrigger */
extern T1 T59f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.drop_table_if_exist */
extern void T59f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_type */
extern void T58f293(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_sp_delete */
extern void T58f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_before_end_delete */
extern void T58f345(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_delete_declaration */
extern void T58f344(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.table_ts_name */
extern T0* T58f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.createtimestamp */
extern T1 T58f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.timestampsupported */
extern T1 T58f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_sp_update */
extern void T58f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_before_end_update */
extern void T58f343(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_update_declaration */
extern void T58f342(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.create_sp_insert */
extern void T58f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_get_auto_generated_primary_key */
extern T0* T58f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.supportsdefaultvalues */
extern T1 T58f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_insert_declaration */
extern void T58f341(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_PGSQL_73.sp_define_out_param */
extern T0* T58f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_return_parameter_format_string */
extern T0* T58f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.storedprocedurereturnparamliststart */
extern T0* T58f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_type */
extern void T58f293p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.forbid_update_of_primary_key */
extern void T58f319(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_primary_key_generator */
extern void T58f318(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_view */
extern void T58f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.createviews */
extern T1 T58f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_table */
extern void T58f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.timestampdatatype */
extern T0* T58f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.column_constraint_name */
extern T0* T58f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.constraint_names */
extern T0* T58f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.make_valid_constraint_identifier */
extern T0* T58f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.maxconstraintidentifierlength */
extern T6 T58f197(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.maxidentifierlength */
extern T6 T58f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.constraintnamesupported */
extern T1 T58f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.inlineuniqueconstraintsupported */
extern T1 T58f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.uniqueconstraintsupported */
extern T1 T58f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.init_forced_default */
extern T1 T58f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.checksnullaftertrigger */
extern T1 T58f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.drop_table_if_exist */
extern void T58f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_type */
extern void T57f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_sp_delete */
extern void T57f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_before_end_delete */
extern void T57f346(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sp_delete_declaration */
extern void T57f345(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.table_ts_name */
extern T0* T57f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.createtimestamp */
extern T1 T57f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.timestampsupported */
extern T1 T57f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_sp_update */
extern void T57f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_before_end_update */
extern void T57f344(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sp_update_declaration */
extern void T57f343(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_81.create_sp_insert */
extern void T57f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_get_auto_generated_primary_key */
extern T0* T57f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.supportsdefaultvalues */
extern T1 T57f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sp_insert_declaration */
extern void T57f342(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_PGSQL_81.sp_define_out_param */
extern T0* T57f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_return_parameter_format_string */
extern T0* T57f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.storedprocedurereturnparamliststart */
extern T0* T57f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_type */
extern void T57f294p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.forbid_update_of_primary_key */
extern void T57f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_primary_key_generator */
extern void T57f319(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_view */
extern void T57f318(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.createviews */
extern T1 T57f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_table */
extern void T57f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.timestampdatatype */
extern T0* T57f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.column_constraint_name */
extern T0* T57f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.constraint_names */
extern T0* T57f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.make_valid_constraint_identifier */
extern T0* T57f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.maxconstraintidentifierlength */
extern T6 T57f198(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.maxidentifierlength */
extern T6 T57f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.constraintnamesupported */
extern T1 T57f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.inlineuniqueconstraintsupported */
extern T1 T57f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.uniqueconstraintsupported */
extern T1 T57f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.init_forced_default */
extern T1 T57f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.checksnullaftertrigger */
extern T1 T57f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.drop_table_if_exist */
extern void T57f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_type */
extern void T56f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_sp_delete */
extern void T56f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_before_end_delete */
extern void T56f346(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sp_delete_declaration */
extern void T56f345(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.table_ts_name */
extern T0* T56f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.createtimestamp */
extern T1 T56f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.timestampsupported */
extern T1 T56f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_sp_update */
extern void T56f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_before_end_update */
extern void T56f344(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sp_update_declaration */
extern void T56f343(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_82.create_sp_insert */
extern void T56f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_get_auto_generated_primary_key */
extern T0* T56f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.supportsdefaultvalues */
extern T1 T56f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sp_insert_declaration */
extern void T56f342(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_PGSQL_82.sp_define_out_param */
extern T0* T56f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_return_parameter_format_string */
extern T0* T56f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.storedprocedurereturnparamliststart */
extern T0* T56f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_type */
extern void T56f294p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.forbid_update_of_primary_key */
extern void T56f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_primary_key_generator */
extern void T56f319(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_view */
extern void T56f318(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.createviews */
extern T1 T56f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_table */
extern void T56f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.timestampdatatype */
extern T0* T56f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.column_constraint_name */
extern T0* T56f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.constraint_names */
extern T0* T56f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.make_valid_constraint_identifier */
extern T0* T56f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.maxconstraintidentifierlength */
extern T6 T56f198(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.maxidentifierlength */
extern T6 T56f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.constraintnamesupported */
extern T1 T56f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.inlineuniqueconstraintsupported */
extern T1 T56f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.uniqueconstraintsupported */
extern T1 T56f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.init_forced_default */
extern T1 T56f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.checksnullaftertrigger */
extern T1 T56f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.drop_table_if_exist */
extern void T56f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_type */
extern void T55f294(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_sp_delete */
extern void T55f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_before_end_delete */
extern void T55f346(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sp_delete_declaration */
extern void T55f345(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.table_ts_name */
extern T0* T55f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.createtimestamp */
extern T1 T55f82(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.timestampsupported */
extern T1 T55f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_sp_update */
extern void T55f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_before_end_update */
extern void T55f344(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sp_update_declaration */
extern void T55f343(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_95.create_sp_insert */
extern void T55f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_get_auto_generated_primary_key */
extern T0* T55f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.supportsdefaultvalues */
extern T1 T55f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sp_insert_declaration */
extern void T55f342(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_PGSQL_95.sp_define_out_param */
extern T0* T55f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_return_parameter_format_string */
extern T0* T55f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.storedprocedurereturnparamliststart */
extern T0* T55f74(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_type */
extern void T55f294p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.forbid_update_of_primary_key */
extern void T55f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_primary_key_generator */
extern void T55f319(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_view */
extern void T55f318(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.createviews */
extern T1 T55f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_table */
extern void T55f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.timestampdatatype */
extern T0* T55f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.column_constraint_name */
extern T0* T55f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.constraint_names */
extern T0* T55f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.make_valid_constraint_identifier */
extern T0* T55f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.maxconstraintidentifierlength */
extern T6 T55f198(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.maxidentifierlength */
extern T6 T55f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.constraintnamesupported */
extern T1 T55f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.inlineuniqueconstraintsupported */
extern T1 T55f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.uniqueconstraintsupported */
extern T1 T55f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.init_forced_default */
extern T1 T55f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.checksnullaftertrigger */
extern T1 T55f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.drop_table_if_exist */
extern void T55f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_type */
extern void T54f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_sp_delete */
extern void T54f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_before_end_delete */
extern void T54f342(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sp_delete_declaration */
extern void T54f341(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.table_ts_name */
extern T0* T54f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.createtimestamp */
extern T1 T54f84(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.timestampsupported */
extern T1 T54f158(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.create_sp_update */
extern void T54f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_before_end_update */
extern void T54f340(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sp_update_declaration */
extern void T54f339(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ORACLE.create_sp_insert */
extern void T54f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_get_auto_generated_primary_key */
extern T0* T54f82(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.supportsdefaultvalues */
extern T1 T54f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sp_insert_declaration */
extern void T54f338(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_ORACLE.sp_define_out_param */
extern T0* T54f79(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_return_parameter_format_string */
extern T0* T54f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.storedprocedurereturnparamliststart */
extern T0* T54f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.outputparameterssupported */
extern T1 T54f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_type */
extern void T54f289p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.forbid_update_of_primary_key */
extern void T54f316(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.trigger_primary_key_update_name */
extern T0* T54f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_primary_key_generator */
extern void T54f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sequence_name */
extern T0* T54f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_view */
extern void T54f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.createviews */
extern T1 T54f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.create_table */
extern void T54f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.timestampdatatype */
extern T0* T54f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.column_constraint_name */
extern T0* T54f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.constraint_names */
extern T0* T54f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.make_valid_constraint_identifier */
extern T0* T54f161(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.maxconstraintidentifierlength */
extern T6 T54f195(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.maxidentifierlength */
extern T6 T54f191(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.constraintnamesupported */
extern T1 T54f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.inlineuniqueconstraintsupported */
extern T1 T54f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.uniqueconstraintsupported */
extern T1 T54f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.init_forced_default */
extern T1 T54f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.checksnullaftertrigger */
extern T1 T54f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.drop_table_if_exist */
extern void T54f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_type */
extern void T53f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.forbid_update_of_primary_key */
extern void T53f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_primary_key_generator */
extern void T53f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_view */
extern void T53f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.createviews */
extern T1 T53f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.create_table */
extern void T53f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.timestampdatatype */
extern T0* T53f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.table_ts_name */
extern T0* T53f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.createtimestamp */
extern T1 T53f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.timestampsupported */
extern T1 T53f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.column_constraint_name */
extern T0* T53f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.constraint_names */
extern T0* T53f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.make_valid_constraint_identifier */
extern T0* T53f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.maxconstraintidentifierlength */
extern T6 T53f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.maxidentifierlength */
extern T6 T53f158(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.constraintnamesupported */
extern T1 T53f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.inlineuniqueconstraintsupported */
extern T1 T53f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.uniqueconstraintsupported */
extern T1 T53f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.init_forced_default */
extern T1 T53f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.drop_table_if_exist */
extern void T53f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_type */
extern void T52f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.forbid_update_of_primary_key */
extern void T52f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_primary_key_generator */
extern void T52f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_view */
extern void T52f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.createviews */
extern T1 T52f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.create_table */
extern void T52f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.timestampdatatype */
extern T0* T52f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.table_ts_name */
extern T0* T52f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.createtimestamp */
extern T1 T52f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.timestampsupported */
extern T1 T52f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.column_constraint_name */
extern T0* T52f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.constraint_names */
extern T0* T52f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.make_valid_constraint_identifier */
extern T0* T52f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.maxconstraintidentifierlength */
extern T6 T52f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.maxidentifierlength */
extern T6 T52f158(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.constraintnamesupported */
extern T1 T52f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.inlineuniqueconstraintsupported */
extern T1 T52f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.uniqueconstraintsupported */
extern T1 T52f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.init_forced_default */
extern T1 T52f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.drop_table_if_exist */
extern void T52f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_type */
extern void T51f280(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_sp_delete */
extern void T51f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_before_end_delete */
extern void T51f333(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_delete_declaration */
extern void T51f332(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.table_ts_name */
extern T0* T51f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.createtimestamp */
extern T1 T51f84(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.timestampsupported */
extern T1 T51f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.create_sp_update */
extern void T51f301(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_before_end_update */
extern void T51f331(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_update_declaration */
extern void T51f330(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.create_sp_insert */
extern void T51f300(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_get_auto_generated_primary_key */
extern T0* T51f82(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.supportsdefaultvalues */
extern T1 T51f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sp_insert_declaration */
extern void T51f329(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_MYSQL5.sp_define_out_param */
extern T0* T51f79(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_return_parameter_format_string */
extern T0* T51f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.storedprocedurereturnparamliststart */
extern T0* T51f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.outputparameterssupported */
extern T1 T51f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_type */
extern void T51f280p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.forbid_update_of_primary_key */
extern void T51f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_primary_key_generator */
extern void T51f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_view */
extern void T51f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.createviews */
extern T1 T51f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.create_table */
extern void T51f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.timestampdatatype */
extern T0* T51f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.column_constraint_name */
extern T0* T51f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.constraint_names */
extern T0* T51f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.make_valid_constraint_identifier */
extern T0* T51f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.maxconstraintidentifierlength */
extern T6 T51f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.maxidentifierlength */
extern T6 T51f181(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.constraintnamesupported */
extern T1 T51f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.inlineuniqueconstraintsupported */
extern T1 T51f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.uniqueconstraintsupported */
extern T1 T51f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.init_forced_default */
extern T1 T51f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.checksnullaftertrigger */
extern T1 T51f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.drop_table_if_exist */
extern void T51f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_type */
extern void T50f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.forbid_update_of_primary_key */
extern void T50f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_primary_key_generator */
extern void T50f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_view */
extern void T50f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.createviews */
extern T1 T50f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.create_table */
extern void T50f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.timestampdatatype */
extern T0* T50f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.table_ts_name */
extern T0* T50f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.createtimestamp */
extern T1 T50f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.timestampsupported */
extern T1 T50f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.column_constraint_name */
extern T0* T50f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.constraint_names */
extern T0* T50f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.make_valid_constraint_identifier */
extern T0* T50f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.maxconstraintidentifierlength */
extern T6 T50f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.maxidentifierlength */
extern T6 T50f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.constraintnamesupported */
extern T1 T50f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.inlineuniqueconstraintsupported */
extern T1 T50f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.uniqueconstraintsupported */
extern T1 T50f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.init_forced_default */
extern T1 T50f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.drop_table_if_exist */
extern void T50f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_type */
extern void T49f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.forbid_update_of_primary_key */
extern void T49f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_primary_key_generator */
extern void T49f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_view */
extern void T49f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.createviews */
extern T1 T49f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.create_table */
extern void T49f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.timestampdatatype */
extern T0* T49f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.table_ts_name */
extern T0* T49f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.createtimestamp */
extern T1 T49f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.timestampsupported */
extern T1 T49f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.column_constraint_name */
extern T0* T49f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.constraint_names */
extern T0* T49f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.make_valid_constraint_identifier */
extern T0* T49f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.maxconstraintidentifierlength */
extern T6 T49f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.maxidentifierlength */
extern T6 T49f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.constraintnamesupported */
extern T1 T49f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.inlineuniqueconstraintsupported */
extern T1 T49f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.uniqueconstraintsupported */
extern T1 T49f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.init_forced_default */
extern T1 T49f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.drop_table_if_exist */
extern void T49f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_type */
extern void T48f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.forbid_update_of_primary_key */
extern void T48f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_primary_key_generator */
extern void T48f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_view */
extern void T48f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.createviews */
extern T1 T48f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.create_table */
extern void T48f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.timestampdatatype */
extern T0* T48f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.table_ts_name */
extern T0* T48f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.createtimestamp */
extern T1 T48f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.timestampsupported */
extern T1 T48f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.column_constraint_name */
extern T0* T48f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.constraint_names */
extern T0* T48f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.make_valid_constraint_identifier */
extern T0* T48f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.maxconstraintidentifierlength */
extern T6 T48f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.maxidentifierlength */
extern T6 T48f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.constraintnamesupported */
extern T1 T48f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.inlineuniqueconstraintsupported */
extern T1 T48f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.uniqueconstraintsupported */
extern T1 T48f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.init_forced_default */
extern T1 T48f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.drop_table_if_exist */
extern void T48f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_type */
extern void T47f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_sp_delete */
extern void T47f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_before_end_delete */
extern void T47f340(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sp_delete_declaration */
extern void T47f339(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.table_ts_name */
extern T0* T47f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.createtimestamp */
extern T1 T47f84(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.timestampsupported */
extern T1 T47f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.create_sp_update */
extern void T47f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_before_end_update */
extern void T47f338(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sp_update_declaration */
extern void T47f337(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.create_sp_insert */
extern void T47f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_get_auto_generated_primary_key */
extern T0* T47f82(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.supportsdefaultvalues */
extern T1 T47f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sp_insert_declaration */
extern void T47f336(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_FIREBIRD_21.sp_define_out_param */
extern T0* T47f79(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_return_parameter_format_string */
extern T0* T47f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.outputparameterssupported */
extern T1 T47f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_type */
extern void T47f284p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.forbid_update_of_primary_key */
extern void T47f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_primary_key_generator */
extern void T47f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.generator_name */
extern T0* T47f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.maxidentifierlength */
extern T6 T47f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.create_view */
extern void T47f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.createviews */
extern T1 T47f42(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.create_table */
extern void T47f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_table */
extern void T47f308p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.timestampdatatype */
extern T0* T47f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.column_constraint_name */
extern T0* T47f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.constraint_names */
extern T0* T47f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.make_valid_constraint_identifier */
extern T0* T47f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.maxconstraintidentifierlength */
extern T6 T47f191(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.constraintnamesupported */
extern T1 T47f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.inlineuniqueconstraintsupported */
extern T1 T47f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.uniqueconstraintsupported */
extern T1 T47f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.init_forced_default */
extern T1 T47f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_table_if_exist */
extern void T47f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_type */
extern void T46f284(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_sp_delete */
extern void T46f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_before_end_delete */
extern void T46f339(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sp_delete_declaration */
extern void T46f338(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.table_ts_name */
extern T0* T46f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.createtimestamp */
extern T1 T46f84(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.timestampsupported */
extern T1 T46f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.create_sp_update */
extern void T46f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_before_end_update */
extern void T46f337(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sp_update_declaration */
extern void T46f336(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.create_sp_insert */
extern void T46f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_get_auto_generated_primary_key */
extern T0* T46f82(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.supportsdefaultvalues */
extern T1 T46f81(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sp_insert_declaration */
extern void T46f335(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_INTERBASE6.sp_define_out_param */
extern T0* T46f79(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_return_parameter_format_string */
extern T0* T46f78(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.outputparameterssupported */
extern T1 T46f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.write_type */
extern void T46f284p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.forbid_update_of_primary_key */
extern void T46f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_primary_key_generator */
extern void T46f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.generator_name */
extern T0* T46f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.maxidentifierlength */
extern T6 T46f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sql_create_generator */
extern T0* T46f93(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.create_view */
extern void T46f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.createviews */
extern T1 T46f42(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.create_table */
extern void T46f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.timestampdatatype */
extern T0* T46f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.column_constraint_name */
extern T0* T46f91(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.constraint_names */
extern T0* T46f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.make_valid_constraint_identifier */
extern T0* T46f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.maxconstraintidentifierlength */
extern T6 T46f191(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.constraintnamesupported */
extern T1 T46f90(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.inlineuniqueconstraintsupported */
extern T1 T46f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.uniqueconstraintsupported */
extern T1 T46f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.init_forced_default */
extern T1 T46f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_table_if_exist */
extern void T46f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_type */
extern void T45f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.forbid_update_of_primary_key */
extern void T45f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_primary_key_generator */
extern void T45f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_view */
extern void T45f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.createviews */
extern T1 T45f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.create_table */
extern void T45f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.timestampdatatype */
extern T0* T45f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.table_ts_name */
extern T0* T45f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.createtimestamp */
extern T1 T45f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.timestampsupported */
extern T1 T45f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.column_constraint_name */
extern T0* T45f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.constraint_names */
extern T0* T45f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.make_valid_constraint_identifier */
extern T0* T45f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.maxconstraintidentifierlength */
extern T6 T45f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.maxidentifierlength */
extern T6 T45f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.constraintnamesupported */
extern T1 T45f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.inlineuniqueconstraintsupported */
extern T1 T45f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.uniqueconstraintsupported */
extern T1 T45f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.init_forced_default */
extern T1 T45f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.drop_table_if_exist */
extern void T45f271(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_type */
extern void T44f285(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_sp_delete */
extern void T44f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_before_end_delete */
extern void T44f338(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sp_delete_declaration */
extern void T44f337(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.table_ts_name */
extern T0* T44f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.createtimestamp */
extern T1 T44f83(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.timestampsupported */
extern T1 T44f158(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.create_sp_update */
extern void T44f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_before_end_update */
extern void T44f336(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sp_update_declaration */
extern void T44f335(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.create_sp_insert */
extern void T44f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_get_auto_generated_primary_key */
extern T0* T44f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.supportsdefaultvalues */
extern T1 T44f80(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sp_insert_declaration */
extern void T44f334(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_DB2_71.sp_define_out_param */
extern T0* T44f78(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_return_parameter_format_string */
extern T0* T44f77(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.storedprocedurereturnparamliststart */
extern T0* T44f76(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.outputparameterssupported */
extern T1 T44f75(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_type */
extern void T44f285p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.forbid_update_of_primary_key */
extern void T44f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_primary_key_generator */
extern void T44f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_view */
extern void T44f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.createviews */
extern T1 T44f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.create_table */
extern void T44f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.timestampdatatype */
extern T0* T44f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.column_constraint_name */
extern T0* T44f90(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.constraint_names */
extern T0* T44f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.make_valid_constraint_identifier */
extern T0* T44f161(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.maxconstraintidentifierlength */
extern T6 T44f191(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.constraintnamesupported */
extern T1 T44f89(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.inlineuniqueconstraintsupported */
extern T1 T44f88(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.uniqueconstraintsupported */
extern T1 T44f87(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.init_forced_default */
extern T1 T44f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.checksnullaftertrigger */
extern T1 T44f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.drop_table_if_exist */
extern void T44f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_type */
extern void T43f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.forbid_update_of_primary_key */
extern void T43f277(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_primary_key_generator */
extern void T43f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_view */
extern void T43f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.createviews */
extern T1 T43f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.create_table */
extern void T43f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.timestampdatatype */
extern T0* T43f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.table_ts_name */
extern T0* T43f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.createtimestamp */
extern T1 T43f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.timestampsupported */
extern T1 T43f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.column_constraint_name */
extern T0* T43f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.constraint_names */
extern T0* T43f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.make_valid_constraint_identifier */
extern T0* T43f133(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.maxconstraintidentifierlength */
extern T6 T43f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.constraintnamesupported */
extern T1 T43f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.inlineuniqueconstraintsupported */
extern T1 T43f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.uniqueconstraintsupported */
extern T1 T43f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.init_forced_default */
extern T1 T43f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.drop_table_if_exist */
extern void T43f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_type */
extern void T42f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.forbid_update_of_primary_key */
extern void T42f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_primary_key_generator */
extern void T42f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_view */
extern void T42f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.createviews */
extern T1 T42f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.create_table */
extern void T42f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.timestampdatatype */
extern T0* T42f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.table_ts_name */
extern T0* T42f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.createtimestamp */
extern T1 T42f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.timestampsupported */
extern T1 T42f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.column_constraint_name */
extern T0* T42f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.constraint_names */
extern T0* T42f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.make_valid_constraint_identifier */
extern T0* T42f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.maxconstraintidentifierlength */
extern T6 T42f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.maxidentifierlength */
extern T6 T42f158(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.constraintnamesupported */
extern T1 T42f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.inlineuniqueconstraintsupported */
extern T1 T42f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.uniqueconstraintsupported */
extern T1 T42f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.init_forced_default */
extern T1 T42f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.drop_table_if_exist */
extern void T42f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_type */
extern void T41f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.forbid_update_of_primary_key */
extern void T41f276(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_primary_key_generator */
extern void T41f275(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_view */
extern void T41f274(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.createviews */
extern T1 T41f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.create_table */
extern void T41f273(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.timestampdatatype */
extern T0* T41f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.table_ts_name */
extern T0* T41f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.createtimestamp */
extern T1 T41f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.timestampsupported */
extern T1 T41f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.column_constraint_name */
extern T0* T41f68(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.constraint_names */
extern T0* T41f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.make_valid_constraint_identifier */
extern T0* T41f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.maxconstraintidentifierlength */
extern T6 T41f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.maxidentifierlength */
extern T6 T41f158(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.constraintnamesupported */
extern T1 T41f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.inlineuniqueconstraintsupported */
extern T1 T41f66(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.uniqueconstraintsupported */
extern T1 T41f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.init_forced_default */
extern T1 T41f64(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.drop_table_if_exist */
extern void T41f272(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_domain */
extern void T64f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_domain */
extern void T63f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_domain */
extern void T62f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_domain */
extern void T61f339(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.drop_domain */
extern void T60f317(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_domain */
extern void T59f363(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_domain */
extern void T58f367(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_domain */
extern void T57f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_domain */
extern void T56f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_domain */
extern void T55f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_domain */
extern void T54f358(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.drop_domain */
extern void T53f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.drop_domain */
extern void T52f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_domain */
extern void T51f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.drop_domain */
extern void T50f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.drop_domain */
extern void T49f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.drop_domain */
extern void T48f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_domain */
extern void T47f356(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_domain */
extern void T46f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.drop_domain */
extern void T45f303(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_domain */
extern void T44f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.drop_domain */
extern void T43f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.drop_domain */
extern void T42f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.drop_domain */
extern void T41f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_table */
extern void T64f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_table */
extern void T64f325p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_primary_key_generator */
extern void T64f331(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_sp */
extern void T64f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_drop_procedure */
extern void T64f335(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_table */
extern void T63f324(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_table */
extern void T63f324p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_primary_key_generator */
extern void T63f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_sp */
extern void T63f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_table */
extern void T62f324(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_table */
extern void T62f324p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_primary_key_generator */
extern void T62f330(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_sp */
extern void T62f329(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_table */
extern void T61f340(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_table */
extern void T61f340p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_primary_key_generator */
extern void T61f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_sp */
extern void T61f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.do_drop_procedure */
extern void T61f349(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.drop_table */
extern void T60f318(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.drop_primary_key_generator */
extern void T60f322(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_table */
extern void T59f364(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_table */
extern void T59f364p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_primary_key_generator */
extern void T59f370(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_sp */
extern void T59f369(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.do_drop_procedure */
extern void T59f373(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_table */
extern void T58f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_table */
extern void T58f368p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_primary_key_generator */
extern void T58f374(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_sp */
extern void T58f373(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.do_drop_procedure */
extern void T58f377(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_table */
extern void T57f369(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_table */
extern void T57f369p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_primary_key_generator */
extern void T57f375(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_sp */
extern void T57f374(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.do_drop_procedure */
extern void T57f378(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_table */
extern void T56f369(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_table */
extern void T56f369p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_primary_key_generator */
extern void T56f375(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_sp */
extern void T56f374(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.do_drop_procedure */
extern void T56f378(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_table */
extern void T55f369(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_table */
extern void T55f369p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_primary_key_generator */
extern void T55f375(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_sp */
extern void T55f374(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.do_drop_procedure */
extern void T55f378(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_table */
extern void T54f359(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_table */
extern void T54f359p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_primary_key_generator */
extern void T54f365(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_sp */
extern void T54f364(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.do_drop_procedure */
extern void T54f369(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.drop_table */
extern void T53f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.drop_primary_key_generator */
extern void T53f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.drop_table */
extern void T52f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.drop_primary_key_generator */
extern void T52f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_table */
extern void T51f348(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_table */
extern void T51f348p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_primary_key_generator */
extern void T51f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_sp */
extern void T51f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.do_drop_procedure */
extern void T51f357(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.drop_table */
extern void T50f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.drop_primary_key_generator */
extern void T50f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.drop_table */
extern void T49f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.drop_primary_key_generator */
extern void T49f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.drop_table */
extern void T48f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.drop_primary_key_generator */
extern void T48f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_table */
extern void T47f357(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_table */
extern void T47f357p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_primary_key_generator */
extern void T47f363(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_sp */
extern void T47f362(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.do_drop_procedure */
extern void T47f366(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_table */
extern void T46f356(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_table */
extern void T46f356p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_primary_key_generator */
extern void T46f362(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_sp */
extern void T46f361(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.do_drop_procedure */
extern void T46f365(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.drop_table */
extern void T45f304(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.drop_primary_key_generator */
extern void T45f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_table */
extern void T44f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_table */
extern void T44f355p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_primary_key_generator */
extern void T44f361(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_sp */
extern void T44f360(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.do_drop_procedure */
extern void T44f364(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.drop_table */
extern void T43f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.drop_primary_key_generator */
extern void T43f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.drop_table */
extern void T42f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.drop_primary_key_generator */
extern void T42f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.drop_table */
extern void T41f305(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.drop_primary_key_generator */
extern void T41f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_drop_column */
extern void T64f346(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.create_drop_column */
extern void T64f350(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.drop_column */
extern void T64f351(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.dropcolumnsupported */
extern T1 T64f243(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.write_drop_column */
extern void T63f344(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.create_drop_column */
extern void T63f348(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.drop_column */
extern void T63f349(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.dropcolumnsupported */
extern T1 T63f242(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.write_drop_column */
extern void T62f344(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.create_drop_column */
extern void T62f348(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.drop_column */
extern void T62f349(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.dropcolumnsupported */
extern T1 T62f242(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.write_drop_column */
extern void T61f341(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.create_drop_column */
extern void T61f347(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.drop_column */
extern void T61f348(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.dropcolumnsupported */
extern T1 T61f242(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.write_drop_column */
extern void T60f319(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.create_drop_column */
extern void T60f323(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.drop_column */
extern void T60f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.dropcolumnsupported */
extern T1 T60f80(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.write_drop_column */
extern void T59f365(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.create_drop_column */
extern void T59f371(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.drop_column */
extern void T59f372(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.dropcolumnsupported */
extern T1 T59f265(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.write_drop_column */
extern void T58f369(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.create_drop_column */
extern void T58f375(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.drop_column */
extern void T58f376(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.dropcolumnsupported */
extern T1 T58f267(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.write_drop_column */
extern void T57f370(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.create_drop_column */
extern void T57f376(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.drop_column */
extern void T57f377(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.dropcolumnsupported */
extern T1 T57f268(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.write_drop_column */
extern void T56f370(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.create_drop_column */
extern void T56f376(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.drop_column */
extern void T56f377(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.dropcolumnsupported */
extern T1 T56f268(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.write_drop_column */
extern void T55f370(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.create_drop_column */
extern void T55f376(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.drop_column */
extern void T55f377(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.dropcolumnsupported */
extern T1 T55f268(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.write_drop_column */
extern void T54f360(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.create_drop_column */
extern void T54f366(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.drop_column */
extern void T54f367(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.dropcolumnsupported */
extern T1 T54f263(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.write_drop_column */
extern void T53f306(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.create_drop_column */
extern void T53f310(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.drop_column */
extern void T53f292(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.dropcolumnsupported */
extern T1 T53f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.write_drop_column */
extern void T52f306(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.create_drop_column */
extern void T52f310(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.drop_column */
extern void T52f292(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.dropcolumnsupported */
extern T1 T52f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.write_drop_column */
extern void T51f349(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.create_drop_column */
extern void T51f355(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.drop_column */
extern void T51f356(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.dropcolumnsupported */
extern T1 T51f253(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.write_drop_column */
extern void T50f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.create_drop_column */
extern void T50f309(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.drop_column */
extern void T50f291(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.dropcolumnsupported */
extern T1 T50f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.write_drop_column */
extern void T49f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.create_drop_column */
extern void T49f309(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.drop_column */
extern void T49f291(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.dropcolumnsupported */
extern T1 T49f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.write_drop_column */
extern void T48f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.create_drop_column */
extern void T48f309(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.drop_column */
extern void T48f291(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.dropcolumnsupported */
extern T1 T48f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.write_drop_column */
extern void T47f358(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.create_drop_column */
extern void T47f364(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.drop_column */
extern void T47f365(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.write_drop_column */
extern void T46f357(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.create_drop_column */
extern void T46f363(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.drop_column */
extern void T46f364(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.write_drop_column */
extern void T45f305(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.create_drop_column */
extern void T45f309(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.drop_column */
extern void T45f291(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.dropcolumnsupported */
extern T1 T45f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.write_drop_column */
extern void T44f356(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.create_drop_column */
extern void T44f362(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.drop_column */
extern void T44f363(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.dropcolumnsupported */
extern T1 T44f259(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.write_drop_column */
extern void T43f307(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.create_drop_column */
extern void T43f311(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.drop_column */
extern void T43f293(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.dropcolumnsupported */
extern T1 T43f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.write_drop_column */
extern void T42f306(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.create_drop_column */
extern void T42f310(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.drop_column */
extern void T42f292(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.dropcolumnsupported */
extern T1 T42f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.write_drop_column */
extern void T41f306(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.create_drop_column */
extern void T41f310(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.drop_column */
extern void T41f292(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.dropcolumnsupported */
extern T1 T41f79(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.drop_constant */
extern void T64f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_constant */
extern void T64f347p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_constant */
extern void T63f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_constant */
extern void T63f345p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_constant */
extern void T62f345(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_constant */
extern void T62f345p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_constant */
extern void T61f342(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_constant */
extern void T61f342p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.drop_constant */
extern void T60f320(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_constant */
extern void T59f366(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_constant */
extern void T58f370(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_constant */
extern void T57f371(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_constant */
extern void T56f371(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_constant */
extern void T55f371(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_constant */
extern void T54f361(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.drop_constant */
extern void T53f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.drop_constant */
extern void T52f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_constant */
extern void T51f350(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.drop_constant */
extern void T50f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.drop_constant */
extern void T49f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.drop_constant */
extern void T48f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_constant */
extern void T47f359(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_constant */
extern void T46f358(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.drop_constant */
extern void T45f306(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_constant */
extern void T44f357(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.drop_constant */
extern void T43f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.drop_constant */
extern void T42f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.drop_constant */
extern void T41f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_value */
extern void T64f348(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].remove */
extern void T114f36(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].remove_position */
extern void T114f42(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].key_storage_keep_head */
extern void T114f52(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].item_storage_keep_head */
extern void T114f51(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_VALUE].keep_head */
extern void T382f6(GE_context* ac, T0* C, T6 a1);
/* SPECIAL [XPLAIN_VALUE].set_count */
extern void T382f9(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].move_cursors_forth */
extern void T114f50(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE_CURSOR [XPLAIN_VALUE, STRING_8].set_position */
extern void T383f9(GE_context* ac, T0* C, T6 a1);
/* DS_HASH_TABLE_CURSOR [XPLAIN_VALUE, STRING_8].set_next_cursor */
extern void T383f8(GE_context* ac, T0* C, T0* a1);
/* DS_HASH_TABLE_CURSOR [XPLAIN_VALUE, STRING_8].set_after */
extern void T383f7(GE_context* ac, T0* C);
/* DS_HASH_TABLE [XPLAIN_VALUE, STRING_8].internal_set_key_equality_tester */
extern void T114f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_value */
extern void T63f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_value */
extern void T62f346(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_value */
extern void T61f343(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.drop_value */
extern void T60f302(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_value */
extern void T59f367(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_value */
extern void T59f367p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_value */
extern void T58f371(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_value */
extern void T58f371p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_value */
extern void T57f372(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_value */
extern void T57f372p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_value */
extern void T56f372(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_value */
extern void T56f372p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_value */
extern void T55f372(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_value */
extern void T55f372p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_value */
extern void T54f362(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_value */
extern void T54f362p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.drop_value */
extern void T53f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.drop_value */
extern void T52f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_value */
extern void T51f351(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_value */
extern void T51f351p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.valuetablename */
extern T0* T51f252(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createtemporaryvaluetable */
extern T1 T51f254(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.drop_value */
extern void T50f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.drop_value */
extern void T49f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.drop_value */
extern void T48f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_value */
extern void T47f360(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_value */
extern void T47f360p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_value */
extern void T46f359(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_value */
extern void T46f359p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.drop_value */
extern void T45f288(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_value */
extern void T44f358(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_value */
extern void T44f358p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.drop_value */
extern void T43f290(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.drop_value */
extern void T42f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.drop_value */
extern void T41f289(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_procedure */
extern void T64f349(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_procedure */
extern void T63f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_procedure */
extern void T62f347(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_procedure */
extern void T61f344(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.drop_procedure */
extern void T60f321(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.drop_procedure */
extern void T59f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.drop_procedure */
extern void T58f372(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.drop_procedure */
extern void T57f373(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.drop_procedure */
extern void T56f373(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.drop_procedure */
extern void T55f373(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.drop_procedure */
extern void T54f363(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.do_drop_function */
extern void T54f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.drop_procedure */
extern void T53f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.drop_procedure */
extern void T52f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.drop_procedure */
extern void T51f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.drop_procedure */
extern void T50f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.drop_procedure */
extern void T49f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.drop_procedure */
extern void T48f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.drop_procedure */
extern void T47f361(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.drop_procedure */
extern void T46f360(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.drop_procedure */
extern void T45f307(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.drop_procedure */
extern void T44f359(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.drop_procedure */
extern void T43f309(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.drop_procedure */
extern void T42f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.drop_procedure */
extern void T41f308(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_drop_assertion */
extern void T64f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_drop_assertion */
extern void T64f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_drop_assertion */
extern void T63f350(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_drop_assertion */
extern void T63f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_drop_assertion */
extern void T62f350(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_drop_assertion */
extern void T62f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_drop_assertion */
extern void T61f350(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_drop_assertion */
extern void T61f352(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_drop_assertion */
extern void T60f324(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_drop_assertion */
extern void T60f326(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_drop_assertion */
extern void T59f374(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_drop_assertion */
extern void T59f376(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_drop_assertion */
extern void T58f378(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_drop_assertion */
extern void T58f380(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_drop_assertion */
extern void T57f379(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_drop_assertion */
extern void T57f381(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_drop_assertion */
extern void T56f379(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_drop_assertion */
extern void T56f381(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_drop_assertion */
extern void T55f379(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_drop_assertion */
extern void T55f381(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_drop_assertion */
extern void T54f370(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_drop_assertion */
extern void T54f372(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_drop_assertion */
extern void T53f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_drop_assertion */
extern void T53f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_drop_assertion */
extern void T52f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_drop_assertion */
extern void T52f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_drop_assertion */
extern void T51f358(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_drop_assertion */
extern void T51f360(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_drop_assertion */
extern void T50f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_drop_assertion */
extern void T50f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_drop_assertion */
extern void T49f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_drop_assertion */
extern void T49f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_drop_assertion */
extern void T48f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_drop_assertion */
extern void T48f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_drop_assertion */
extern void T47f367(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_drop_assertion */
extern void T47f369(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_drop_assertion */
extern void T46f366(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_drop_assertion */
extern void T46f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_drop_assertion */
extern void T45f310(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_drop_assertion */
extern void T45f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_drop_assertion */
extern void T44f365(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_drop_assertion */
extern void T44f367(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_drop_assertion */
extern void T43f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_drop_assertion */
extern void T43f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_drop_assertion */
extern void T42f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_drop_assertion */
extern void T42f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_drop_assertion */
extern void T41f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_drop_assertion */
extern void T41f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.write_drop_extension */
extern void T64f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.create_drop_extension */
extern void T64f355(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.drop_temporary_table_if_exist */
extern void T64f356(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.write_drop_extension */
extern void T63f351(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.create_drop_extension */
extern void T63f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.drop_temporary_table_if_exist */
extern void T63f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.write_drop_extension */
extern void T62f351(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.create_drop_extension */
extern void T62f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.drop_temporary_table_if_exist */
extern void T62f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.write_drop_extension */
extern void T61f351(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.create_drop_extension */
extern void T61f353(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.drop_temporary_table_if_exist */
extern void T61f354(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.write_drop_extension */
extern void T60f325(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.create_drop_extension */
extern void T60f327(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.write_drop_extension */
extern void T59f375(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.create_drop_extension */
extern void T59f377(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.write_drop_extension */
extern void T58f379(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.create_drop_extension */
extern void T58f381(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.write_drop_extension */
extern void T57f380(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.create_drop_extension */
extern void T57f382(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.write_drop_extension */
extern void T56f380(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.create_drop_extension */
extern void T56f382(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.write_drop_extension */
extern void T55f380(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.create_drop_extension */
extern void T55f382(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.write_drop_extension */
extern void T54f371(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.create_drop_extension */
extern void T54f373(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.write_drop_extension */
extern void T53f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.create_drop_extension */
extern void T53f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.write_drop_extension */
extern void T52f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.create_drop_extension */
extern void T52f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.write_drop_extension */
extern void T51f359(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.create_drop_extension */
extern void T51f361(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.write_drop_extension */
extern void T50f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.create_drop_extension */
extern void T50f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.write_drop_extension */
extern void T49f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.create_drop_extension */
extern void T49f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.write_drop_extension */
extern void T48f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.create_drop_extension */
extern void T48f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.write_drop_extension */
extern void T47f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.create_drop_extension */
extern void T47f370(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.write_drop_extension */
extern void T46f367(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.create_drop_extension */
extern void T46f369(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.write_drop_extension */
extern void T45f311(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.create_drop_extension */
extern void T45f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.write_drop_extension */
extern void T44f366(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.create_drop_extension */
extern void T44f368(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.write_drop_extension */
extern void T43f313(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.create_drop_extension */
extern void T43f315(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.write_drop_extension */
extern void T42f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.create_drop_extension */
extern void T42f314(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.write_drop_extension */
extern void T41f312(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.create_drop_extension */
extern void T41f314(GE_context* ac, T0* C, T0* a1);
/* SERIALIZATION_FAILURE.set_throwing_exception */
extern void T102f7(GE_context* ac, T0* C, T0* a1);
/* ADDRESS_APPLIED_TO_MELTED_FEATURE.set_throwing_exception */
extern void T101f7(GE_context* ac, T0* C, T0* a1);
/* DEVELOPER_EXCEPTION.set_throwing_exception */
extern void T100f11(GE_context* ac, T0* C, T0* a1);
/* MISMATCH_FAILURE.set_throwing_exception */
extern void T99f7(GE_context* ac, T0* C, T0* a1);
/* EXCEPTION_IN_SIGNAL_HANDLER_FAILURE.set_throwing_exception */
extern void T98f7(GE_context* ac, T0* C, T0* a1);
/* VOID_ASSIGNED_TO_EXPANDED.set_throwing_exception */
extern void T97f7(GE_context* ac, T0* C, T0* a1);
/* EXTERNAL_FAILURE.set_throwing_exception */
extern void T96f7(GE_context* ac, T0* C, T0* a1);
/* CREATE_ON_DEFERRED.set_throwing_exception */
extern void T95f7(GE_context* ac, T0* C, T0* a1);
/* RESUMPTION_FAILURE.set_throwing_exception */
extern void T94f7(GE_context* ac, T0* C, T0* a1);
/* RESCUE_FAILURE.set_throwing_exception */
extern void T93f7(GE_context* ac, T0* C, T0* a1);
/* LOOP_INVARIANT_VIOLATION.set_throwing_exception */
extern void T92f7(GE_context* ac, T0* C, T0* a1);
/* VARIANT_VIOLATION.set_throwing_exception */
extern void T91f7(GE_context* ac, T0* C, T0* a1);
/* BAD_INSPECT_VALUE.set_throwing_exception */
extern void T90f7(GE_context* ac, T0* C, T0* a1);
/* CHECK_VIOLATION.set_throwing_exception */
extern void T89f7(GE_context* ac, T0* C, T0* a1);
/* FLOATING_POINT_FAILURE.set_throwing_exception */
extern void T88f7(GE_context* ac, T0* C, T0* a1);
/* POSTCONDITION_VIOLATION.set_throwing_exception */
extern void T87f7(GE_context* ac, T0* C, T0* a1);
/* PRECONDITION_VIOLATION.set_throwing_exception */
extern void T86f7(GE_context* ac, T0* C, T0* a1);
/* EIFFEL_RUNTIME_PANIC.set_throwing_exception */
extern void T84f10(GE_context* ac, T0* C, T0* a1);
/* COM_FAILURE.set_throwing_exception */
extern void T83f13(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_FAILURE.set_throwing_exception */
extern void T82f8(GE_context* ac, T0* C, T0* a1);
/* IO_FAILURE.set_throwing_exception */
extern void T81f10(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_SIGNAL_FAILURE.set_throwing_exception */
extern void T80f8(GE_context* ac, T0* C, T0* a1);
/* INVARIANT_VIOLATION.set_throwing_exception */
extern void T79f8(GE_context* ac, T0* C, T0* a1);
/* NO_MORE_MEMORY.set_throwing_exception */
extern void T78f11(GE_context* ac, T0* C, T0* a1);
/* OLD_VIOLATION.set_throwing_exception */
extern void T76f7(GE_context* ac, T0* C, T0* a1);
/* ROUTINE_FAILURE.set_throwing_exception */
extern void T74f11(GE_context* ac, T0* C, T0* a1);
/* VOID_TARGET.set_throwing_exception */
extern void T72f7(GE_context* ac, T0* C, T0* a1);
/* SERIALIZATION_FAILURE.set_exception_trace */
extern void T102f8(GE_context* ac, T0* C, T0* a1);
/* ADDRESS_APPLIED_TO_MELTED_FEATURE.set_exception_trace */
extern void T101f8(GE_context* ac, T0* C, T0* a1);
/* DEVELOPER_EXCEPTION.set_exception_trace */
extern void T100f12(GE_context* ac, T0* C, T0* a1);
/* MISMATCH_FAILURE.set_exception_trace */
extern void T99f8(GE_context* ac, T0* C, T0* a1);
/* EXCEPTION_IN_SIGNAL_HANDLER_FAILURE.set_exception_trace */
extern void T98f8(GE_context* ac, T0* C, T0* a1);
/* VOID_ASSIGNED_TO_EXPANDED.set_exception_trace */
extern void T97f8(GE_context* ac, T0* C, T0* a1);
/* EXTERNAL_FAILURE.set_exception_trace */
extern void T96f8(GE_context* ac, T0* C, T0* a1);
/* CREATE_ON_DEFERRED.set_exception_trace */
extern void T95f8(GE_context* ac, T0* C, T0* a1);
/* RESUMPTION_FAILURE.set_exception_trace */
extern void T94f8(GE_context* ac, T0* C, T0* a1);
/* RESCUE_FAILURE.set_exception_trace */
extern void T93f8(GE_context* ac, T0* C, T0* a1);
/* LOOP_INVARIANT_VIOLATION.set_exception_trace */
extern void T92f8(GE_context* ac, T0* C, T0* a1);
/* VARIANT_VIOLATION.set_exception_trace */
extern void T91f8(GE_context* ac, T0* C, T0* a1);
/* BAD_INSPECT_VALUE.set_exception_trace */
extern void T90f8(GE_context* ac, T0* C, T0* a1);
/* CHECK_VIOLATION.set_exception_trace */
extern void T89f8(GE_context* ac, T0* C, T0* a1);
/* FLOATING_POINT_FAILURE.set_exception_trace */
extern void T88f8(GE_context* ac, T0* C, T0* a1);
/* POSTCONDITION_VIOLATION.set_exception_trace */
extern void T87f8(GE_context* ac, T0* C, T0* a1);
/* PRECONDITION_VIOLATION.set_exception_trace */
extern void T86f8(GE_context* ac, T0* C, T0* a1);
/* EIFFEL_RUNTIME_PANIC.set_exception_trace */
extern void T84f11(GE_context* ac, T0* C, T0* a1);
/* COM_FAILURE.set_exception_trace */
extern void T83f16(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_FAILURE.set_exception_trace */
extern void T82f10(GE_context* ac, T0* C, T0* a1);
/* IO_FAILURE.set_exception_trace */
extern void T81f12(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_SIGNAL_FAILURE.set_exception_trace */
extern void T80f10(GE_context* ac, T0* C, T0* a1);
/* INVARIANT_VIOLATION.set_exception_trace */
extern void T79f10(GE_context* ac, T0* C, T0* a1);
/* NO_MORE_MEMORY.set_exception_trace */
extern void T78f9(GE_context* ac, T0* C, T0* a1);
/* OLD_VIOLATION.set_exception_trace */
extern void T76f8(GE_context* ac, T0* C, T0* a1);
/* ROUTINE_FAILURE.set_exception_trace */
extern void T74f12(GE_context* ac, T0* C, T0* a1);
/* VOID_TARGET.set_exception_trace */
extern void T72f8(GE_context* ac, T0* C, T0* a1);
/* SERIALIZATION_FAILURE.set_description */
extern void T102f9(GE_context* ac, T0* C, T0* a1);
/* UTF_CONVERTER.utf_32_string_into_utf_8_0_pointer */
extern void T349f7(GE_context* ac, T349* C, T0* a1, T0* a2, T6 a3, T0* a4);
/* CELL [INTEGER_32].put */
extern void T350f2(GE_context* ac, T0* C, T6 a1);
/* CELL [INTEGER_32].put */
extern T0* T350c2(GE_context* ac, T6 a1);
/* ADDRESS_APPLIED_TO_MELTED_FEATURE.set_description */
extern void T101f9(GE_context* ac, T0* C, T0* a1);
/* DEVELOPER_EXCEPTION.set_description */
extern void T100f13(GE_context* ac, T0* C, T0* a1);
/* MISMATCH_FAILURE.set_description */
extern void T99f9(GE_context* ac, T0* C, T0* a1);
/* EXCEPTION_IN_SIGNAL_HANDLER_FAILURE.set_description */
extern void T98f9(GE_context* ac, T0* C, T0* a1);
/* VOID_ASSIGNED_TO_EXPANDED.set_description */
extern void T97f9(GE_context* ac, T0* C, T0* a1);
/* EXTERNAL_FAILURE.set_description */
extern void T96f9(GE_context* ac, T0* C, T0* a1);
/* CREATE_ON_DEFERRED.set_description */
extern void T95f9(GE_context* ac, T0* C, T0* a1);
/* RESUMPTION_FAILURE.set_description */
extern void T94f9(GE_context* ac, T0* C, T0* a1);
/* RESCUE_FAILURE.set_description */
extern void T93f9(GE_context* ac, T0* C, T0* a1);
/* LOOP_INVARIANT_VIOLATION.set_description */
extern void T92f9(GE_context* ac, T0* C, T0* a1);
/* VARIANT_VIOLATION.set_description */
extern void T91f9(GE_context* ac, T0* C, T0* a1);
/* BAD_INSPECT_VALUE.set_description */
extern void T90f9(GE_context* ac, T0* C, T0* a1);
/* CHECK_VIOLATION.set_description */
extern void T89f9(GE_context* ac, T0* C, T0* a1);
/* FLOATING_POINT_FAILURE.set_description */
extern void T88f9(GE_context* ac, T0* C, T0* a1);
/* POSTCONDITION_VIOLATION.set_description */
extern void T87f9(GE_context* ac, T0* C, T0* a1);
/* PRECONDITION_VIOLATION.set_description */
extern void T86f9(GE_context* ac, T0* C, T0* a1);
/* EIFFEL_RUNTIME_PANIC.set_description */
extern void T84f12(GE_context* ac, T0* C, T0* a1);
/* COM_FAILURE.set_description */
extern void T83f17(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_FAILURE.set_description */
extern void T82f11(GE_context* ac, T0* C, T0* a1);
/* IO_FAILURE.set_description */
extern void T81f13(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_SIGNAL_FAILURE.set_description */
extern void T80f11(GE_context* ac, T0* C, T0* a1);
/* INVARIANT_VIOLATION.set_description */
extern void T79f11(GE_context* ac, T0* C, T0* a1);
/* NO_MORE_MEMORY.set_description */
extern void T78f12(GE_context* ac, T0* C, T0* a1);
/* OLD_VIOLATION.set_description */
extern void T76f9(GE_context* ac, T0* C, T0* a1);
/* ROUTINE_FAILURE.set_description */
extern void T74f13(GE_context* ac, T0* C, T0* a1);
/* VOID_TARGET.set_description */
extern void T72f9(GE_context* ac, T0* C, T0* a1);
/* SERIALIZATION_FAILURE.set_recipient_name */
extern void T102f10(GE_context* ac, T0* C, T0* a1);
/* ADDRESS_APPLIED_TO_MELTED_FEATURE.set_recipient_name */
extern void T101f10(GE_context* ac, T0* C, T0* a1);
/* DEVELOPER_EXCEPTION.set_recipient_name */
extern void T100f14(GE_context* ac, T0* C, T0* a1);
/* MISMATCH_FAILURE.set_recipient_name */
extern void T99f10(GE_context* ac, T0* C, T0* a1);
/* EXCEPTION_IN_SIGNAL_HANDLER_FAILURE.set_recipient_name */
extern void T98f10(GE_context* ac, T0* C, T0* a1);
/* VOID_ASSIGNED_TO_EXPANDED.set_recipient_name */
extern void T97f10(GE_context* ac, T0* C, T0* a1);
/* EXTERNAL_FAILURE.set_recipient_name */
extern void T96f10(GE_context* ac, T0* C, T0* a1);
/* CREATE_ON_DEFERRED.set_recipient_name */
extern void T95f10(GE_context* ac, T0* C, T0* a1);
/* RESUMPTION_FAILURE.set_recipient_name */
extern void T94f10(GE_context* ac, T0* C, T0* a1);
/* RESCUE_FAILURE.set_recipient_name */
extern void T93f10(GE_context* ac, T0* C, T0* a1);
/* LOOP_INVARIANT_VIOLATION.set_recipient_name */
extern void T92f10(GE_context* ac, T0* C, T0* a1);
/* VARIANT_VIOLATION.set_recipient_name */
extern void T91f10(GE_context* ac, T0* C, T0* a1);
/* BAD_INSPECT_VALUE.set_recipient_name */
extern void T90f10(GE_context* ac, T0* C, T0* a1);
/* CHECK_VIOLATION.set_recipient_name */
extern void T89f10(GE_context* ac, T0* C, T0* a1);
/* FLOATING_POINT_FAILURE.set_recipient_name */
extern void T88f10(GE_context* ac, T0* C, T0* a1);
/* POSTCONDITION_VIOLATION.set_recipient_name */
extern void T87f10(GE_context* ac, T0* C, T0* a1);
/* PRECONDITION_VIOLATION.set_recipient_name */
extern void T86f10(GE_context* ac, T0* C, T0* a1);
/* EIFFEL_RUNTIME_PANIC.set_recipient_name */
extern void T84f13(GE_context* ac, T0* C, T0* a1);
/* COM_FAILURE.set_recipient_name */
extern void T83f18(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_FAILURE.set_recipient_name */
extern void T82f12(GE_context* ac, T0* C, T0* a1);
/* IO_FAILURE.set_recipient_name */
extern void T81f14(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_SIGNAL_FAILURE.set_recipient_name */
extern void T80f12(GE_context* ac, T0* C, T0* a1);
/* INVARIANT_VIOLATION.set_recipient_name */
extern void T79f12(GE_context* ac, T0* C, T0* a1);
/* NO_MORE_MEMORY.set_recipient_name */
extern void T78f13(GE_context* ac, T0* C, T0* a1);
/* OLD_VIOLATION.set_recipient_name */
extern void T76f10(GE_context* ac, T0* C, T0* a1);
/* ROUTINE_FAILURE.set_recipient_name */
extern void T74f14(GE_context* ac, T0* C, T0* a1);
/* VOID_TARGET.set_recipient_name */
extern void T72f10(GE_context* ac, T0* C, T0* a1);
/* SERIALIZATION_FAILURE.set_type_name */
extern void T102f11(GE_context* ac, T0* C, T0* a1);
/* ADDRESS_APPLIED_TO_MELTED_FEATURE.set_type_name */
extern void T101f11(GE_context* ac, T0* C, T0* a1);
/* DEVELOPER_EXCEPTION.set_type_name */
extern void T100f15(GE_context* ac, T0* C, T0* a1);
/* MISMATCH_FAILURE.set_type_name */
extern void T99f11(GE_context* ac, T0* C, T0* a1);
/* EXCEPTION_IN_SIGNAL_HANDLER_FAILURE.set_type_name */
extern void T98f11(GE_context* ac, T0* C, T0* a1);
/* VOID_ASSIGNED_TO_EXPANDED.set_type_name */
extern void T97f11(GE_context* ac, T0* C, T0* a1);
/* EXTERNAL_FAILURE.set_type_name */
extern void T96f11(GE_context* ac, T0* C, T0* a1);
/* CREATE_ON_DEFERRED.set_type_name */
extern void T95f11(GE_context* ac, T0* C, T0* a1);
/* RESUMPTION_FAILURE.set_type_name */
extern void T94f11(GE_context* ac, T0* C, T0* a1);
/* RESCUE_FAILURE.set_type_name */
extern void T93f11(GE_context* ac, T0* C, T0* a1);
/* LOOP_INVARIANT_VIOLATION.set_type_name */
extern void T92f11(GE_context* ac, T0* C, T0* a1);
/* VARIANT_VIOLATION.set_type_name */
extern void T91f11(GE_context* ac, T0* C, T0* a1);
/* BAD_INSPECT_VALUE.set_type_name */
extern void T90f11(GE_context* ac, T0* C, T0* a1);
/* CHECK_VIOLATION.set_type_name */
extern void T89f11(GE_context* ac, T0* C, T0* a1);
/* FLOATING_POINT_FAILURE.set_type_name */
extern void T88f11(GE_context* ac, T0* C, T0* a1);
/* POSTCONDITION_VIOLATION.set_type_name */
extern void T87f11(GE_context* ac, T0* C, T0* a1);
/* PRECONDITION_VIOLATION.set_type_name */
extern void T86f11(GE_context* ac, T0* C, T0* a1);
/* EIFFEL_RUNTIME_PANIC.set_type_name */
extern void T84f14(GE_context* ac, T0* C, T0* a1);
/* COM_FAILURE.set_type_name */
extern void T83f19(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_FAILURE.set_type_name */
extern void T82f13(GE_context* ac, T0* C, T0* a1);
/* IO_FAILURE.set_type_name */
extern void T81f15(GE_context* ac, T0* C, T0* a1);
/* OPERATING_SYSTEM_SIGNAL_FAILURE.set_type_name */
extern void T80f13(GE_context* ac, T0* C, T0* a1);
/* INVARIANT_VIOLATION.set_type_name */
extern void T79f13(GE_context* ac, T0* C, T0* a1);
/* NO_MORE_MEMORY.set_type_name */
extern void T78f14(GE_context* ac, T0* C, T0* a1);
/* OLD_VIOLATION.set_type_name */
extern void T76f11(GE_context* ac, T0* C, T0* a1);
/* ROUTINE_FAILURE.set_type_name */
extern void T74f15(GE_context* ac, T0* C, T0* a1);
/* VOID_TARGET.set_type_name */
extern void T72f11(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlinitvalue_if */
extern T0* T60f224(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlinitvalue_if */
extern T0* T59f247(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlinitvalue_if */
extern T0* T58f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlinitvalue_if */
extern T0* T57f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlinitvalue_if */
extern T0* T56f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlinitvalue_if */
extern T0* T55f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlinitvalue_if */
extern T0* T54f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlinitvalue_if */
extern T0* T51f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlinitvalue_if */
extern T0* T47f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlinitvalue_if */
extern T0* T46f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlinitvalue_if */
extern T0* T44f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_init_combine_expression */
extern T0* T60f225(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_string_combine_end */
extern T0* T60f146(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sql_string_combine_start */
extern T0* T60f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sql_init_combine_expression */
extern T0* T59f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_string_combine_end */
extern T0* T59f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sql_string_combine_start */
extern T0* T59f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sql_init_combine_expression */
extern T0* T58f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_string_combine_end */
extern T0* T58f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sql_string_combine_start */
extern T0* T58f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sql_init_combine_expression */
extern T0* T57f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_string_combine_end */
extern T0* T57f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sql_string_combine_start */
extern T0* T57f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sql_init_combine_expression */
extern T0* T56f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_string_combine_end */
extern T0* T56f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sql_string_combine_start */
extern T0* T56f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sql_init_combine_expression */
extern T0* T55f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_string_combine_end */
extern T0* T55f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sql_string_combine_start */
extern T0* T55f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sql_init_combine_expression */
extern T0* T54f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_string_combine_end */
extern T0* T54f172(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sql_string_combine_start */
extern T0* T54f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sql_init_combine_expression */
extern T0* T51f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_init_combine_expression */
extern T0* T47f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_string_combine_end */
extern T0* T47f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sql_string_combine_start */
extern T0* T47f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sql_init_combine_expression */
extern T0* T46f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_string_combine_end */
extern T0* T46f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sql_string_combine_start */
extern T0* T46f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sql_init_combine_expression */
extern T0* T44f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_string_combine_end */
extern T0* T44f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sql_string_combine_start */
extern T0* T44f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sql_init_cast_to_date */
extern T0* T60f226(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.do_sql_cast_to_date */
extern T0* T60f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_init_cast_to_date */
extern T0* T59f249(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.do_sql_cast_to_date */
extern T0* T59f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_init_cast_to_date */
extern T0* T58f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.do_sql_cast_to_date */
extern T0* T58f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_init_cast_to_date */
extern T0* T57f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.do_sql_cast_to_date */
extern T0* T57f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_init_cast_to_date */
extern T0* T56f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.do_sql_cast_to_date */
extern T0* T56f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_init_cast_to_date */
extern T0* T55f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.do_sql_cast_to_date */
extern T0* T55f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_init_cast_to_date */
extern T0* T54f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.do_sql_cast_to_date */
extern T0* T54f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_init_cast_to_date */
extern T0* T51f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.do_sql_cast_to_date */
extern T0* T51f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_init_cast_to_date */
extern T0* T47f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.do_sql_cast_to_date */
extern T0* T47f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_init_cast_to_date */
extern T0* T46f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.do_sql_cast_to_date */
extern T0* T46f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_init_cast_to_date */
extern T0* T44f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.do_sql_cast_to_date */
extern T0* T44f171(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_init_cast_to_integer */
extern T0* T60f227(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.do_sql_cast_to_integer */
extern T0* T60f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_init_cast_to_integer */
extern T0* T59f250(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.do_sql_cast_to_integer */
extern T0* T59f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_init_cast_to_integer */
extern T0* T58f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.do_sql_cast_to_integer */
extern T0* T58f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_init_cast_to_integer */
extern T0* T57f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.do_sql_cast_to_integer */
extern T0* T57f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_init_cast_to_integer */
extern T0* T56f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.do_sql_cast_to_integer */
extern T0* T56f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_init_cast_to_integer */
extern T0* T55f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.do_sql_cast_to_integer */
extern T0* T55f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_init_cast_to_integer */
extern T0* T54f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.do_sql_cast_to_integer */
extern T0* T54f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_init_cast_to_integer */
extern T0* T51f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.do_sql_cast_to_integer */
extern T0* T51f166(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_init_cast_to_integer */
extern T0* T47f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.do_sql_cast_to_integer */
extern T0* T47f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_init_cast_to_integer */
extern T0* T46f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.do_sql_cast_to_integer */
extern T0* T46f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_init_cast_to_integer */
extern T0* T44f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.do_sql_cast_to_integer */
extern T0* T44f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_init_cast_to_real */
extern T0* T60f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.do_sql_cast_to_real */
extern T0* T60f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_init_cast_to_real */
extern T0* T59f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.do_sql_cast_to_real */
extern T0* T59f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_init_cast_to_real */
extern T0* T58f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.do_sql_cast_to_real */
extern T0* T58f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_init_cast_to_real */
extern T0* T57f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.do_sql_cast_to_real */
extern T0* T57f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_init_cast_to_real */
extern T0* T56f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.do_sql_cast_to_real */
extern T0* T56f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_init_cast_to_real */
extern T0* T55f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.do_sql_cast_to_real */
extern T0* T55f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_init_cast_to_real */
extern T0* T54f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.do_sql_cast_to_real */
extern T0* T54f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_init_cast_to_real */
extern T0* T51f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.do_sql_cast_to_real */
extern T0* T51f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_init_cast_to_real */
extern T0* T47f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.do_sql_cast_to_real */
extern T0* T47f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_init_cast_to_real */
extern T0* T46f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.do_sql_cast_to_real */
extern T0* T46f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_init_cast_to_real */
extern T0* T44f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.do_sql_cast_to_real */
extern T0* T44f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_init_cast_to_string */
extern T0* T60f229(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.do_sql_cast_to_string */
extern T0* T60f150(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_init_cast_to_string */
extern T0* T59f252(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.do_sql_cast_to_string */
extern T0* T59f184(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_init_cast_to_string */
extern T0* T58f253(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.do_sql_cast_to_string */
extern T0* T58f184(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_init_cast_to_string */
extern T0* T57f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.do_sql_cast_to_string */
extern T0* T57f184(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_init_cast_to_string */
extern T0* T56f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.do_sql_cast_to_string */
extern T0* T56f184(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_init_cast_to_string */
extern T0* T55f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.do_sql_cast_to_string */
extern T0* T55f184(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_init_cast_to_string */
extern T0* T54f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.do_sql_cast_to_string */
extern T0* T54f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_init_cast_to_string */
extern T0* T51f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.do_sql_cast_to_string */
extern T0* T51f168(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_init_cast_to_string */
extern T0* T47f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.do_sql_cast_to_string */
extern T0* T47f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_init_cast_to_string */
extern T0* T46f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.do_sql_cast_to_string */
extern T0* T46f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_init_cast_to_string */
extern T0* T44f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.do_sql_cast_to_string */
extern T0* T44f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_init_infix_expression */
extern T0* T60f223(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.sql_init_infix_expression */
extern T0* T59f246(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.sql_init_infix_expression */
extern T0* T58f247(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_81.sql_init_infix_expression */
extern T0* T57f248(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_82.sql_init_infix_expression */
extern T0* T56f248(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_95.sql_init_infix_expression */
extern T0* T55f248(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ORACLE.sql_init_infix_expression */
extern T0* T54f240(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.sql_init_infix_expression */
extern T0* T51f233(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.sql_init_infix_expression */
extern T0* T47f240(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.sql_init_infix_expression */
extern T0* T46f240(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.sql_init_infix_expression */
extern T0* T44f240(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_SQLITE_3.sqlinitvalue_attribute */
extern T0* T60f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.new_row_prefix */
extern T0* T60f237(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlinitvalue_attribute */
extern T0* T59f254(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.new_row_prefix */
extern T0* T59f260(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlinitvalue_attribute */
extern T0* T58f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.new_row_prefix */
extern T0* T58f262(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlinitvalue_attribute */
extern T0* T57f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.new_row_prefix */
extern T0* T57f263(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlinitvalue_attribute */
extern T0* T56f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.new_row_prefix */
extern T0* T56f263(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlinitvalue_attribute */
extern T0* T55f256(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.new_row_prefix */
extern T0* T55f263(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlinitvalue_attribute */
extern T0* T54f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlinitvalue_attribute */
extern T0* T51f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.new_row_prefix */
extern T0* T51f247(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlinitvalue_attribute */
extern T0* T47f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlinitvalue_attribute */
extern T0* T46f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlinitvalue_attribute */
extern T0* T44f248(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.new_row_prefix */
extern T0* T44f254(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_function_type_for_selection */
extern T0* T58f145(GE_context* ac, T0* C, T0* a1, T1 a2);
/* XPLAIN_SELECTION_LIST.sp_function_type */
extern T0* T161f8(GE_context* ac, T0* C, T0* a1, T1 a2);
/* XPLAIN_SELECTION_FUNCTION.sp_function_type */
extern T0* T154f8(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_81.sp_function_type_for_selection */
extern T0* T57f146(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_82.sp_function_type_for_selection */
extern T0* T56f146(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_95.sp_function_type_for_selection */
extern T0* T55f146(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_72.storedproceduresupportstruefunction */
extern T1 T59f145(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.storedproceduresupportstruefunction */
extern T1 T58f147(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.storedproceduresupportstruefunction */
extern T1 T57f148(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.storedproceduresupportstruefunction */
extern T1 T56f148(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.storedproceduresupportstruefunction */
extern T1 T54f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.storedproceduresupportstruefunction */
extern T1 T47f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.storedproceduresupportstruefunction */
extern T1 T46f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.storedproceduresupportstruefunction */
extern T1 T44f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sp_function_type_for_selection_list */
extern T0* T58f246(GE_context* ac, T0* C, T0* a1, T1 a2);
/* XPLAIN_EXPRESSION_NODE.column_name */
extern T0* T164f5(GE_context* ac, T0* C);
/* XPLAIN_EXPRESSION_NODE.path_name */
extern T0* T164f4(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.path_identifier */
extern T0* T58f261(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_function_type_for_selection_list */
extern T0* T57f247(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_81.path_identifier */
extern T0* T57f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_function_type_for_selection_list */
extern T0* T56f247(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_82.path_identifier */
extern T0* T56f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_function_type_for_selection_list */
extern T0* T55f247(GE_context* ac, T0* C, T0* a1, T1 a2);
/* SQL_GENERATOR_PGSQL_95.path_identifier */
extern T0* T55f262(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_function_type_for_selection_value */
extern T0* T58f146(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_PGSQL_81.sp_function_type_for_selection_value */
extern T0* T57f147(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_PGSQL_82.sp_function_type_for_selection_value */
extern T0* T56f147(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* SQL_GENERATOR_PGSQL_95.sp_function_type_for_selection_value */
extern T0* T55f147(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* ST_STRING_FORMATTER.valid_parameter */
extern T1 T368f8(GE_context* ac, T0* C, T0* a1);
extern T1 T368f8ot1(T0* a1);
/* ST_POINTER_FORMATTER.valid_parameter */
extern T1 T367f8(GE_context* ac, T0* C, T0* a1);
/* ST_UNSIGNED_DECIMAL_FORMATTER.valid_parameter */
extern T1 T366f9(GE_context* ac, T0* C, T0* a1);
extern T1 T366f9ot1(T0* a1, T0** a2);
/* ST_UNSIGNED_HEXADECIMAL_FORMATTER.valid_parameter */
extern T1 T365f9(GE_context* ac, T0* C, T0* a1);
extern T1 T365f9ot1(T0* a1, T0** a2);
/* ST_UNSIGNED_OCTAL_FORMATTER.valid_parameter */
extern T1 T364f9(GE_context* ac, T0* C, T0* a1);
extern T1 T364f9ot1(T0* a1, T0** a2);
/* ST_DECIMAL_FORMATTER.valid_parameter */
extern T1 T363f9(GE_context* ac, T0* C, T0* a1);
extern T1 T363f9ot1(T0* a1);
/* ST_FIXED_OR_FLOATING_POINT_FORMATTER.valid_parameter */
extern T1 T362f19(GE_context* ac, T0* C, T0* a1);
extern T1 T362f19ot1(T0* a1);
/* ST_FIXED_POINT_FORMATTER.valid_parameter */
extern T1 T361f19(GE_context* ac, T0* C, T0* a1);
extern T1 T361f19ot1(T0* a1);
/* ST_FLOATING_POINT_FORMATTER.valid_parameter */
extern T1 T360f17(GE_context* ac, T0* C, T0* a1);
extern T1 T360f17ot1(T0* a1);
/* ST_CHARACTER_FORMATTER.valid_parameter */
extern T1 T359f8(GE_context* ac, T0* C, T0* a1);
/* ST_BOOLEAN_FORMATTER.valid_parameter */
extern T1 T358f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].off */
extern T1 T408f7(GE_context* ac, T0* C);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.off */
extern T1 T387f9(GE_context* ac, T0* C);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].off */
extern T1 T386f10(GE_context* ac, T0* C);
/* DS_LINKED_LIST_CURSOR [XPLAIN_ATTRIBUTE].off */
extern T1 T338f7(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.datatype_boolean */
extern T0* T64f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_boolean */
extern T0* T63f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_boolean */
extern T0* T62f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_boolean */
extern T0* T61f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_boolean */
extern T0* T60f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_boolean */
extern T0* T59f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_boolean */
extern T0* T58f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_boolean */
extern T0* T57f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_boolean */
extern T0* T56f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_boolean */
extern T0* T55f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_boolean */
extern T0* T54f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_boolean */
extern T0* T53f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_boolean */
extern T0* T52f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_boolean */
extern T0* T51f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_boolean */
extern T0* T50f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_boolean */
extern T0* T49f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_boolean */
extern T0* T48f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_boolean */
extern T0* T47f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_boolean */
extern T0* T46f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_boolean */
extern T0* T45f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_boolean */
extern T0* T44f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_boolean */
extern T0* T43f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_boolean */
extern T0* T42f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_boolean */
extern T0* T41f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_char */
extern T0* T64f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_char */
extern T0* T63f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_char */
extern T0* T62f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_char */
extern T0* T61f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_char */
extern T0* T60f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_char */
extern T0* T59f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_char */
extern T0* T58f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_char */
extern T0* T57f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_char */
extern T0* T56f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_char */
extern T0* T55f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_char */
extern T0* T54f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_char */
extern T0* T53f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_char */
extern T0* T52f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_char */
extern T0* T51f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_char */
extern T0* T50f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_char */
extern T0* T49f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_char */
extern T0* T48f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_char */
extern T0* T47f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_char */
extern T0* T46f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_char */
extern T0* T45f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_char */
extern T0* T44f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_char */
extern T0* T43f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_char */
extern T0* T42f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_char */
extern T0* T41f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_datetime */
extern T0* T64f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_datetime */
extern T0* T63f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_datetime */
extern T0* T62f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_datetime */
extern T0* T61f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_datetime */
extern T0* T60f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_datetime */
extern T0* T59f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_datetime */
extern T0* T58f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_datetime */
extern T0* T57f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_datetime */
extern T0* T56f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_datetime */
extern T0* T55f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_datetime */
extern T0* T54f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_datetime */
extern T0* T53f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_datetime */
extern T0* T52f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_datetime */
extern T0* T51f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_datetime */
extern T0* T50f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_datetime */
extern T0* T49f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_datetime */
extern T0* T48f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_datetime */
extern T0* T47f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_datetime */
extern T0* T46f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_datetime */
extern T0* T45f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_datetime */
extern T0* T44f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_datetime */
extern T0* T43f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_datetime */
extern T0* T42f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_datetime */
extern T0* T41f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_int */
extern T0* T64f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.max_numeric_precision */
extern T6 T64f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.datatype_int */
extern T0* T63f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.max_numeric_precision */
extern T6 T63f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.datatype_int */
extern T0* T62f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.max_numeric_precision */
extern T6 T62f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.datatype_int */
extern T0* T61f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.max_numeric_precision */
extern T6 T61f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.datatype_int */
extern T0* T60f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_int */
extern T0* T59f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_int */
extern T0* T58f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_int */
extern T0* T57f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_int */
extern T0* T56f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_int */
extern T0* T55f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_int */
extern T0* T55f128p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_int */
extern T0* T54f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_int */
extern T0* T53f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.max_numeric_precision */
extern T6 T53f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.datatype_int */
extern T0* T52f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.max_numeric_precision */
extern T6 T52f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.datatype_int */
extern T0* T51f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.max_numeric_precision */
extern T6 T51f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.datatype_int */
extern T0* T50f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_int */
extern T0* T49f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_int */
extern T0* T48f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_int */
extern T0* T47f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.max_numeric_precision */
extern T6 T47f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.datatype_int */
extern T0* T46f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.max_numeric_precision */
extern T6 T46f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.datatype_int */
extern T0* T45f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_int */
extern T0* T44f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_int */
extern T0* T43f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_int */
extern T0* T42f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_int */
extern T0* T41f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_money */
extern T0* T64f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_money */
extern T0* T63f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_money */
extern T0* T62f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_money */
extern T0* T61f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_money */
extern T0* T60f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_money */
extern T0* T59f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_money */
extern T0* T58f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_money */
extern T0* T57f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_money */
extern T0* T56f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_money */
extern T0* T55f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_money */
extern T0* T54f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_money */
extern T0* T53f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_money */
extern T0* T52f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_money */
extern T0* T51f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_money */
extern T0* T50f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_money */
extern T0* T49f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_money */
extern T0* T48f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_money */
extern T0* T47f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_money */
extern T0* T46f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_money */
extern T0* T45f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_money */
extern T0* T44f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_money */
extern T0* T43f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_money */
extern T0* T42f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_money */
extern T0* T41f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_picture */
extern T0* T64f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_picture */
extern T0* T63f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_picture */
extern T0* T62f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_picture */
extern T0* T61f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_picture */
extern T0* T60f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_picture */
extern T0* T59f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_picture */
extern T0* T58f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_picture */
extern T0* T57f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_picture */
extern T0* T56f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_picture */
extern T0* T55f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_picture */
extern T0* T54f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_picture */
extern T0* T53f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_picture */
extern T0* T52f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_picture */
extern T0* T51f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_picture */
extern T0* T50f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_picture */
extern T0* T49f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_picture */
extern T0* T48f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_picture */
extern T0* T47f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_picture */
extern T0* T46f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_picture */
extern T0* T45f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_picture */
extern T0* T44f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_picture */
extern T0* T43f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_picture */
extern T0* T42f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_picture */
extern T0* T41f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_numeric */
extern T0* T64f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_numeric */
extern T0* T63f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_numeric */
extern T0* T62f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_numeric */
extern T0* T61f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_numeric */
extern T0* T60f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.max_numeric_precision */
extern T6 T60f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.datatype_numeric */
extern T0* T59f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.max_numeric_precision */
extern T6 T59f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.datatype_numeric */
extern T0* T58f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.max_numeric_precision */
extern T6 T58f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.datatype_numeric */
extern T0* T57f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.max_numeric_precision */
extern T6 T57f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.datatype_numeric */
extern T0* T56f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.max_numeric_precision */
extern T6 T56f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.datatype_numeric */
extern T0* T55f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.max_numeric_precision */
extern T6 T55f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.datatype_numeric */
extern T0* T54f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.max_numeric_precision */
extern T6 T54f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.datatype_numeric */
extern T0* T53f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_numeric */
extern T0* T52f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_numeric */
extern T0* T51f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_numeric */
extern T0* T50f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_numeric */
extern T0* T49f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_numeric */
extern T0* T48f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_numeric */
extern T0* T47f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_numeric */
extern T0* T46f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_numeric */
extern T0* T45f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_numeric */
extern T0* T44f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.max_numeric_precision */
extern T6 T44f176(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.datatype_numeric */
extern T0* T43f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.max_numeric_precision */
extern T6 T43f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.datatype_numeric */
extern T0* T42f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.max_numeric_precision */
extern T6 T42f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.datatype_numeric */
extern T0* T41f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.max_numeric_precision */
extern T6 T41f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.datatype_text */
extern T0* T64f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_text */
extern T0* T63f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_text */
extern T0* T62f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_text */
extern T0* T61f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_text */
extern T0* T60f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_text */
extern T0* T59f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_text */
extern T0* T58f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_text */
extern T0* T57f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_text */
extern T0* T56f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_text */
extern T0* T55f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_text */
extern T0* T54f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_text */
extern T0* T53f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_text */
extern T0* T52f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_text */
extern T0* T51f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_text */
extern T0* T50f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_text */
extern T0* T49f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_text */
extern T0* T48f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_text */
extern T0* T47f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_text */
extern T0* T46f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_text */
extern T0* T45f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_text */
extern T0* T44f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_text */
extern T0* T43f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_text */
extern T0* T42f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_text */
extern T0* T41f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_pk_int */
extern T0* T64f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.primarykeyconstraint */
extern T0* T64f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.autoprimarykeyconstraint */
extern T0* T64f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.datatype_pk_int */
extern T0* T63f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.primarykeyconstraint */
extern T0* T63f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.autoprimarykeyconstraint */
extern T0* T63f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.datatype_pk_int */
extern T0* T62f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.primarykeyconstraint */
extern T0* T62f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.autoprimarykeyconstraint */
extern T0* T62f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.datatype_pk_int */
extern T0* T61f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.primarykeyconstraint */
extern T0* T61f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.autoprimarykeyconstraint */
extern T0* T61f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.datatype_pk_int */
extern T0* T60f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.autoprimarykeyconstraint */
extern T0* T60f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.datatype_pk_int */
extern T0* T59f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_pk_int */
extern T0* T59f132p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.autoprimarykeyconstraint */
extern T0* T59f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.datatype_pk_int */
extern T0* T58f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_pk_int */
extern T0* T58f132p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.autoprimarykeyconstraint */
extern T0* T58f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.datatype_pk_int */
extern T0* T57f133(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_pk_int */
extern T0* T57f133p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.autoprimarykeyconstraint */
extern T0* T57f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.datatype_pk_int */
extern T0* T56f133(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_pk_int */
extern T0* T56f133p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.autoprimarykeyconstraint */
extern T0* T56f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.datatype_pk_int */
extern T0* T55f133(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_pk_int */
extern T0* T55f133p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.autoprimarykeyconstraint */
extern T0* T55f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.datatype_pk_int */
extern T0* T54f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.autoprimarykeyconstraint */
extern T0* T54f181(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.datatype_pk_int */
extern T0* T53f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.autoprimarykeyconstraint */
extern T0* T53f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.datatype_pk_int */
extern T0* T52f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.autoprimarykeyconstraint */
extern T0* T52f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.datatype_pk_int */
extern T0* T51f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.autoprimarykeyconstraint */
extern T0* T51f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.datatype_pk_int */
extern T0* T50f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.autoprimarykeyconstraint */
extern T0* T50f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.datatype_pk_int */
extern T0* T49f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_pk_int */
extern T0* T49f107p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.autoprimarykeyconstraint */
extern T0* T49f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.datatype_pk_int */
extern T0* T48f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_pk_int */
extern T0* T48f107p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.autoprimarykeyconstraint */
extern T0* T48f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.datatype_pk_int */
extern T0* T47f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.autoprimarykeyconstraint */
extern T0* T47f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.datatype_pk_int */
extern T0* T46f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.autoprimarykeyconstraint */
extern T0* T46f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.datatype_pk_int */
extern T0* T45f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.autoprimarykeyconstraint */
extern T0* T45f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.datatype_pk_int */
extern T0* T44f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.primarykeyconstraint */
extern T0* T44f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.autoprimarykeyconstraint */
extern T0* T44f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.datatype_pk_int */
extern T0* T43f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.autoprimarykeyconstraint */
extern T0* T43f152(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.datatype_pk_int */
extern T0* T42f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.autoprimarykeyconstraint */
extern T0* T42f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.datatype_pk_int */
extern T0* T41f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.autoprimarykeyconstraint */
extern T0* T41f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.datatype_ref_int */
extern T0* T64f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_ref_int */
extern T0* T63f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_ref_int */
extern T0* T62f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_ref_int */
extern T0* T61f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_ref_int */
extern T0* T60f205(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_ref_int */
extern T0* T59f133(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_ref_int */
extern T0* T58f133(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_ref_int */
extern T0* T57f134(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_ref_int */
extern T0* T56f134(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_ref_int */
extern T0* T55f134(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_ref_int */
extern T0* T54f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_ref_int */
extern T0* T53f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_ref_int */
extern T0* T52f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_ref_int */
extern T0* T51f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_ref_int */
extern T0* T50f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_ref_int */
extern T0* T49f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_ref_int */
extern T0* T49f202p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_ref_int */
extern T0* T48f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_ref_int */
extern T0* T48f202p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_ref_int */
extern T0* T47f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_ref_int */
extern T0* T46f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_ref_int */
extern T0* T45f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_ref_int */
extern T0* T44f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_ref_int */
extern T0* T43f204(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_ref_int */
extern T0* T42f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_ref_int */
extern T0* T41f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_pk_char */
extern T0* T64f206(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_pk_char */
extern T0* T63f205(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_pk_char */
extern T0* T62f205(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_pk_char */
extern T0* T61f205(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_pk_char */
extern T0* T60f185(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_pk_char */
extern T0* T59f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_pk_char */
extern T0* T58f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_pk_char */
extern T0* T57f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_pk_char */
extern T0* T56f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_pk_char */
extern T0* T55f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_pk_char */
extern T0* T54f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_pk_char */
extern T0* T53f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_pk_char */
extern T0* T52f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_pk_char */
extern T0* T51f205(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_pk_char */
extern T0* T50f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_pk_char */
extern T0* T49f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_pk_char */
extern T0* T48f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_pk_char */
extern T0* T47f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_pk_char */
extern T0* T46f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_pk_char */
extern T0* T45f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_pk_char */
extern T0* T44f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_pk_char */
extern T0* T43f184(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_pk_char */
extern T0* T42f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_pk_char */
extern T0* T41f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_varchar */
extern T0* T64f204(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_varchar */
extern T0* T63f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_varchar */
extern T0* T62f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_varchar */
extern T0* T61f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_varchar */
extern T0* T60f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_varchar */
extern T0* T59f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_varchar */
extern T0* T58f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_varchar */
extern T0* T57f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_varchar */
extern T0* T56f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_varchar */
extern T0* T55f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_varchar */
extern T0* T54f210(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_varchar */
extern T0* T53f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_varchar */
extern T0* T52f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_varchar */
extern T0* T51f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_varchar */
extern T0* T50f180(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_varchar */
extern T0* T49f180(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_varchar */
extern T0* T48f180(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_varchar */
extern T0* T47f210(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_varchar */
extern T0* T46f210(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_varchar */
extern T0* T45f180(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_varchar */
extern T0* T44f210(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_varchar */
extern T0* T43f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_varchar */
extern T0* T42f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_varchar */
extern T0* T41f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.datatype_float */
extern T0* T64f223(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.datatype_float */
extern T0* T63f222(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.datatype_float */
extern T0* T62f222(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.datatype_float */
extern T0* T61f222(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.datatype_float */
extern T0* T60f211(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.datatype_float */
extern T0* T59f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.datatype_float */
extern T0* T58f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.datatype_float */
extern T0* T57f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.datatype_float */
extern T0* T56f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.datatype_float */
extern T0* T55f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.datatype_float */
extern T0* T54f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.datatype_float */
extern T0* T53f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.datatype_float */
extern T0* T52f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.datatype_float */
extern T0* T51f221(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.datatype_float */
extern T0* T50f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.datatype_float */
extern T0* T49f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.datatype_float */
extern T0* T48f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.datatype_float */
extern T0* T47f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.datatype_float */
extern T0* T46f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.datatype_float */
extern T0* T45f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.datatype_float */
extern T0* T44f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.datatype_float */
extern T0* T43f210(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.datatype_float */
extern T0* T42f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.datatype_float */
extern T0* T41f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.columndatatype_base */
extern T0* T64f226(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.columndatatype_base */
extern T0* T63f225(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.columndatatype_base */
extern T0* T62f225(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.columndatatype_base */
extern T0* T61f225(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.columndatatype_base */
extern T0* T60f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.columndatatype_base */
extern T0* T59f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.columndatatype_base */
extern T0* T58f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.columndatatype_base */
extern T0* T57f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.columndatatype_base */
extern T0* T56f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.columndatatype_base */
extern T0* T55f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.columndatatype_base */
extern T0* T54f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.columndatatype_base */
extern T0* T53f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.columndatatype_base */
extern T0* T52f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.columndatatype_base */
extern T0* T51f224(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.columndatatype_base */
extern T0* T50f211(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.columndatatype_base */
extern T0* T49f211(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.columndatatype_base */
extern T0* T48f211(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.columndatatype_base */
extern T0* T47f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.columndatatype_base */
extern T0* T46f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.columndatatype_base */
extern T0* T45f211(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.columndatatype_base */
extern T0* T44f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.columndatatype_base */
extern T0* T43f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.columndatatype_base */
extern T0* T42f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.columndatatype_base */
extern T0* T41f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.columndatatype_type */
extern T0* T64f230(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.columndatatype_type */
extern T0* T63f229(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.columndatatype_type */
extern T0* T62f229(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.columndatatype_type */
extern T0* T61f229(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.columndatatype_type */
extern T0* T60f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.columndatatype_type */
extern T0* T59f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.columndatatype_type */
extern T0* T58f241(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.columndatatype_type */
extern T0* T57f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.columndatatype_type */
extern T0* T56f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.columndatatype_type */
extern T0* T55f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.columndatatype_type */
extern T0* T54f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.columndatatype_type */
extern T0* T53f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.columndatatype_type */
extern T0* T52f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.columndatatype_type */
extern T0* T51f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.columndatatype_type */
extern T0* T50f215(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.columndatatype_type */
extern T0* T49f215(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.columndatatype_type */
extern T0* T48f215(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.columndatatype_type */
extern T0* T47f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.columndatatype_type */
extern T0* T46f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.columndatatype_type */
extern T0* T45f215(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.columndatatype_type */
extern T0* T44f235(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.columndatatype_type */
extern T0* T43f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.columndatatype_type */
extern T0* T42f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.columndatatype_type */
extern T0* T41f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.columndatatype_assertion */
extern T0* T64f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.columndatatype_assertion */
extern T0* T64f233p1(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.sqlvalue */
extern T0* T301f9(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.asserted_format_string */
extern T0* T64f239(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.columndatatype_assertion */
extern T0* T63f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.columndatatype_assertion */
extern T0* T63f232p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.asserted_format_string */
extern T0* T63f238(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.columndatatype_assertion */
extern T0* T62f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.columndatatype_assertion */
extern T0* T62f232p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.asserted_format_string */
extern T0* T62f238(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.columndatatype_assertion */
extern T0* T61f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.columndatatype_assertion */
extern T0* T61f232p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.asserted_format_string */
extern T0* T61f238(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.columndatatype_assertion */
extern T0* T60f221(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.columndatatype_assertion */
extern T0* T60f221p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.asserted_format_string */
extern T0* T60f236(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.columndatatype_assertion */
extern T0* T59f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.columndatatype_assertion */
extern T0* T59f244p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.asserted_format_string */
extern T0* T59f259(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.columndatatype_assertion */
extern T0* T58f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.columndatatype_assertion */
extern T0* T58f244p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.asserted_format_string */
extern T0* T58f260(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.columndatatype_assertion */
extern T0* T57f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.columndatatype_assertion */
extern T0* T57f245p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.asserted_format_string */
extern T0* T57f261(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.columndatatype_assertion */
extern T0* T56f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.columndatatype_assertion */
extern T0* T56f245p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.asserted_format_string */
extern T0* T56f261(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.columndatatype_assertion */
extern T0* T55f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.columndatatype_assertion */
extern T0* T55f245p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.asserted_format_string */
extern T0* T55f261(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.columndatatype_assertion */
extern T0* T54f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.columndatatype_assertion */
extern T0* T54f238p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.asserted_format_string */
extern T0* T54f257(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.columndatatype_assertion */
extern T0* T53f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.columndatatype_assertion */
extern T0* T53f219p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.asserted_format_string */
extern T0* T53f225(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.columndatatype_assertion */
extern T0* T52f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.columndatatype_assertion */
extern T0* T52f219p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.asserted_format_string */
extern T0* T52f225(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.columndatatype_assertion */
extern T0* T51f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.columndatatype_assertion */
extern T0* T51f231p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.asserted_format_string */
extern T0* T51f246(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.columndatatype_assertion */
extern T0* T50f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.columndatatype_assertion */
extern T0* T50f218p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.asserted_format_string */
extern T0* T50f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.columndatatype_assertion */
extern T0* T49f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.columndatatype_assertion */
extern T0* T49f218p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.asserted_format_string */
extern T0* T49f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.columndatatype_assertion */
extern T0* T48f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.columndatatype_assertion */
extern T0* T48f218p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.asserted_format_string */
extern T0* T48f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.columndatatype_assertion */
extern T0* T47f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.columndatatype_assertion */
extern T0* T47f238p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.asserted_format_string */
extern T0* T47f253(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.columndatatype_assertion */
extern T0* T46f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.columndatatype_assertion */
extern T0* T46f238p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.asserted_format_string */
extern T0* T46f253(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.columndatatype_assertion */
extern T0* T45f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.columndatatype_assertion */
extern T0* T45f218p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.asserted_format_string */
extern T0* T45f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.columndatatype_assertion */
extern T0* T44f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.columndatatype_assertion */
extern T0* T44f238p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.asserted_format_string */
extern T0* T44f253(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.columndatatype_assertion */
extern T0* T43f220(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.columndatatype_assertion */
extern T0* T43f220p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.asserted_format_string */
extern T0* T43f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.columndatatype_assertion */
extern T0* T42f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.columndatatype_assertion */
extern T0* T42f219p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.asserted_format_string */
extern T0* T42f225(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.columndatatype_assertion */
extern T0* T41f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.columndatatype_assertion */
extern T0* T41f219p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.asserted_format_string */
extern T0* T41f225(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.sqlcolumndefault */
extern T0* T157f24(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.sqlcolumndefault */
extern T0* T143f23(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TYPE.sqlcolumndefault */
extern T0* T129f21(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_BASE.sqlcolumndefault */
extern T0* T128f7(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.sqlcolumnrequired */
extern T0* T157f25(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.sqlcolumnrequired */
extern T0* T143f24(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TYPE.sqlcolumnrequired */
extern T0* T129f22(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_BASE.sqlcolumnrequired */
extern T0* T128f8(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_BASE.columndatatype */
extern T0* T128f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_BASE.sqlcolumnidentifier */
extern T0* T128f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.sql_select_name */
extern T0* T157f23(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.sql_select_name */
extern T0* T143f21(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TYPE.sql_select_name */
extern T0* T129f27(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_BASE.sql_select_name */
extern T0* T128f10(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_BASE.q_sql_select_name */
extern T0* T128f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_PROCEDURE.create_expression */
extern T0* T318f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE.create_expression */
extern T0* T256f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_NAME.value */
extern T0* T138f15(GE_context* ac, T0* C);
extern T1 T138f15ot1(T0* a1, T0** a2);
/* XPLAIN_VARIABLE.create_expression */
extern T0* T179f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_NAME.variable */
extern T0* T138f14(GE_context* ac, T0* C);
extern T1 T138f14ot1(T0* a1, T0** a2);
/* XPLAIN_EXTENSION.create_expression */
extern T0* T157f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.create_expression */
extern T0* T143f28(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.make */
extern T0* T448c27(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_TYPE.create_expression */
extern T0* T129f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_BASE.create_expression */
extern T0* T128f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE.may_be_redefined */
extern T1 T318f18(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE.may_be_redefined */
extern T1 T179f8(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.may_be_redefined */
extern T1 T157f34(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.may_be_redefined */
extern T1 T143f36(GE_context* ac, T0* C);
/* XPLAIN_TYPE.may_be_redefined */
extern T1 T129f26(GE_context* ac, T0* C);
/* XPLAIN_BASE.may_be_redefined */
extern T1 T128f9(GE_context* ac, T0* C);
/* XPLAIN_NIL_FUNCTION.needs_coalesce */
extern T1 T314f1(GE_context* ac, T0* C);
/* XPLAIN_ANY_FUNCTION.needs_coalesce */
extern T1 T313f3(GE_context* ac, T0* C);
/* XPLAIN_TOTAL_FUNCTION.needs_coalesce */
extern T1 T311f3(GE_context* ac, T0* C);
/* XPLAIN_MIN_FUNCTION.needs_coalesce */
extern T1 T310f3(GE_context* ac, T0* C);
/* XPLAIN_MAX_FUNCTION.needs_coalesce */
extern T1 T308f3(GE_context* ac, T0* C);
/* XPLAIN_SOME_FUNCTION.sqlfunction */
extern T0* T315f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NIL_FUNCTION.sqlfunction */
extern T0* T314f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ANY_FUNCTION.sqlfunction */
extern T0* T313f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COUNT_FUNCTION.sqlfunction */
extern T0* T312f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TOTAL_FUNCTION.sqlfunction */
extern T0* T311f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_MIN_FUNCTION.sqlfunction */
extern T0* T310f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_MAX_FUNCTION.sqlfunction */
extern T0* T308f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SOME_FUNCTION.needs_distinct */
extern T1 T315f9(GE_context* ac, T0* C);
/* XPLAIN_NIL_FUNCTION.needs_distinct */
extern T1 T314f9(GE_context* ac, T0* C);
/* XPLAIN_ANY_FUNCTION.needs_distinct */
extern T1 T313f9(GE_context* ac, T0* C);
/* XPLAIN_TOTAL_FUNCTION.needs_distinct */
extern T1 T311f9(GE_context* ac, T0* C);
/* XPLAIN_MIN_FUNCTION.needs_distinct */
extern T1 T310f9(GE_context* ac, T0* C);
/* XPLAIN_MAX_FUNCTION.needs_distinct */
extern T1 T308f9(GE_context* ac, T0* C);
/* XPLAIN_SOME_FUNCTION.is_existential */
extern T1 T315f5(GE_context* ac, T0* C);
/* XPLAIN_COUNT_FUNCTION.is_existential */
extern T1 T312f5(GE_context* ac, T0* C);
/* XPLAIN_TOTAL_FUNCTION.is_existential */
extern T1 T311f5(GE_context* ac, T0* C);
/* XPLAIN_MIN_FUNCTION.is_existential */
extern T1 T310f5(GE_context* ac, T0* C);
/* XPLAIN_MAX_FUNCTION.is_existential */
extern T1 T308f5(GE_context* ac, T0* C);
/* XPLAIN_SOME_FUNCTION.needs_limit */
extern T1 T315f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NIL_FUNCTION.needs_limit */
extern T1 T314f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ANY_FUNCTION.needs_limit */
extern T1 T313f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COUNT_FUNCTION.needs_limit */
extern T1 T312f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TOTAL_FUNCTION.needs_limit */
extern T1 T311f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_MIN_FUNCTION.needs_limit */
extern T1 T310f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_MAX_FUNCTION.needs_limit */
extern T1 T308f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NIL_FUNCTION.is_some */
extern T1 T314f10(GE_context* ac, T0* C);
/* XPLAIN_ANY_FUNCTION.is_some */
extern T1 T313f10(GE_context* ac, T0* C);
/* XPLAIN_COUNT_FUNCTION.is_some */
extern T1 T312f10(GE_context* ac, T0* C);
/* XPLAIN_TOTAL_FUNCTION.is_some */
extern T1 T311f10(GE_context* ac, T0* C);
/* XPLAIN_MIN_FUNCTION.is_some */
extern T1 T310f10(GE_context* ac, T0* C);
/* XPLAIN_MAX_FUNCTION.is_some */
extern T1 T308f10(GE_context* ac, T0* C);
/* XPLAIN_SOME_FUNCTION.representation */
extern T0* T315f6(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_NIL_FUNCTION.representation */
extern T0* T314f4(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_ANY_FUNCTION.representation */
extern T0* T313f6(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_COUNT_FUNCTION.representation */
extern T0* T312f6(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_TOTAL_FUNCTION.representation */
extern T0* T311f6(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_MIN_FUNCTION.representation */
extern T0* T310f6(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_MAX_FUNCTION.representation */
extern T0* T308f6(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* XPLAIN_SOME_FUNCTION.sp_function_type */
extern T0* T315f11(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* XPLAIN_NIL_FUNCTION.sp_function_type */
extern T0* T314f11(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* XPLAIN_ANY_FUNCTION.sp_function_type */
extern T0* T313f11(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* XPLAIN_COUNT_FUNCTION.sp_function_type */
extern T0* T312f11(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* XPLAIN_TOTAL_FUNCTION.sp_function_type */
extern T0* T311f11(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* XPLAIN_MIN_FUNCTION.sp_function_type */
extern T0* T310f11(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* XPLAIN_MAX_FUNCTION.sp_function_type */
extern T0* T308f11(GE_context* ac, T0* C, T0* a1, T0* a2, T1 a3);
/* XPLAIN_SOME_FUNCTION.sqlextenddefault */
extern T0* T315f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_NIL_FUNCTION.sqlextenddefault */
extern T0* T314f2(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ANY_FUNCTION.sqlextenddefault */
extern T0* T313f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_COUNT_FUNCTION.sqlextenddefault */
extern T0* T312f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TOTAL_FUNCTION.sqlextenddefault */
extern T0* T311f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_MIN_FUNCTION.sqlextenddefault */
extern T0* T310f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_MAX_FUNCTION.sqlextenddefault */
extern T0* T308f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_SOME_FUNCTION.is_nil */
extern T1 T315f12(GE_context* ac, T0* C);
/* XPLAIN_ANY_FUNCTION.is_nil */
extern T1 T313f12(GE_context* ac, T0* C);
/* XPLAIN_COUNT_FUNCTION.is_nil */
extern T1 T312f12(GE_context* ac, T0* C);
/* XPLAIN_TOTAL_FUNCTION.is_nil */
extern T1 T311f12(GE_context* ac, T0* C);
/* XPLAIN_MIN_FUNCTION.is_nil */
extern T1 T310f12(GE_context* ac, T0* C);
/* XPLAIN_MAX_FUNCTION.is_nil */
extern T1 T308f12(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_ATTRIBUTE.is_logical_extension */
extern T1 T446f15(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.is_nil_expression */
extern T1 T303f19(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.is_nil_expression */
extern T1 T301f13(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.is_logical_expression */
extern T1 T303f13(GE_context* ac, T0* C);
extern T1 T303f13ot1(T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.is_logical_expression */
extern T1 T301f8(GE_context* ac, T0* C);
/* XPLAIN_VIRTUAL_ATTRIBUTE.is_logical_extension */
extern T1 T445f15(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE.is_logical_extension */
extern T1 T142f12(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_ATTRIBUTE.sql_select_name */
extern T0* T446f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VIRTUAL_ATTRIBUTE.sql_select_name */
extern T0* T445f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE.sql_select_name */
extern T0* T142f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_ATTRIBUTE.name */
extern T0* T446f13(GE_context* ac, T0* C);
/* XPLAIN_VIRTUAL_ATTRIBUTE.name */
extern T0* T445f13(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE.name */
extern T0* T142f10(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_ATTRIBUTE.is_assertion */
extern T1 T446f10(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE.is_assertion */
extern T1 T142f14(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_ATTRIBUTE.full_name */
extern T0* T446f9(GE_context* ac, T0* C);
/* XPLAIN_VIRTUAL_ATTRIBUTE.full_name */
extern T0* T445f9(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE.full_name */
extern T0* T142f16(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_ATTRIBUTE.q_sql_select_name */
extern T0* T446f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VIRTUAL_ATTRIBUTE.q_sql_select_name */
extern T0* T445f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE.q_sql_select_name */
extern T0* T142f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VIRTUAL_ATTRIBUTE.is_extension */
extern T1 T445f12(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE.is_extension */
extern T1 T142f11(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_ATTRIBUTE.extension */
extern T0* T446f16(GE_context* ac, T0* C);
/* XPLAIN_VIRTUAL_ATTRIBUTE.abstracttype */
extern T0* T445f16(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE.abstracttype */
extern T0* T142f13(GE_context* ac, T0* C);
/* XPLAIN_F_REPRESENTATION.is_blob */
extern T1 T403f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_I_REPRESENTATION.is_blob */
extern T1 T249f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_A_REPRESENTATION.is_blob */
extern T1 T246f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_T_REPRESENTATION.is_blob */
extern T1 T245f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_R_REPRESENTATION.is_blob */
extern T1 T244f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_P_REPRESENTATION.is_blob */
extern T1 T243f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_M_REPRESENTATION.is_blob */
extern T1 T242f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_I_REPRESENTATION.is_blob */
extern T1 T241f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_D_REPRESENTATION.is_blob */
extern T1 T240f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_C_REPRESENTATION.is_blob */
extern T1 T239f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_B_REPRESENTATION.is_blob */
extern T1 T238f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_A_REPRESENTATION.is_blob */
extern T1 T236f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_I_REPRESENTATION.default_value */
extern T0* T249f12(GE_context* ac, T0* C);
/* XPLAIN_PK_A_REPRESENTATION.default_value */
extern T0* T246f13(GE_context* ac, T0* C);
/* XPLAIN_R_REPRESENTATION.default_value */
extern T0* T244f11(GE_context* ac, T0* C);
/* XPLAIN_I_REPRESENTATION.default_value */
extern T0* T241f10(GE_context* ac, T0* C);
/* XPLAIN_C_REPRESENTATION.default_value */
extern T0* T239f11(GE_context* ac, T0* C);
/* XPLAIN_A_REPRESENTATION.default_value */
extern T0* T236f11(GE_context* ac, T0* C);
/* XPLAIN_F_REPRESENTATION.value_representation */
extern T0* T403f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_I_REPRESENTATION.value_representation */
extern T0* T249f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_A_REPRESENTATION.value_representation */
extern T0* T246f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_T_REPRESENTATION.value_representation */
extern T0* T245f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_R_REPRESENTATION.value_representation */
extern T0* T244f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_P_REPRESENTATION.value_representation */
extern T0* T243f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_M_REPRESENTATION.value_representation */
extern T0* T242f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_I_REPRESENTATION.value_representation */
extern T0* T241f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_D_REPRESENTATION.value_representation */
extern T0* T240f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_C_REPRESENTATION.value_representation */
extern T0* T239f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_B_REPRESENTATION.value_representation */
extern T0* T238f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_A_REPRESENTATION.value_representation */
extern T0* T236f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_I_REPRESENTATION.domain */
extern T0* T249f7(GE_context* ac, T0* C);
/* XPLAIN_PK_A_REPRESENTATION.domain */
extern T0* T246f7(GE_context* ac, T0* C);
/* XPLAIN_R_REPRESENTATION.domain */
extern T0* T244f4(GE_context* ac, T0* C);
/* XPLAIN_I_REPRESENTATION.domain */
extern T0* T241f4(GE_context* ac, T0* C);
/* XPLAIN_C_REPRESENTATION.domain */
extern T0* T239f4(GE_context* ac, T0* C);
/* XPLAIN_A_REPRESENTATION.domain */
extern T0* T236f3(GE_context* ac, T0* C);
/* XPLAIN_F_REPRESENTATION.xml_schema_data_type */
extern T0* T403f8(GE_context* ac, T0* C);
/* XPLAIN_PK_I_REPRESENTATION.xml_schema_data_type */
extern T0* T249f8(GE_context* ac, T0* C);
/* XPLAIN_PK_A_REPRESENTATION.xml_schema_data_type */
extern T0* T246f9(GE_context* ac, T0* C);
/* XPLAIN_T_REPRESENTATION.xml_schema_data_type */
extern T0* T245f9(GE_context* ac, T0* C);
/* XPLAIN_R_REPRESENTATION.xml_schema_data_type */
extern T0* T244f10(GE_context* ac, T0* C);
/* XPLAIN_P_REPRESENTATION.xml_schema_data_type */
extern T0* T243f9(GE_context* ac, T0* C);
/* XPLAIN_M_REPRESENTATION.xml_schema_data_type */
extern T0* T242f8(GE_context* ac, T0* C);
/* XPLAIN_I_REPRESENTATION.xml_schema_data_type */
extern T0* T241f9(GE_context* ac, T0* C);
extern T1 T241f9ot1(T0* a1, T0** a2);
extern T1 T241f9ot2(T0* a1, T0** a2);
/* XPLAIN_D_REPRESENTATION.xml_schema_data_type */
extern T0* T240f8(GE_context* ac, T0* C);
/* XPLAIN_C_REPRESENTATION.xml_schema_data_type */
extern T0* T239f10(GE_context* ac, T0* C);
/* XPLAIN_B_REPRESENTATION.xml_schema_data_type */
extern T0* T238f9(GE_context* ac, T0* C);
/* XPLAIN_A_REPRESENTATION.xml_schema_data_type */
extern T0* T236f10(GE_context* ac, T0* C);
/* XPLAIN_F_REPRESENTATION.datatype */
extern T0* T403f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_I_REPRESENTATION.datatype */
extern T0* T249f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_A_REPRESENTATION.datatype */
extern T0* T246f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_T_REPRESENTATION.datatype */
extern T0* T245f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_R_REPRESENTATION.datatype */
extern T0* T244f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_P_REPRESENTATION.datatype */
extern T0* T243f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_M_REPRESENTATION.datatype */
extern T0* T242f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_I_REPRESENTATION.datatype */
extern T0* T241f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_D_REPRESENTATION.datatype */
extern T0* T240f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_C_REPRESENTATION.datatype */
extern T0* T239f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_B_REPRESENTATION.datatype */
extern T0* T238f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_A_REPRESENTATION.datatype */
extern T0* T236f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_F_REPRESENTATION.min_value */
extern T0* T403f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_I_REPRESENTATION.min_value */
extern T0* T249f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_A_REPRESENTATION.min_value */
extern T0* T246f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_A_REPRESENTATION.std */
extern T0* T246f8(GE_context* ac, T0* C);
/* XPLAIN_T_REPRESENTATION.min_value */
extern T0* T245f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_T_REPRESENTATION.std */
extern T0* T245f6(GE_context* ac, T0* C);
/* XPLAIN_R_REPRESENTATION.min_value */
extern T0* T244f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_P_REPRESENTATION.min_value */
extern T0* T243f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_P_REPRESENTATION.std */
extern T0* T243f6(GE_context* ac, T0* C);
/* XPLAIN_M_REPRESENTATION.min_value */
extern T0* T242f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_I_REPRESENTATION.min_value */
extern T0* T241f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_D_REPRESENTATION.min_value */
extern T0* T240f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_C_REPRESENTATION.min_value */
extern T0* T239f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_C_REPRESENTATION.std */
extern T0* T239f7(GE_context* ac, T0* C);
/* XPLAIN_B_REPRESENTATION.min_value */
extern T0* T238f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_B_REPRESENTATION.std */
extern T0* T238f6(GE_context* ac, T0* C);
/* XPLAIN_A_REPRESENTATION.min_value */
extern T0* T236f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_A_REPRESENTATION.std */
extern T0* T236f7(GE_context* ac, T0* C);
/* XPLAIN_F_REPRESENTATION.max_value */
extern T0* T403f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_I_REPRESENTATION.max_value */
extern T0* T249f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PK_A_REPRESENTATION.max_value */
extern T0* T246f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_T_REPRESENTATION.max_value */
extern T0* T245f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_R_REPRESENTATION.max_value */
extern T0* T244f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_P_REPRESENTATION.max_value */
extern T0* T243f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_M_REPRESENTATION.max_value */
extern T0* T242f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_I_REPRESENTATION.max_value */
extern T0* T241f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_D_REPRESENTATION.max_value */
extern T0* T240f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_C_REPRESENTATION.max_value */
extern T0* T239f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_B_REPRESENTATION.max_value */
extern T0* T238f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_A_REPRESENTATION.max_value */
extern T0* T236f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.sqlmaxvalue */
extern T0* T448f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.sqlmaxvalue */
extern T0* T389f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.last */
extern T0* T389f10(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.sqlmaxvalue */
extern T0* T346f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.sqlmaxvalue */
extern T0* T345f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.sqlmaxvalue */
extern T0* T303f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.sqlmaxvalue */
extern T0* T285f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.sqlmaxvalue */
extern T0* T283f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.sqlmaxvalue */
extern T0* T257f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.sqlmaxvalue */
extern T0* T255f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.sqlmaxvalue */
extern T0* T233f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.sqlmaxvalue */
extern T0* T232f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.sqlmaxvalue */
extern T0* T231f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.sqlmaxvalue */
extern T0* T230f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.sqlmaxvalue */
extern T0* T229f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.sqlmaxvalue */
extern T0* T228f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.sqlmaxvalue */
extern T0* T227f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.sqlmaxvalue */
extern T0* T226f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.sqlmaxvalue */
extern T0* T225f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.sqlmaxvalue */
extern T0* T224f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.sqlmaxvalue */
extern T0* T223f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.sqlmaxvalue */
extern T0* T222f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.sqlmaxvalue */
extern T0* T220f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.sqlmaxvalue */
extern T0* T219f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.sqlmaxvalue */
extern T0* T218f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.sqlmaxvalue */
extern T0* T215f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.sqlmaxvalue */
extern T0* T212f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.sqlmaxvalue */
extern T0* T211f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.sqlmaxvalue */
extern T0* T210f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.sqlmaxvalue */
extern T0* T209f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.sqlmaxvalue */
extern T0* T208f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.sqlmaxvalue */
extern T0* T207f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.sqlmaxvalue */
extern T0* T206f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.sqlmaxvalue */
extern T0* T203f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.sqlmaxvalue */
extern T0* T159f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.sqlmaxvalue */
extern T0* T135f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.sqlmaxvalue */
extern T0* T133f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.is_string_expression */
extern T1 T448f13(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.is_string_expression */
extern T1 T389f4(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.is_string_expression */
extern T1 T346f9(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.is_string_expression */
extern T1 T345f9(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.is_string_expression */
extern T1 T285f10(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.is_string_expression */
extern T1 T283f10(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.is_string_expression */
extern T1 T257f10(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.is_string_expression */
extern T1 T255f10(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.is_string_expression */
extern T1 T233f10(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.is_string_expression */
extern T1 T232f11(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.is_string_expression */
extern T1 T231f10(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.is_string_expression */
extern T1 T230f10(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.is_string_expression */
extern T1 T229f10(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.is_string_expression */
extern T1 T228f12(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.is_string_expression */
extern T1 T225f10(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.is_string_expression */
extern T1 T224f10(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.is_string_expression */
extern T1 T223f10(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.is_string_expression */
extern T1 T220f11(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.is_string_expression */
extern T1 T219f12(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.is_string_expression */
extern T1 T218f9(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.is_string_expression */
extern T1 T215f9(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.is_string_expression */
extern T1 T212f10(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.is_string_expression */
extern T1 T211f12(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.is_string_expression */
extern T1 T210f11(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.is_string_expression */
extern T1 T209f11(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.is_string_expression */
extern T1 T208f10(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.is_string_expression */
extern T1 T207f12(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.is_string_expression */
extern T1 T206f10(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.is_string_expression */
extern T1 T203f12(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.is_string_expression */
extern T1 T159f15(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.is_string_expression */
extern T1 T135f10(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.is_string_expression */
extern T1 T133f10(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.can_be_null */
extern T1 T448f21(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.can_be_null */
extern T1 T389f22(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.can_be_null */
extern T1 T346f11(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.can_be_null */
extern T1 T345f11(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.can_be_null */
extern T1 T285f12(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.can_be_null */
extern T1 T283f12(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.can_be_null */
extern T1 T257f12(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.can_be_null */
extern T1 T255f12(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.can_be_null */
extern T1 T233f12(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.can_be_null */
extern T1 T232f13(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.can_be_null */
extern T1 T231f12(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.can_be_null */
extern T1 T230f12(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.can_be_null */
extern T1 T229f12(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.can_be_null */
extern T1 T228f14(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.can_be_null */
extern T1 T227f12(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.can_be_null */
extern T1 T226f12(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.can_be_null */
extern T1 T225f12(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.can_be_null */
extern T1 T224f12(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.can_be_null */
extern T1 T223f12(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.can_be_null */
extern T1 T222f12(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.can_be_null */
extern T1 T220f13(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.can_be_null */
extern T1 T219f14(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.can_be_null */
extern T1 T218f11(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.can_be_null */
extern T1 T215f11(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.can_be_null */
extern T1 T212f12(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.can_be_null */
extern T1 T211f14(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.can_be_null */
extern T1 T210f13(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.can_be_null */
extern T1 T209f13(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.can_be_null */
extern T1 T208f12(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.can_be_null */
extern T1 T207f14(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.can_be_null */
extern T1 T206f12(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.can_be_null */
extern T1 T203f14(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.can_be_null */
extern T1 T159f24(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.can_be_null */
extern T1 T135f12(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.can_be_null */
extern T1 T133f12(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.sql_alias */
extern T0* T448f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.sql_alias */
extern T0* T389f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.sql_alias */
extern T0* T346f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.sql_alias */
extern T0* T345f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.sql_alias */
extern T0* T285f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.sql_alias */
extern T0* T283f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.sql_alias */
extern T0* T257f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.sql_alias */
extern T0* T255f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.sql_alias */
extern T0* T233f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.sql_alias */
extern T0* T232f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.sql_alias */
extern T0* T231f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.sql_alias */
extern T0* T230f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.sql_alias */
extern T0* T229f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.sql_alias */
extern T0* T228f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.sql_alias */
extern T0* T227f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.sql_alias */
extern T0* T226f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.sql_alias */
extern T0* T225f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.sql_alias */
extern T0* T224f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.sql_alias */
extern T0* T223f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.sql_alias */
extern T0* T222f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.sql_alias */
extern T0* T220f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.sql_alias */
extern T0* T219f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.sql_alias */
extern T0* T218f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.sql_alias */
extern T0* T215f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.sql_alias */
extern T0* T212f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.sql_alias */
extern T0* T211f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.sql_alias */
extern T0* T210f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.sql_alias */
extern T0* T209f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.sql_alias */
extern T0* T208f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.sql_alias */
extern T0* T207f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.sql_alias */
extern T0* T206f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.sql_alias */
extern T0* T203f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.sql_alias */
extern T0* T159f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.sql_alias */
extern T0* T157f28(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.sql_alias */
extern T0* T135f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.sql_alias */
extern T0* T133f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.outer_sqlvalue */
extern T0* T448f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.outer_sqlvalue */
extern T0* T389f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.outer_sqlvalue */
extern T0* T346f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.outer_sqlvalue */
extern T0* T345f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.outer_sqlvalue */
extern T0* T303f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.outer_sqlvalue */
extern T0* T285f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.outer_sqlvalue */
extern T0* T283f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.outer_sqlvalue */
extern T0* T257f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.outer_sqlvalue */
extern T0* T255f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.outer_sqlvalue */
extern T0* T233f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.outer_sqlvalue */
extern T0* T232f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.outer_sqlvalue */
extern T0* T231f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.outer_sqlvalue */
extern T0* T230f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.outer_sqlvalue */
extern T0* T229f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.outer_sqlvalue */
extern T0* T228f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.outer_sqlvalue */
extern T0* T227f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.outer_sqlvalue */
extern T0* T226f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.outer_sqlvalue */
extern T0* T225f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.outer_sqlvalue */
extern T0* T224f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.outer_sqlvalue */
extern T0* T223f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.outer_sqlvalue */
extern T0* T222f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.outer_sqlvalue */
extern T0* T220f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.outer_sqlvalue */
extern T0* T219f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.outer_sqlvalue */
extern T0* T218f1(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.outer_sqlvalue */
extern T0* T215f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.outer_sqlvalue */
extern T0* T212f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.outer_sqlvalue */
extern T0* T211f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.outer_sqlvalue */
extern T0* T210f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.outer_sqlvalue */
extern T0* T209f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.outer_sqlvalue */
extern T0* T208f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.outer_sqlvalue */
extern T0* T207f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.outer_sqlvalue */
extern T0* T206f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.outer_sqlvalue */
extern T0* T203f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.outer_sqlvalue */
extern T0* T159f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.outer_sqlvalue */
extern T0* T135f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.outer_sqlvalue */
extern T0* T133f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.is_logical_expression */
extern T1 T448f25(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.is_logical_expression */
extern T1 T389f13(GE_context* ac, T0* C);
extern T1 T389f13ot1(T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.is_logical_expression */
extern T1 T346f15(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.is_logical_expression */
extern T1 T345f15(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.is_logical_expression */
extern T1 T285f16(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.is_logical_expression */
extern T1 T283f16(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.is_logical_expression */
extern T1 T257f16(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.is_logical_expression */
extern T1 T255f16(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.is_logical_expression */
extern T1 T233f16(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.is_logical_expression */
extern T1 T232f17(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.is_logical_expression */
extern T1 T231f16(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.is_logical_expression */
extern T1 T230f16(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.is_logical_expression */
extern T1 T229f16(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.is_logical_expression */
extern T1 T228f18(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.is_logical_expression */
extern T1 T227f16(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.is_logical_expression */
extern T1 T226f16(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.is_logical_expression */
extern T1 T225f16(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.is_logical_expression */
extern T1 T224f16(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.is_logical_expression */
extern T1 T223f16(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.is_logical_expression */
extern T1 T222f16(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.is_logical_expression */
extern T1 T220f17(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.is_logical_expression */
extern T1 T219f18(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.is_logical_expression */
extern T1 T218f15(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.is_logical_expression */
extern T1 T215f15(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.is_logical_expression */
extern T1 T212f16(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.is_logical_expression */
extern T1 T211f18(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.is_logical_expression */
extern T1 T210f17(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.is_logical_expression */
extern T1 T209f17(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.is_logical_expression */
extern T1 T208f16(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.is_logical_expression */
extern T1 T207f18(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.is_logical_expression */
extern T1 T206f16(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.is_logical_expression */
extern T1 T159f3(GE_context* ac, T0* C);
extern T1 T159f3ot1(T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.selects_max_one_row */
extern T1 T448f22(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.selects_max_one_row */
extern T1 T389f23(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.selects_max_one_row */
extern T1 T346f16(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.selects_max_one_row */
extern T1 T345f16(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.selects_max_one_row */
extern T1 T285f17(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.selects_max_one_row */
extern T1 T283f17(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.selects_max_one_row */
extern T1 T257f17(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.selects_max_one_row */
extern T1 T255f17(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.selects_max_one_row */
extern T1 T233f17(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.selects_max_one_row */
extern T1 T232f18(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.selects_max_one_row */
extern T1 T231f17(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.selects_max_one_row */
extern T1 T230f17(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.selects_max_one_row */
extern T1 T229f17(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.selects_max_one_row */
extern T1 T228f19(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.selects_max_one_row */
extern T1 T227f17(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.selects_max_one_row */
extern T1 T226f17(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.selects_max_one_row */
extern T1 T225f17(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.selects_max_one_row */
extern T1 T224f17(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.selects_max_one_row */
extern T1 T223f17(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.selects_max_one_row */
extern T1 T222f17(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.selects_max_one_row */
extern T1 T220f18(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.selects_max_one_row */
extern T1 T219f19(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.selects_max_one_row */
extern T1 T218f16(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.selects_max_one_row */
extern T1 T215f16(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.selects_max_one_row */
extern T1 T212f17(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.selects_max_one_row */
extern T1 T211f19(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.selects_max_one_row */
extern T1 T210f18(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.selects_max_one_row */
extern T1 T209f18(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.selects_max_one_row */
extern T1 T208f17(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.selects_max_one_row */
extern T1 T207f19(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.selects_max_one_row */
extern T1 T206f17(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.selects_max_one_row */
extern T1 T203f20(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.selects_max_one_row */
extern T1 T159f25(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.selects_max_one_row */
extern T1 T135f17(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.selects_max_one_row */
extern T1 T133f17(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.sqlminvalue */
extern T0* T448f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.sqlminvalue */
extern T0* T389f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.sqlminvalue */
extern T0* T346f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.sqlminvalue */
extern T0* T345f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.sqlminvalue */
extern T0* T303f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.sqlminvalue */
extern T0* T285f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.sqlminvalue */
extern T0* T283f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.sqlminvalue */
extern T0* T257f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.sqlminvalue */
extern T0* T255f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.sqlminvalue */
extern T0* T233f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.sqlminvalue */
extern T0* T232f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.sqlminvalue */
extern T0* T231f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.sqlminvalue */
extern T0* T230f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.sqlminvalue */
extern T0* T229f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.sqlminvalue */
extern T0* T228f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.sqlminvalue */
extern T0* T227f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.sqlminvalue */
extern T0* T226f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.sqlminvalue */
extern T0* T225f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.sqlminvalue */
extern T0* T224f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.sqlminvalue */
extern T0* T223f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.sqlminvalue */
extern T0* T222f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.sqlminvalue */
extern T0* T220f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.sqlminvalue */
extern T0* T219f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.sqlminvalue */
extern T0* T218f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.sqlminvalue */
extern T0* T215f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.sqlminvalue */
extern T0* T212f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.sqlminvalue */
extern T0* T211f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.sqlminvalue */
extern T0* T210f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.sqlminvalue */
extern T0* T209f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.sqlminvalue */
extern T0* T208f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.sqlminvalue */
extern T0* T207f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.sqlminvalue */
extern T0* T206f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.sqlminvalue */
extern T0* T203f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.sqlminvalue */
extern T0* T159f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.sqlminvalue */
extern T0* T135f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.sqlminvalue */
extern T0* T133f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.has_wild_card_characters */
extern T1 T448f12(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.has_wild_card_characters */
extern T1 T389f2(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.has_wild_card_characters */
extern T1 T346f20(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.has_wild_card_characters */
extern T1 T345f19(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.has_wild_card_characters */
extern T1 T285f2(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.has_wild_card_characters */
extern T1 T283f2(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.has_wild_card_characters */
extern T1 T257f2(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.has_wild_card_characters */
extern T1 T255f2(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.has_wild_card_characters */
extern T1 T233f2(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.has_wild_card_characters */
extern T1 T232f7(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.has_wild_card_characters */
extern T1 T231f2(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.has_wild_card_characters */
extern T1 T230f2(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.has_wild_card_characters */
extern T1 T229f2(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.has_wild_card_characters */
extern T1 T228f7(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.has_wild_card_characters */
extern T1 T227f2(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.has_wild_card_characters */
extern T1 T226f2(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.has_wild_card_characters */
extern T1 T225f2(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.has_wild_card_characters */
extern T1 T224f2(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.has_wild_card_characters */
extern T1 T223f2(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.has_wild_card_characters */
extern T1 T222f2(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.has_wild_card_characters */
extern T1 T220f7(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.has_wild_card_characters */
extern T1 T219f7(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.has_wild_card_characters */
extern T1 T218f2(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.has_wild_card_characters */
extern T1 T215f4(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.has_wild_card_characters */
extern T1 T212f2(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.has_wild_card_characters */
extern T1 T211f6(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.has_wild_card_characters */
extern T1 T210f2(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.has_wild_card_characters */
extern T1 T209f2(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.has_wild_card_characters */
extern T1 T208f2(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.has_wild_card_characters */
extern T1 T207f6(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.has_wild_card_characters */
extern T1 T206f2(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.has_wild_card_characters */
extern T1 T203f5(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.has_wild_card_characters */
extern T1 T159f14(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.has_wild_card_characters */
extern T1 T135f3(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.has_wild_card_characters */
extern T1 T133f3(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.is_using_other_attributes */
extern T1 T448f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.is_using_other_attributes */
extern T1 T389f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.is_using_other_attributes */
extern T1 T346f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.is_using_other_attributes */
extern T1 T345f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.is_using_other_attributes */
extern T1 T285f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.is_using_other_attributes */
extern T1 T283f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.is_using_other_attributes */
extern T1 T257f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.is_using_other_attributes */
extern T1 T255f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.is_using_other_attributes */
extern T1 T233f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.is_using_other_attributes */
extern T1 T232f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.is_using_other_attributes */
extern T1 T231f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.is_using_other_attributes */
extern T1 T230f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.is_using_other_attributes */
extern T1 T229f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.is_using_other_attributes */
extern T1 T228f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.is_using_other_attributes */
extern T1 T227f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.is_using_other_attributes */
extern T1 T226f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.is_using_other_attributes */
extern T1 T225f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.is_using_other_attributes */
extern T1 T224f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.is_using_other_attributes */
extern T1 T223f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.is_using_other_attributes */
extern T1 T222f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.is_using_other_attributes */
extern T1 T220f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.is_using_other_attributes */
extern T1 T219f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.is_using_other_attributes */
extern T1 T218f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.is_using_other_attributes */
extern T1 T215f1(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.is_using_other_attributes */
extern T1 T212f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.is_using_other_attributes */
extern T1 T211f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.is_using_other_attributes */
extern T1 T210f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.is_using_other_attributes */
extern T1 T209f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.is_using_other_attributes */
extern T1 T208f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.is_using_other_attributes */
extern T1 T207f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.is_using_other_attributes */
extern T1 T206f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.is_using_other_attributes */
extern T1 T203f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.is_using_other_attributes */
extern T1 T159f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.is_using_other_attributes */
extern T1 T135f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.is_using_other_attributes */
extern T1 T133f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.uses_its */
extern T1 T448f7(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.uses_its */
extern T1 T389f9(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.uses_its */
extern T1 T346f10(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.uses_its */
extern T1 T345f10(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.uses_its */
extern T1 T303f15(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.uses_its */
extern T1 T285f11(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.uses_its */
extern T1 T283f11(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.uses_its */
extern T1 T257f11(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.uses_its */
extern T1 T255f11(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.uses_its */
extern T1 T233f11(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.uses_its */
extern T1 T232f12(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.uses_its */
extern T1 T231f11(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.uses_its */
extern T1 T230f11(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.uses_its */
extern T1 T229f11(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.uses_its */
extern T1 T228f13(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.uses_its */
extern T1 T227f11(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.uses_its */
extern T1 T226f11(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.uses_its */
extern T1 T225f11(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.uses_its */
extern T1 T224f11(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.uses_its */
extern T1 T223f11(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.uses_its */
extern T1 T222f11(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.uses_its */
extern T1 T220f12(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.uses_its */
extern T1 T219f13(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.uses_its */
extern T1 T218f10(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.uses_its */
extern T1 T215f10(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.uses_its */
extern T1 T212f11(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.uses_its */
extern T1 T211f13(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.uses_its */
extern T1 T210f12(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.uses_its */
extern T1 T209f12(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.uses_its */
extern T1 T208f11(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.uses_its */
extern T1 T207f13(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.uses_its */
extern T1 T206f11(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.uses_its */
extern T1 T203f13(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.uses_its */
extern T1 T159f9(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.uses_its */
extern T1 T135f11(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.uses_its */
extern T1 T133f11(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.is_logical_constant */
extern T1 T448f10(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.is_logical_constant */
extern T1 T389f16(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.is_logical_constant */
extern T1 T346f24(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.is_logical_constant */
extern T1 T345f24(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.is_logical_constant */
extern T1 T285f21(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.is_logical_constant */
extern T1 T283f21(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.is_logical_constant */
extern T1 T257f21(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.is_logical_constant */
extern T1 T255f21(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.is_logical_constant */
extern T1 T233f21(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.is_logical_constant */
extern T1 T232f22(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.is_logical_constant */
extern T1 T231f21(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.is_logical_constant */
extern T1 T230f21(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.is_logical_constant */
extern T1 T229f21(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.is_logical_constant */
extern T1 T228f23(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.is_logical_constant */
extern T1 T227f21(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.is_logical_constant */
extern T1 T226f21(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.is_logical_constant */
extern T1 T225f21(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.is_logical_constant */
extern T1 T224f21(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.is_logical_constant */
extern T1 T223f21(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.is_logical_constant */
extern T1 T222f21(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.is_logical_constant */
extern T1 T220f22(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.is_logical_constant */
extern T1 T219f23(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.is_logical_constant */
extern T1 T218f20(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.is_logical_constant */
extern T1 T215f20(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.is_logical_constant */
extern T1 T212f21(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.is_logical_constant */
extern T1 T211f23(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.is_logical_constant */
extern T1 T210f22(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.is_logical_constant */
extern T1 T209f22(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.is_logical_constant */
extern T1 T208f21(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.is_logical_constant */
extern T1 T207f23(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.is_logical_constant */
extern T1 T206f21(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.is_logical_constant */
extern T1 T203f24(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.is_logical_constant */
extern T1 T159f12(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.is_logical_constant */
extern T1 T133f21(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T448f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T389f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T346f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T345f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T285f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T283f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T257f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T255f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T233f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.sqlvalue_as_wildcard */
extern T0* T232f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T231f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T230f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.sqlvalue_as_wildcard */
extern T0* T229f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.sqlvalue_as_wildcard */
extern T0* T228f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T227f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.sqlvalue_as_wildcard */
extern T0* T226f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.sqlvalue_as_wildcard */
extern T0* T225f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.sqlvalue_as_wildcard */
extern T0* T224f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.sqlvalue_as_wildcard */
extern T0* T223f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.sqlvalue_as_wildcard */
extern T0* T222f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T220f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T219f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T218f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T215f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T212f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T211f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T210f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T209f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T208f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T207f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T206f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T203f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T159f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T135f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.sqlvalue_as_wildcard */
extern T0* T133f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.sqlname */
extern T0* T448f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.sqlname */
extern T0* T389f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.sqlname */
extern T0* T346f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.sqlname */
extern T0* T345f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.sqlname */
extern T0* T285f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.sqlname */
extern T0* T283f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.sqlname */
extern T0* T257f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.sqlname */
extern T0* T255f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.sqlname */
extern T0* T233f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.sqlname */
extern T0* T232f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.sqlname */
extern T0* T231f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.sqlname */
extern T0* T230f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.sqlname */
extern T0* T229f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.sqlname */
extern T0* T228f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.sqlname */
extern T0* T227f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.sqlname */
extern T0* T226f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.sqlname */
extern T0* T225f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.sqlname */
extern T0* T224f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.sqlname */
extern T0* T223f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.sqlname */
extern T0* T222f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.sqlname */
extern T0* T220f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.sqlname */
extern T0* T219f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.sqlname */
extern T0* T218f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.sqlname */
extern T0* T215f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.sqlname */
extern T0* T212f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.sqlname */
extern T0* T211f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.sqlname */
extern T0* T210f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.sqlname */
extern T0* T209f21(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.sqlname */
extern T0* T208f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.sqlname */
extern T0* T207f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.sqlname */
extern T0* T206f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.sqlname */
extern T0* T203f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.sqlname */
extern T0* T159f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.sqlname */
extern T0* T135f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.sqlname */
extern T0* T133f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.is_specialization */
extern T1 T448f18(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.is_specialization */
extern T1 T389f19(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.is_specialization */
extern T1 T346f25(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.is_specialization */
extern T1 T345f25(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.is_specialization */
extern T1 T285f22(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.is_specialization */
extern T1 T283f22(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.is_specialization */
extern T1 T257f22(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.is_specialization */
extern T1 T255f22(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.is_specialization */
extern T1 T233f22(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.is_specialization */
extern T1 T232f23(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.is_specialization */
extern T1 T231f22(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.is_specialization */
extern T1 T230f22(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.is_specialization */
extern T1 T229f22(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.is_specialization */
extern T1 T228f24(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.is_specialization */
extern T1 T227f22(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.is_specialization */
extern T1 T226f22(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.is_specialization */
extern T1 T225f22(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.is_specialization */
extern T1 T224f22(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.is_specialization */
extern T1 T223f22(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.is_specialization */
extern T1 T222f22(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.is_specialization */
extern T1 T220f23(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.is_specialization */
extern T1 T219f24(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.is_specialization */
extern T1 T218f21(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.is_specialization */
extern T1 T215f21(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.is_specialization */
extern T1 T212f22(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.is_specialization */
extern T1 T211f24(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.is_specialization */
extern T1 T210f23(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.is_specialization */
extern T1 T209f23(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.is_specialization */
extern T1 T208f22(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.is_specialization */
extern T1 T207f24(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.is_specialization */
extern T1 T206f22(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.is_specialization */
extern T1 T203f25(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.is_specialization */
extern T1 T159f21(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.is_specialization */
extern T1 T135f22(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.is_specialization */
extern T1 T133f22(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.representation */
extern T0* T448f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.representation */
extern T0* T389f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.representation */
extern T0* T346f6(GE_context* ac, T0* C, T0* a1);
extern T1 T346f6ot1(T0* a1);
extern T1 T346f6ot2(T0* a1);
/* XPLAIN_LIKE_EXPRESSION.representation */
extern T0* T345f6(GE_context* ac, T0* C, T0* a1);
extern T1 T345f6ot1(T0* a1);
extern T1 T345f6ot2(T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.representation */
extern T0* T303f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.representation */
extern T0* T285f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.representation */
extern T0* T283f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.representation */
extern T0* T257f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.representation */
extern T0* T255f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.representation */
extern T0* T233f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.representation */
extern T0* T232f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.representation */
extern T0* T231f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.representation */
extern T0* T230f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.representation */
extern T0* T229f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.representation */
extern T0* T228f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.representation */
extern T0* T227f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.representation */
extern T0* T226f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.representation */
extern T0* T225f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.representation */
extern T0* T224f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.representation */
extern T0* T223f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.representation */
extern T0* T222f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.representation */
extern T0* T220f8(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.representation */
extern T0* T219f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.representation */
extern T0* T218f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.representation */
extern T0* T215f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.representation */
extern T0* T212f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.representation */
extern T0* T211f9(GE_context* ac, T0* C, T0* a1);
extern T1 T211f9ot1(T0* a1);
extern T1 T211f9ot2(T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.representation */
extern T0* T210f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.representation */
extern T0* T209f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.representation */
extern T0* T208f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.representation */
extern T0* T207f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.representation */
extern T0* T206f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.representation */
extern T0* T203f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.representation */
extern T0* T159f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.representation */
extern T0* T135f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.representation */
extern T0* T133f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.exact_representation */
extern T0* T448f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.exact_representation */
extern T0* T389f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.exact_representation */
extern T0* T346f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.exact_representation */
extern T0* T345f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.exact_representation */
extern T0* T285f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.exact_representation */
extern T0* T283f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.exact_representation */
extern T0* T257f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.exact_representation */
extern T0* T255f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.exact_representation */
extern T0* T233f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.exact_representation */
extern T0* T232f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.exact_representation */
extern T0* T231f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.exact_representation */
extern T0* T230f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.exact_representation */
extern T0* T229f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.exact_representation */
extern T0* T228f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.exact_representation */
extern T0* T227f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.exact_representation */
extern T0* T226f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.exact_representation */
extern T0* T225f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.exact_representation */
extern T0* T224f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.exact_representation */
extern T0* T223f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.exact_representation */
extern T0* T222f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.exact_representation */
extern T0* T220f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.exact_representation */
extern T0* T219f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.exact_representation */
extern T0* T218f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.exact_representation */
extern T0* T215f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.exact_representation */
extern T0* T212f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.exact_representation */
extern T0* T211f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.exact_representation */
extern T0* T210f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.exact_representation */
extern T0* T209f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.exact_representation */
extern T0* T208f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.exact_representation */
extern T0* T207f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.exact_representation */
extern T0* T206f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.exact_representation */
extern T0* T203f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.exact_representation */
extern T0* T159f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.exact_representation */
extern T0* T135f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.exact_representation */
extern T0* T133f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.sqlvalue */
extern T0* T448f3(GE_context* ac, T0* C, T0* a1);
extern T1 T448f3ot1(T0* a1, T0** a2);
/* XPLAIN_ASSERTION.sql_qualified_name */
extern T0* T143f41(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ATTRIBUTE_EXPRESSION.sqlvalue */
extern T0* T389f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.sqlvalue */
extern T0* T346f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.sqlvalue */
extern T0* T345f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.sqlvalue */
extern T0* T303f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.sqlvalue */
extern T0* T285f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.sqlvalue */
extern T0* T283f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_FUNCTION.sqlvalue */
extern T0* T154f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.sqlvalue */
extern T0* T257f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.sqlvalue */
extern T0* T255f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.sqlvalue */
extern T0* T233f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.sqlvalue */
extern T0* T232f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.sqlvalue */
extern T0* T231f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.sqlvalue */
extern T0* T230f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.sqlvalue */
extern T0* T229f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.sqlvalue */
extern T0* T228f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.sqlvalue */
extern T0* T227f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.sqlvalue */
extern T0* T226f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.sqlvalue */
extern T0* T225f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.sqlvalue */
extern T0* T224f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.sqlvalue */
extern T0* T223f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.sqlvalue */
extern T0* T222f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.sqlvalue */
extern T0* T220f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.sqlvalue */
extern T0* T219f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.sqlvalue */
extern T0* T218f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.sqlvalue */
extern T0* T215f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.sqlvalue */
extern T0* T212f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.sqlvalue */
extern T0* T211f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.sqlvalue */
extern T0* T210f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.sqlvalue */
extern T0* T209f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.sqlvalue */
extern T0* T208f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.sqlvalue */
extern T0* T207f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.sqlvalue */
extern T0* T206f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.sqlvalue */
extern T0* T203f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.sqlvalue */
extern T0* T159f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.sql_qualified_name */
extern T0* T157f27(GE_context* ac, T0* C, T0* a1, T0* a2);
extern T1 T157f27ot1(T0* a1, T0** a2);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.sqlvalue */
extern T0* T135f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.sqlvalue */
extern T0* T133f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.sqlinitvalue */
extern T0* T448f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.sqlinitvalue */
extern T0* T389f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.sqlinitvalue */
extern T0* T346f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.sqlinitvalue */
extern T0* T345f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.sqlinitvalue */
extern T0* T285f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.sqlinitvalue */
extern T0* T283f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.sqlinitvalue */
extern T0* T257f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.sqlinitvalue */
extern T0* T255f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.sqlinitvalue */
extern T0* T233f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.sqlinitvalue */
extern T0* T232f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.sqlinitvalue */
extern T0* T231f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.sqlinitvalue */
extern T0* T230f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.sqlinitvalue */
extern T0* T229f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.sqlinitvalue */
extern T0* T228f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.sqlinitvalue */
extern T0* T227f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.sqlinitvalue */
extern T0* T226f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.sqlinitvalue */
extern T0* T225f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.sqlinitvalue */
extern T0* T224f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.sqlinitvalue */
extern T0* T223f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.sqlinitvalue */
extern T0* T222f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.sqlinitvalue */
extern T0* T220f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.sqlinitvalue */
extern T0* T219f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.sqlinitvalue */
extern T0* T218f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.sqlinitvalue */
extern T0* T215f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.sqlinitvalue */
extern T0* T212f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.sqlinitvalue */
extern T0* T211f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.sqlinitvalue */
extern T0* T210f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.sqlinitvalue */
extern T0* T209f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.sqlinitvalue */
extern T0* T208f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.sqlinitvalue */
extern T0* T207f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.sqlinitvalue */
extern T0* T206f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.sqlinitvalue */
extern T0* T203f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.sqlinitvalue */
extern T0* T159f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.sqlinitvalue */
extern T0* T135f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.sqlinitvalue */
extern T0* T133f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.uses_parameter */
extern T1 T448f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ATTRIBUTE_EXPRESSION.uses_parameter */
extern T1 T389f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_LIKE_EXPRESSION.uses_parameter */
extern T1 T346f27(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LIKE_EXPRESSION.uses_parameter */
extern T1 T345f27(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.uses_parameter */
extern T1 T303f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_FUNCTION.uses_parameter */
extern T1 T154f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_FUNCTION.uses_parameter */
extern T1 T154f9p1(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.uses_parameter */
extern T1 T285f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_EXPRESSION.uses_parameter */
extern T1 T283f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_EXPRESSION.uses_parameter */
extern T1 T257f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE_EXPRESSION.uses_parameter */
extern T1 T255f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_EXPRESSION.uses_parameter */
extern T1 T233f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_USER_FUNCTION.uses_parameter */
extern T1 T232f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.uses_parameter */
extern T1 T231f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NUMBER_EXPRESSION.uses_parameter */
extern T1 T230f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ID_FUNCTION.uses_parameter */
extern T1 T229f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NEWDATE_FUNCTION.uses_parameter */
extern T1 T228f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_EXPRESSION.uses_parameter */
extern T1 T227f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_STRING_FUNCTION.uses_parameter */
extern T1 T226f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_REAL_FUNCTION.uses_parameter */
extern T1 T225f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INTEGER_FUNCTION.uses_parameter */
extern T1 T224f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATEF_FUNCTION.uses_parameter */
extern T1 T223f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_COMBINE_FUNCTION.uses_parameter */
extern T1 T222f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PREFIX_EXPRESSION.uses_parameter */
extern T1 T220f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_IF_EXPRESSION.uses_parameter */
extern T1 T219f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGINNAME_EXPRESSION.uses_parameter */
extern T1 T218f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SYSTEMDATE_EXPRESSION.uses_parameter */
extern T1 T215f23(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARENTHESIS_EXPRESSION.uses_parameter */
extern T1 T212f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INFIX_EXPRESSION.uses_parameter */
extern T1 T211f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NE_NULL_EXPRESSION.uses_parameter */
extern T1 T210f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EQ_NULL_EXPRESSION.uses_parameter */
extern T1 T209f25(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PARAMETER_EXPRESSION.uses_parameter */
extern T1 T208f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOT_EXPRESSION.uses_parameter */
extern T1 T207f26(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_NOTNOT_EXPRESSION.uses_parameter */
extern T1 T206f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.uses_parameter */
extern T1 T203f27(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION.uses_parameter */
extern T1 T159f19(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.uses_parameter */
extern T1 T135f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_LOGICAL_EXPRESSION.uses_parameter */
extern T1 T133f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION_EXPRESSION.is_constant */
extern T1 T448f4(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.is_constant */
extern T1 T389f11(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.is_constant */
extern T1 T346f5(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.is_constant */
extern T1 T345f5(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.is_constant */
extern T1 T285f5(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.is_constant */
extern T1 T283f5(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.is_constant */
extern T1 T257f5(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.is_constant */
extern T1 T255f5(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.is_constant */
extern T1 T233f5(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.is_constant */
extern T1 T232f5(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.is_constant */
extern T1 T231f5(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.is_constant */
extern T1 T229f5(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.is_constant */
extern T1 T228f5(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.is_constant */
extern T1 T226f5(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.is_constant */
extern T1 T225f5(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.is_constant */
extern T1 T224f5(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.is_constant */
extern T1 T223f5(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.is_constant */
extern T1 T222f5(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.is_constant */
extern T1 T220f5(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.is_constant */
extern T1 T219f5(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.is_constant */
extern T1 T218f5(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.is_constant */
extern T1 T215f5(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.is_constant */
extern T1 T212f6(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.is_constant */
extern T1 T211f8(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.is_constant */
extern T1 T210f8(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.is_constant */
extern T1 T209f8(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.is_constant */
extern T1 T208f6(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.is_constant */
extern T1 T207f8(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.is_constant */
extern T1 T206f6(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.is_constant */
extern T1 T203f8(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.is_constant */
extern T1 T159f6(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.is_constant */
extern T1 T133f6(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.is_literal */
extern T1 T448f6(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.is_literal */
extern T1 T389f8(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.is_literal */
extern T1 T346f7(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.is_literal */
extern T1 T345f7(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.is_literal */
extern T1 T303f9(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_FUNCTION_EXPRESSION.is_constant */
extern T1 T303f10(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.is_literal */
extern T1 T285f7(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.is_literal */
extern T1 T283f7(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.is_literal */
extern T1 T257f7(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.is_literal */
extern T1 T255f8(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.is_literal */
extern T1 T233f8(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.is_literal */
extern T1 T232f9(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.is_literal */
extern T1 T231f8(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.is_literal */
extern T1 T230f8(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.is_literal */
extern T1 T229f8(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.is_literal */
extern T1 T228f10(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.is_literal */
extern T1 T227f8(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.is_literal */
extern T1 T226f8(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.is_literal */
extern T1 T225f8(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.is_literal */
extern T1 T224f8(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.is_literal */
extern T1 T223f8(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.is_literal */
extern T1 T222f8(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.is_literal */
extern T1 T220f9(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.is_literal */
extern T1 T219f10(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.is_literal */
extern T1 T212f8(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.is_literal */
extern T1 T211f10(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.is_literal */
extern T1 T210f5(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.is_literal */
extern T1 T209f5(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.is_literal */
extern T1 T208f8(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.is_literal */
extern T1 T207f10(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.is_literal */
extern T1 T206f8(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.is_literal */
extern T1 T203f10(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.is_literal */
extern T1 T159f8(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.is_literal */
extern T1 T135f8(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.is_literal */
extern T1 T133f8(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.path_name */
extern T0* T448f24(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.path_name */
extern T0* T389f26(GE_context* ac, T0* C);
extern T1 T389f26ot1(T0* a1, T0** a2);
/* XPLAIN_NOT_LIKE_EXPRESSION.path_name */
extern T0* T346f28(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.path_name */
extern T0* T345f28(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.path_name */
extern T0* T285f25(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.path_name */
extern T0* T283f25(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.path_name */
extern T0* T257f25(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.path_name */
extern T0* T255f25(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.path_name */
extern T0* T233f25(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.path_name */
extern T0* T232f26(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.path_name */
extern T0* T231f25(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.path_name */
extern T0* T230f25(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.path_name */
extern T0* T229f25(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.path_name */
extern T0* T228f27(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.path_name */
extern T0* T227f25(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.path_name */
extern T0* T226f25(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.path_name */
extern T0* T225f25(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.path_name */
extern T0* T224f25(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.path_name */
extern T0* T223f25(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.path_name */
extern T0* T222f25(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.path_name */
extern T0* T220f26(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.path_name */
extern T0* T219f27(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.path_name */
extern T0* T218f24(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.path_name */
extern T0* T215f24(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.path_name */
extern T0* T212f25(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.path_name */
extern T0* T211f27(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.path_name */
extern T0* T210f26(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.path_name */
extern T0* T209f26(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.path_name */
extern T0* T208f25(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.path_name */
extern T0* T207f27(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.path_name */
extern T0* T206f25(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.path_name */
extern T0* T203f28(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.path_name */
extern T0* T159f26(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.path_name */
extern T0* T135f25(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.path_name */
extern T0* T133f25(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION_EXPRESSION.column_name */
extern T0* T448f8(GE_context* ac, T0* C);
/* XPLAIN_ATTRIBUTE_EXPRESSION.column_name */
extern T0* T389f14(GE_context* ac, T0* C);
/* XPLAIN_NOT_LIKE_EXPRESSION.column_name */
extern T0* T346f12(GE_context* ac, T0* C);
/* XPLAIN_LIKE_EXPRESSION.column_name */
extern T0* T345f12(GE_context* ac, T0* C);
/* XPLAIN_LAST_AUTO_PK_EXPRESSION.column_name */
extern T0* T285f13(GE_context* ac, T0* C);
/* XPLAIN_SELECTION_EXPRESSION.column_name */
extern T0* T283f13(GE_context* ac, T0* C);
/* XPLAIN_VALUE_EXPRESSION.column_name */
extern T0* T257f13(GE_context* ac, T0* C);
/* XPLAIN_VARIABLE_EXPRESSION.column_name */
extern T0* T255f13(GE_context* ac, T0* C);
/* XPLAIN_SQL_EXPRESSION.column_name */
extern T0* T233f13(GE_context* ac, T0* C);
/* XPLAIN_USER_FUNCTION.column_name */
extern T0* T232f14(GE_context* ac, T0* C);
/* XPLAIN_UNMANAGED_PARAMETER_EXPRESSION.column_name */
extern T0* T231f13(GE_context* ac, T0* C);
/* XPLAIN_NUMBER_EXPRESSION.column_name */
extern T0* T230f13(GE_context* ac, T0* C);
/* XPLAIN_ID_FUNCTION.column_name */
extern T0* T229f13(GE_context* ac, T0* C);
/* XPLAIN_NEWDATE_FUNCTION.column_name */
extern T0* T228f15(GE_context* ac, T0* C);
/* XPLAIN_STRING_EXPRESSION.column_name */
extern T0* T227f13(GE_context* ac, T0* C);
/* XPLAIN_STRING_FUNCTION.column_name */
extern T0* T226f13(GE_context* ac, T0* C);
/* XPLAIN_REAL_FUNCTION.column_name */
extern T0* T225f13(GE_context* ac, T0* C);
/* XPLAIN_INTEGER_FUNCTION.column_name */
extern T0* T224f13(GE_context* ac, T0* C);
/* XPLAIN_DATEF_FUNCTION.column_name */
extern T0* T223f13(GE_context* ac, T0* C);
/* XPLAIN_COMBINE_FUNCTION.column_name */
extern T0* T222f13(GE_context* ac, T0* C);
/* XPLAIN_PREFIX_EXPRESSION.column_name */
extern T0* T220f14(GE_context* ac, T0* C);
/* XPLAIN_IF_EXPRESSION.column_name */
extern T0* T219f15(GE_context* ac, T0* C);
/* XPLAIN_LOGINNAME_EXPRESSION.column_name */
extern T0* T218f12(GE_context* ac, T0* C);
/* XPLAIN_SYSTEMDATE_EXPRESSION.column_name */
extern T0* T215f12(GE_context* ac, T0* C);
/* XPLAIN_PARENTHESIS_EXPRESSION.column_name */
extern T0* T212f13(GE_context* ac, T0* C);
/* XPLAIN_INFIX_EXPRESSION.column_name */
extern T0* T211f15(GE_context* ac, T0* C);
/* XPLAIN_NE_NULL_EXPRESSION.column_name */
extern T0* T210f14(GE_context* ac, T0* C);
/* XPLAIN_EQ_NULL_EXPRESSION.column_name */
extern T0* T209f14(GE_context* ac, T0* C);
/* XPLAIN_PARAMETER_EXPRESSION.column_name */
extern T0* T208f13(GE_context* ac, T0* C);
/* XPLAIN_NOT_EXPRESSION.column_name */
extern T0* T207f15(GE_context* ac, T0* C);
/* XPLAIN_NOTNOT_EXPRESSION.column_name */
extern T0* T206f13(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_INFIX_EXPRESSION.column_name */
extern T0* T203f15(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION_EXPRESSION.column_name */
extern T0* T159f10(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_VALUE_EXPRESSION.column_name */
extern T0* T135f13(GE_context* ac, T0* C);
/* XPLAIN_LOGICAL_EXPRESSION.column_name */
extern T0* T133f13(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.has_attribute */
extern T1 T157f33(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.has_attribute */
extern T1 T143f35(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TYPE.has_attribute */
extern T1 T129f25(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.new_init_attributes_cursor */
extern T0* T157f37(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].make */
extern T0* T408c10(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_INIT_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].ds_make */
extern void T408f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.new_init_attributes_cursor */
extern T0* T143f39(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.new_init_attributes_cursor */
extern T0* T129f15(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.has_auto_pk */
extern T1 T157f31(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.has_auto_pk */
extern T1 T143f33(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.has_auto_pk */
extern T1 T129f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.new_all_attributes_cursor */
extern T0* T157f29(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].make */
extern T0* T386c11(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_ALL_ATTRIBUTES_CURSOR [XPLAIN_ATTRIBUTE].ds_make */
extern void T386f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.new_all_attributes_cursor */
extern T0* T143f30(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.new_all_attributes_cursor */
extern T0* T129f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.has_updatable_attributes */
extern T1 T157f32(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.has_updatable_attributes */
extern T1 T143f34(GE_context* ac, T0* C);
/* XPLAIN_TYPE.has_updatable_attributes */
extern T1 T129f8(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.columndatatype */
extern T0* T157f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.columndatatype */
extern T0* T143f22(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.columndatatype */
extern T0* T129f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.has_non_constant_init */
extern T1 T157f35(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.has_non_constant_init */
extern T1 T143f37(GE_context* ac, T0* C);
/* XPLAIN_TYPE.has_non_constant_init */
extern T1 T129f16(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.has_non_literal_init */
extern T1 T157f36(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.has_non_literal_init */
extern T1 T143f38(GE_context* ac, T0* C);
/* XPLAIN_TYPE.has_non_literal_init */
extern T1 T129f17(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.q_sql_select_name */
extern T0* T157f15(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.q_sql_select_name */
extern T0* T143f18(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TYPE.q_sql_select_name */
extern T0* T129f19(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.sqltablename */
extern T0* T157f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.sqltablename */
extern T0* T143f29(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.sqltablename */
extern T0* T129f10(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.sqlcolumnidentifier */
extern T0* T157f21(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.sqlcolumnidentifier */
extern T0* T143f15(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TYPE.sqlcolumnidentifier */
extern T0* T129f18(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTENSION.find_attribute */
extern T0* T157f18(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.find_attribute */
extern T0* T143f27(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.find_attribute */
extern T0* T129f24(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.sqlname */
extern T0* T157f30(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.sqlname */
extern T0* T143f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.sqlname */
extern T0* T129f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.q_sqlpkname */
extern T0* T157f14(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.q_sqlpkname */
extern T0* T143f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.q_sqlpkname */
extern T0* T129f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.new_data_attributes_cursor */
extern T0* T157f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.make */
extern T0* T387c10(GE_context* ac, T0* a1, T0* a2);
/* XPLAIN_DATA_ATTRIBUTES_CURSOR.ds_make */
extern void T387f13(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.new_data_attributes_cursor */
extern T0* T143f32(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.new_data_attributes_cursor */
extern T0* T129f6(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.sqlpkname */
extern T0* T157f17(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.sqlpkname */
extern T0* T143f20(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.sqlpkname */
extern T0* T129f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION.hash_code */
extern T6 T157f38(GE_context* ac, T0* C);
/* XPLAIN_ASSERTION.hash_code */
extern T6 T143f40(GE_context* ac, T0* C);
/* XPLAIN_TYPE.hash_code */
extern T6 T129f28(GE_context* ac, T0* C);
/* XPLAIN_EXTENSION.quoted_name */
extern T0* T157f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_ASSERTION.quoted_name */
extern T0* T143f16(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE.quoted_name */
extern T0* T129f7(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_GET_INSERT_STATEMENT.uses_parameter */
extern T1 T269f5(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_LIST.uses_parameter */
extern T1 T161f9(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SELECTION_LIST.uses_parameter */
extern T1 T161f9p1(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_INSERT_STATEMENT.uses_parameter */
extern T1 T267f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_BASE_STATEMENT.uses_parameter */
extern T1 T177f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_TYPE_STATEMENT.uses_parameter */
extern T1 T174f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_SQL_STATEMENT.uses_parameter */
extern T1 T166f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_PROCEDURE_STATEMENT.uses_parameter */
extern T1 T165f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTEND_STATEMENT.uses_parameter */
extern T1 T156f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_EXTENSION_EXPRESSION_EXPRESSION.uses_parameter */
extern T1 T301f11(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_GET_STATEMENT.uses_parameter */
extern T1 T155f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_SELECTION_STATEMENT.uses_parameter */
extern T1 T152f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VALUE_STATEMENT.uses_parameter */
extern T1 T151f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_UPDATE_STATEMENT.uses_parameter */
extern T1 T150f4(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_DELETE_STATEMENT.uses_parameter */
extern T1 T148f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CASCADE_STATEMENT.uses_parameter */
extern T1 T146f12(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CASCADE_FUNCTION_EXPRESSION.uses_parameter */
extern T1 T147f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CONSTANT_STATEMENT.uses_parameter */
extern T1 T130f2(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT.uses_parameter */
extern T1 T127f3(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_GET_INSERT_STATEMENT.updates_attribute */
extern T1 T269f6(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_INSERT_STATEMENT.updates_attribute */
extern T1 T267f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_BASE_STATEMENT.updates_attribute */
extern T1 T177f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TYPE_STATEMENT.updates_attribute */
extern T1 T174f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_SQL_STATEMENT.updates_attribute */
extern T1 T166f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_PROCEDURE_STATEMENT.updates_attribute */
extern T1 T165f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_EXTEND_STATEMENT.updates_attribute */
extern T1 T156f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_GET_STATEMENT.updates_attribute */
extern T1 T155f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_VALUE_SELECTION_STATEMENT.updates_attribute */
extern T1 T152f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_VALUE_STATEMENT.updates_attribute */
extern T1 T151f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_UPDATE_STATEMENT.updates_attribute */
extern T1 T150f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_DELETE_STATEMENT.updates_attribute */
extern T1 T148f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_CASCADE_STATEMENT.updates_attribute */
extern T1 T146f13(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_CONSTANT_STATEMENT.updates_attribute */
extern T1 T130f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT.updates_attribute */
extern T1 T127f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_B_RESTRICTION.sqlcolumnconstraint */
extern T0* T342f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_I_REFERENCES.sqlcolumnconstraint */
extern T0* T250f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_A_REFERENCES.sqlcolumnconstraint */
extern T0* T247f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TRAJECTORY.sqlcolumnconstraint */
extern T0* T200f6(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_I_ENUMERATION.sqlcolumnconstraint */
extern T0* T196f11(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_A_ENUMERATION.sqlcolumnconstraint */
extern T0* T194f5(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_A_PATTERN.sqlcolumnconstraint */
extern T0* T192f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_REQUIRED.sqlcolumnconstraint */
extern T0* T122f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_B_RESTRICTION.sqldomainconstraint */
extern T0* T342f2(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_TRAJECTORY.sqldomainconstraint */
extern T0* T200f4(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_I_ENUMERATION.sqldomainconstraint */
extern T0* T196f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_A_ENUMERATION.sqldomainconstraint */
extern T0* T194f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_A_PATTERN.sqldomainconstraint */
extern T0* T192f3(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_REQUIRED.sqldomainconstraint */
extern T0* T122f2(GE_context* ac, T0* C, T0* a1, T0* a2);
/* [attached] ARRAY [DS_CELL [INTEGER_32]].item */
extern T0* T411f4(GE_context* ac, T0* C, T6 a1);
/* ARRAY [ANY].item */
extern T0* T37f4(GE_context* ac, T0* C, T6 a1);
/* [attached] ARRAY [[attached] STRING_8].item */
extern T0* T35f4(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL65.target_name */
extern T0* T64f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.target_name */
extern T0* T63f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.target_name */
extern T0* T62f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.target_name */
extern T0* T61f61(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.target_name */
extern T0* T60f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.target_name */
extern T0* T59f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.target_name */
extern T0* T58f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.target_name */
extern T0* T57f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.target_name */
extern T0* T56f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.target_name */
extern T0* T55f58(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.target_name */
extern T0* T54f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.target_name */
extern T0* T53f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.target_name */
extern T0* T52f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.target_name */
extern T0* T51f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.target_name */
extern T0* T50f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.target_name */
extern T0* T49f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.target_name */
extern T0* T48f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.target_name */
extern T0* T47f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.target_name */
extern T0* T46f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.target_name */
extern T0* T45f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.target_name */
extern T0* T44f59(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.target_name */
extern T0* T43f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.target_name */
extern T0* T42f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.target_name */
extern T0* T41f57(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.check_if_required */
extern T1 T64f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.check_if_required */
extern T1 T63f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.check_if_required */
extern T1 T62f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.check_if_required */
extern T1 T61f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.check_if_required */
extern T1 T60f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.check_if_required */
extern T1 T59f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.check_if_required */
extern T1 T58f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.check_if_required */
extern T1 T57f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.check_if_required */
extern T1 T56f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.check_if_required */
extern T1 T55f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.check_if_required */
extern T1 T54f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.check_if_required */
extern T1 T53f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.check_if_required */
extern T1 T52f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.check_if_required */
extern T1 T51f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.check_if_required */
extern T1 T50f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.check_if_required */
extern T1 T49f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.check_if_required */
extern T1 T48f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.check_if_required */
extern T1 T47f27(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.check_if_required */
extern T1 T46f27(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.check_if_required */
extern T1 T45f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.check_if_required */
extern T1 T44f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.check_if_required */
extern T1 T43f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.check_if_required */
extern T1 T42f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.check_if_required */
extern T1 T41f26(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.createautoprimarykey */
extern T1 T64f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.autoprimarykeysupported */
extern T1 T64f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.createautoprimarykey */
extern T1 T63f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.autoprimarykeysupported */
extern T1 T63f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.createautoprimarykey */
extern T1 T62f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.autoprimarykeysupported */
extern T1 T62f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.createautoprimarykey */
extern T1 T61f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.autoprimarykeysupported */
extern T1 T61f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.createautoprimarykey */
extern T1 T60f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createautoprimarykey */
extern T1 T59f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.autoprimarykeysupported */
extern T1 T59f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.createautoprimarykey */
extern T1 T58f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.autoprimarykeysupported */
extern T1 T58f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.createautoprimarykey */
extern T1 T57f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.autoprimarykeysupported */
extern T1 T57f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.createautoprimarykey */
extern T1 T56f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.autoprimarykeysupported */
extern T1 T56f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.createautoprimarykey */
extern T1 T55f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.autoprimarykeysupported */
extern T1 T55f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.createautoprimarykey */
extern T1 T54f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.autoprimarykeysupported */
extern T1 T54f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.createautoprimarykey */
extern T1 T53f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.autoprimarykeysupported */
extern T1 T53f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.createautoprimarykey */
extern T1 T52f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.autoprimarykeysupported */
extern T1 T52f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createautoprimarykey */
extern T1 T51f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.createautoprimarykey */
extern T1 T50f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.autoprimarykeysupported */
extern T1 T50f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.createautoprimarykey */
extern T1 T49f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.autoprimarykeysupported */
extern T1 T49f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.createautoprimarykey */
extern T1 T48f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.autoprimarykeysupported */
extern T1 T48f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createautoprimarykey */
extern T1 T47f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.autoprimarykeysupported */
extern T1 T47f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createautoprimarykey */
extern T1 T46f29(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.autoprimarykeysupported */
extern T1 T46f31(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.createautoprimarykey */
extern T1 T45f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.autoprimarykeysupported */
extern T1 T45f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createautoprimarykey */
extern T1 T44f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.autoprimarykeysupported */
extern T1 T44f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.createautoprimarykey */
extern T1 T43f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.autoprimarykeysupported */
extern T1 T43f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.createautoprimarykey */
extern T1 T42f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.autoprimarykeysupported */
extern T1 T42f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.createautoprimarykey */
extern T1 T41f28(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.autoprimarykeysupported */
extern T1 T41f30(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.table_pk_name */
extern T0* T64f58(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.table_pk_name */
extern T0* T63f58(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.table_pk_name */
extern T0* T62f58(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.table_pk_name */
extern T0* T61f58(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.table_pk_name */
extern T0* T60f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.table_pk_name */
extern T0* T59f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.table_pk_name */
extern T0* T58f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.table_pk_name */
extern T0* T57f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.table_pk_name */
extern T0* T56f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.table_pk_name */
extern T0* T55f54(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.table_pk_name */
extern T0* T54f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.table_pk_name */
extern T0* T53f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.table_pk_name */
extern T0* T52f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.table_pk_name */
extern T0* T51f56(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.table_pk_name */
extern T0* T50f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.table_pk_name */
extern T0* T49f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.table_pk_name */
extern T0* T48f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.table_pk_name */
extern T0* T47f56(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.table_pk_name */
extern T0* T46f56(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.table_pk_name */
extern T0* T45f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.table_pk_name */
extern T0* T44f55(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.table_pk_name */
extern T0* T43f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.table_pk_name */
extern T0* T42f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.table_pk_name */
extern T0* T41f53(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.table_name */
extern T0* T64f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.table_name */
extern T0* T63f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.table_name */
extern T0* T62f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.table_name */
extern T0* T61f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.table_name */
extern T0* T60f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.table_name */
extern T0* T59f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.table_name */
extern T0* T58f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.table_name */
extern T0* T57f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.table_name */
extern T0* T56f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.table_name */
extern T0* T55f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.table_name */
extern T0* T54f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.table_name */
extern T0* T53f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.table_name */
extern T0* T52f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.table_name */
extern T0* T51f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.table_name */
extern T0* T50f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.table_name */
extern T0* T49f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.table_name */
extern T0* T48f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.table_name */
extern T0* T47f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.table_name */
extern T0* T46f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.table_name */
extern T0* T45f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.table_name */
extern T0* T44f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.table_name */
extern T0* T43f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.table_name */
extern T0* T42f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.table_name */
extern T0* T41f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.assertion_name */
extern T0* T64f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.assertion_name */
extern T0* T63f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.assertion_name */
extern T0* T62f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.assertion_name */
extern T0* T61f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.assertion_name */
extern T0* T60f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.assertion_name */
extern T0* T59f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.assertion_name */
extern T0* T58f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.assertion_name */
extern T0* T57f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.assertion_name */
extern T0* T56f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.assertion_name */
extern T0* T55f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.assertion_name */
extern T0* T54f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.assertion_name */
extern T0* T53f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.assertion_name */
extern T0* T52f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.assertion_name */
extern T0* T51f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.assertion_name */
extern T0* T50f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.assertion_name */
extern T0* T49f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.assertion_name */
extern T0* T48f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.assertion_name */
extern T0* T47f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.assertion_name */
extern T0* T46f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.assertion_name */
extern T0* T45f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.assertion_name */
extern T0* T44f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.assertion_name */
extern T0* T43f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.assertion_name */
extern T0* T42f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.assertion_name */
extern T0* T41f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_notnot_expression */
extern T0* T64f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.supportstrueboolean */
extern T1 T64f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sql_notnot_expression */
extern T0* T63f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.supportstrueboolean */
extern T1 T63f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sql_notnot_expression */
extern T0* T62f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.supportstrueboolean */
extern T1 T62f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sql_notnot_expression */
extern T0* T61f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.supportstrueboolean */
extern T1 T61f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sql_notnot_expression */
extern T0* T60f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_notnot_expression */
extern T0* T59f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.supportstrueboolean */
extern T1 T59f175(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sql_notnot_expression */
extern T0* T58f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.supportstrueboolean */
extern T1 T58f175(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sql_notnot_expression */
extern T0* T57f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.supportstrueboolean */
extern T1 T57f175(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sql_notnot_expression */
extern T0* T56f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.supportstrueboolean */
extern T1 T56f175(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sql_notnot_expression */
extern T0* T55f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.supportstrueboolean */
extern T1 T55f175(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sql_notnot_expression */
extern T0* T54f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.supportstrueboolean */
extern T1 T54f167(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sql_notnot_expression */
extern T0* T53f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.supportstrueboolean */
extern T1 T53f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sql_notnot_expression */
extern T0* T52f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.supportstrueboolean */
extern T1 T52f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sql_notnot_expression */
extern T0* T51f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.supportstrueboolean */
extern T1 T51f159(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sql_notnot_expression */
extern T0* T50f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.supportstrueboolean */
extern T1 T50f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sql_notnot_expression */
extern T0* T49f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.supportstrueboolean */
extern T1 T49f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sql_notnot_expression */
extern T0* T48f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.supportstrueboolean */
extern T1 T48f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sql_notnot_expression */
extern T0* T47f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.supportstrueboolean */
extern T1 T47f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sql_notnot_expression */
extern T0* T46f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.supportstrueboolean */
extern T1 T46f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sql_notnot_expression */
extern T0* T45f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.supportstrueboolean */
extern T1 T45f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sql_notnot_expression */
extern T0* T44f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.supportstrueboolean */
extern T1 T44f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sql_notnot_expression */
extern T0* T43f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.supportstrueboolean */
extern T1 T43f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sql_notnot_expression */
extern T0* T42f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.supportstrueboolean */
extern T1 T42f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sql_notnot_expression */
extern T0* T41f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.supportstrueboolean */
extern T1 T41f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sql_not_expression */
extern T0* T64f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_not_expression */
extern T0* T63f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_not_expression */
extern T0* T62f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_not_expression */
extern T0* T61f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_not_expression */
extern T0* T60f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_not_expression */
extern T0* T59f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_not_expression */
extern T0* T58f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_not_expression */
extern T0* T57f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_not_expression */
extern T0* T56f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_not_expression */
extern T0* T55f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_not_expression */
extern T0* T54f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_not_expression */
extern T0* T53f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_not_expression */
extern T0* T52f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_not_expression */
extern T0* T51f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_not_expression */
extern T0* T50f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_not_expression */
extern T0* T49f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_not_expression */
extern T0* T48f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_not_expression */
extern T0* T47f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_not_expression */
extern T0* T46f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_not_expression */
extern T0* T45f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_not_expression */
extern T0* T44f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_not_expression */
extern T0* T43f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_not_expression */
extern T0* T42f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_not_expression */
extern T0* T41f88(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlsysfunction_system_user */
extern T0* T64f107(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlsysfunction_system_user */
extern T0* T63f106(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlsysfunction_system_user */
extern T0* T62f106(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlsysfunction_system_user */
extern T0* T61f106(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlsysfunction_system_user */
extern T0* T60f92(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlsysfunction_system_user */
extern T0* T59f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlsysfunction_system_user */
extern T0* T58f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlsysfunction_system_user */
extern T0* T57f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlsysfunction_system_user */
extern T0* T56f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlsysfunction_system_user */
extern T0* T55f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlsysfunction_system_user */
extern T0* T54f112(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlsysfunction_system_user */
extern T0* T53f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlsysfunction_system_user */
extern T0* T52f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlsysfunction_system_user */
extern T0* T51f105(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlsysfunction_system_user */
extern T0* T50f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlsysfunction_system_user */
extern T0* T49f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlsysfunction_system_user */
extern T0* T48f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlsysfunction_system_user */
extern T0* T47f112(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlsysfunction_system_user */
extern T0* T46f112(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlsysfunction_system_user */
extern T0* T45f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlsysfunction_system_user */
extern T0* T44f108(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlsysfunction_system_user */
extern T0* T43f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlsysfunction_system_user */
extern T0* T42f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlsysfunction_system_user */
extern T0* T41f91(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sql_combine_expression */
extern T0* T64f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_string_combine_end */
extern T0* T64f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sql_string_combine_start */
extern T0* T64f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sql_combine_expression */
extern T0* T63f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_string_combine_end */
extern T0* T63f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sql_string_combine_start */
extern T0* T63f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sql_combine_expression */
extern T0* T62f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_string_combine_end */
extern T0* T62f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sql_string_combine_start */
extern T0* T62f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sql_combine_expression */
extern T0* T61f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_string_combine_end */
extern T0* T61f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sql_string_combine_start */
extern T0* T61f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sql_combine_expression */
extern T0* T60f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_combine_expression */
extern T0* T59f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_combine_expression */
extern T0* T58f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_combine_expression */
extern T0* T57f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_combine_expression */
extern T0* T56f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_combine_expression */
extern T0* T55f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_combine_expression */
extern T0* T54f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_combine_expression */
extern T0* T53f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_string_combine_end */
extern T0* T53f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sql_string_combine_separator */
extern T0* T53f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sql_string_combine_start */
extern T0* T53f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sql_combine_expression */
extern T0* T52f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_string_combine_end */
extern T0* T52f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sql_string_combine_separator */
extern T0* T52f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sql_string_combine_start */
extern T0* T52f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sql_combine_expression */
extern T0* T51f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_combine_expression */
extern T0* T50f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_string_combine_end */
extern T0* T50f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sql_string_combine_separator */
extern T0* T50f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sql_string_combine_start */
extern T0* T50f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sql_combine_expression */
extern T0* T49f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_string_combine_end */
extern T0* T49f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sql_string_combine_separator */
extern T0* T49f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sql_string_combine_start */
extern T0* T49f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sql_combine_expression */
extern T0* T48f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_string_combine_end */
extern T0* T48f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sql_string_combine_separator */
extern T0* T48f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sql_string_combine_start */
extern T0* T48f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sql_combine_expression */
extern T0* T47f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_combine_expression */
extern T0* T46f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_combine_expression */
extern T0* T45f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_string_combine_end */
extern T0* T45f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sql_string_combine_separator */
extern T0* T45f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sql_string_combine_start */
extern T0* T45f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sql_combine_expression */
extern T0* T44f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_combine_expression */
extern T0* T43f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_string_combine_end */
extern T0* T43f145(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sql_string_combine_start */
extern T0* T43f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sql_combine_expression */
extern T0* T42f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_string_combine_end */
extern T0* T42f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sql_string_combine_separator */
extern T0* T42f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sql_string_combine_start */
extern T0* T42f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sql_combine_expression */
extern T0* T41f92(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_string_combine_end */
extern T0* T41f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sql_string_combine_separator */
extern T0* T41f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sql_string_combine_start */
extern T0* T41f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sql_cast_to_date */
extern T0* T64f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_sql_cast_to_date */
extern T0* T64f164(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_cast_to_date */
extern T0* T63f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.do_sql_cast_to_date */
extern T0* T63f163(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_cast_to_date */
extern T0* T62f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.do_sql_cast_to_date */
extern T0* T62f163(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_cast_to_date */
extern T0* T61f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.do_sql_cast_to_date */
extern T0* T61f163(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_cast_to_date */
extern T0* T60f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_cast_to_date */
extern T0* T59f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_cast_to_date */
extern T0* T58f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_cast_to_date */
extern T0* T57f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_cast_to_date */
extern T0* T56f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_cast_to_date */
extern T0* T55f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_cast_to_date */
extern T0* T54f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_cast_to_date */
extern T0* T53f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.do_sql_cast_to_date */
extern T0* T53f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_cast_to_date */
extern T0* T52f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.do_sql_cast_to_date */
extern T0* T52f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_cast_to_date */
extern T0* T51f107(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_cast_to_date */
extern T0* T50f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.do_sql_cast_to_date */
extern T0* T50f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_cast_to_date */
extern T0* T49f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.do_sql_cast_to_date */
extern T0* T49f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_cast_to_date */
extern T0* T48f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.do_sql_cast_to_date */
extern T0* T48f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_cast_to_date */
extern T0* T47f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_cast_to_date */
extern T0* T46f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_cast_to_date */
extern T0* T45f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.do_sql_cast_to_date */
extern T0* T45f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_cast_to_date */
extern T0* T44f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_cast_to_date */
extern T0* T43f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.do_sql_cast_to_date */
extern T0* T43f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_cast_to_date */
extern T0* T42f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.do_sql_cast_to_date */
extern T0* T42f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_cast_to_date */
extern T0* T41f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.do_sql_cast_to_date */
extern T0* T41f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_cast_to_integer */
extern T0* T64f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_sql_cast_to_integer */
extern T0* T64f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_cast_to_integer */
extern T0* T63f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.do_sql_cast_to_integer */
extern T0* T63f164(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_cast_to_integer */
extern T0* T62f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.do_sql_cast_to_integer */
extern T0* T62f164(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_cast_to_integer */
extern T0* T61f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.do_sql_cast_to_integer */
extern T0* T61f164(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_cast_to_integer */
extern T0* T60f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_cast_to_integer */
extern T0* T59f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_cast_to_integer */
extern T0* T58f119(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_cast_to_integer */
extern T0* T57f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_cast_to_integer */
extern T0* T56f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_cast_to_integer */
extern T0* T55f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_cast_to_integer */
extern T0* T54f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_cast_to_integer */
extern T0* T53f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.do_sql_cast_to_integer */
extern T0* T53f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_cast_to_integer */
extern T0* T52f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.do_sql_cast_to_integer */
extern T0* T52f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_cast_to_integer */
extern T0* T51f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_cast_to_integer */
extern T0* T50f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.do_sql_cast_to_integer */
extern T0* T50f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_cast_to_integer */
extern T0* T49f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.do_sql_cast_to_integer */
extern T0* T49f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_cast_to_integer */
extern T0* T48f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.do_sql_cast_to_integer */
extern T0* T48f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_cast_to_integer */
extern T0* T47f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_cast_to_integer */
extern T0* T46f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_cast_to_integer */
extern T0* T45f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.do_sql_cast_to_integer */
extern T0* T45f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_cast_to_integer */
extern T0* T44f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_cast_to_integer */
extern T0* T43f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.do_sql_cast_to_integer */
extern T0* T43f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_cast_to_integer */
extern T0* T42f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.do_sql_cast_to_integer */
extern T0* T42f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_cast_to_integer */
extern T0* T41f94(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.do_sql_cast_to_integer */
extern T0* T41f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_cast_to_real */
extern T0* T64f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_sql_cast_to_real */
extern T0* T64f166(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_cast_to_real */
extern T0* T63f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.do_sql_cast_to_real */
extern T0* T63f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_cast_to_real */
extern T0* T62f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.do_sql_cast_to_real */
extern T0* T62f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_cast_to_real */
extern T0* T61f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.do_sql_cast_to_real */
extern T0* T61f165(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_cast_to_real */
extern T0* T60f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_cast_to_real */
extern T0* T59f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_cast_to_real */
extern T0* T58f120(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_cast_to_real */
extern T0* T57f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_cast_to_real */
extern T0* T56f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_cast_to_real */
extern T0* T55f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_cast_to_real */
extern T0* T54f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_cast_to_real */
extern T0* T53f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.do_sql_cast_to_real */
extern T0* T53f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_cast_to_real */
extern T0* T52f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.do_sql_cast_to_real */
extern T0* T52f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_cast_to_real */
extern T0* T51f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_cast_to_real */
extern T0* T50f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.do_sql_cast_to_real */
extern T0* T50f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_cast_to_real */
extern T0* T49f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.do_sql_cast_to_real */
extern T0* T49f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_cast_to_real */
extern T0* T48f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.do_sql_cast_to_real */
extern T0* T48f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_cast_to_real */
extern T0* T47f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_cast_to_real */
extern T0* T46f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_cast_to_real */
extern T0* T45f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.do_sql_cast_to_real */
extern T0* T45f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_cast_to_real */
extern T0* T44f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_cast_to_real */
extern T0* T43f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.do_sql_cast_to_real */
extern T0* T43f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_cast_to_real */
extern T0* T42f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.do_sql_cast_to_real */
extern T0* T42f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_cast_to_real */
extern T0* T41f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.do_sql_cast_to_real */
extern T0* T41f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_cast_to_string */
extern T0* T64f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.do_sql_cast_to_string */
extern T0* T64f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_cast_to_string */
extern T0* T63f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.do_sql_cast_to_string */
extern T0* T63f166(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_cast_to_string */
extern T0* T62f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.do_sql_cast_to_string */
extern T0* T62f166(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_cast_to_string */
extern T0* T61f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.do_sql_cast_to_string */
extern T0* T61f166(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_cast_to_string */
extern T0* T60f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_cast_to_string */
extern T0* T59f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_cast_to_string */
extern T0* T58f121(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_cast_to_string */
extern T0* T57f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_cast_to_string */
extern T0* T56f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_cast_to_string */
extern T0* T55f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_cast_to_string */
extern T0* T54f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_cast_to_string */
extern T0* T53f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.do_sql_cast_to_string */
extern T0* T53f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_cast_to_string */
extern T0* T52f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.do_sql_cast_to_string */
extern T0* T52f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_cast_to_string */
extern T0* T51f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_cast_to_string */
extern T0* T50f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.do_sql_cast_to_string */
extern T0* T50f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_cast_to_string */
extern T0* T49f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.do_sql_cast_to_string */
extern T0* T49f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_cast_to_string */
extern T0* T48f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.do_sql_cast_to_string */
extern T0* T48f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_cast_to_string */
extern T0* T47f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_cast_to_string */
extern T0* T46f117(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_cast_to_string */
extern T0* T45f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.do_sql_cast_to_string */
extern T0* T45f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_cast_to_string */
extern T0* T44f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_cast_to_string */
extern T0* T43f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.do_sql_cast_to_string */
extern T0* T43f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_cast_to_string */
extern T0* T42f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.do_sql_cast_to_string */
extern T0* T42f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_cast_to_string */
extern T0* T41f96(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.do_sql_cast_to_string */
extern T0* T41f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_newdate */
extern T0* T64f114(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.sql_newdate */
extern T0* T63f113(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.sql_newdate */
extern T0* T62f113(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.sql_newdate */
extern T0* T61f113(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_SQLITE_3.sql_newdate */
extern T0* T60f99(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.sql_newdate */
extern T0* T59f123(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.sql_newdate */
extern T0* T58f123(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T58f123ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_81.sql_newdate */
extern T0* T57f124(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T57f124ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_82.sql_newdate */
extern T0* T56f124(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T56f124ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_PGSQL_95.sql_newdate */
extern T0* T55f124(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
extern T1 T55f124ot1(T0* a1, T0** a2);
/* SQL_GENERATOR_ORACLE.sql_newdate */
extern T0* T54f119(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL322.sql_newdate */
extern T0* T53f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL4.sql_newdate */
extern T0* T52f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.sql_newdate */
extern T0* T51f112(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSQL.sql_newdate */
extern T0* T50f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS2000.sql_newdate */
extern T0* T49f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS97.sql_newdate */
extern T0* T48f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.sql_newdate */
extern T0* T47f119(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.sql_newdate */
extern T0* T46f119(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FOXPRO.sql_newdate */
extern T0* T45f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.sql_newdate */
extern T0* T44f115(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_6.sql_newdate */
extern T0* T43f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_BASIC.sql_newdate */
extern T0* T42f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ANSI.sql_newdate */
extern T0* T41f98(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.sp_use_param */
extern T0* T64f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_use_param */
extern T0* T63f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_use_param */
extern T0* T62f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_use_param */
extern T0* T61f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sp_use_param */
extern T0* T60f90(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_use_param */
extern T0* T59f78(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_use_param */
extern T0* T58f78(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_use_param */
extern T0* T57f78(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_use_param */
extern T0* T56f78(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_use_param */
extern T0* T55f78(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_use_param */
extern T0* T54f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sp_use_param */
extern T0* T53f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sp_use_param */
extern T0* T52f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_use_param */
extern T0* T51f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sp_use_param */
extern T0* T50f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sp_use_param */
extern T0* T49f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sp_use_param */
extern T0* T48f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_use_param */
extern T0* T47f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_use_param */
extern T0* T46f80(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sp_use_param */
extern T0* T45f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_use_param */
extern T0* T44f79(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.no_space_identifier */
extern T0* T44f156(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.maxidentifierlength */
extern T6 T44f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sp_use_param */
extern T0* T43f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sp_use_param */
extern T0* T42f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sp_use_param */
extern T0* T41f89(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlgetconstant */
extern T0* T64f125(GE_context* ac, T0* C, T0* a1);
/* XPLAIN_VARIABLE.quoted_name */
extern T0* T179f7(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlgetconstant */
extern T0* T63f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlgetconstant */
extern T0* T62f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlgetconstant */
extern T0* T61f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlgetconstant */
extern T0* T60f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlgetconstant */
extern T0* T59f134(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlgetconstant */
extern T0* T58f134(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlgetconstant */
extern T0* T57f135(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlgetconstant */
extern T0* T56f135(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlgetconstant */
extern T0* T55f135(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlgetconstant */
extern T0* T54f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sqlgetconstant */
extern T0* T53f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sqlgetconstant */
extern T0* T52f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlgetconstant */
extern T0* T51f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sqlgetconstant */
extern T0* T50f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sqlgetconstant */
extern T0* T49f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sqlgetconstant */
extern T0* T48f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlgetconstant */
extern T0* T47f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlgetconstant */
extern T0* T46f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sqlgetconstant */
extern T0* T45f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlgetconstant */
extern T0* T44f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sqlgetconstant */
extern T0* T43f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sqlgetconstant */
extern T0* T42f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sqlgetconstant */
extern T0* T41f108(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.value_identifier */
extern T0* T64f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.value_identifier */
extern T0* T63f98(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.value_identifier */
extern T0* T62f98(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.value_identifier */
extern T0* T61f98(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.value_identifier */
extern T0* T60f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.value_identifier */
extern T0* T59f187(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.value_identifier */
extern T0* T58f187(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.value_identifier */
extern T0* T57f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.value_identifier */
extern T0* T56f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.value_identifier */
extern T0* T55f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.value_identifier */
extern T0* T54f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.value_identifier */
extern T0* T53f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.value_identifier */
extern T0* T52f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.value_identifier */
extern T0* T51f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.value_identifier */
extern T0* T50f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.value_identifier */
extern T0* T49f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.value_identifier */
extern T0* T48f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.value_identifier */
extern T0* T47f179(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.value_identifier */
extern T0* T46f179(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.value_identifier */
extern T0* T45f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.value_identifier */
extern T0* T44f179(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.value_identifier */
extern T0* T44f179p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.value_identifier */
extern T0* T43f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.value_identifier */
extern T0* T42f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.value_identifier */
extern T0* T41f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.quoted_value_identifier */
extern T0* T60f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.quoted_value_identifier */
extern T0* T59f135(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.quoted_value_identifier */
extern T0* T58f135(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.quoted_value_identifier */
extern T0* T57f136(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.quoted_value_identifier */
extern T0* T56f136(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.quoted_value_identifier */
extern T0* T55f136(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.quoted_value_identifier */
extern T0* T54f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.quoted_value_identifier */
extern T0* T53f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.quoted_value_identifier */
extern T0* T52f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.quoted_value_identifier */
extern T0* T51f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.quoted_value_identifier */
extern T0* T50f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.quoted_value_identifier */
extern T0* T49f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.quoted_value_identifier */
extern T0* T48f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.quoted_value_identifier */
extern T0* T47f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.quoted_value_identifier */
extern T0* T46f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.quoted_value_identifier */
extern T0* T45f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.quoted_value_identifier */
extern T0* T44f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.quoted_value_identifier */
extern T0* T43f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.quoted_value_identifier */
extern T0* T42f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.quoted_value_identifier */
extern T0* T41f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlgetvalue */
extern T0* T64f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlgetvalue_outside_sp */
extern T0* T64f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlgetvalue_inside_sp */
extern T0* T64f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlgetvalue */
extern T0* T63f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlgetvalue_outside_sp */
extern T0* T63f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlgetvalue_inside_sp */
extern T0* T63f171(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlgetvalue */
extern T0* T62f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlgetvalue_outside_sp */
extern T0* T62f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlgetvalue_inside_sp */
extern T0* T62f171(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlgetvalue */
extern T0* T61f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlgetvalue_outside_sp */
extern T0* T61f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlgetvalue_inside_sp */
extern T0* T61f171(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlgetvalue */
extern T0* T60f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlgetvalue_outside_sp */
extern T0* T60f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlgetvalue */
extern T0* T59f136(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlgetvalue_outside_sp */
extern T0* T59f189(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlgetvalue_inside_sp */
extern T0* T59f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlgetvalue */
extern T0* T58f136(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlgetvalue_outside_sp */
extern T0* T58f189(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlgetvalue_inside_sp */
extern T0* T58f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlgetvalue */
extern T0* T57f137(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlgetvalue_outside_sp */
extern T0* T57f190(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlgetvalue_inside_sp */
extern T0* T57f189(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlgetvalue */
extern T0* T56f137(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlgetvalue_outside_sp */
extern T0* T56f190(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlgetvalue_inside_sp */
extern T0* T56f189(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlgetvalue */
extern T0* T55f137(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlgetvalue_outside_sp */
extern T0* T55f190(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlgetvalue_inside_sp */
extern T0* T55f189(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlgetvalue */
extern T0* T54f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlgetvalue_outside_sp */
extern T0* T54f184(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlgetvalue_inside_sp */
extern T0* T54f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sqlgetvalue */
extern T0* T53f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sqlgetvalue_outside_sp */
extern T0* T53f152(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sqlgetvalue */
extern T0* T52f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sqlgetvalue_outside_sp */
extern T0* T52f152(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlgetvalue */
extern T0* T51f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlgetvalue_outside_sp */
extern T0* T51f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlgetvalue_inside_sp */
extern T0* T51f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sqlgetvalue */
extern T0* T50f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sqlgetvalue_outside_sp */
extern T0* T50f151(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sqlgetvalue */
extern T0* T49f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sqlgetvalue_outside_sp */
extern T0* T49f151(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sqlgetvalue */
extern T0* T48f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sqlgetvalue_outside_sp */
extern T0* T48f151(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlgetvalue */
extern T0* T47f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlgetvalue_outside_sp */
extern T0* T47f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlgetvalue_inside_sp */
extern T0* T47f180(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlgetvalue */
extern T0* T46f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlgetvalue_outside_sp */
extern T0* T46f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlgetvalue_inside_sp */
extern T0* T46f180(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sqlgetvalue */
extern T0* T45f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sqlgetvalue_outside_sp */
extern T0* T45f151(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlgetvalue */
extern T0* T44f128(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlgetvalue_outside_sp */
extern T0* T44f181(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlgetvalue_inside_sp */
extern T0* T44f180(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sqlgetvalue */
extern T0* T43f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sqlgetvalue_outside_sp */
extern T0* T43f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sqlgetvalue */
extern T0* T42f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sqlgetvalue_outside_sp */
extern T0* T42f152(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sqlgetvalue */
extern T0* T41f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sqlgetvalue_outside_sp */
extern T0* T41f152(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_last_auto_generated_primary_key */
extern T0* T64f127(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_last_auto_generated_primary_key */
extern T0* T63f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_last_auto_generated_primary_key */
extern T0* T62f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_last_auto_generated_primary_key */
extern T0* T61f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_last_auto_generated_primary_key */
extern T0* T60f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_last_auto_generated_primary_key */
extern T0* T59f137(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_last_auto_generated_primary_key */
extern T0* T58f137(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_last_auto_generated_primary_key */
extern T0* T57f138(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_last_auto_generated_primary_key */
extern T0* T56f138(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_last_auto_generated_primary_key */
extern T0* T55f138(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_last_auto_generated_primary_key */
extern T0* T54f133(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_last_auto_generated_primary_key */
extern T0* T53f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_last_auto_generated_primary_key */
extern T0* T52f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_last_auto_generated_primary_key */
extern T0* T51f126(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_last_auto_generated_primary_key */
extern T0* T50f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_last_auto_generated_primary_key */
extern T0* T49f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_last_auto_generated_primary_key */
extern T0* T48f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_last_auto_generated_primary_key */
extern T0* T47f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_last_auto_generated_primary_key */
extern T0* T46f95(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_last_auto_generated_primary_key */
extern T0* T45f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_last_auto_generated_primary_key */
extern T0* T44f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_last_auto_generated_primary_key */
extern T0* T43f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_last_auto_generated_primary_key */
extern T0* T42f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_last_auto_generated_primary_key */
extern T0* T41f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_extension_function */
extern T0* T64f130(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_select_function_as_left_outer_join */
extern T0* T64f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_select_function_limit_before */
extern T0* T64f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_extension_function */
extern T0* T63f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_select_function_as_left_outer_join */
extern T0* T63f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_select_function_limit_before */
extern T0* T63f187(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_extension_function */
extern T0* T62f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_select_function_as_left_outer_join */
extern T0* T62f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_select_function_limit_before */
extern T0* T62f187(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_extension_function */
extern T0* T61f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_select_function_as_left_outer_join */
extern T0* T61f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_select_function_limit_before */
extern T0* T61f187(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_extension_function */
extern T0* T60f116(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_select_function_as_left_outer_join */
extern T0* T60f157(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_select_function_limit_before */
extern T0* T60f170(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_extension_function */
extern T0* T59f139(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_select_function_as_left_outer_join */
extern T0* T59f190(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_select_function_limit_before */
extern T0* T59f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_extension_function */
extern T0* T58f139(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_select_function_as_left_outer_join */
extern T0* T58f190(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_select_function_limit_before */
extern T0* T58f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_extension_function */
extern T0* T57f140(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_select_function_as_left_outer_join */
extern T0* T57f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_select_function_limit_before */
extern T0* T57f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_extension_function */
extern T0* T56f140(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_select_function_as_left_outer_join */
extern T0* T56f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_select_function_limit_before */
extern T0* T56f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_extension_function */
extern T0* T55f140(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_select_function_as_left_outer_join */
extern T0* T55f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_select_function_limit_before */
extern T0* T55f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_extension_function */
extern T0* T54f136(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_select_function_as_left_outer_join */
extern T0* T54f187(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_select_function_limit_before */
extern T0* T54f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_extension_function */
extern T0* T53f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_select_function_as_left_outer_join */
extern T0* T53f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_select_function_limit_before */
extern T0* T53f168(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_extension_function */
extern T0* T52f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_select_function_as_left_outer_join */
extern T0* T52f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_select_function_limit_before */
extern T0* T52f168(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_extension_function */
extern T0* T51f129(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_select_function_as_left_outer_join */
extern T0* T51f177(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_select_function_limit_before */
extern T0* T51f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_extension_function */
extern T0* T50f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_select_function_as_left_outer_join */
extern T0* T50f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_select_function_limit_before */
extern T0* T50f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_extension_function */
extern T0* T49f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_select_function_as_left_outer_join */
extern T0* T49f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_select_function_limit_before */
extern T0* T49f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_extension_function */
extern T0* T48f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_select_function_as_left_outer_join */
extern T0* T48f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_select_function_limit_before */
extern T0* T48f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_extension_function */
extern T0* T47f134(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_function_as_left_outer_join */
extern T0* T47f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_function_limit_before */
extern T0* T47f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_extension_function */
extern T0* T46f134(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_select_function_as_left_outer_join */
extern T0* T46f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_select_function_limit_before */
extern T0* T46f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_extension_function */
extern T0* T45f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_select_function_as_left_outer_join */
extern T0* T45f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_select_function_limit_before */
extern T0* T45f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_extension_function */
extern T0* T44f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_select_function_as_left_outer_join */
extern T0* T44f184(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_select_function_limit_before */
extern T0* T44f197(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_extension_function */
extern T0* T43f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_select_function_as_left_outer_join */
extern T0* T43f156(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_select_function_limit_before */
extern T0* T43f169(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_extension_function */
extern T0* T42f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_select_function_as_left_outer_join */
extern T0* T42f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_select_function_limit_before */
extern T0* T42f168(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_extension_function */
extern T0* T41f115(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_select_function_as_left_outer_join */
extern T0* T41f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_select_function_limit_before */
extern T0* T41f168(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_select_for_extension_function */
extern T0* T64f129(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.do_sql_select_for_extension_function */
extern T0* T64f174(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sql_extend_insert_missing_rows */
extern T0* T64f187(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.q_sql_insert_name */
extern T0* T143f14(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_ASSERTION.sql_insert_name */
extern T0* T143f19(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sql_select_for_extension_function */
extern T0* T63f128(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.do_sql_select_for_extension_function */
extern T0* T63f173(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sql_extend_insert_missing_rows */
extern T0* T63f186(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sql_select_for_extension_function */
extern T0* T62f128(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.do_sql_select_for_extension_function */
extern T0* T62f173(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sql_extend_insert_missing_rows */
extern T0* T62f186(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sql_select_for_extension_function */
extern T0* T61f128(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.do_sql_select_for_extension_function */
extern T0* T61f173(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sql_extend_insert_missing_rows */
extern T0* T61f186(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sql_select_for_extension_function */
extern T0* T60f115(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.do_sql_select_for_extension_function */
extern T0* T60f155(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sql_extend_insert_missing_rows */
extern T0* T60f169(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.tabtab */
extern T0* T60f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sql_select_for_extension_function */
extern T0* T59f140(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.do_sql_select_for_extension_function */
extern T0* T59f192(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sql_extend_insert_missing_rows */
extern T0* T59f206(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.tabtab */
extern T0* T59f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sql_select_for_extension_function */
extern T0* T58f140(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.do_sql_select_for_extension_function */
extern T0* T58f192(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sql_extend_insert_missing_rows */
extern T0* T58f206(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.tabtab */
extern T0* T58f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sql_select_for_extension_function */
extern T0* T57f141(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.do_sql_select_for_extension_function */
extern T0* T57f193(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sql_extend_insert_missing_rows */
extern T0* T57f207(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.tabtab */
extern T0* T57f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sql_select_for_extension_function */
extern T0* T56f141(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.do_sql_select_for_extension_function */
extern T0* T56f193(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sql_extend_insert_missing_rows */
extern T0* T56f207(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.tabtab */
extern T0* T56f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sql_select_for_extension_function */
extern T0* T55f141(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.do_sql_select_for_extension_function */
extern T0* T55f193(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sql_extend_insert_missing_rows */
extern T0* T55f206(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.tabtab */
extern T0* T55f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sql_select_for_extension_function */
extern T0* T54f135(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.do_sql_select_for_extension_function */
extern T0* T54f185(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sql_extend_insert_missing_rows */
extern T0* T54f200(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.tabtab */
extern T0* T54f199(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sql_select_for_extension_function */
extern T0* T53f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.do_sql_select_for_extension_function */
extern T0* T53f153(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sql_extend_insert_missing_rows */
extern T0* T53f167(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.tabtab */
extern T0* T53f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sql_select_for_extension_function */
extern T0* T52f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.do_sql_select_for_extension_function */
extern T0* T52f153(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sql_extend_insert_missing_rows */
extern T0* T52f167(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.tabtab */
extern T0* T52f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sql_select_for_extension_function */
extern T0* T51f128(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.do_sql_select_for_extension_function */
extern T0* T51f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sql_extend_insert_missing_rows */
extern T0* T51f190(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.tabtab */
extern T0* T51f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sql_select_for_extension_function */
extern T0* T50f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.do_sql_select_for_extension_function */
extern T0* T50f152(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sql_extend_insert_missing_rows */
extern T0* T50f166(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.tabtab */
extern T0* T50f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sql_select_for_extension_function */
extern T0* T49f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.do_sql_select_for_extension_function */
extern T0* T49f152(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sql_extend_insert_missing_rows */
extern T0* T49f166(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.tabtab */
extern T0* T49f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sql_select_for_extension_function */
extern T0* T48f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.do_sql_select_for_extension_function */
extern T0* T48f152(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sql_extend_insert_missing_rows */
extern T0* T48f166(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.tabtab */
extern T0* T48f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_for_extension_function */
extern T0* T47f135(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.do_sql_select_for_extension_function */
extern T0* T47f184(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sql_extend_insert_missing_rows */
extern T0* T47f200(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.tabtab */
extern T0* T47f199(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sql_select_for_extension_function */
extern T0* T46f135(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.do_sql_select_for_extension_function */
extern T0* T46f184(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sql_extend_insert_missing_rows */
extern T0* T46f200(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.tabtab */
extern T0* T46f199(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sql_select_for_extension_function */
extern T0* T45f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.do_sql_select_for_extension_function */
extern T0* T45f152(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sql_extend_insert_missing_rows */
extern T0* T45f166(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.tabtab */
extern T0* T45f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sql_select_for_extension_function */
extern T0* T44f131(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.do_sql_select_for_extension_function */
extern T0* T44f182(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sql_extend_insert_missing_rows */
extern T0* T44f196(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.tabtab */
extern T0* T44f195(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sql_select_for_extension_function */
extern T0* T43f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.do_sql_select_for_extension_function */
extern T0* T43f154(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sql_extend_insert_missing_rows */
extern T0* T43f168(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.tabtab */
extern T0* T43f167(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sql_select_for_extension_function */
extern T0* T42f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.do_sql_select_for_extension_function */
extern T0* T42f153(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sql_extend_insert_missing_rows */
extern T0* T42f167(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.tabtab */
extern T0* T42f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sql_select_for_extension_function */
extern T0* T41f114(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.do_sql_select_for_extension_function */
extern T0* T41f153(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sql_extend_insert_missing_rows */
extern T0* T41f167(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.tabtab */
extern T0* T41f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_name */
extern T0* T64f132(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.make_valid_sp_identifier */
extern T0* T64f178(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_name */
extern T0* T63f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.make_valid_sp_identifier */
extern T0* T63f177(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_name */
extern T0* T62f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.make_valid_sp_identifier */
extern T0* T62f177(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_name */
extern T0* T61f131(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.make_valid_sp_identifier */
extern T0* T61f177(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sp_name */
extern T0* T60f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_name */
extern T0* T59f144(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.make_valid_sp_identifier */
extern T0* T59f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_name */
extern T0* T58f144(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.make_valid_sp_identifier */
extern T0* T58f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_name */
extern T0* T57f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.make_valid_sp_identifier */
extern T0* T57f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_name */
extern T0* T56f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.make_valid_sp_identifier */
extern T0* T56f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_name */
extern T0* T55f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.make_valid_sp_identifier */
extern T0* T55f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_name */
extern T0* T54f140(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.make_valid_sp_identifier */
extern T0* T54f189(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sp_name */
extern T0* T53f198(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sp_name */
extern T0* T52f198(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_name */
extern T0* T51f133(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.make_valid_sp_identifier */
extern T0* T51f179(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sp_name */
extern T0* T50f197(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sp_name */
extern T0* T49f197(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sp_name */
extern T0* T48f197(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_name */
extern T0* T47f139(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.make_valid_sp_identifier */
extern T0* T47f186(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_name */
extern T0* T46f139(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.make_valid_sp_identifier */
extern T0* T46f186(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sp_name */
extern T0* T45f197(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_name */
extern T0* T44f136(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.make_valid_sp_identifier */
extern T0* T44f186(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sp_name */
extern T0* T43f199(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sp_name */
extern T0* T42f198(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sp_name */
extern T0* T41f198(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_expression_as_boolean_value */
extern T0* T64f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_expression_as_boolean_value */
extern T0* T63f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_expression_as_boolean_value */
extern T0* T62f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_expression_as_boolean_value */
extern T0* T61f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_expression_as_boolean_value */
extern T0* T60f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_expression_as_boolean_value */
extern T0* T59f207(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_expression_as_boolean_value */
extern T0* T58f207(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_expression_as_boolean_value */
extern T0* T57f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_expression_as_boolean_value */
extern T0* T56f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_expression_as_boolean_value */
extern T0* T55f207(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_expression_as_boolean_value */
extern T0* T54f204(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_expression_as_boolean_value */
extern T0* T53f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_expression_as_boolean_value */
extern T0* T52f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_expression_as_boolean_value */
extern T0* T51f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_expression_as_boolean_value */
extern T0* T50f171(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_expression_as_boolean_value */
extern T0* T49f171(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_expression_as_boolean_value */
extern T0* T48f171(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_expression_as_boolean_value */
extern T0* T47f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_expression_as_boolean_value */
extern T0* T46f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_expression_as_boolean_value */
extern T0* T45f171(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_expression_as_boolean_value */
extern T0* T44f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_expression_as_boolean_value */
extern T0* T43f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_expression_as_boolean_value */
extern T0* T42f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_expression_as_boolean_value */
extern T0* T41f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqltrue */
extern T0* T64f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqltrue */
extern T0* T63f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqltrue */
extern T0* T62f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqltrue */
extern T0* T61f155(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqltrue */
extern T0* T60f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqltrue */
extern T0* T59f176(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqltrue */
extern T0* T58f176(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqltrue */
extern T0* T57f176(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqltrue */
extern T0* T56f176(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqltrue */
extern T0* T55f176(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqltrue */
extern T0* T53f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqltrue */
extern T0* T52f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqltrue */
extern T0* T51f160(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqltrue */
extern T0* T50f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqltrue */
extern T0* T49f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqltrue */
extern T0* T48f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqltrue */
extern T0* T45f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqltrue */
extern T0* T44f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqltrue */
extern T0* T43f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqltrue */
extern T0* T42f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqltrue */
extern T0* T41f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.assert_implemented_as_view */
extern T1 T64f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.assert_implemented_as_view */
extern T1 T63f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.assert_implemented_as_view */
extern T1 T62f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.assert_implemented_as_view */
extern T1 T61f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.assert_implemented_as_view */
extern T1 T60f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.assert_implemented_as_view */
extern T1 T59f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.assert_implemented_as_view */
extern T1 T58f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.assert_implemented_as_view */
extern T1 T57f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.assert_implemented_as_view */
extern T1 T56f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.assert_implemented_as_view */
extern T1 T55f208(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.assert_implemented_as_view */
extern T1 T54f205(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.assert_implemented_as_view */
extern T1 T53f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.assert_implemented_as_view */
extern T1 T52f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.assert_implemented_as_view */
extern T1 T51f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.assert_implemented_as_view */
extern T1 T50f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.assert_implemented_as_view */
extern T1 T49f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.assert_implemented_as_view */
extern T1 T48f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.assert_implemented_as_view */
extern T1 T47f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.assert_implemented_as_view */
extern T1 T46f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.assert_implemented_as_view */
extern T1 T45f172(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.assert_implemented_as_view */
extern T1 T44f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.assert_implemented_as_view */
extern T1 T43f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.assert_implemented_as_view */
extern T1 T42f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.assert_implemented_as_view */
extern T1 T41f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_select_function_as_subselect */
extern T0* T64f177(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_select_function_limit_after */
extern T0* T64f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.existentialfromtable */
extern T0* T64f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sql_select_function_as_subselect */
extern T0* T63f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_select_function_limit_after */
extern T0* T63f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.existentialfromtable */
extern T0* T63f191(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sql_select_function_as_subselect */
extern T0* T62f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_select_function_limit_after */
extern T0* T62f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.existentialfromtable */
extern T0* T62f191(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sql_select_function_as_subselect */
extern T0* T61f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_select_function_limit_after */
extern T0* T61f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.existentialfromtable */
extern T0* T61f191(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sql_select_function_as_subselect */
extern T0* T60f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_select_function_limit_after */
extern T0* T60f173(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.existentialfromtable */
extern T0* T60f172(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sql_select_function_as_subselect */
extern T0* T59f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_select_function_limit_after */
extern T0* T59f204(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sql_select_function_as_subselect */
extern T0* T58f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_select_function_limit_after */
extern T0* T58f204(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sql_select_function_as_subselect */
extern T0* T57f192(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_select_function_limit_after */
extern T0* T57f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sql_select_function_as_subselect */
extern T0* T56f192(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_select_function_limit_after */
extern T0* T56f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sql_select_function_as_subselect */
extern T0* T55f192(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_select_function_limit_after */
extern T0* T55f204(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sql_select_function_as_subselect */
extern T0* T54f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_select_function_limit_after */
extern T0* T54f203(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sql_select_function_as_subselect */
extern T0* T53f156(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_select_function_limit_after */
extern T0* T53f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.existentialfromtable */
extern T0* T53f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sql_select_function_as_subselect */
extern T0* T52f156(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_select_function_limit_after */
extern T0* T52f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.existentialfromtable */
extern T0* T52f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sql_select_function_as_subselect */
extern T0* T51f178(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_select_function_limit_after */
extern T0* T51f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sql_select_function_as_subselect */
extern T0* T50f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_select_function_limit_after */
extern T0* T50f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.existentialfromtable */
extern T0* T50f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sql_select_function_as_subselect */
extern T0* T49f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_select_function_limit_after */
extern T0* T49f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.existentialfromtable */
extern T0* T49f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sql_select_function_as_subselect */
extern T0* T48f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_select_function_limit_after */
extern T0* T48f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.existentialfromtable */
extern T0* T48f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_function_as_subselect */
extern T0* T47f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_function_limit_after */
extern T0* T47f198(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sql_select_function_as_subselect */
extern T0* T46f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_select_function_limit_after */
extern T0* T46f198(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sql_select_function_as_subselect */
extern T0* T45f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_select_function_limit_after */
extern T0* T45f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.existentialfromtable */
extern T0* T45f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sql_select_function_as_subselect */
extern T0* T44f185(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_select_function_limit_after */
extern T0* T44f200(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sql_select_function_as_subselect */
extern T0* T43f157(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_select_function_limit_after */
extern T0* T43f172(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.existentialfromtable */
extern T0* T43f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sql_select_function_as_subselect */
extern T0* T42f156(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_select_function_limit_after */
extern T0* T42f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.existentialfromtable */
extern T0* T42f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sql_select_function_as_subselect */
extern T0* T41f156(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_select_function_limit_after */
extern T0* T41f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.existentialfromtable */
extern T0* T41f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.extension_name */
extern T0* T64f197(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.maxtemporarytablenamelength */
extern T6 T64f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.extension_name */
extern T0* T63f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.maxtemporarytablenamelength */
extern T6 T63f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.extension_name */
extern T0* T62f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.maxtemporarytablenamelength */
extern T6 T62f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.extension_name */
extern T0* T61f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.maxtemporarytablenamelength */
extern T6 T61f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.extension_name */
extern T0* T60f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.extension_name */
extern T0* T59f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.extension_name */
extern T0* T58f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.extension_name */
extern T0* T57f210(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.extension_name */
extern T0* T56f210(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.extension_name */
extern T0* T55f209(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.extension_name */
extern T0* T54f206(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.extension_name */
extern T0* T53f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.extension_name */
extern T0* T52f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.extension_name */
extern T0* T51f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.extension_name */
extern T0* T50f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.extension_name */
extern T0* T49f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.extension_name */
extern T0* T48f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.extension_name */
extern T0* T47f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.extension_name */
extern T0* T46f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.extension_name */
extern T0* T45f173(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.extension_name */
extern T0* T44f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.extension_name */
extern T0* T43f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.extension_name */
extern T0* T42f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.extension_name */
extern T0* T41f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.temporarytableprefix */
extern T0* T64f194(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.temporarytableprefix */
extern T0* T63f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.temporarytableprefix */
extern T0* T62f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.temporarytableprefix */
extern T0* T61f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.temporarytableprefix */
extern T0* T60f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.temporarytableprefix */
extern T0* T59f62(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.temporarytableprefix */
extern T0* T58f62(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.temporarytableprefix */
extern T0* T57f62(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.temporarytableprefix */
extern T0* T56f62(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.temporarytableprefix */
extern T0* T55f62(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.temporarytableprefix */
extern T0* T54f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.temporarytableprefix */
extern T0* T53f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.temporarytableprefix */
extern T0* T52f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.temporarytableprefix */
extern T0* T51f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.temporarytableprefix */
extern T0* T50f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.temporarytableprefix */
extern T0* T49f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.temporarytableprefix */
extern T0* T48f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.temporarytableprefix */
extern T0* T47f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.temporarytableprefix */
extern T0* T46f64(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.temporarytableprefix */
extern T0* T45f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.temporarytableprefix */
extern T0* T44f63(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.temporarytableprefix */
extern T0* T43f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.temporarytableprefix */
extern T0* T42f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.temporarytableprefix */
extern T0* T41f60(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlcheck_like */
extern T0* T64f198(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sqlcheck_like */
extern T0* T63f197(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sqlcheck_like */
extern T0* T62f197(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sqlcheck_like */
extern T0* T61f197(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sqlcheck_like */
extern T0* T60f177(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sqlcheck_like */
extern T0* T59f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sqlcheck_like */
extern T0* T58f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sqlcheck_like */
extern T0* T57f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sqlcheck_like */
extern T0* T56f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sqlcheck_like */
extern T0* T55f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sqlcheck_like */
extern T0* T54f251(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sqlcheck_like */
extern T0* T53f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sqlcheck_like */
extern T0* T52f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sqlcheck_like */
extern T0* T51f197(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sqlcheck_like */
extern T0* T50f174(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sqlcheck_like */
extern T0* T49f174(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sqlcheck_like */
extern T0* T48f174(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sqlcheck_like */
extern T0* T47f204(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sqlcheck_like */
extern T0* T46f204(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sqlcheck_like */
extern T0* T45f174(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sqlcheck_like */
extern T0* T44f204(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sqlcheck_like */
extern T0* T43f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sqlcheck_like */
extern T0* T42f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sqlcheck_like */
extern T0* T41f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sqlcheck_in */
extern T0* T64f199(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_I_NODE.to_sqlcode */
extern T0* T132f3(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlcheck_in */
extern T0* T63f198(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sqlcheck_in */
extern T0* T62f198(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sqlcheck_in */
extern T0* T61f198(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sqlcheck_in */
extern T0* T60f178(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sqlcheck_in */
extern T0* T59f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sqlcheck_in */
extern T0* T58f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sqlcheck_in */
extern T0* T57f212(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sqlcheck_in */
extern T0* T56f212(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sqlcheck_in */
extern T0* T55f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sqlcheck_in */
extern T0* T54f252(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sqlcheck_in */
extern T0* T53f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sqlcheck_in */
extern T0* T52f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sqlcheck_in */
extern T0* T51f198(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sqlcheck_in */
extern T0* T50f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sqlcheck_in */
extern T0* T49f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sqlcheck_in */
extern T0* T48f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sqlcheck_in */
extern T0* T47f205(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sqlcheck_in */
extern T0* T46f205(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sqlcheck_in */
extern T0* T45f175(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sqlcheck_in */
extern T0* T44f205(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sqlcheck_in */
extern T0* T43f177(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sqlcheck_in */
extern T0* T42f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sqlcheck_in */
extern T0* T41f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sqlcheck_between */
extern T0* T64f200(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sqlcheck_between */
extern T0* T63f199(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sqlcheck_between */
extern T0* T62f199(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sqlcheck_between */
extern T0* T61f199(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sqlcheck_between */
extern T0* T60f179(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sqlcheck_between */
extern T0* T59f212(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sqlcheck_between */
extern T0* T58f212(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sqlcheck_between */
extern T0* T57f213(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sqlcheck_between */
extern T0* T56f213(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sqlcheck_between */
extern T0* T55f212(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sqlcheck_between */
extern T0* T54f253(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sqlcheck_between */
extern T0* T53f177(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sqlcheck_between */
extern T0* T52f177(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sqlcheck_between */
extern T0* T51f199(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sqlcheck_between */
extern T0* T50f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sqlcheck_between */
extern T0* T49f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sqlcheck_between */
extern T0* T48f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sqlcheck_between */
extern T0* T47f206(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sqlcheck_between */
extern T0* T46f206(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sqlcheck_between */
extern T0* T45f176(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sqlcheck_between */
extern T0* T44f206(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sqlcheck_between */
extern T0* T43f178(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sqlcheck_between */
extern T0* T42f177(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sqlcheck_between */
extern T0* T41f177(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sql_infix_expression */
extern T0* T64f106(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.sql_infix_expression */
extern T0* T64f106p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.sql_infix_expression */
extern T0* T63f105(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.sql_infix_expression */
extern T0* T63f105p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.sql_infix_expression */
extern T0* T62f105(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.sql_infix_expression */
extern T0* T62f105p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.sql_infix_expression */
extern T0* T61f105(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.sql_infix_expression */
extern T0* T61f105p1(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_SQLITE_3.sql_infix_expression */
extern T0* T60f91(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.sql_infix_expression */
extern T0* T59f115(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.sql_infix_expression */
extern T0* T58f115(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_81.sql_infix_expression */
extern T0* T57f116(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_82.sql_infix_expression */
extern T0* T56f116(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_95.sql_infix_expression */
extern T0* T55f116(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ORACLE.sql_infix_expression */
extern T0* T54f111(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL322.sql_infix_expression */
extern T0* T53f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL4.sql_infix_expression */
extern T0* T52f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.sql_infix_expression */
extern T0* T51f104(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSQL.sql_infix_expression */
extern T0* T50f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS2000.sql_infix_expression */
extern T0* T49f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS97.sql_infix_expression */
extern T0* T48f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.sql_infix_expression */
extern T0* T47f111(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.sql_infix_expression */
extern T0* T46f111(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FOXPRO.sql_infix_expression */
extern T0* T45f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.sql_infix_expression */
extern T0* T44f107(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_6.sql_infix_expression */
extern T0* T43f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_BASIC.sql_infix_expression */
extern T0* T42f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ANSI.sql_infix_expression */
extern T0* T41f90(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.sqlsysfunction_current_timestamp */
extern T0* T64f201(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlsysfunction_current_timestamp */
extern T0* T63f200(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlsysfunction_current_timestamp */
extern T0* T62f200(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlsysfunction_current_timestamp */
extern T0* T61f200(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlsysfunction_current_timestamp */
extern T0* T60f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlsysfunction_current_timestamp */
extern T0* T59f213(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlsysfunction_current_timestamp */
extern T0* T58f213(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlsysfunction_current_timestamp */
extern T0* T57f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlsysfunction_current_timestamp */
extern T0* T56f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlsysfunction_current_timestamp */
extern T0* T55f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlsysfunction_current_timestamp */
extern T0* T54f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlsysfunction_current_timestamp */
extern T0* T53f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlsysfunction_current_timestamp */
extern T0* T52f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlsysfunction_current_timestamp */
extern T0* T51f200(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlsysfunction_current_timestamp */
extern T0* T50f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlsysfunction_current_timestamp */
extern T0* T49f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlsysfunction_current_timestamp */
extern T0* T48f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlsysfunction_current_timestamp */
extern T0* T47f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlsysfunction_current_timestamp */
extern T0* T46f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlsysfunction_current_timestamp */
extern T0* T45f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlsysfunction_current_timestamp */
extern T0* T44f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlsysfunction_current_timestamp */
extern T0* T43f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlsysfunction_current_timestamp */
extern T0* T42f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlsysfunction_current_timestamp */
extern T0* T41f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.value_representation_current_timestamp */
extern T0* T64f202(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.value_representation_current_timestamp */
extern T0* T63f201(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.value_representation_current_timestamp */
extern T0* T62f201(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.value_representation_current_timestamp */
extern T0* T61f201(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.value_representation_current_timestamp */
extern T0* T60f181(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.value_representation_current_timestamp */
extern T0* T59f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.value_representation_current_timestamp */
extern T0* T58f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.value_representation_current_timestamp */
extern T0* T57f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.value_representation_current_timestamp */
extern T0* T56f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.value_representation_current_timestamp */
extern T0* T55f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.value_representation_current_timestamp */
extern T0* T54f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.value_representation_current_timestamp */
extern T0* T53f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.value_representation_current_timestamp */
extern T0* T52f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.value_representation_current_timestamp */
extern T0* T51f201(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.value_representation_current_timestamp */
extern T0* T50f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.value_representation_current_timestamp */
extern T0* T49f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.value_representation_current_timestamp */
extern T0* T48f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_current_timestamp */
extern T0* T47f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.value_representation_current_timestamp */
extern T0* T46f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.value_representation_current_timestamp */
extern T0* T45f178(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.value_representation_current_timestamp */
extern T0* T44f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.value_representation_current_timestamp */
extern T0* T43f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.value_representation_current_timestamp */
extern T0* T42f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.value_representation_current_timestamp */
extern T0* T41f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.value_representation_system_user */
extern T0* T64f203(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.value_representation_system_user */
extern T0* T63f202(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.value_representation_system_user */
extern T0* T62f202(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.value_representation_system_user */
extern T0* T61f202(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.value_representation_system_user */
extern T0* T60f182(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.value_representation_system_user */
extern T0* T59f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.value_representation_system_user */
extern T0* T58f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.value_representation_system_user */
extern T0* T57f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.value_representation_system_user */
extern T0* T56f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.value_representation_system_user */
extern T0* T55f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.value_representation_system_user */
extern T0* T54f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.value_representation_system_user */
extern T0* T53f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.value_representation_system_user */
extern T0* T52f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.value_representation_system_user */
extern T0* T51f202(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.value_representation_system_user */
extern T0* T50f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.value_representation_system_user */
extern T0* T49f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.value_representation_system_user */
extern T0* T48f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_system_user */
extern T0* T47f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.value_representation_system_user */
extern T0* T46f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.value_representation_system_user */
extern T0* T45f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.value_representation_system_user */
extern T0* T44f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.value_representation_system_user */
extern T0* T43f181(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.value_representation_system_user */
extern T0* T42f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.value_representation_system_user */
extern T0* T41f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sql_select_for_extension_expression */
extern T0* T64f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_select_for_extension_expression */
extern T0* T63f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_select_for_extension_expression */
extern T0* T62f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_select_for_extension_expression */
extern T0* T61f174(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_select_for_extension_expression */
extern T0* T60f156(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_select_for_extension_expression */
extern T0* T59f193(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_select_for_extension_expression */
extern T0* T58f193(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_select_for_extension_expression */
extern T0* T57f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_select_for_extension_expression */
extern T0* T56f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_select_for_extension_expression */
extern T0* T55f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_select_for_extension_expression */
extern T0* T54f186(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_select_for_extension_expression */
extern T0* T53f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_select_for_extension_expression */
extern T0* T52f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_select_for_extension_expression */
extern T0* T51f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_select_for_extension_expression */
extern T0* T50f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_select_for_extension_expression */
extern T0* T49f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_select_for_extension_expression */
extern T0* T48f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_select_for_extension_expression */
extern T0* T47f185(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_select_for_extension_expression */
extern T0* T46f185(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_select_for_extension_expression */
extern T0* T45f153(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_select_for_extension_expression */
extern T0* T44f183(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_select_for_extension_expression */
extern T0* T43f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_select_for_extension_expression */
extern T0* T42f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_select_for_extension_expression */
extern T0* T41f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlfunction_max */
extern T0* T64f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlfunction_max */
extern T0* T63f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlfunction_max */
extern T0* T62f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlfunction_max */
extern T0* T61f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlfunction_max */
extern T0* T60f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlfunction_max */
extern T0* T59f219(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlfunction_max */
extern T0* T58f219(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlfunction_max */
extern T0* T57f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlfunction_max */
extern T0* T56f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlfunction_max */
extern T0* T55f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlfunction_max */
extern T0* T54f213(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlfunction_max */
extern T0* T53f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlfunction_max */
extern T0* T52f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlfunction_max */
extern T0* T51f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlfunction_max */
extern T0* T50f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlfunction_max */
extern T0* T49f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlfunction_max */
extern T0* T48f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlfunction_max */
extern T0* T47f213(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlfunction_max */
extern T0* T46f213(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlfunction_max */
extern T0* T45f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlfunction_max */
extern T0* T44f213(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlfunction_max */
extern T0* T43f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlfunction_max */
extern T0* T42f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlfunction_max */
extern T0* T41f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlfunction_min */
extern T0* T64f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlfunction_min */
extern T0* T63f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlfunction_min */
extern T0* T62f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlfunction_min */
extern T0* T61f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlfunction_min */
extern T0* T60f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlfunction_min */
extern T0* T59f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlfunction_min */
extern T0* T58f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlfunction_min */
extern T0* T57f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlfunction_min */
extern T0* T56f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlfunction_min */
extern T0* T55f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlfunction_min */
extern T0* T54f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlfunction_min */
extern T0* T53f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlfunction_min */
extern T0* T52f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlfunction_min */
extern T0* T51f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlfunction_min */
extern T0* T50f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlfunction_min */
extern T0* T49f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlfunction_min */
extern T0* T48f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlfunction_min */
extern T0* T47f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlfunction_min */
extern T0* T46f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlfunction_min */
extern T0* T45f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlfunction_min */
extern T0* T44f214(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlfunction_min */
extern T0* T43f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlfunction_min */
extern T0* T42f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlfunction_min */
extern T0* T41f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlfunction_total */
extern T0* T64f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlfunction_total */
extern T0* T63f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlfunction_total */
extern T0* T62f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlfunction_total */
extern T0* T61f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlfunction_total */
extern T0* T60f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlfunction_total */
extern T0* T59f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlfunction_total */
extern T0* T58f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlfunction_total */
extern T0* T57f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlfunction_total */
extern T0* T56f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlfunction_total */
extern T0* T55f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlfunction_total */
extern T0* T54f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlfunction_total */
extern T0* T53f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlfunction_total */
extern T0* T52f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlfunction_total */
extern T0* T51f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlfunction_total */
extern T0* T50f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlfunction_total */
extern T0* T49f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlfunction_total */
extern T0* T48f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlfunction_total */
extern T0* T47f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlfunction_total */
extern T0* T46f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlfunction_total */
extern T0* T45f185(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlfunction_total */
extern T0* T44f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlfunction_total */
extern T0* T43f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlfunction_total */
extern T0* T42f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlfunction_total */
extern T0* T41f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlfunction_count */
extern T0* T64f210(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlfunction_count */
extern T0* T63f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlfunction_count */
extern T0* T62f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlfunction_count */
extern T0* T61f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlfunction_count */
extern T0* T60f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlfunction_count */
extern T0* T59f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlfunction_count */
extern T0* T58f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlfunction_count */
extern T0* T57f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlfunction_count */
extern T0* T56f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlfunction_count */
extern T0* T55f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlfunction_count */
extern T0* T54f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlfunction_count */
extern T0* T53f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlfunction_count */
extern T0* T52f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlfunction_count */
extern T0* T51f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlfunction_count */
extern T0* T50f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlfunction_count */
extern T0* T49f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlfunction_count */
extern T0* T48f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlfunction_count */
extern T0* T47f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlfunction_count */
extern T0* T46f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlfunction_count */
extern T0* T45f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlfunction_count */
extern T0* T44f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlfunction_count */
extern T0* T43f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlfunction_count */
extern T0* T42f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlfunction_count */
extern T0* T41f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlfunction_any */
extern T0* T64f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlfunction_any */
extern T0* T63f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlfunction_any */
extern T0* T62f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlfunction_any */
extern T0* T61f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlfunction_any */
extern T0* T60f119(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlfunction_any */
extern T0* T59f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlfunction_any */
extern T0* T58f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlfunction_any */
extern T0* T57f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlfunction_any */
extern T0* T56f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlfunction_any */
extern T0* T55f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlfunction_any */
extern T0* T54f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlfunction_any */
extern T0* T53f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlfunction_any */
extern T0* T52f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlfunction_any */
extern T0* T51f132(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlfunction_any */
extern T0* T50f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlfunction_any */
extern T0* T49f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlfunction_any */
extern T0* T48f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlfunction_any */
extern T0* T47f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlfunction_any */
extern T0* T46f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlfunction_any */
extern T0* T45f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlfunction_any */
extern T0* T44f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlfunction_any */
extern T0* T43f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlfunction_any */
extern T0* T42f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlfunction_any */
extern T0* T41f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.existentialfromneeded */
extern T1 T60f171(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.existentialfromneeded */
extern T1 T54f202(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.existentialfromneeded */
extern T1 T53f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.existentialfromneeded */
extern T1 T52f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.existentialfromneeded */
extern T1 T51f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.existentialfromneeded */
extern T1 T50f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.existentialfromneeded */
extern T1 T49f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.existentialfromneeded */
extern T1 T48f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.existentialfromneeded */
extern T1 T47f196(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.existentialfromneeded */
extern T1 T46f196(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.existentialfromneeded */
extern T1 T45f168(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.existentialfromneeded */
extern T1 T44f198(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.existentialfromneeded */
extern T1 T43f170(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.existentialfromneeded */
extern T1 T42f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.existentialfromneeded */
extern T1 T41f169(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlfunction_nil */
extern T0* T64f190(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlfunction_nil */
extern T0* T63f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlfunction_nil */
extern T0* T62f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlfunction_nil */
extern T0* T61f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlfunction_nil */
extern T0* T60f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlfunction_nil */
extern T0* T59f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlfunction_nil */
extern T0* T58f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlfunction_nil */
extern T0* T57f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlfunction_nil */
extern T0* T56f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlfunction_nil */
extern T0* T55f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlfunction_nil */
extern T0* T54f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlfunction_nil */
extern T0* T53f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlfunction_nil */
extern T0* T52f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlfunction_nil */
extern T0* T51f130(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlfunction_nil */
extern T0* T50f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlfunction_nil */
extern T0* T49f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlfunction_nil */
extern T0* T48f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlfunction_nil */
extern T0* T47f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlfunction_nil */
extern T0* T46f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlfunction_nil */
extern T0* T45f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlfunction_nil */
extern T0* T44f133(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlfunction_nil */
extern T0* T43f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlfunction_nil */
extern T0* T42f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlfunction_nil */
extern T0* T41f116(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlfunction_some */
extern T0* T64f211(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlfunction_some */
extern T0* T63f210(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlfunction_some */
extern T0* T62f210(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlfunction_some */
extern T0* T61f210(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlfunction_some */
extern T0* T60f190(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlfunction_some */
extern T0* T59f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlfunction_some */
extern T0* T58f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlfunction_some */
extern T0* T57f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlfunction_some */
extern T0* T56f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlfunction_some */
extern T0* T55f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlfunction_some */
extern T0* T54f217(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlfunction_some */
extern T0* T53f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlfunction_some */
extern T0* T52f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlfunction_some */
extern T0* T51f210(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlfunction_some */
extern T0* T50f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlfunction_some */
extern T0* T49f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlfunction_some */
extern T0* T48f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlfunction_some */
extern T0* T47f217(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlfunction_some */
extern T0* T46f217(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlfunction_some */
extern T0* T45f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlfunction_some */
extern T0* T44f217(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlfunction_some */
extern T0* T43f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlfunction_some */
extern T0* T42f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlfunction_some */
extern T0* T41f188(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlcheck_boolean */
extern T0* T64f212(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sqlcheck_boolean */
extern T0* T63f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sqlcheck_boolean */
extern T0* T62f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sqlcheck_boolean */
extern T0* T61f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sqlcheck_boolean */
extern T0* T60f191(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sqlcheck_boolean */
extern T0* T59f224(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sqlcheck_boolean */
extern T0* T58f224(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sqlcheck_boolean */
extern T0* T57f225(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sqlcheck_boolean */
extern T0* T56f225(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sqlcheck_boolean */
extern T0* T55f225(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sqlcheck_boolean */
extern T0* T54f254(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sqlcheck_boolean */
extern T0* T53f189(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sqlcheck_boolean */
extern T0* T52f189(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sqlcheck_boolean */
extern T0* T51f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sqlcheck_boolean */
extern T0* T50f188(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sqlcheck_boolean */
extern T0* T49f188(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sqlcheck_boolean */
extern T0* T48f188(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sqlcheck_boolean */
extern T0* T47f218(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sqlcheck_boolean */
extern T0* T46f218(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sqlcheck_boolean */
extern T0* T45f188(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sqlcheck_boolean */
extern T0* T44f218(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sqlcheck_boolean */
extern T0* T43f190(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sqlcheck_boolean */
extern T0* T42f189(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sqlcheck_boolean */
extern T0* T41f189(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sql_like_operator */
extern T0* T64f213(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sql_like_operator */
extern T0* T63f212(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sql_like_operator */
extern T0* T62f212(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sql_like_operator */
extern T0* T61f212(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sql_like_operator */
extern T0* T60f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sql_like_operator */
extern T0* T54f218(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sql_like_operator */
extern T0* T53f190(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sql_like_operator */
extern T0* T52f190(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sql_like_operator */
extern T0* T51f212(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sql_like_operator */
extern T0* T50f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sql_like_operator */
extern T0* T49f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sql_like_operator */
extern T0* T48f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sql_like_operator */
extern T0* T47f219(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sql_like_operator */
extern T0* T46f219(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sql_like_operator */
extern T0* T45f189(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sql_like_operator */
extern T0* T44f219(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sql_like_operator */
extern T0* T43f191(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sql_like_operator */
extern T0* T42f190(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sql_like_operator */
extern T0* T41f190(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sql_subselect_for_attribute */
extern T0* T64f215(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_subselect_for_attribute */
extern T0* T63f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_subselect_for_attribute */
extern T0* T62f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_subselect_for_attribute */
extern T0* T61f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_subselect_for_attribute */
extern T0* T60f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_subselect_for_attribute */
extern T0* T59f227(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_subselect_for_attribute */
extern T0* T58f227(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_subselect_for_attribute */
extern T0* T57f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_subselect_for_attribute */
extern T0* T56f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_subselect_for_attribute */
extern T0* T55f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_subselect_for_attribute */
extern T0* T54f220(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_subselect_for_attribute */
extern T0* T53f192(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_subselect_for_attribute */
extern T0* T52f192(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_subselect_for_attribute */
extern T0* T51f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_subselect_for_attribute */
extern T0* T50f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_subselect_for_attribute */
extern T0* T49f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_subselect_for_attribute */
extern T0* T48f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_subselect_for_attribute */
extern T0* T47f221(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_subselect_for_attribute */
extern T0* T46f221(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_subselect_for_attribute */
extern T0* T45f191(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_subselect_for_attribute */
extern T0* T44f221(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_subselect_for_attribute */
extern T0* T43f193(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_subselect_for_attribute */
extern T0* T42f192(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_subselect_for_attribute */
extern T0* T41f192(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.createstoredprocedure */
extern T1 T64f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.createstoredprocedure */
extern T1 T63f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.createstoredprocedure */
extern T1 T62f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.createstoredprocedure */
extern T1 T61f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createstoredprocedure */
extern T1 T59f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.createstoredprocedure */
extern T1 T58f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.createstoredprocedure */
extern T1 T57f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.createstoredprocedure */
extern T1 T56f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.createstoredprocedure */
extern T1 T55f39(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.createstoredprocedure */
extern T1 T54f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createstoredprocedure */
extern T1 T51f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createstoredprocedure */
extern T1 T47f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createstoredprocedure */
extern T1 T46f41(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createstoredprocedure */
extern T1 T44f40(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_delete_name */
extern T0* T64f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_delete_name */
extern T0* T63f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_delete_name */
extern T0* T62f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_delete_name */
extern T0* T61f87(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sp_delete_name */
extern T0* T60f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_delete_name */
extern T0* T59f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_delete_name */
extern T0* T58f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_delete_name */
extern T0* T57f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_delete_name */
extern T0* T56f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_delete_name */
extern T0* T55f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_delete_name */
extern T0* T54f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sp_delete_name */
extern T0* T53f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sp_delete_name */
extern T0* T52f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_delete_name */
extern T0* T51f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sp_delete_name */
extern T0* T50f193(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sp_delete_name */
extern T0* T49f193(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sp_delete_name */
extern T0* T48f193(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_delete_name */
extern T0* T47f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_delete_name */
extern T0* T46f86(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sp_delete_name */
extern T0* T45f193(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_delete_name */
extern T0* T44f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sp_delete_name */
extern T0* T43f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sp_delete_name */
extern T0* T42f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sp_delete_name */
extern T0* T41f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_insert_name */
extern T0* T64f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_insert_name */
extern T0* T63f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_insert_name */
extern T0* T62f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_insert_name */
extern T0* T61f76(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sp_insert_name */
extern T0* T60f197(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_insert_name */
extern T0* T59f72(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_insert_name */
extern T0* T58f72(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_insert_name */
extern T0* T57f72(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_insert_name */
extern T0* T56f72(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_insert_name */
extern T0* T55f72(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_insert_name */
extern T0* T54f75(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sp_insert_name */
extern T0* T53f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sp_insert_name */
extern T0* T52f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_insert_name */
extern T0* T51f75(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sp_insert_name */
extern T0* T50f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sp_insert_name */
extern T0* T49f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sp_insert_name */
extern T0* T48f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_insert_name */
extern T0* T47f75(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_insert_name */
extern T0* T46f75(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sp_insert_name */
extern T0* T45f194(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_insert_name */
extern T0* T44f74(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sp_insert_name */
extern T0* T43f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sp_insert_name */
extern T0* T42f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sp_insert_name */
extern T0* T41f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sp_update_name */
extern T0* T64f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_update_name */
extern T0* T63f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_update_name */
extern T0* T62f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_update_name */
extern T0* T61f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sp_update_name */
extern T0* T60f198(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_update_name */
extern T0* T59f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_update_name */
extern T0* T58f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_update_name */
extern T0* T57f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_update_name */
extern T0* T56f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_update_name */
extern T0* T55f81(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_update_name */
extern T0* T54f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sp_update_name */
extern T0* T53f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sp_update_name */
extern T0* T52f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_update_name */
extern T0* T51f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sp_update_name */
extern T0* T50f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sp_update_name */
extern T0* T49f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sp_update_name */
extern T0* T48f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_update_name */
extern T0* T47f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_update_name */
extern T0* T46f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sp_update_name */
extern T0* T45f195(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_update_name */
extern T0* T44f82(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sp_update_name */
extern T0* T43f197(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sp_update_name */
extern T0* T42f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sp_update_name */
extern T0* T41f196(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.namedparameterssupported */
extern T1 T64f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.namedparameterssupported */
extern T1 T63f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.namedparameterssupported */
extern T1 T62f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.namedparameterssupported */
extern T1 T61f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.namedparameterssupported */
extern T1 T59f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.namedparameterssupported */
extern T1 T58f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.namedparameterssupported */
extern T1 T57f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.namedparameterssupported */
extern T1 T56f65(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.namedparameterssupported */
extern T1 T54f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.namedparameterssupported */
extern T1 T51f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.namedparameterssupported */
extern T1 T47f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.namedparameterssupported */
extern T1 T46f69(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.namedparameterssupported */
extern T1 T44f68(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_define_in_param */
extern T0* T64f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_define_in_param */
extern T0* T63f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_define_in_param */
extern T0* T62f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_define_in_param */
extern T0* T61f71(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sp_define_in_param */
extern T0* T60f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_define_in_param */
extern T0* T59f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_define_in_param */
extern T0* T58f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_define_in_param */
extern T0* T57f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_define_in_param */
extern T0* T56f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_define_in_param */
extern T0* T55f66(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_define_in_param */
extern T0* T54f69(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sp_define_in_param */
extern T0* T53f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sp_define_in_param */
extern T0* T52f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_define_in_param */
extern T0* T51f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sp_define_in_param */
extern T0* T50f199(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sp_define_in_param */
extern T0* T49f199(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sp_define_in_param */
extern T0* T48f199(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_define_in_param */
extern T0* T47f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_define_in_param */
extern T0* T46f70(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sp_define_in_param */
extern T0* T45f199(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_define_in_param */
extern T0* T44f69(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sp_define_in_param */
extern T0* T43f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sp_define_in_param */
extern T0* T42f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sp_define_in_param */
extern T0* T41f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.supportsdomainsinstoredprocedures */
extern T1 T64f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.supportsdomainsinstoredprocedures */
extern T1 T63f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.supportsdomainsinstoredprocedures */
extern T1 T62f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.supportsdomainsinstoredprocedures */
extern T1 T61f72(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.supportsdomainsinstoredprocedures */
extern T1 T59f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.supportsdomainsinstoredprocedures */
extern T1 T58f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.supportsdomainsinstoredprocedures */
extern T1 T57f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.supportsdomainsinstoredprocedures */
extern T1 T56f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.supportsdomainsinstoredprocedures */
extern T1 T55f67(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.supportsdomainsinstoredprocedures */
extern T1 T54f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.supportsdomainsinstoredprocedures */
extern T1 T51f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.supportsdomainsinstoredprocedures */
extern T1 T47f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.supportsdomainsinstoredprocedures */
extern T1 T46f71(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.supportsdomainsinstoredprocedures */
extern T1 T44f70(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.quote_valid_identifier */
extern T0* T64f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.quote_valid_identifier */
extern T0* T63f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.quote_valid_identifier */
extern T0* T62f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.quote_valid_identifier */
extern T0* T61f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.quote_valid_identifier */
extern T0* T60f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.quote_valid_identifier */
extern T0* T59f50(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.quote_valid_identifier */
extern T0* T58f50(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.quote_valid_identifier */
extern T0* T57f50(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.quote_valid_identifier */
extern T0* T56f50(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.quote_valid_identifier */
extern T0* T55f50(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.quote_valid_identifier */
extern T0* T54f51(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.quote_valid_identifier */
extern T0* T53f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.quote_valid_identifier */
extern T0* T52f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.quote_valid_identifier */
extern T0* T51f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.quote_valid_identifier */
extern T0* T50f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.quote_valid_identifier */
extern T0* T49f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.quote_valid_identifier */
extern T0* T48f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.quote_valid_identifier */
extern T0* T47f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.quote_valid_identifier */
extern T0* T46f52(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.quote_valid_identifier */
extern T0* T45f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.quote_valid_identifier */
extern T0* T44f51(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.quote_valid_identifier */
extern T0* T43f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.quote_valid_identifier */
extern T0* T42f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.quote_valid_identifier */
extern T0* T41f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.storedproceduresupported */
extern T1 T64f217(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.storedproceduresupported */
extern T1 T63f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.storedproceduresupported */
extern T1 T62f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.storedproceduresupported */
extern T1 T61f216(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.storedproceduresupported */
extern T1 T59f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.storedproceduresupported */
extern T1 T58f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.storedproceduresupported */
extern T1 T57f229(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.storedproceduresupported */
extern T1 T56f229(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.storedproceduresupported */
extern T1 T55f229(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.storedproceduresupported */
extern T1 T54f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.storedproceduresupported */
extern T1 T51f215(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.storedproceduresupported */
extern T1 T47f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.storedproceduresupported */
extern T1 T46f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.storedproceduresupported */
extern T1 T44f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sp_define_param_name */
extern T0* T64f145(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sp_define_param_name */
extern T0* T63f144(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sp_define_param_name */
extern T0* T62f144(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sp_define_param_name */
extern T0* T61f144(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sp_define_param_name */
extern T0* T60f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sp_define_param_name */
extern T0* T59f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.no_space_identifier */
extern T0* T59f169(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sp_define_param_name */
extern T0* T58f103(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.no_space_identifier */
extern T0* T58f169(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sp_define_param_name */
extern T0* T57f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.no_space_identifier */
extern T0* T57f169(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sp_define_param_name */
extern T0* T56f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.no_space_identifier */
extern T0* T56f169(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sp_define_param_name */
extern T0* T55f104(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.no_space_identifier */
extern T0* T55f169(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sp_define_param_name */
extern T0* T54f155(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sp_define_param_name */
extern T0* T53f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sp_define_param_name */
extern T0* T52f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sp_define_param_name */
extern T0* T51f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sp_define_param_name */
extern T0* T50f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sp_define_param_name */
extern T0* T49f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sp_define_param_name */
extern T0* T48f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sp_define_param_name */
extern T0* T47f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sp_define_param_name */
extern T0* T46f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sp_define_param_name */
extern T0* T45f200(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sp_define_param_name */
extern T0* T44f154(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sp_define_param_name */
extern T0* T43f202(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sp_define_param_name */
extern T0* T42f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sp_define_param_name */
extern T0* T41f201(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.constant_identifier */
extern T0* T64f48(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.constant_identifier */
extern T0* T63f48(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.constant_identifier */
extern T0* T62f48(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.constant_identifier */
extern T0* T61f48(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.constant_identifier */
extern T0* T60f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.constant_identifier */
extern T0* T59f47(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.constant_identifier */
extern T0* T58f47(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.constant_identifier */
extern T0* T57f47(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.constant_identifier */
extern T0* T56f47(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.constant_identifier */
extern T0* T55f47(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.constant_identifier */
extern T0* T54f48(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.constant_identifier */
extern T0* T53f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.constant_identifier */
extern T0* T52f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.constant_identifier */
extern T0* T51f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.constant_identifier */
extern T0* T50f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.constant_identifier */
extern T0* T49f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.constant_identifier */
extern T0* T48f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.constant_identifier */
extern T0* T47f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.constant_identifier */
extern T0* T46f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.constant_identifier */
extern T0* T45f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.constant_identifier */
extern T0* T44f48(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.constant_identifier */
extern T0* T43f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.constant_identifier */
extern T0* T42f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.constant_identifier */
extern T0* T41f46(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_combine_expression_as_wildcard */
extern T0* T64f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_combine_expression_as_wildcard */
extern T0* T63f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_combine_expression_as_wildcard */
extern T0* T62f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_combine_expression_as_wildcard */
extern T0* T61f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_combine_expression_as_wildcard */
extern T0* T60f206(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_combine_expression_as_wildcard */
extern T0* T59f229(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_combine_expression_as_wildcard */
extern T0* T58f229(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_combine_expression_as_wildcard */
extern T0* T57f230(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_combine_expression_as_wildcard */
extern T0* T56f230(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_combine_expression_as_wildcard */
extern T0* T55f230(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_combine_expression_as_wildcard */
extern T0* T54f223(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_combine_expression_as_wildcard */
extern T0* T53f204(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_combine_expression_as_wildcard */
extern T0* T52f204(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_combine_expression_as_wildcard */
extern T0* T51f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_combine_expression_as_wildcard */
extern T0* T50f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_combine_expression_as_wildcard */
extern T0* T49f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_combine_expression_as_wildcard */
extern T0* T48f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_combine_expression_as_wildcard */
extern T0* T47f223(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_combine_expression_as_wildcard */
extern T0* T46f223(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_combine_expression_as_wildcard */
extern T0* T45f203(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_combine_expression_as_wildcard */
extern T0* T44f223(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_combine_expression_as_wildcard */
extern T0* T43f205(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_combine_expression_as_wildcard */
extern T0* T42f204(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_combine_expression_as_wildcard */
extern T0* T41f204(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.value_representation_boolean */
extern T0* T64f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.value_representation_boolean */
extern T0* T63f130(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.value_representation_boolean */
extern T0* T62f130(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.value_representation_boolean */
extern T0* T61f130(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.value_representation_boolean */
extern T0* T60f118(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.value_representation_boolean */
extern T0* T59f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.value_representation_boolean */
extern T0* T58f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.value_representation_boolean */
extern T0* T57f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.value_representation_boolean */
extern T0* T56f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.value_representation_boolean */
extern T0* T55f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.value_representation_boolean */
extern T0* T54f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.value_representation_boolean */
extern T0* T53f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.value_representation_boolean */
extern T0* T52f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.value_representation_boolean */
extern T0* T51f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.value_representation_boolean */
extern T0* T50f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.value_representation_boolean */
extern T0* T49f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.value_representation_boolean */
extern T0* T48f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_boolean */
extern T0* T47f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.value_representation_boolean */
extern T0* T46f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.value_representation_boolean */
extern T0* T45f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.value_representation_boolean */
extern T0* T44f134(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.value_representation_boolean */
extern T0* T43f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.value_representation_boolean */
extern T0* T42f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.value_representation_boolean */
extern T0* T41f117(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.minimum_date_value */
extern T0* T64f219(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.minimum_date_value */
extern T0* T63f218(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.minimum_date_value */
extern T0* T62f218(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.minimum_date_value */
extern T0* T61f218(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.minimum_date_value */
extern T0* T60f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.minimum_date_value */
extern T0* T59f230(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.minimum_date_value */
extern T0* T58f230(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.minimum_date_value */
extern T0* T57f231(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.minimum_date_value */
extern T0* T56f231(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.minimum_date_value */
extern T0* T55f231(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.minimum_date_value */
extern T0* T54f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.minimum_date_value */
extern T0* T53f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.minimum_date_value */
extern T0* T52f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.minimum_date_value */
extern T0* T50f204(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.minimum_date_value */
extern T0* T49f204(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.minimum_date_value */
extern T0* T48f204(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.minimum_date_value */
extern T0* T47f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.minimum_date_value */
extern T0* T46f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.minimum_date_value */
extern T0* T45f204(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.minimum_date_value */
extern T0* T44f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.minimum_date_value */
extern T0* T43f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.minimum_date_value */
extern T0* T42f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.minimum_date_value */
extern T0* T41f205(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.as_string */
extern T0* T64f113(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.safe_string */
extern T0* T64f168(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.as_string */
extern T0* T63f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.safe_string */
extern T0* T63f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.as_string */
extern T0* T62f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.safe_string */
extern T0* T62f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.as_string */
extern T0* T61f112(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.safe_string */
extern T0* T61f167(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.as_string */
extern T0* T60f98(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.safe_string */
extern T0* T60f151(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.as_string */
extern T0* T59f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.as_string */
extern T0* T59f122p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.as_string */
extern T0* T58f122(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.as_string */
extern T0* T58f122p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.as_string */
extern T0* T57f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.safe_string */
extern T0* T57f185(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.as_string */
extern T0* T56f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.safe_string */
extern T0* T56f185(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.as_string */
extern T0* T55f123(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.safe_string */
extern T0* T55f185(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.as_string */
extern T0* T54f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.as_string */
extern T0* T54f118p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.safe_string */
extern T0* T54f177(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.as_string */
extern T0* T53f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.safe_string */
extern T0* T53f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.as_string */
extern T0* T52f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.safe_string */
extern T0* T52f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.as_string */
extern T0* T51f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.safe_string */
extern T0* T51f169(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.as_string */
extern T0* T50f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.safe_string */
extern T0* T50f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.as_string */
extern T0* T49f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.safe_string */
extern T0* T49f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.as_string */
extern T0* T48f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.safe_string */
extern T0* T48f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.as_string */
extern T0* T47f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.safe_string */
extern T0* T47f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.as_string */
extern T0* T46f118(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.safe_string */
extern T0* T46f176(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.as_string */
extern T0* T45f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.safe_string */
extern T0* T45f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.as_string */
extern T0* T44f114(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.safe_string */
extern T0* T44f175(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.as_string */
extern T0* T43f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.safe_string */
extern T0* T43f150(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.as_string */
extern T0* T42f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.safe_string */
extern T0* T42f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.as_string */
extern T0* T41f97(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.safe_string */
extern T0* T41f149(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.value_representation_date */
extern T0* T64f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.value_representation_date */
extern T0* T63f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.value_representation_date */
extern T0* T62f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.value_representation_date */
extern T0* T61f183(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.value_representation_date */
extern T0* T60f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.value_representation_date */
extern T0* T59f198(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.value_representation_date */
extern T0* T58f198(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.value_representation_date */
extern T0* T57f199(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.value_representation_date */
extern T0* T56f199(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.value_representation_date */
extern T0* T55f199(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.value_representation_date */
extern T0* T54f196(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.value_representation_date */
extern T0* T53f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.value_representation_date */
extern T0* T52f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.value_representation_date */
extern T0* T51f186(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.value_representation_date */
extern T0* T50f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.value_representation_date */
extern T0* T49f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.value_representation_date */
extern T0* T48f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_date */
extern T0* T47f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.value_representation_date */
extern T0* T46f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.value_representation_date */
extern T0* T45f162(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.value_representation_date */
extern T0* T44f192(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.value_representation_date */
extern T0* T43f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.value_representation_date */
extern T0* T42f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.value_representation_date */
extern T0* T41f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.value_representation_money */
extern T0* T64f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.value_representation_money */
extern T0* T63f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.value_representation_money */
extern T0* T62f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.value_representation_money */
extern T0* T61f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.value_representation_money */
extern T0* T60f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.value_representation_money */
extern T0* T59f232(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.value_representation_money */
extern T0* T58f232(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.value_representation_money */
extern T0* T57f233(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.value_representation_money */
extern T0* T56f233(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.value_representation_money */
extern T0* T55f233(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.value_representation_money */
extern T0* T54f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.value_representation_money */
extern T0* T53f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.value_representation_money */
extern T0* T52f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.value_representation_money */
extern T0* T51f219(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.value_representation_money */
extern T0* T50f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.value_representation_money */
extern T0* T49f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.value_representation_money */
extern T0* T48f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_money */
extern T0* T47f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.value_representation_money */
extern T0* T46f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.value_representation_money */
extern T0* T45f206(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.value_representation_money */
extern T0* T44f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.value_representation_money */
extern T0* T43f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.value_representation_money */
extern T0* T42f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.value_representation_money */
extern T0* T41f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.value_representation_float */
extern T0* T64f185(GE_context* ac, T0* C);
/* XPLAIN_F_REPRESENTATION.set_domain_restriction */
extern void T403f11(GE_context* ac, T0* C, T0* a1, T0* a2);
/* XPLAIN_F_REPRESENTATION.default_create */
extern T0* T403c10(GE_context* ac);
/* SQL_GENERATOR_TSQL70.value_representation_float */
extern T0* T63f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.value_representation_float */
extern T0* T62f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.value_representation_float */
extern T0* T61f184(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.value_representation_float */
extern T0* T60f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.value_representation_float */
extern T0* T59f199(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.value_representation_float */
extern T0* T58f199(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.value_representation_float */
extern T0* T57f200(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.value_representation_float */
extern T0* T56f200(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.value_representation_float */
extern T0* T55f213(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.value_representation_float */
extern T0* T54f197(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.value_representation_float */
extern T0* T53f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.value_representation_float */
extern T0* T52f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.value_representation_float */
extern T0* T51f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.value_representation_float */
extern T0* T50f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.value_representation_float */
extern T0* T49f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.value_representation_float */
extern T0* T48f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_float */
extern T0* T47f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.value_representation_float */
extern T0* T46f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.value_representation_float */
extern T0* T45f163(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.value_representation_float */
extern T0* T44f193(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.value_representation_float */
extern T0* T43f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.value_representation_float */
extern T0* T42f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.value_representation_float */
extern T0* T41f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.value_representation_text */
extern T0* T64f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.value_representation_text */
extern T0* T63f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.value_representation_text */
extern T0* T62f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.value_representation_text */
extern T0* T61f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.value_representation_text */
extern T0* T60f210(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.value_representation_text */
extern T0* T59f233(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.value_representation_text */
extern T0* T58f233(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.value_representation_text */
extern T0* T57f234(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.value_representation_text */
extern T0* T56f234(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.value_representation_text */
extern T0* T55f234(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.value_representation_text */
extern T0* T54f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.value_representation_text */
extern T0* T53f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.value_representation_text */
extern T0* T52f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.value_representation_text */
extern T0* T51f220(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.value_representation_text */
extern T0* T50f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.value_representation_text */
extern T0* T49f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.value_representation_text */
extern T0* T48f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_text */
extern T0* T47f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.value_representation_text */
extern T0* T46f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.value_representation_text */
extern T0* T45f207(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.value_representation_text */
extern T0* T44f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.value_representation_text */
extern T0* T43f209(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.value_representation_text */
extern T0* T42f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.value_representation_text */
extern T0* T41f208(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.value_representation_char */
extern T0* T64f186(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL70.value_representation_char */
extern T0* T63f185(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL2000.value_representation_char */
extern T0* T62f185(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL2016.value_representation_char */
extern T0* T61f185(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_SQLITE_3.value_representation_char */
extern T0* T60f167(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_72.value_representation_char */
extern T0* T59f200(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_73.value_representation_char */
extern T0* T58f200(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_81.value_representation_char */
extern T0* T57f201(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_82.value_representation_char */
extern T0* T56f201(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_95.value_representation_char */
extern T0* T55f200(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_ORACLE.value_representation_char */
extern T0* T54f198(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MYSQL322.value_representation_char */
extern T0* T53f165(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MYSQL4.value_representation_char */
extern T0* T52f165(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MYSQL5.value_representation_char */
extern T0* T51f188(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MSQL.value_representation_char */
extern T0* T50f164(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MSACCESS2000.value_representation_char */
extern T0* T49f164(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MSACCESS97.value_representation_char */
extern T0* T48f164(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_char */
extern T0* T47f194(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_INTERBASE6.value_representation_char */
extern T0* T46f194(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_FOXPRO.value_representation_char */
extern T0* T45f164(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_DB2_71.value_representation_char */
extern T0* T44f194(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_DB2_6.value_representation_char */
extern T0* T43f166(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_BASIC.value_representation_char */
extern T0* T42f165(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_ANSI.value_representation_char */
extern T0* T41f165(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL65.value_representation_integer */
extern T0* T64f128(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL70.value_representation_integer */
extern T0* T63f127(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL2000.value_representation_integer */
extern T0* T62f127(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL2016.value_representation_integer */
extern T0* T61f127(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_SQLITE_3.value_representation_integer */
extern T0* T60f114(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_72.value_representation_integer */
extern T0* T59f138(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_73.value_representation_integer */
extern T0* T58f138(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_81.value_representation_integer */
extern T0* T57f139(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_82.value_representation_integer */
extern T0* T56f139(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_PGSQL_95.value_representation_integer */
extern T0* T55f139(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_ORACLE.value_representation_integer */
extern T0* T54f134(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MYSQL322.value_representation_integer */
extern T0* T53f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MYSQL4.value_representation_integer */
extern T0* T52f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MYSQL5.value_representation_integer */
extern T0* T51f127(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MSQL.value_representation_integer */
extern T0* T50f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MSACCESS2000.value_representation_integer */
extern T0* T49f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_MSACCESS97.value_representation_integer */
extern T0* T48f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_FIREBIRD_21.value_representation_integer */
extern T0* T47f133(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_INTERBASE6.value_representation_integer */
extern T0* T46f133(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_FOXPRO.value_representation_integer */
extern T0* T45f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_DB2_71.value_representation_integer */
extern T0* T44f130(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_DB2_6.value_representation_integer */
extern T0* T43f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_BASIC.value_representation_integer */
extern T0* T42f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_ANSI.value_representation_integer */
extern T0* T41f113(GE_context* ac, T0* C, T6 a1);
/* SQL_GENERATOR_TSQL65.sql_infix_expression_as_wildcard */
extern T0* T64f214(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL70.sql_infix_expression_as_wildcard */
extern T0* T63f213(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2000.sql_infix_expression_as_wildcard */
extern T0* T62f213(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL2016.sql_infix_expression_as_wildcard */
extern T0* T61f213(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_SQLITE_3.sql_infix_expression_as_wildcard */
extern T0* T60f193(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_72.sql_infix_expression_as_wildcard */
extern T0* T59f226(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_73.sql_infix_expression_as_wildcard */
extern T0* T58f226(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_81.sql_infix_expression_as_wildcard */
extern T0* T57f227(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_82.sql_infix_expression_as_wildcard */
extern T0* T56f227(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_PGSQL_95.sql_infix_expression_as_wildcard */
extern T0* T55f227(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ORACLE.sql_infix_expression_as_wildcard */
extern T0* T54f219(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL322.sql_infix_expression_as_wildcard */
extern T0* T53f191(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL4.sql_infix_expression_as_wildcard */
extern T0* T52f191(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MYSQL5.sql_infix_expression_as_wildcard */
extern T0* T51f213(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSQL.sql_infix_expression_as_wildcard */
extern T0* T50f190(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS2000.sql_infix_expression_as_wildcard */
extern T0* T49f190(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_MSACCESS97.sql_infix_expression_as_wildcard */
extern T0* T48f190(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FIREBIRD_21.sql_infix_expression_as_wildcard */
extern T0* T47f220(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_INTERBASE6.sql_infix_expression_as_wildcard */
extern T0* T46f220(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_FOXPRO.sql_infix_expression_as_wildcard */
extern T0* T45f190(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_71.sql_infix_expression_as_wildcard */
extern T0* T44f220(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_DB2_6.sql_infix_expression_as_wildcard */
extern T0* T43f192(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_BASIC.sql_infix_expression_as_wildcard */
extern T0* T42f191(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_ANSI.sql_infix_expression_as_wildcard */
extern T0* T41f191(GE_context* ac, T0* C, T0* a1, T0* a2, T0* a3);
/* SQL_GENERATOR_TSQL65.make_valid_identifier */
extern T0* T64f141(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.identifierwithspacessupported */
extern T1 T64f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.make_valid_identifier */
extern T0* T63f140(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.identifierwithspacessupported */
extern T1 T63f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.make_valid_identifier */
extern T0* T62f140(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.identifierwithspacessupported */
extern T1 T62f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.make_valid_identifier */
extern T0* T61f140(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.identifierwithspacessupported */
extern T1 T61f179(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.make_valid_identifier */
extern T0* T60f125(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.no_space_identifier */
extern T0* T60f161(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.identifierwithspacessupported */
extern T1 T60f159(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.make_valid_identifier */
extern T0* T59f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.make_valid_identifier */
extern T0* T59f93p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.identifierwithspacessupported */
extern T1 T59f167(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.make_valid_identifier */
extern T0* T58f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.identifierwithspacessupported */
extern T1 T58f167(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.make_valid_identifier */
extern T0* T57f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.identifierwithspacessupported */
extern T1 T57f167(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.make_valid_identifier */
extern T0* T56f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.identifierwithspacessupported */
extern T1 T56f167(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.make_valid_identifier */
extern T0* T55f93(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.identifierwithspacessupported */
extern T1 T55f167(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.make_valid_identifier */
extern T0* T54f148(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.no_space_identifier */
extern T0* T54f192(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.identifierwithspacessupported */
extern T1 T54f190(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.make_valid_identifier */
extern T0* T53f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.no_space_identifier */
extern T0* T53f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.identifierwithspacessupported */
extern T1 T53f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.make_valid_identifier */
extern T0* T52f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.no_space_identifier */
extern T0* T52f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.identifierwithspacessupported */
extern T1 T52f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.make_valid_identifier */
extern T0* T51f140(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.no_space_identifier */
extern T0* T51f182(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.identifierwithspacessupported */
extern T1 T51f180(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.make_valid_identifier */
extern T0* T50f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.no_space_identifier */
extern T0* T50f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.identifierwithspacessupported */
extern T1 T50f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.make_valid_identifier */
extern T0* T49f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.no_space_identifier */
extern T0* T49f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.identifierwithspacessupported */
extern T1 T49f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.make_valid_identifier */
extern T0* T48f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.no_space_identifier */
extern T0* T48f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.identifierwithspacessupported */
extern T1 T48f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.make_valid_identifier */
extern T0* T47f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.no_space_identifier */
extern T0* T47f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.identifierwithspacessupported */
extern T1 T47f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.make_valid_identifier */
extern T0* T46f147(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.no_space_identifier */
extern T0* T46f188(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.identifierwithspacessupported */
extern T1 T46f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.make_valid_identifier */
extern T0* T45f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.no_space_identifier */
extern T0* T45f158(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.identifierwithspacessupported */
extern T1 T45f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.make_valid_identifier */
extern T0* T44f146(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.identifierwithspacessupported */
extern T1 T44f187(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.make_valid_identifier */
extern T0* T43f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.no_space_identifier */
extern T0* T43f160(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.maxidentifierlength */
extern T6 T43f159(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.identifierwithspacessupported */
extern T1 T43f158(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.make_valid_identifier */
extern T0* T42f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.no_space_identifier */
extern T0* T42f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.identifierwithspacessupported */
extern T1 T42f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.make_valid_identifier */
extern T0* T41f124(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.no_space_identifier */
extern T0* T41f159(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.identifierwithspacessupported */
extern T1 T41f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlcolumnidentifier_base */
extern T0* T64f225(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sqlcolumnidentifier_base */
extern T0* T63f224(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sqlcolumnidentifier_base */
extern T0* T62f224(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sqlcolumnidentifier_base */
extern T0* T61f224(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sqlcolumnidentifier_base */
extern T0* T60f213(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sqlcolumnidentifier_base */
extern T0* T59f236(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sqlcolumnidentifier_base */
extern T0* T58f236(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sqlcolumnidentifier_base */
extern T0* T57f237(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sqlcolumnidentifier_base */
extern T0* T56f237(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sqlcolumnidentifier_base */
extern T0* T55f237(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sqlcolumnidentifier_base */
extern T0* T54f230(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sqlcolumnidentifier_base */
extern T0* T53f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sqlcolumnidentifier_base */
extern T0* T52f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sqlcolumnidentifier_base */
extern T0* T51f223(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sqlcolumnidentifier_base */
extern T0* T50f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sqlcolumnidentifier_base */
extern T0* T49f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sqlcolumnidentifier_base */
extern T0* T48f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumnidentifier_base */
extern T0* T47f230(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sqlcolumnidentifier_base */
extern T0* T46f230(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sqlcolumnidentifier_base */
extern T0* T45f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sqlcolumnidentifier_base */
extern T0* T44f230(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sqlcolumnidentifier_base */
extern T0* T43f212(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sqlcolumnidentifier_base */
extern T0* T42f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sqlcolumnidentifier_base */
extern T0* T41f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sqlcolumndefault_base */
extern T0* T64f227(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlcolumndefault_base */
extern T0* T63f226(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlcolumndefault_base */
extern T0* T62f226(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlcolumndefault_base */
extern T0* T61f226(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlcolumndefault_base */
extern T0* T60f215(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlcolumndefault_base */
extern T0* T59f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlcolumndefault_base */
extern T0* T58f238(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlcolumndefault_base */
extern T0* T57f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlcolumndefault_base */
extern T0* T56f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlcolumndefault_base */
extern T0* T55f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlcolumndefault_base */
extern T0* T54f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sqlcolumndefault_base */
extern T0* T53f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sqlcolumndefault_base */
extern T0* T52f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlcolumndefault_base */
extern T0* T51f225(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sqlcolumndefault_base */
extern T0* T50f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sqlcolumndefault_base */
extern T0* T49f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sqlcolumndefault_base */
extern T0* T48f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumndefault_base */
extern T0* T47f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlcolumndefault_base */
extern T0* T46f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sqlcolumndefault_base */
extern T0* T45f212(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlcolumndefault_base */
extern T0* T44f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sqlcolumndefault_base */
extern T0* T43f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sqlcolumndefault_base */
extern T0* T42f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sqlcolumndefault_base */
extern T0* T41f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlcolumnrequired_base */
extern T0* T64f228(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlcolumnrequired_base */
extern T0* T64f228p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.column_null_or_not_null */
extern T0* T64f238(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_TSQL65.columnnullallowed */
extern T1 T64f242(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.columnnotnullallowed */
extern T1 T64f241(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.columnnulldefault */
extern T1 T64f240(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.init_forced_null */
extern T1 T64f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlcolumnrequired_base */
extern T0* T63f227(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlcolumnrequired_base */
extern T0* T63f227p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.column_null_or_not_null */
extern T0* T63f237(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_TSQL70.columnnullallowed */
extern T1 T63f241(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.columnnotnullallowed */
extern T1 T63f240(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.columnnulldefault */
extern T1 T63f239(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.init_forced_null */
extern T1 T63f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlcolumnrequired_base */
extern T0* T62f227(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlcolumnrequired_base */
extern T0* T62f227p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.column_null_or_not_null */
extern T0* T62f237(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_TSQL2000.columnnullallowed */
extern T1 T62f241(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.columnnotnullallowed */
extern T1 T62f240(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.columnnulldefault */
extern T1 T62f239(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.init_forced_null */
extern T1 T62f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlcolumnrequired_base */
extern T0* T61f227(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlcolumnrequired_base */
extern T0* T61f227p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.column_null_or_not_null */
extern T0* T61f237(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_TSQL2016.columnnullallowed */
extern T1 T61f241(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.columnnotnullallowed */
extern T1 T61f240(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.columnnulldefault */
extern T1 T61f239(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.init_forced_null */
extern T1 T61f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlcolumnrequired_base */
extern T0* T60f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlcolumnrequired_base */
extern T0* T60f216p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.column_null_or_not_null */
extern T0* T60f235(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_SQLITE_3.columnnullallowed */
extern T1 T60f241(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.columnnotnullallowed */
extern T1 T60f240(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.columnnulldefault */
extern T1 T60f239(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.init_forced_null */
extern T1 T60f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlcolumnrequired_base */
extern T0* T59f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlcolumnrequired_base */
extern T0* T59f239p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.column_null_or_not_null */
extern T0* T59f258(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_PGSQL_72.columnnullallowed */
extern T1 T59f264(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.columnnotnullallowed */
extern T1 T59f263(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.columnnulldefault */
extern T1 T59f262(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.init_forced_null */
extern T1 T59f257(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlcolumnrequired_base */
extern T0* T58f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlcolumnrequired_base */
extern T0* T58f239p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.column_null_or_not_null */
extern T0* T58f259(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_PGSQL_73.columnnullallowed */
extern T1 T58f266(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.columnnotnullallowed */
extern T1 T58f265(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.columnnulldefault */
extern T1 T58f264(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.init_forced_null */
extern T1 T58f258(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlcolumnrequired_base */
extern T0* T57f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlcolumnrequired_base */
extern T0* T57f240p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.column_null_or_not_null */
extern T0* T57f260(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_PGSQL_81.columnnullallowed */
extern T1 T57f267(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.columnnotnullallowed */
extern T1 T57f266(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.columnnulldefault */
extern T1 T57f265(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.init_forced_null */
extern T1 T57f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlcolumnrequired_base */
extern T0* T56f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlcolumnrequired_base */
extern T0* T56f240p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.column_null_or_not_null */
extern T0* T56f260(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_PGSQL_82.columnnullallowed */
extern T1 T56f267(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.columnnotnullallowed */
extern T1 T56f266(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.columnnulldefault */
extern T1 T56f265(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.init_forced_null */
extern T1 T56f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlcolumnrequired_base */
extern T0* T55f240(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlcolumnrequired_base */
extern T0* T55f240p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.column_null_or_not_null */
extern T0* T55f260(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_PGSQL_95.columnnullallowed */
extern T1 T55f267(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.columnnotnullallowed */
extern T1 T55f266(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.columnnulldefault */
extern T1 T55f265(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.init_forced_null */
extern T1 T55f259(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlcolumnrequired_base */
extern T0* T54f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlcolumnrequired_base */
extern T0* T54f233p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.column_null_or_not_null */
extern T0* T54f256(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_ORACLE.columnnullallowed */
extern T1 T54f262(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.columnnotnullallowed */
extern T1 T54f261(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.columnnulldefault */
extern T1 T54f260(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.init_forced_null */
extern T1 T54f255(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sqlcolumnrequired_base */
extern T0* T53f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.column_null_or_not_null */
extern T0* T53f224(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_MYSQL322.columnnullallowed */
extern T1 T53f229(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.columnnotnullallowed */
extern T1 T53f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.columnnulldefault */
extern T1 T53f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlcolumnrequired_base */
extern T0* T52f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.column_null_or_not_null */
extern T0* T52f224(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_MYSQL4.columnnullallowed */
extern T1 T52f229(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.columnnotnullallowed */
extern T1 T52f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.columnnulldefault */
extern T1 T52f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlcolumnrequired_base */
extern T0* T51f226(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlcolumnrequired_base */
extern T0* T51f226p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.column_null_or_not_null */
extern T0* T51f245(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_MYSQL5.columnnullallowed */
extern T1 T51f251(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.columnnotnullallowed */
extern T1 T51f250(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.columnnulldefault */
extern T1 T51f249(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.init_forced_null */
extern T1 T51f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sqlcolumnrequired_base */
extern T0* T50f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.column_null_or_not_null */
extern T0* T50f223(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_MSQL.columnnullallowed */
extern T1 T50f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.columnnotnullallowed */
extern T1 T50f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.columnnulldefault */
extern T1 T50f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlcolumnrequired_base */
extern T0* T49f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.column_null_or_not_null */
extern T0* T49f223(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_MSACCESS2000.columnnullallowed */
extern T1 T49f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.columnnotnullallowed */
extern T1 T49f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.columnnulldefault */
extern T1 T49f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlcolumnrequired_base */
extern T0* T48f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.column_null_or_not_null */
extern T0* T48f223(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_MSACCESS97.columnnullallowed */
extern T1 T48f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.columnnotnullallowed */
extern T1 T48f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.columnnulldefault */
extern T1 T48f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumnrequired_base */
extern T0* T47f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumnrequired_base */
extern T0* T47f233p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.column_null_or_not_null */
extern T0* T47f252(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_FIREBIRD_21.columnnullallowed */
extern T1 T47f258(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.columnnotnullallowed */
extern T1 T47f257(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.columnnulldefault */
extern T1 T47f256(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.init_forced_null */
extern T1 T47f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.checksnullaftertrigger */
extern T1 T47f255(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlcolumnrequired_base */
extern T0* T46f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlcolumnrequired_base */
extern T0* T46f233p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.column_null_or_not_null */
extern T0* T46f252(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_INTERBASE6.columnnullallowed */
extern T1 T46f258(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.columnnotnullallowed */
extern T1 T46f257(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.columnnulldefault */
extern T1 T46f256(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.init_forced_null */
extern T1 T46f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.checksnullaftertrigger */
extern T1 T46f255(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlcolumnrequired_base */
extern T0* T45f213(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.column_null_or_not_null */
extern T0* T45f223(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_FOXPRO.columnnullallowed */
extern T1 T45f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.columnnotnullallowed */
extern T1 T45f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.columnnulldefault */
extern T1 T45f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlcolumnrequired_base */
extern T0* T44f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlcolumnrequired_base */
extern T0* T44f233p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.column_null_or_not_null */
extern T0* T44f252(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_DB2_71.columnnullallowed */
extern T1 T44f258(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.columnnotnullallowed */
extern T1 T44f257(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.columnnulldefault */
extern T1 T44f256(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.init_forced_null */
extern T1 T44f251(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sqlcolumnrequired_base */
extern T0* T43f215(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.column_null_or_not_null */
extern T0* T43f225(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_DB2_6.columnnullallowed */
extern T1 T43f230(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.columnnotnullallowed */
extern T1 T43f229(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.columnnulldefault */
extern T1 T43f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlcolumnrequired_base */
extern T0* T42f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.column_null_or_not_null */
extern T0* T42f224(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_BASIC.columnnullallowed */
extern T1 T42f229(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.columnnotnullallowed */
extern T1 T42f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.columnnulldefault */
extern T1 T42f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlcolumnrequired_base */
extern T0* T41f214(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.column_null_or_not_null */
extern T0* T41f224(GE_context* ac, T0* C, T1 a1);
/* SQL_GENERATOR_ANSI.columnnullallowed */
extern T1 T41f229(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.columnnotnullallowed */
extern T1 T41f228(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.columnnulldefault */
extern T1 T41f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlcolumnidentifier_type */
extern T0* T64f229(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sqlcolumnidentifier_type */
extern T0* T63f228(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sqlcolumnidentifier_type */
extern T0* T62f228(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sqlcolumnidentifier_type */
extern T0* T61f228(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sqlcolumnidentifier_type */
extern T0* T60f217(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sqlcolumnidentifier_type */
extern T0* T59f240(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sqlcolumnidentifier_type */
extern T0* T58f240(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sqlcolumnidentifier_type */
extern T0* T57f241(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sqlcolumnidentifier_type */
extern T0* T56f241(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sqlcolumnidentifier_type */
extern T0* T55f241(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sqlcolumnidentifier_type */
extern T0* T54f234(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sqlcolumnidentifier_type */
extern T0* T53f215(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sqlcolumnidentifier_type */
extern T0* T52f215(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sqlcolumnidentifier_type */
extern T0* T51f227(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sqlcolumnidentifier_type */
extern T0* T50f214(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sqlcolumnidentifier_type */
extern T0* T49f214(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sqlcolumnidentifier_type */
extern T0* T48f214(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumnidentifier_type */
extern T0* T47f234(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sqlcolumnidentifier_type */
extern T0* T46f234(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sqlcolumnidentifier_type */
extern T0* T45f214(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sqlcolumnidentifier_type */
extern T0* T44f234(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sqlcolumnidentifier_type */
extern T0* T43f216(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sqlcolumnidentifier_type */
extern T0* T42f215(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sqlcolumnidentifier_type */
extern T0* T41f215(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sqlcolumnrequired_type */
extern T0* T64f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlcolumnrequired_type */
extern T0* T64f232p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlcolumnrequired_type */
extern T0* T63f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlcolumnrequired_type */
extern T0* T63f231p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlcolumnrequired_type */
extern T0* T62f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlcolumnrequired_type */
extern T0* T62f231p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlcolumnrequired_type */
extern T0* T61f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlcolumnrequired_type */
extern T0* T61f231p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlcolumnrequired_type */
extern T0* T60f220(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlcolumnrequired_type */
extern T0* T60f220p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlcolumnrequired_type */
extern T0* T59f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlcolumnrequired_type */
extern T0* T59f243p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlcolumnrequired_type */
extern T0* T58f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlcolumnrequired_type */
extern T0* T58f243p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlcolumnrequired_type */
extern T0* T57f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlcolumnrequired_type */
extern T0* T57f244p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlcolumnrequired_type */
extern T0* T56f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlcolumnrequired_type */
extern T0* T56f244p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlcolumnrequired_type */
extern T0* T55f244(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlcolumnrequired_type */
extern T0* T55f244p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlcolumnrequired_type */
extern T0* T54f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlcolumnrequired_type */
extern T0* T54f237p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sqlcolumnrequired_type */
extern T0* T53f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sqlcolumnrequired_type */
extern T0* T52f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlcolumnrequired_type */
extern T0* T51f230(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlcolumnrequired_type */
extern T0* T51f230p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sqlcolumnrequired_type */
extern T0* T50f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sqlcolumnrequired_type */
extern T0* T49f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sqlcolumnrequired_type */
extern T0* T48f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumnrequired_type */
extern T0* T47f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumnrequired_type */
extern T0* T47f237p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlcolumnrequired_type */
extern T0* T46f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlcolumnrequired_type */
extern T0* T46f237p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sqlcolumnrequired_type */
extern T0* T45f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlcolumnrequired_type */
extern T0* T44f237(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlcolumnrequired_type */
extern T0* T44f237p1(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sqlcolumnrequired_type */
extern T0* T43f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sqlcolumnrequired_type */
extern T0* T42f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sqlcolumnrequired_type */
extern T0* T41f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlcolumndefault_type */
extern T0* T64f231(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sqlcolumndefault_type */
extern T0* T63f230(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sqlcolumndefault_type */
extern T0* T62f230(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sqlcolumndefault_type */
extern T0* T61f230(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sqlcolumndefault_type */
extern T0* T60f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sqlcolumndefault_type */
extern T0* T59f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sqlcolumndefault_type */
extern T0* T58f242(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sqlcolumndefault_type */
extern T0* T57f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sqlcolumndefault_type */
extern T0* T56f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sqlcolumndefault_type */
extern T0* T55f243(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sqlcolumndefault_type */
extern T0* T54f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sqlcolumndefault_type */
extern T0* T53f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sqlcolumndefault_type */
extern T0* T52f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sqlcolumndefault_type */
extern T0* T51f229(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sqlcolumndefault_type */
extern T0* T50f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sqlcolumndefault_type */
extern T0* T49f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sqlcolumndefault_type */
extern T0* T48f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumndefault_type */
extern T0* T47f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sqlcolumndefault_type */
extern T0* T46f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sqlcolumndefault_type */
extern T0* T45f216(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sqlcolumndefault_type */
extern T0* T44f236(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sqlcolumndefault_type */
extern T0* T43f218(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sqlcolumndefault_type */
extern T0* T42f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sqlcolumndefault_type */
extern T0* T41f217(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sql_subselect_for_extension */
extern T0* T64f234(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.sql_subselect_for_extension */
extern T0* T63f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.sql_subselect_for_extension */
extern T0* T62f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.sql_subselect_for_extension */
extern T0* T61f233(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.sql_subselect_for_extension */
extern T0* T60f222(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.sql_subselect_for_extension */
extern T0* T59f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.sql_subselect_for_extension */
extern T0* T58f245(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.sql_subselect_for_extension */
extern T0* T57f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.sql_subselect_for_extension */
extern T0* T56f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.sql_subselect_for_extension */
extern T0* T55f246(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.sql_subselect_for_extension */
extern T0* T54f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.sql_subselect_for_extension */
extern T0* T53f220(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.sql_subselect_for_extension */
extern T0* T52f220(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.sql_subselect_for_extension */
extern T0* T51f232(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.sql_subselect_for_extension */
extern T0* T50f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.sql_subselect_for_extension */
extern T0* T49f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.sql_subselect_for_extension */
extern T0* T48f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.sql_subselect_for_extension */
extern T0* T47f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.sql_subselect_for_extension */
extern T0* T46f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.sql_subselect_for_extension */
extern T0* T45f219(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.sql_subselect_for_extension */
extern T0* T44f239(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.sql_subselect_for_extension */
extern T0* T43f221(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.sql_subselect_for_extension */
extern T0* T42f220(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.sql_subselect_for_extension */
extern T0* T41f220(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlcolumnconstraint_type */
extern T0* T64f235(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.sqlcolumnconstraint_type */
extern T0* T63f234(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.sqlcolumnconstraint_type */
extern T0* T62f234(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.sqlcolumnconstraint_type */
extern T0* T61f234(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.sqlcolumnconstraint_type */
extern T0* T60f230(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.sqlcolumnconstraint_type */
extern T0* T59f253(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.sqlcolumnconstraint_type */
extern T0* T58f254(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.sqlcolumnconstraint_type */
extern T0* T57f255(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.sqlcolumnconstraint_type */
extern T0* T56f255(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.sqlcolumnconstraint_type */
extern T0* T55f255(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.sqlcolumnconstraint_type */
extern T0* T54f247(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.sqlcolumnconstraint_type */
extern T0* T53f221(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.sqlcolumnconstraint_type */
extern T0* T52f221(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.sqlcolumnconstraint_type */
extern T0* T51f240(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.sqlcolumnconstraint_type */
extern T0* T50f220(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.sqlcolumnconstraint_type */
extern T0* T49f220(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.sqlcolumnconstraint_type */
extern T0* T48f220(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumnconstraint_type */
extern T0* T47f247(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.sqlcolumnconstraint_type */
extern T0* T46f247(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.sqlcolumnconstraint_type */
extern T0* T45f220(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.sqlcolumnconstraint_type */
extern T0* T44f247(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.sqlcolumnconstraint_type */
extern T0* T43f222(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.sqlcolumnconstraint_type */
extern T0* T42f221(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.sqlcolumnconstraint_type */
extern T0* T41f221(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.sqlcolumnconstraint_base */
extern T0* T64f224(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL65.checkconstraintsupported */
extern T1 T64f236(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlcolumnconstraint_base */
extern T0* T63f223(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL70.checkconstraintsupported */
extern T1 T63f235(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlcolumnconstraint_base */
extern T0* T62f223(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2000.checkconstraintsupported */
extern T1 T62f235(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlcolumnconstraint_base */
extern T0* T61f223(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_TSQL2016.checkconstraintsupported */
extern T1 T61f235(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlcolumnconstraint_base */
extern T0* T60f212(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_SQLITE_3.checkconstraintsupported */
extern T1 T60f233(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.createdomaincheck */
extern T1 T60f232(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.domainchecksupported */
extern T1 T60f238(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlcolumnconstraint_base */
extern T0* T59f235(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_72.checkconstraintsupported */
extern T1 T59f256(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.createdomaincheck */
extern T1 T59f255(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.domainchecksupported */
extern T1 T59f261(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlcolumnconstraint_base */
extern T0* T58f235(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_73.checkconstraintsupported */
extern T1 T58f257(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.createdomaincheck */
extern T1 T58f256(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.domainchecksupported */
extern T1 T58f263(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlcolumnconstraint_base */
extern T0* T57f236(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_81.checkconstraintsupported */
extern T1 T57f258(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.createdomaincheck */
extern T1 T57f257(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.domainchecksupported */
extern T1 T57f264(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlcolumnconstraint_base */
extern T0* T56f236(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_82.checkconstraintsupported */
extern T1 T56f258(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.createdomaincheck */
extern T1 T56f257(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.domainchecksupported */
extern T1 T56f264(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlcolumnconstraint_base */
extern T0* T55f236(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_PGSQL_95.checkconstraintsupported */
extern T1 T55f258(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.createdomaincheck */
extern T1 T55f257(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.domainchecksupported */
extern T1 T55f264(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlcolumnconstraint_base */
extern T0* T54f229(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ORACLE.checkconstraintsupported */
extern T1 T54f250(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.createdomaincheck */
extern T1 T54f249(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.domainchecksupported */
extern T1 T54f259(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlcolumnconstraint_base */
extern T0* T53f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL322.checkconstraintsupported */
extern T1 T53f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.createdomaincheck */
extern T1 T53f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.domainchecksupported */
extern T1 T53f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlcolumnconstraint_base */
extern T0* T52f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL4.checkconstraintsupported */
extern T1 T52f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.createdomaincheck */
extern T1 T52f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.domainchecksupported */
extern T1 T52f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlcolumnconstraint_base */
extern T0* T51f222(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MYSQL5.checkconstraintsupported */
extern T1 T51f243(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.createdomaincheck */
extern T1 T51f242(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.domainchecksupported */
extern T1 T51f248(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlcolumnconstraint_base */
extern T0* T50f209(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSQL.checkconstraintsupported */
extern T1 T50f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.createdomaincheck */
extern T1 T50f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.domainchecksupported */
extern T1 T50f225(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlcolumnconstraint_base */
extern T0* T49f209(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS2000.checkconstraintsupported */
extern T1 T49f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.createdomaincheck */
extern T1 T49f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.domainchecksupported */
extern T1 T49f225(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlcolumnconstraint_base */
extern T0* T48f209(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_MSACCESS97.checkconstraintsupported */
extern T1 T48f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.createdomaincheck */
extern T1 T48f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.domainchecksupported */
extern T1 T48f225(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlcolumnconstraint_base */
extern T0* T47f229(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FIREBIRD_21.checkconstraintsupported */
extern T1 T47f250(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.createdomaincheck */
extern T1 T47f249(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.domainchecksupported */
extern T1 T47f254(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlcolumnconstraint_base */
extern T0* T46f229(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_INTERBASE6.checkconstraintsupported */
extern T1 T46f250(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.createdomaincheck */
extern T1 T46f249(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.domainchecksupported */
extern T1 T46f254(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlcolumnconstraint_base */
extern T0* T45f209(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_FOXPRO.checkconstraintsupported */
extern T1 T45f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.createdomaincheck */
extern T1 T45f221(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.domainchecksupported */
extern T1 T45f225(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlcolumnconstraint_base */
extern T0* T44f229(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_71.checkconstraintsupported */
extern T1 T44f250(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.createdomaincheck */
extern T1 T44f249(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.domainchecksupported */
extern T1 T44f255(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlcolumnconstraint_base */
extern T0* T43f211(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_DB2_6.checkconstraintsupported */
extern T1 T43f224(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.createdomaincheck */
extern T1 T43f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.domainchecksupported */
extern T1 T43f227(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlcolumnconstraint_base */
extern T0* T42f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_BASIC.checkconstraintsupported */
extern T1 T42f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.createdomaincheck */
extern T1 T42f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.domainchecksupported */
extern T1 T42f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlcolumnconstraint_base */
extern T0* T41f210(GE_context* ac, T0* C, T0* a1, T0* a2);
/* SQL_GENERATOR_ANSI.checkconstraintsupported */
extern T1 T41f223(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.createdomaincheck */
extern T1 T41f222(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.domainchecksupported */
extern T1 T41f226(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.create_table_name */
extern T0* T64f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.tablenameprefix */
extern T0* T64f154(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.create_table_name */
extern T0* T63f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.tablenameprefix */
extern T0* T63f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.create_table_name */
extern T0* T62f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.tablenameprefix */
extern T0* T62f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.create_table_name */
extern T0* T61f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.tablenameprefix */
extern T0* T61f153(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.create_table_name */
extern T0* T60f85(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.tablenameprefix */
extern T0* T60f140(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.create_table_name */
extern T0* T59f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.tablenameprefix */
extern T0* T59f174(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.create_table_name */
extern T0* T58f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.tablenameprefix */
extern T0* T58f174(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.create_table_name */
extern T0* T57f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.tablenameprefix */
extern T0* T57f174(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.create_table_name */
extern T0* T56f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.tablenameprefix */
extern T0* T56f174(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.create_table_name */
extern T0* T55f111(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.tablenameprefix */
extern T0* T55f174(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.create_table_name */
extern T0* T54f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.tablenameprefix */
extern T0* T54f166(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.create_table_name */
extern T0* T53f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.tablenameprefix */
extern T0* T53f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.create_table_name */
extern T0* T52f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.tablenameprefix */
extern T0* T52f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.create_table_name */
extern T0* T51f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.tablenameprefix */
extern T0* T51f158(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.create_table_name */
extern T0* T50f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.tablenameprefix */
extern T0* T50f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.create_table_name */
extern T0* T49f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.tablenameprefix */
extern T0* T49f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.create_table_name */
extern T0* T48f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.tablenameprefix */
extern T0* T48f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.create_table_name */
extern T0* T47f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.tablenameprefix */
extern T0* T47f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.create_table_name */
extern T0* T46f106(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.tablenameprefix */
extern T0* T46f165(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.create_table_name */
extern T0* T45f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.tablenameprefix */
extern T0* T45f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.create_table_name */
extern T0* T44f102(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.tablenameprefix */
extern T0* T44f164(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.create_table_name */
extern T0* T43f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.tablenameprefix */
extern T0* T43f139(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.create_table_name */
extern T0* T42f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.tablenameprefix */
extern T0* T42f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.create_table_name */
extern T0* T41f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.tablenameprefix */
extern T0* T41f138(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.sqlfalse */
extern T0* T64f157(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlfalse */
extern T0* T63f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlfalse */
extern T0* T62f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlfalse */
extern T0* T61f156(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlfalse */
extern T0* T60f143(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlfalse */
extern T0* T59f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlfalse */
extern T0* T58f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlfalse */
extern T0* T57f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlfalse */
extern T0* T56f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlfalse */
extern T0* T55f177(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlfalse */
extern T0* T53f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlfalse */
extern T0* T52f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlfalse */
extern T0* T51f161(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlfalse */
extern T0* T50f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlfalse */
extern T0* T49f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlfalse */
extern T0* T48f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlfalse */
extern T0* T45f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlfalse */
extern T0* T44f167(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlfalse */
extern T0* T43f142(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlfalse */
extern T0* T42f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlfalse */
extern T0* T41f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.table_has_auto_pk */
extern T1 T64f100(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.table_has_auto_pk */
extern T1 T63f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.table_has_auto_pk */
extern T1 T62f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.table_has_auto_pk */
extern T1 T61f99(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.table_has_auto_pk */
extern T1 T60f84(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.table_has_auto_pk */
extern T1 T59f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.table_has_auto_pk */
extern T1 T58f109(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.table_has_auto_pk */
extern T1 T57f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.table_has_auto_pk */
extern T1 T56f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.table_has_auto_pk */
extern T1 T55f110(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.table_has_auto_pk */
extern T1 T54f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.table_has_auto_pk */
extern T1 T53f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.table_has_auto_pk */
extern T1 T52f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.table_has_auto_pk */
extern T1 T51f98(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.table_has_auto_pk */
extern T1 T50f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.table_has_auto_pk */
extern T1 T49f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.table_has_auto_pk */
extern T1 T48f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.table_has_auto_pk */
extern T1 T47f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.table_has_auto_pk */
extern T1 T46f105(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.table_has_auto_pk */
extern T1 T45f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.table_has_auto_pk */
extern T1 T44f101(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.table_has_auto_pk */
extern T1 T43f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.table_has_auto_pk */
extern T1 T42f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.table_has_auto_pk */
extern T1 T41f83(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL65.sqlcoalesce */
extern T0* T64f136(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL70.sqlcoalesce */
extern T0* T63f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2000.sqlcoalesce */
extern T0* T62f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL2016.sqlcoalesce */
extern T0* T61f135(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.sqlcoalesce */
extern T0* T60f132(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.sqlcoalesce */
extern T0* T59f148(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.sqlcoalesce */
extern T0* T58f150(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.sqlcoalesce */
extern T0* T57f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.sqlcoalesce */
extern T0* T56f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.sqlcoalesce */
extern T0* T55f151(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.sqlcoalesce */
extern T0* T54f145(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.sqlcoalesce */
extern T0* T53f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.sqlcoalesce */
extern T0* T52f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.sqlcoalesce */
extern T0* T51f137(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.sqlcoalesce */
extern T0* T50f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.sqlcoalesce */
extern T0* T49f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.sqlcoalesce */
extern T0* T48f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_FIREBIRD_21.sqlcoalesce */
extern T0* T47f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_INTERBASE6.sqlcoalesce */
extern T0* T46f144(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.sqlcoalesce */
extern T0* T45f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.sqlcoalesce */
extern T0* T44f141(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.sqlcoalesce */
extern T0* T43f132(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.sqlcoalesce */
extern T0* T42f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.sqlcoalesce */
extern T0* T41f131(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.calculatedcolumnssupported */
extern T1 T64f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_SQLITE_3.calculatedcolumnssupported */
extern T1 T60f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_72.calculatedcolumnssupported */
extern T1 T59f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_73.calculatedcolumnssupported */
extern T1 T58f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_81.calculatedcolumnssupported */
extern T1 T57f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_82.calculatedcolumnssupported */
extern T1 T56f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_PGSQL_95.calculatedcolumnssupported */
extern T1 T55f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_ORACLE.calculatedcolumnssupported */
extern T1 T54f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL322.calculatedcolumnssupported */
extern T1 T53f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL4.calculatedcolumnssupported */
extern T1 T52f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_MYSQL5.calculatedcolumnssupported */
extern T1 T51f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSQL.calculatedcolumnssupported */
extern T1 T50f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS2000.calculatedcolumnssupported */
extern T1 T49f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_MSACCESS97.calculatedcolumnssupported */
extern T1 T48f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_FOXPRO.calculatedcolumnssupported */
extern T1 T45f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_71.calculatedcolumnssupported */
extern T1 T44f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_DB2_6.calculatedcolumnssupported */
extern T1 T43f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_BASIC.calculatedcolumnssupported */
extern T1 T42f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_ANSI.calculatedcolumnssupported */
extern T1 T41f27(GE_context* ac, T0* C);
/* SQL_GENERATOR_TSQL65.quote_identifier */
extern T0* T64f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL70.quote_identifier */
extern T0* T63f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2000.quote_identifier */
extern T0* T62f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_TSQL2016.quote_identifier */
extern T0* T61f49(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_SQLITE_3.quote_identifier */
extern T0* T60f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_72.quote_identifier */
extern T0* T59f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_73.quote_identifier */
extern T0* T58f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_81.quote_identifier */
extern T0* T57f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_82.quote_identifier */
extern T0* T56f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_PGSQL_95.quote_identifier */
extern T0* T55f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ORACLE.quote_identifier */
extern T0* T54f43(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL322.quote_identifier */
extern T0* T53f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL4.quote_identifier */
extern T0* T52f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MYSQL5.quote_identifier */
extern T0* T51f45(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSQL.quote_identifier */
extern T0* T50f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS2000.quote_identifier */
extern T0* T49f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_MSACCESS97.quote_identifier */
extern T0* T48f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FIREBIRD_21.quote_identifier */
extern T0* T47f45(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_INTERBASE6.quote_identifier */
extern T0* T46f45(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_FOXPRO.quote_identifier */
extern T0* T45f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_71.quote_identifier */
extern T0* T44f44(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_DB2_6.quote_identifier */
extern T0* T43f42(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_BASIC.quote_identifier */
extern T0* T42f41(GE_context* ac, T0* C, T0* a1);
/* SQL_GENERATOR_ANSI.quote_identifier */
extern T0* T41f41(GE_context* ac, T0* C, T0* a1);
/* DS_CELL [REAL_64].out */
extern T0* T413f2(GE_context* ac, T0* C);
/* DS_CELL [REAL_64].tagged_out */
extern T0* T413f3(GE_context* ac, T0* C);
/* DS_CELL [INTEGER_32].out */
extern T0* T356f2(GE_context* ac, T0* C);
/* DS_CELL [INTEGER_32].tagged_out */
extern T0* T356f3(GE_context* ac, T0* C);
/* STRING_8.out */
extern T0* T17f15(GE_context* ac, T0* C);
/* PLATFORM.is_windows */
extern T1 T371s1(GE_context* ac);
extern T0* GE_ma35(T6 c, T6 n, ...);
extern T0* GE_ma347(T6 c, T6 n, ...);
extern T0* GE_ma411(T6 c, T6 n, ...);
extern T0* GE_ma37(T6 c, T6 n, ...);
extern T0* GE_mt30(T6 a1, T6 a2, T6 a3, T0* a4, T0* a5, T0* a6, T0* a7, T0* a8, T0* a9, T6 a10, T1 a11);
extern T0* ge160ov5003;
extern T0* ge173ov5003;
extern T0* ge19ov4767;
extern T0* ge19ov4768;
extern T0* ge5ov4762;
extern T0* ge183ov4766;
extern T0* ge160ov5002;
extern T0* ge173ov5002;
extern T0* ge114ov5813;
extern T0* ge178ov5813;
extern T0* ge67ov5813;
extern T0* ge89ov5813;
extern T0* ge31ov5813;
extern T0* ge152ov5813;
extern T0* ge114ov5819;
extern T0* ge178ov5819;
extern T0* ge67ov5819;
extern T0* ge89ov5819;
extern T0* ge31ov5819;
extern T0* ge152ov5819;
extern T0* ge105ov7433;
extern T0* ge20ov7433;
extern T0* ge30ov7433;
extern T0* ge45ov7433;
extern T0* ge41ov7433;
extern T0* ge63ov7433;
extern T0* ge109ov7433;
extern T0* ge88ov2823;
extern T0* ge62ov7567;
extern T0* ge688ov2942;
extern T0* ge753ov3628;
extern T0* ge90ov5199;
extern T0* ge151ov7471;
extern T0* ge151ov7472;
extern T0* ge151ov7470;
extern T0* ge151ov7473;
extern T0* ge151ov7474;
extern T0* ge234ov7860;
extern T0* ge28ov3341;
extern T0* ge28ov3342;
extern T0* ge127ov8733;
extern T0* ge747ov5518;
extern T0* ge731ov3607;
extern T0* ge249ov9693;
extern T0* ge249ov9694;
extern T0* ge250ov7950;
extern T0* ge240ov7943;
extern T0* ge240ov7944;
extern T0* ge240ov7945;
extern T0* ge240ov7946;
extern T0* ge102ov7748;
extern T0* ge102ov7744;
extern T0* ge102ov7746;
extern T0* ge102ov7742;
extern T0* ge102ov7745;
extern T0* ge102ov7741;
extern T0* ge19ov4680;
extern T0* ge121ov5695;
extern T0* ge121ov5694;
extern T0* ge25ov7379;
extern T0* ge19ov4923;
extern T0* ge19ov4731;
extern T0* ge19ov4708;
extern T0* ge5ov4753;
extern T0* ge129ov6321;
extern T0* ge19ov4741;
extern T0* ge74ov4724;
extern T0* ge129ov6391;
extern T0* ge129ov6390;
extern T0* ge173ov4753;
extern T0* ge173ov4726;
extern T0* ge132ov4727;
extern T0* ge183ov6235;
extern T0* ge755ov5538;
extern T0* ge742ov5538;
extern T0* ge122ov6215;
extern T0* ge183ov6234;
extern T0* ge173ov6136;
extern T0* ge160ov5738;
extern T0* ge132ov5939;
extern T0* ge166ov4764;
extern T0* ge183ov4764;
extern T0* ge173ov4764;
extern T0* ge5ov4763;
extern T0* ge5ov4764;
extern T0* ge5ov4765;
extern T0* ge160ov4764;
extern T0* ge121ov4764;
extern T0* ge173ov5803;
extern T0* ge173ov6139;
extern T0* ge173ov6140;
extern T0* ge173ov6141;
extern T0* ge185ov8764;
extern T0* ge52ov8764;
extern T0* ge129ov4764;
extern T0* ge47ov4764;
extern T0* ge183ov4753;
extern T0* ge176ov4753;
extern T0* ge121ov4753;
extern T0* ge129ov6389;
extern T0* ge129ov6392;
extern T0* ge129ov6393;
extern T0* ge42ov5790;
extern T0* ge42ov5791;
extern T0* ge42ov5792;
extern T0* ge80ov6248;
extern T0* ge80ov6247;
extern T0* geic2;
extern T0* geic3;
extern T0* geic4;
extern T0* geic161;
extern T0* geic162;
extern T0* geic163;
extern T0* geic164;
extern T0* geic165;
extern T0* geic166;
extern T0* geic167;
extern T0* geic168;
extern T0* geic169;
extern T0* geic170;
extern T0* geic171;
extern T0* geic172;
extern T0* geic173;
extern T0* geic174;
extern T0* geic175;
extern T0* geic176;
extern T0* geic177;
extern T0* geic178;
extern T0* geic179;
extern T0* geic180;
extern T0* geic12;
extern T0* geic13;
extern T0* geic14;
extern T0* geic15;
extern T0* geic16;
extern T0* geic17;
extern T0* geic18;
extern T0* geic19;
extern T0* geic20;
extern T0* geic21;
extern T0* geic35;
extern T0* geic36;
extern T0* geic37;
extern T0* geic38;
extern T0* geic39;
extern T0* geic84;
extern T0* geic85;
extern T0* geic86;
extern T0* geic87;
extern T0* geic88;
extern T0* geic148;
extern T0* geic149;
extern T0* geic150;
extern T0* geic151;
extern T0* geic181;
extern T0* geic22;
extern T0* geic23;
extern T0* geic24;
extern T0* geic25;
extern T0* geic26;
extern T0* geic27;
extern T0* geic28;
extern T0* geic137;
extern T0* geic138;
extern T0* geic29;
extern T0* geic30;
extern T0* geic31;
extern T0* geic117;
extern T0* geic116;
extern T0* geic158;
extern T0* geic159;
extern T0* geic6;
extern T0* geic7;
extern T0* geic8;
extern T0* geic9;
extern T0* geic10;
extern T0* geic11;
extern T0* geic113;
extern T0* geic114;
extern T0* geic115;
extern T0* geic143;
extern T0* geic144;
extern T0* geic145;
extern T0* geic146;
extern T0* geic147;
extern T0* geic141;
extern T0* geic142;
extern T0* geic139;
extern T0* geic140;
extern T0* geic135;
extern T0* geic136;
extern T0* geic134;
extern T0* geic157;
extern T0* geic5;
extern T0* geic152;
extern T0* geic153;
extern T0* geic154;
extern T0* geic155;
extern T0* geic156;
extern T0* geic160;
extern T0* geic100;
extern T0* geic182;
extern T0* geic183;
extern T0* geic184;
extern T0* geic101;
extern T0* geic102;
extern T0* geic103;
extern T0* geic104;
extern T0* geic105;
extern T0* geic106;
extern T0* geic111;
extern T0* geic32;
extern T0* geic33;
extern T0* geic75;
extern T0* geic76;
extern T0* geic77;
extern T0* geic78;
extern T0* geic79;
extern T0* geic80;
extern T0* geic81;
extern T0* geic82;
extern T0* geic83;
extern T0* geic44;
extern T0* geic45;
extern T0* geic46;
extern T0* geic47;
extern T0* geic48;
extern T0* geic49;
extern T0* geic50;
extern T0* geic51;
extern T0* geic52;
extern T0* geic53;
extern T0* geic54;
extern T0* geic55;
extern T0* geic56;
extern T0* geic57;
extern T0* geic58;
extern T0* geic59;
extern T0* geic118;
extern T0* geic119;
extern T0* geic120;
extern T0* geic121;
extern T0* geic122;
extern T0* geic123;
extern T0* geic124;
extern T0* geic125;
extern T0* geic126;
extern T0* geic127;
extern T0* geic128;
extern T0* geic129;
extern T0* geic130;
extern T0* geic131;
extern T0* geic132;
extern T0* geic133;
extern T0* geic112;
extern T0* geic60;
extern T0* geic61;
extern T0* geic62;
extern T0* geic63;
extern T0* geic64;
extern T0* geic65;
extern T0* geic66;
extern T0* geic67;
extern T0* geic68;
extern T0* geic69;
extern T0* geic70;
extern T0* geic71;
extern T0* geic72;
extern T0* geic73;
extern T0* geic74;
extern T0* geic34;
extern T0* geic40;
extern T0* geic41;
extern T0* geic42;
extern T0* geic43;
extern T0* geic89;
extern T0* geic90;
extern T0* geic91;
extern T0* geic92;
extern T0* geic93;
extern T0* geic94;
extern T0* geic95;
extern T0* geic96;
extern void GE_init_const1(void);
extern void GE_init_const2(void);
extern void GE_init_const3(void);
extern void GE_init_const(void);

#ifdef __cplusplus
}
#endif


/*
	description:

		"Part of ISE Eiffel runtime. Needed to compile the EiffelCOM library."

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2010-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef EIF_CECIL_H
#define EIF_CECIL_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

typedef void (*EIF_PROCEDURE)(EIF_REFERENCE, ...);
#define EIF_PROC EIF_PROCEDURE
typedef EIF_INTEGER_32 (*EIF_INTEGER_32_FUNCTION)(EIF_REFERENCE, ...); /* Returns an Eiffel Integer 32 bits */
#define EIF_INTEGER_FUNCTION EIF_INTEGER_32_FUNCTION
typedef EIF_REFERENCE (*EIF_REFERENCE_FUNCTION)(EIF_REFERENCE, ...); /* Returns an Eiffel Reference */
typedef EIF_POINTER (*EIF_POINTER_FUNCTION)(EIF_REFERENCE, ...); /* Returns an Eiffel Pointer */
typedef EIF_BOOLEAN (*EIF_BOOLEAN_FUNCTION)(EIF_REFERENCE, ...); /* Returns an Eiffel Boolean */
typedef EIF_CHARACTER_8 (*EIF_CHARACTER_8_FUNCTION)(EIF_REFERENCE, ...); /* Returns char */
#define EIF_CHARACTER_FUNCTION EIF_CHARACTER_8_FUNCTION
typedef EIF_REAL_64 (*EIF_REAL_64_FUNCTION)(EIF_REFERENCE, ...); /* Returns an Eiffel Double */
#define EIF_DOUBLE_FUNCTION EIF_REAL_64_FUNCTION
typedef EIF_REAL_32 (*EIF_REAL_32_FUNCTION)(EIF_REFERENCE, ...); /* Returns an Eiffel Real */
#define EIF_REAL_FUNCTION EIF_REAL_32_FUNCTION

extern EIF_PROCEDURE eif_procedure(char* rout, EIF_TYPE_ID cid);
#define eif_proc eif_procedure /* Use `eif_procedure' instead */
extern EIF_INTEGER_FUNCTION eif_integer_function(char* rout, EIF_TYPE_ID cid);
extern EIF_REFERENCE_FUNCTION eif_reference_function(char* rout, EIF_TYPE_ID cid);
extern EIF_POINTER_FUNCTION eif_pointer_function(char* rout, EIF_TYPE_ID cid);
extern EIF_BOOLEAN_FUNCTION eif_boolean_function(char* rout, EIF_TYPE_ID cid);
extern EIF_REAL_64_FUNCTION eif_real_64_function(char* rout, EIF_TYPE_ID cid);
#define eif_double_function(rout,cid) eif_real_64_function((rout),(cid))
extern EIF_REAL_32_FUNCTION eif_real_32_function(char* rout, EIF_TYPE_ID cid);
#define eif_real_function(rout,cid) eif_real_32_function((rout),(cid))
extern EIF_CHARACTER_8_FUNCTION eif_character_8_function(char* rout, EIF_TYPE_ID cid);
#define eif_character_function(rout,cid) eif_character_8_function((rout),(cid))
extern EIF_OBJECT eif_create(EIF_TYPE_ID cid);
extern EIF_TYPE_ID eif_type_id(char* type_string);
extern EIF_INTEGER eifaddr_offset(EIF_REFERENCE object, char *name, int * const ret);
#define eif_string(s) RTMS(s)
#define makestr(s,c) RTMS_EX((s),(c))
#define eifaddr(object,name,ret) ((void *) ((char *) object + eifaddr_offset (object, name, ret)))
#define eif_field(object,name,type) *(type *)(eifaddr(object,name, NULL)) /* Obsolete. Use "eif_attribute" instead. */
#define eif_attribute(object,name,type,ret) *(type *)(eifaddr(object,name,ret)) /* Returns the attribute of an object. Return status in "ret".*/

/* Miscellaneous useful functions. */

/* Make an Eiffel array from a C array:
 * `eif_array' is the direct reference to the Eiffel array.
 * `c_array' is the C array.
 * `nelts' the number of elements to copy in the eiffel array, it has to
 * be equal to `eif_array.count'.
 * type is an Eiffel type.
 */
#define eif_make_from_c(eif_array, c_array, nelts, type) \
	{ \
		EIF_REFERENCE area = eif_field (eif_array, \
										"area", EIF_REFERENCE); \
		memcpy ((type *) area, c_array, nelts * sizeof (type));\
	}

#define eif_type eiftype /* Dynamic type ID */
extern EIF_TYPE_ID eiftype(EIF_OBJECT object); /* Give dynamic type of EIF_OBJECT. Obsolete, use "eif_type_by_object". */
extern EIF_TYPE_ID eif_type_by_reference (EIF_REFERENCE object);
extern EIF_TYPE_INDEX eif_gen_param_id(EIF_TYPE_INDEX dftype, uint32_t pos);

#ifdef __cplusplus
}
#endif

#endif
/*
	description:

		"Part of ISE Eiffel runtime. Needed to compile the EiffelCOM library."

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2010-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef EIF_PLUG_H
#define EIF_PLUG_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifdef __cplusplus
extern "C" {
#endif

extern int nstcall;	/* Nested call global variable: signals a nested call and
					 * trigger an invariant check in generated C routines  */

#ifdef __cplusplus
}
#endif

#endif
/*
	description:

		"C functions used to implement class FILE"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2006-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef EIF_FILE_H
#define EIF_FILE_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#include <time.h>
#include <sys/stat.h>

#ifdef __cplusplus
extern "C" {
#endif

/* Let's define the stat structure for our platforms. */
/* The definition is the same for both ANSI and Unicode versions on Windows. */
#ifdef EIF_WINDOWS
#	ifdef EIF_64_BITS
#		define rt_stat_buf	struct _stat64
#	else
#		define rt_stat_buf	struct _stat64i32
#	endif
#else
#	define rt_stat_buf		struct stat
#endif

/*
 * Create directory `dirname'.
 */
extern void eif_file_mkdir(EIF_FILENAME dirname);

/*
 * Rename file `from' into `to'.
 */
extern void eif_file_rename(EIF_FILENAME from, EIF_FILENAME  to);

/*
 * Link file `from' into `to'.
 */
extern void eif_file_link(EIF_FILENAME from, EIF_FILENAME to);

/*
 * Delete file or directory `name'.
 */
extern void eif_file_unlink(EIF_FILENAME name);

/*
 * Open file `name' with the corresponding type `how'.
 */
extern EIF_POINTER eif_file_open(EIF_FILENAME name, int how);

/*
 * Open file `fd' with the corresponding type `how'.
 */
extern EIF_POINTER eif_file_dopen(int fd, int how);

/*
 * Reopen file `name' with the corresponding type `how' and substitute that
 * to the old stream described by `old'. This is useful to redirect 'stdout'
 * to another place, for instance.
 */
extern EIF_POINTER eif_file_reopen(EIF_FILENAME name, int how, FILE *old);

/*
 * Close the file.
 */
extern void eif_file_close(FILE *fp);

/*
 * Flush data held in stdio buffer.
 */
extern void eif_file_flush(FILE *fp);

/*
 * Return the associated file descriptor.
 */
extern EIF_INTEGER eif_file_fd(FILE *f);

/*
 * Get a character from `f'.
 */
extern EIF_CHARACTER_8 eif_file_gc(FILE *f);

/*
 * Get a string from `f' and fill it into `s' (at most `bound' characters),
 * with `start' being the amount of bytes already stored within s. This
 * means we really have to read (bound - start) characters.
 */
extern EIF_INTEGER eif_file_gs(FILE *f, char *s, EIF_INTEGER bound, EIF_INTEGER start);

/*
 * Read min (bound, remaining bytes in file) characters into `s' and
 * return the number of characters read.
 */
extern EIF_INTEGER eif_file_gss(FILE *f, char *s, EIF_INTEGER bound);

/*
 * Get a word from `f' and fill it into `s' (at most `bound' characters),
 * with `start' being the amount of bytes already stored within s. This
 * means we really have to read (bound - start) characters. Any leading
 * spaces are skipped.
 */
extern EIF_INTEGER eif_file_gw(FILE *f, char *s, EIF_INTEGER bound, EIF_INTEGER start);

/*
 * Look ahead one character. If EOF, return 0.
 */
extern EIF_CHARACTER_8 eif_file_lh(FILE *f);

/*
 * Size of file `fp'.
 */
extern EIF_INTEGER eif_file_size(FILE *fp);

/*
 * Read upto next input line.
 */
extern void eif_file_tnil(FILE *f);

/*
 * Current position within file.
 */
extern EIF_INTEGER eif_file_tell(FILE *f);

/*
 * Touch file `name' by setting both access and modification time to the
 * current time stamp. This external function exists only because there
 * is no way within UNIX_FILE to get the current time stamp. Otherwise,
 * we could simply call file_utime.
 */
extern void eif_file_touch(EIF_FILENAME name);

/*
 * Modify the modification and/or the access time stored in the file's
 * inode. The 'how' parameter tells which attributes should be set.
 */
extern void eif_file_utime(EIF_FILENAME name, time_t stamp, int how);

/*
 * This is an encapsulation of the stat() system call. The routine either
 * succeeds and returns or fails and raises the appropriate exception.
 */
extern int eif_file_stat(EIF_FILENAME path, rt_stat_buf *buf, int follow);

/*
 * Change permissions of file `name', using an interface like chmod(1).
 * The flag is true if permissions are to be added, 0 to remove them.
 */
extern void eif_file_perm(EIF_FILENAME name, char *who, char *what, int flag);

/*
 * Change permission mode on file `path'.
 */
extern void eif_file_chmod(EIF_FILENAME path, int mode);

/*
 * Change the owner of the file to `uid'.
 */
extern void eif_file_chown(EIF_FILENAME name, int uid);

/*
 * Change the group of the file to `gid'.
 */
extern void eif_file_chgrp(EIF_FILENAME name, int gid);

/*
 * Put new_line onto `f'.
 */
extern void eif_file_tnwl(FILE *f);

/*
 * Append a copy of `other' to `f'.
 */
extern void eif_file_append(FILE *f, FILE *other, EIF_INTEGER l);

/*
 * Write string `str' on `f'.
 */
extern void eif_file_ps(FILE *f, char *str, EIF_INTEGER len);

/*
 * Write character `c' on `f'.
 */
extern void eif_file_pc(FILE *f, char c);

/*
 * Go to absolute position `pos' counted from start.
 */
extern void eif_file_go(FILE *f, EIF_INTEGER pos);

/*
 * Go to absolute position `pos' counted from end.
 */
extern void eif_file_recede(FILE *f, EIF_INTEGER pos);

/*
 * Go to absolute position `pos' counted from current position.
 */
extern void eif_file_move(FILE *f, EIF_INTEGER pos);

/*
 * End of file.
 */
extern EIF_BOOLEAN eif_file_feof(FILE *fp);

/*
 * Test whether file exists or not. If `name' represents a symbolic link,
 * it will check that pointed file does exist.
 */
extern EIF_BOOLEAN eif_file_exists(EIF_FILENAME name);

/*
 * Test whether file exists or not without following the symbolic link
 * if `name' represents one.
 */
extern EIF_BOOLEAN eif_file_path_exists(EIF_FILENAME name);

/*
 * Check whether access permission `op' are possible on file `name' using
 * real UID and real GID. This is probably only useful to setuid or setgid
 * programs.
 */
extern EIF_BOOLEAN eif_file_access(EIF_FILENAME name, EIF_INTEGER op);

/*
 * Check whether the file `path' may be created: we need write permissions
 * in the parent directory and there must not be any file bearing that name
 * with no write permissions...
 */
extern EIF_BOOLEAN eif_file_creatable(EIF_FILENAME path, EIF_INTEGER nbytes);

/*
 * Get an integer from `f'.
 */
extern EIF_INTEGER eif_file_gi(FILE *f);

/*
 * Get a real from `f'.
 */
extern EIF_REAL_32 eif_file_gr(FILE *f);

/*
 * Get a double from `f'.
 */
extern EIF_REAL_64 eif_file_gd(FILE *f);

/*
 * Write `number' on `f'.
 */
extern void eif_file_pi(FILE *f, EIF_INTEGER number);

/*
 * Write `number' on `f'.
 */
extern void eif_file_pr(FILE *f, EIF_REAL_32 number);

/*
 * Write double `val' onto `f'.
 */
extern void eif_file_pd(FILE *f, EIF_REAL_64 val);

/*
 * Size of the stat structure. This is used by the Eiffel side to create
 * the area (special object) which will play the role of a stat buffer
 * structure.
 */
extern EIF_INTEGER stat_size(void);

/*
 * Check file permissions using effective UID and effective GID. The
 * current permission mode is held in the st_mode field of the stat()
 * buffer structure `buf'.
 */
extern EIF_BOOLEAN eif_file_eaccess(rt_stat_buf *buf, int op);

/*
 * Perform the field dereferencing from the appropriate stat structure,
 * which Eiffel cannot do directly.
 */
extern EIF_INTEGER eif_file_info(rt_stat_buf *buf, int op);

/*
 * Return the Eiffel string filled in with the name associated with `uid'
 * if found in /etc/passwd. Otherwise, return fill it in with the numeric
 * value.
 */
extern EIF_REFERENCE eif_file_owner(int uid);

/*
 * Return the Eiffel string filled in with the name associated with `gid'
 * if found in /etc/group. Otherwise, return fill it in with the numeric
 * value.
 */
extern EIF_REFERENCE eif_file_group(int gid);

/*
 * Get an integer from `f'.
 */
extern EIF_INTEGER eif_file_gib(FILE* f);

/*
 * Get a real from `f'.
 */
extern EIF_REAL_32 eif_file_grb(FILE* f);

/*
 * Get a double from `f'.
 */
extern EIF_REAL_64 eif_file_gdb(FILE* f);

/*
 * Open file `name' with the corresponding type `how'.
 */
extern EIF_POINTER eif_file_binary_open(EIF_FILENAME name, int how);

/*
 * Open file `fd' with the corresponding type `how'.
 */
extern EIF_POINTER eif_file_binary_dopen(int fd, int how);

/*
 * Reopen file `name' with the corresponding type `how' and substitute that
 * to the old stream described by `old'. This is useful to redirect 'stdout'
 * to another place, for instance.
 */
extern EIF_POINTER eif_file_binary_reopen(EIF_FILENAME name, int how, FILE* old);

/*
 * Write `number' on `f'.
 */
extern void eif_file_pib(FILE* f, EIF_INTEGER number);

/*
 * Write `number' on `f'.
 */
extern void eif_file_prb(FILE* f, EIF_REAL_32 number);

/*
 * Write double `val' onto `f'.
 */
extern void eif_file_pdb(FILE* f, EIF_REAL_64 val);

/*
 * Modification time of a file.
 * Seconds since epoch (01 January 1970) in UTC or 0 if time cannot be retrieved.
 */
extern EIF_INTEGER eif_file_date(EIF_FILENAME  name);

/*
 * Access time of a file.
 * Seconds since epoch (01 January 1970) in UTC or 0 if time cannot be retrieved.
 */
extern EIF_INTEGER eif_file_access_date(EIF_FILENAME  name);

#ifdef __cplusplus
}
#endif

#endif
/*
	description:

		"C functions used to implement class EXCEPTIONS"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2006-2016, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef EIF_EXCEPT_H
#define EIF_EXCEPT_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif
#ifndef GE_EXCEPTION_H
#include "ge_exception.h"
#endif

#include <errno.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Predefined exception codes.
 */
#define EN_VOID		GE_EX_VOID			/* Feature applied to void reference */
#define EN_MEM		GE_EX_MEM			/* No more memory */
#define EN_PRE		GE_EX_PRE			/* Pre-condition violated */
#define EN_POST		GE_EX_POST			/* Post-condition violated */
#define EN_FLOAT	GE_EX_FLOAT			/* Floating point exception (signal SIGFPE) */
#define EN_CINV		GE_EX_CINV			/* Class invariant violated */
#define EN_CHECK	GE_EX_CHECK			/* Assertion violated */
#define EN_FAIL		GE_EX_FAIL			/* Routine failure */
#define EN_WHEN		GE_EX_WHEN			/* Unmatched inspect value */
#define EN_VAR		GE_EX_VAR			/* Non-decreasing loop variant */
#define EN_LINV		GE_EX_LINV			/* Loop invariant violated */
#define EN_SIG		GE_EX_SIG			/* Operating system signal */
#define EN_BYE		GE_EX_BYE			/* Eiffel run-time panic */
#define EN_RESC		GE_EX_RESC			/* Exception in rescue clause */
#define EN_OMEM		GE_EX_OMEM			/* Out of memory (cannot be ignored) */
#define EN_RES		GE_EX_RES			/* Resumption failed (retry did not succeed) */
#define EN_CDEF		GE_EX_CDEF			/* Create on deferred */
#define EN_EXT		GE_EX_EXT			/* External event */
#define EN_VEXP		GE_EX_VEXP			/* Void assigned to expanded */
#define EN_HDLR		GE_EX_HDLR			/* Exception in signal handler */
#define EN_IO		GE_EX_IO			/* I/O error */
#define EN_SYS		GE_EX_SYS			/* Operating system error */
#define EN_RETR		GE_EX_RETR			/* Retrieval error */
#define EN_PROG		GE_EX_PROG			/* Developer exception */
#define EN_FATAL	GE_EX_FATAL			/* Eiffel run-time fatal error */
#define EN_DOL		GE_EX_DOL			/* $ applied to melted feature */
#define EN_ISE_IO	GE_EX_ISE_IO		/* I/O error raised by the ISE Eiffel runtime */
#define EN_COM		GE_EX_COM			/* COM error raised by EiffelCOM runtime */
#define EN_RT_CHECK	GE_EX_RT_CHECK		/* Runtime check error such as out-of-bound array access */
#define EN_OLD		GE_EX_OLD			/* Old violation */
#define EN_SEL		GE_EX_SEL			/* Serialization failure */
#define EN_DIRTY	GE_EX_DIRTY			/* SCOOP processor dirty exception. */
#define EN_NEX		GE_EX_NEX			/* Number of internal exceptions */

/*
 * Raise an Eiffel exception.
 */
extern void eraise(const char* name, long code);

/*
 * Raise an Eiffel exception of the given code with no associated tag.
 */
extern void xraise(int code);

/*
 * Raise an "Operating system error" exception.
 */
extern void esys(void);

/*
 * As a special case, an I/O error is raised when a system call which is I/O bound fails.
 */
extern void eise_io(const char* tag);

/*
 * Raise a "No more memory" exception.
 */
extern void enomem(void);

/*
 * Raise EiffelCOM exception.
 */
extern void com_eraise(const char* tag, long num);

/*
 * Terminate execution with exit status `code',
 * without triggering an exception.
 */
extern void esdie(int code);

/*
 * Exception tag associated with `code'.
 * This is a duplication from Eiffel classes, but still used for trace printing and in EiffelCom.
 */
extern EIF_REFERENCE eename(long except);

/*
 * Is exception `ex' defined?
 * Used in EiffelCOM.
 */
extern char eedefined(long ex);

/*
 * Enable/diable printing of the exception trace.
 * Per thead information.
 */
extern void eetrace(char b);

/*
 * Is current execution during rescue?
 */
extern EIF_BOOLEAN eif_is_in_rescue(void);

#ifdef EIF_WINDOWS
/*
 * Set default exception handler.
 */
extern void set_windows_exception_filter();
#endif

/*
 * Used in EiffelCOM.
 */
#define echval GE_current_context()->exception_code
#define echtg GE_current_context()->exception_tag

#ifdef __cplusplus
}
#endif

#endif
/*
	description:

		"C functions used to implement class REAL"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2006-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_REAL_H
#define GE_REAL_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#include <math.h>

#ifndef GE_power
#define GE_power(x,y) pow((x),(y))
#endif
#define GE_ceiling(x) ceil(x)
#define GE_floor(x) floor(x)

extern EIF_NATURAL_32 GE_real_32_to_bits (EIF_REAL_32 v);
extern EIF_NATURAL_64 GE_real_64_to_bits (EIF_REAL_64 v);
extern EIF_REAL_32 GE_real_32_from_bits (EIF_NATURAL_32 v);
extern EIF_REAL_64 GE_real_64_from_bits (EIF_NATURAL_64 v);

#define GE_real_32_is_nan(v) ((v)!=(v) ? EIF_TRUE : ((GE_real_32_to_bits(v) & ~GE_nat32(0x80000000)) > GE_nat32(0x7FF00000)))
#define GE_real_64_is_nan(v) ((v)!=(v) ? EIF_TRUE : ((GE_real_64_to_bits(v) & ~GE_nat64(0x8000000000000000)) > GE_nat64(0x7FF0000000000000)))
#define GE_real_32_is_negative_infinity(v) (GE_real_32_to_bits(v) == GE_nat32(0xFF800000))
#define GE_real_64_is_negative_infinity(v) (GE_real_64_to_bits(v) == GE_nat64(0xFFF0000000000000))
#define GE_real_32_is_positive_infinity(v) (GE_real_32_to_bits(v) == GE_nat32(0x7F800000))
#define GE_real_64_is_positive_infinity(v) (GE_real_64_to_bits(v) == GE_nat64(0x7FF0000000000000))
#define GE_real_32_nan GE_real_32_from_bits(GE_nat32(0x7FC00000))
#define GE_real_64_nan GE_real_64_from_bits(GE_nat64(0x7FF8000000000000))
#define GE_real_32_negative_infinity GE_real_32_from_bits(GE_nat32(0xFF800000))
#define GE_real_64_negative_infinity GE_real_64_from_bits(GE_nat64(0xFFF0000000000000))
#define GE_real_32_positive_infinity GE_real_32_from_bits(GE_nat32(0x7F800000))
#define GE_real_64_positive_infinity GE_real_64_from_bits(GE_nat64(0x7FF0000000000000))

#endif
/*
	description:

		"C functions used to implement Thread support"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2007-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef EIF_THREADS_H
#define EIF_THREADS_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef EIF_CECIL_H
#include "eif_cecil.h"
#endif
#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif
#ifdef GE_USE_THREADS
#ifndef GE_THREAD_H
#include "ge_thread.h"
#endif
#endif

#ifdef __cplusplus
extern "C" {
#endif

#ifndef GE_USE_THREADS

/*
 * Empty stubs for EiffelThread library so that it may be compiled against a non-multithreaded run-time.
 */

/* THREAD_ENVIRONMENT */
#define eif_thr_thread_id() NULL

/* THREAD_CONTROL */
#define eif_thr_yield()
#define eif_thr_join_all()

/* THREAD */
#define eif_thr_create_with_attr(current_obj, init_func, set_terminated_func, attr)
#define eif_thr_wait(obj,get_terminated)
#define eif_thr_wait_with_timeout(obj,get_terminated,tms) EIF_TRUE
#define eif_thr_last_thread() NULL
#define eif_thr_exit()

/* THREAD_ATTRIBUTES */
#define eif_thr_default_priority() 0
#define eif_thr_min_priority() 0
#define eif_thr_max_priority() 0

/* MUTEX */
#define eif_thr_mutex_create() NULL
#define eif_thr_mutex_lock(a_mutex_pointer)
#define eif_thr_mutex_trylock(a_mutex_pointer) EIF_TRUE
#define eif_thr_mutex_unlock(a_mutex_pointer)
#define eif_thr_mutex_destroy(a_mutex_pointer)

/* CONDITION_VARIABLE */
#define eif_thr_cond_create() NULL
#define eif_thr_cond_broadcast(a_cond_ptr)
#define eif_thr_cond_signal(a_cond_ptr)
#define eif_thr_cond_wait(a_cond_ptr,a_mutex_ptr)
#define eif_thr_cond_wait_with_timeout(a_cond_ptr,a_mutex_ptr,a_timeout) 1
#define eif_thr_cond_destroy(a_cond_ptr)

/* SEMAPHORE */
#define eif_thr_sem_create(a_count) NULL
#define eif_thr_sem_wait(a_sem_pointer)
#define eif_thr_sem_post(a_sem_pointer)
#define eif_thr_sem_trywait(a_sem_pointer) EIF_TRUE
#define eif_thr_sem_destroy(a_sem_pointer)

/* READ_WRITE_LOCK */
#define eif_thr_rwl_create() NULL
#define eif_thr_rwl_rdlock(a_read_write_lock_pointer)
#define eif_thr_rwl_unlock(a_read_write_lock_pointer)
#define eif_thr_rwl_wrlock(a_read_write_lock_pointer)
#define eif_thr_rwl_destroy(a_read_write_lock_pointer)

#else

/* THREAD_ENVIRONMENT */
#define eif_thr_thread_id() GE_thread_id()

/* THREAD_CONTROL */
#define eif_thr_yield() GE_thread_yield()
#define eif_thr_join_all() GE_thread_join_all()

/* THREAD */
#define eif_thr_create_with_attr(current_obj,init_func,set_terminated_func,attr) GE_thread_create_with_attr((current_obj),(void (*)(EIF_REFERENCE))(init_func),(void (*)(EIF_REFERENCE,EIF_BOOLEAN))(set_terminated_func),(EIF_THR_ATTR_TYPE*)(attr))
#define eif_thr_wait(obj,get_terminated) GE_thread_wait((obj),(EIF_BOOLEAN (*)(EIF_REFERENCE))(get_terminated))
#define eif_thr_wait_with_timeout(obj,get_terminated,tms) GE_thread_wait_with_timeout((obj),(EIF_BOOLEAN (*)(EIF_REFERENCE))(get_terminated),(tms))
#define eif_thr_last_thread() GE_last_thread_created()
#define eif_thr_exit() GE_thread_exit()

/* THREAD_ATTRIBUTES */
#define eif_thr_default_priority() GE_thread_default_priority()
#define eif_thr_min_priority() GE_thread_min_priority()
#define eif_thr_max_priority() GE_thread_max_priority()

/* MUTEX */
#define eif_thr_mutex_create() GE_mutex_create()
#define eif_thr_mutex_lock(a_mutex_pointer) GE_mutex_lock(a_mutex_pointer)
#define eif_thr_mutex_trylock(a_mutex_pointer) GE_mutex_try_lock(a_mutex_pointer)
#define eif_thr_mutex_unlock(a_mutex_pointer) GE_mutex_unlock(a_mutex_pointer)
#define eif_thr_mutex_destroy(a_mutex_pointer) GE_mutex_destroy(a_mutex_pointer)

/* CONDITION_VARIABLE */
#define eif_thr_cond_create() GE_condition_variable_create()
#define eif_thr_cond_broadcast(a_cond_ptr) GE_condition_variable_broadcast(a_cond_ptr)
#define eif_thr_cond_signal(a_cond_ptr) GE_condition_variable_signal(a_cond_ptr)
#define eif_thr_cond_wait(a_cond_ptr,a_mutex_ptr) GE_condition_variable_wait((a_cond_ptr),(a_mutex_ptr))
#define eif_thr_cond_wait_with_timeout(a_cond_ptr,a_mutex_ptr,a_timeout) GE_condition_variable_wait_with_timeout((a_cond_ptr),(a_mutex_ptr),(a_timeout))
#define eif_thr_cond_destroy(a_cond_ptr) GE_condition_variable_destroy(a_cond_ptr)

/* SEMAPHORE */
#define eif_thr_sem_create(a_count) GE_semaphore_create(a_count)
#define eif_thr_sem_wait(a_sem_pointer) GE_semaphore_wait(a_sem_pointer)
#define eif_thr_sem_post(a_sem_pointer) GE_semaphore_post(a_sem_pointer)
#define eif_thr_sem_trywait(a_sem_pointer) GE_semaphore_try_wait(a_sem_pointer)
#define eif_thr_sem_destroy(a_sem_pointer) GE_semaphore_destroy(a_sem_pointer)

/* READ_WRITE_LOCK */
#define eif_thr_rwl_create() GE_read_write_lock_create()
#define eif_thr_rwl_rdlock(a_read_write_lock_pointer) GE_read_write_lock_read_lock(a_read_write_lock_pointer)
#define eif_thr_rwl_unlock(a_read_write_lock_pointer) GE_read_write_lock_unlock(a_read_write_lock_pointer)
#define eif_thr_rwl_wrlock(a_read_write_lock_pointer) GE_read_write_lock_write_lock(a_read_write_lock_pointer)
#define eif_thr_rwl_destroy(a_read_write_lock_pointer) GE_read_write_lock_destroy(a_read_write_lock_pointer)

/* WEL */
#ifdef EIF_WINDOWS
#define eif_thr_create_wel_per_thread_data(a_size) GE_thread_create_wel_per_thread_data(a_size)
#endif

#endif

#ifdef __cplusplus
}
#endif

#endif
/*
	description:

		"Part of ISE Eiffel runtime. Needed to compile the EiffelCOM library."

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2010-2016, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef EIF_GLOBALS_H
#define EIF_GLOBALS_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EXCEPTION_H
#include "ge_exception.h"
#endif
#ifndef EIF_THREADS_H
#include "eif_threads.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

#ifdef GE_USE_THREADS
#define EIF_GET_CONTEXT \
	GE_context* eif_globals = GE_current_context();
#else
#define EIF_GET_CONTEXT
#endif

#define GTCX EIF_GET_CONTEXT

#ifdef __cplusplus
}
#endif

#endif
/*
	description:

		"C declarations for the ISE Eiffel runtime."

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2006-2016, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef EIF_EIFFEL_H
#define EIF_EIFFEL_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif
#ifndef GE_STRING_H
#include "ge_string.h"
#endif
#ifndef EIF_GLOBALS_H
#include "eif_globals.h"
#endif
#ifndef EIF_EXCEPT_H
#include "eif_except.h"
#endif

#endif
/*
	description:

		"C functions used to implement class CONSOLE"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2006-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef EIF_CONSOLE_H
#define EIF_CONSOLE_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_POINTER console_def(EIF_INTEGER file);
extern EIF_BOOLEAN console_eof(FILE* fp);
extern EIF_CHARACTER_8 console_separator(FILE* f);
extern void console_ps(FILE* f, char* str, EIF_INTEGER len);
extern void console_pr(FILE* f, EIF_REAL_32 number);
extern void console_pc(FILE* f, EIF_CHARACTER_8 c);
extern void console_pd(FILE* f, EIF_REAL_64 val);
extern void console_pi(FILE* f, EIF_INTEGER number);
extern void console_tnwl(FILE* f);
extern EIF_CHARACTER_8 console_readchar(FILE* f);
extern EIF_REAL_32 console_readreal(FILE* f);
extern EIF_INTEGER console_readint(FILE* f);
extern EIF_REAL_64 console_readdouble(FILE* f);
extern EIF_INTEGER console_readword(FILE* f, char* s, EIF_INTEGER bound, EIF_INTEGER start);
extern EIF_INTEGER console_readline(FILE* f, char* s, EIF_INTEGER bound, EIF_INTEGER start);
extern void console_next_line(FILE* f);
extern EIF_INTEGER console_readstream(FILE* f, char* s, EIF_INTEGER bound);
extern void console_file_close (FILE* f);

#ifdef __cplusplus
}
#endif

#endif
/*
	description:

		"C functions used to implement class COM_FAILURE"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2016, Eric Bezault and others"
	license: "MIT License"
	date: "$Date$"
	revision: "$Revision$"
*/

#ifndef GE_COM_FAILURE_H
#define GE_COM_FAILURE_H
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef GE_EIFFEL_H
#include "ge_eiffel.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_INTEGER GE_ccom_hresult(EIF_POINTER an_exception_code);

extern EIF_INTEGER GE_ccom_hresult_code(EIF_INTEGER an_hresult);

extern EIF_INTEGER GE_ccom_hresult_facility(EIF_INTEGER an_hresult);

/*
 * Get text from error `a_code'. It is up to the caller to free
 * the returned buffer using `GE_ccom_local_free'.
 */
extern EIF_POINTER GE_ccom_error_text(EIF_INTEGER a_code);

/*
 * Number of characters in `ptr'.
 */
extern EIF_INTEGER_32 GE_ccom_strlen(EIF_POINTER ptr);

/*
 * Number of bytes occupied by a TCHAR.
 */
extern EIF_INTEGER_32 GE_ccom_character_size();

/*
 * Free `a_ptr' using LocalFree.
 */
extern void GE_ccom_local_free(EIF_POINTER a_ptr);

#ifdef __cplusplus
}
#endif

#endif
#include <string.h>
#include <stdlib.h>
#include <math.h>
